@@ -3,7 +3,7 @@
  *  @file  ApproximationAlgorithmImplementation.cxx
  *  @brief Regression from a data sample upon a particular basis
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,18 +27,17 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(ApproximationAlgorithmImplementation);
 
+static Factory<ApproximationAlgorithmImplementation> RegisteredFactory("ApproximationAlgorithmImplementation");
 
 /* Default constructor */
 ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation()
-  : PersistentObject(),
-    isAlreadyComputedCoefficients_(false),
-    residual_(0.0),
-    relativeError_(0.0),
-    verbose_(false)
+  : PersistentObject()
+  , isAlreadyComputedCoefficients_(false)
+  , residual_(0.0)
+  , relativeError_(0.0)
+  , verbose_(false)
 {
   // Nothing to do
 }
@@ -47,15 +46,15 @@ ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation()
 ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation(const NumericalSample & x,
     const NumericalSample & y,
     const Basis & psi)
-  : PersistentObject(),
-    x_(x),
-    y_(y),
-    weight_(NumericalPoint( x.getSize(), 1.0 )),
-    psi_(psi),
-    isAlreadyComputedCoefficients_(false),
-    residual_(0.0),
-    relativeError_(0.0),
-    verbose_(false)
+  : PersistentObject()
+  , x_(x)
+  , y_(y)
+  , weight_(NumericalPoint( x.getSize(), 1.0 ))
+  , psi_(psi)
+  , isAlreadyComputedCoefficients_(false)
+  , residual_(0.0)
+  , relativeError_(0.0)
+  , verbose_(false)
 {
   const UnsignedLong dataSize(x.getSize());
   if (dataSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on an empty sample.";
@@ -71,15 +70,15 @@ ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation(const
     const NumericalSample & y,
     const NumericalPoint & weight,
     const Basis & psi)
-  : PersistentObject(),
-    x_(x),
-    y_(y),
-    weight_(weight),
-    psi_(psi),
-    isAlreadyComputedCoefficients_(false),
-    residual_(0.0),
-    relativeError_(0.0),
-    verbose_(false)
+  : PersistentObject()
+  , x_(x)
+  , y_(y)
+  , weight_(weight)
+  , psi_(psi)
+  , isAlreadyComputedCoefficients_(false)
+  , residual_(0.0)
+  , relativeError_(0.0)
+  , verbose_(false)
 {
   UnsignedLong dataSize( x.getSize() );
   if (dataSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot perform approximation based on an empty sample.";
@@ -93,6 +92,12 @@ ApproximationAlgorithmImplementation::ApproximationAlgorithmImplementation(const
     if ( weight[i] < 0.0 ) throw InvalidArgumentException(HERE) << "Error: can only use positive weight.";
 }
 
+/* Virtual constructor */
+ApproximationAlgorithmImplementation * ApproximationAlgorithmImplementation::clone() const
+{
+  return new ApproximationAlgorithmImplementation(*this);
+}
+
 /* Accessors */
 NumericalSample ApproximationAlgorithmImplementation::getX() const
 {
@@ -114,11 +119,16 @@ Basis ApproximationAlgorithmImplementation::getPsi() const
   return psi_;
 }
 
+/* Perform the selection */
+void ApproximationAlgorithmImplementation::run()
+{
+  throw NotYetImplementedException(HERE);
+}
 
 /* String converter */
 String ApproximationAlgorithmImplementation::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " x=" << x_
          << " y=" << y_
          << " weight=" << weight_
