@@ -3,7 +3,7 @@
  *  @file  FFTImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -120,7 +120,7 @@ FFT::NumericalComplexCollection FFT::inverseTransform(const NumericalComplexColl
 /* String converter */
 String FFT::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << FFT::GetClassName()
       << " implementation=" << getImplementation()->__repr__();
   return oss;
@@ -129,7 +129,7 @@ String FFT::__repr__() const
 /* String converter */
 String FFT::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << "class=" << FFT::GetClassName()
       << " implementation=" << getImplementation()->__str__(offset);
   return oss;
