@@ -3,7 +3,7 @@
  *  @file  FFTImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,10 @@ FFTImplementation * FFTImplementation::clone() const
 /* FFT transformation on real */
 FFTImplementation::NumericalComplexCollection FFTImplementation::transform(const NumericalScalarCollection & collection) const
 {
-  throw NotYetImplementedException(HERE);
+  const UnsignedLong size(collection.getSize());
+  NumericalComplexCollection coll(size);
+  for (UnsignedLong i = 0; i < size; ++i) coll[i] = collection[i];
+  return transform(coll);
 }
 
 
@@ -104,7 +107,7 @@ FFTImplementation::NumericalComplexCollection FFTImplementation::inverseTransfor
 /* String converter */
 String FFTImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << FFTImplementation::GetClassName();
   return oss;
 }
