@@ -3,7 +3,7 @@
  *  @file  FittingAlgorithmImplementation.cxx
  *  @brief Cross-validation algorithm implementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,10 +27,10 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(FittingAlgorithmImplementation);
 
+static Factory<FittingAlgorithmImplementation> RegisteredFactory("FittingAlgorithmImplementation");
+
 /* Default constructor */
 FittingAlgorithmImplementation::FittingAlgorithmImplementation()
   : PersistentObject()
@@ -38,6 +38,20 @@ FittingAlgorithmImplementation::FittingAlgorithmImplementation()
   // Nothing to do
 }
 
+/* Virtual constructor */
+FittingAlgorithmImplementation * FittingAlgorithmImplementation::clone() const
+{
+  return new FittingAlgorithmImplementation(*this);
+}
+
+/* Perform cross-validation */
+NumericalScalar FittingAlgorithmImplementation::run(const NumericalSample & x,
+    const NumericalSample & y,
+    const Basis & basis) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* String converter */
 String FittingAlgorithmImplementation::__repr__() const
 {
