@@ -3,7 +3,7 @@
  *  @file  KissFFT.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -54,7 +54,7 @@ KissFFT * KissFFT::clone() const
 /* String converter */
 String KissFFT::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << KissFFT::GetClassName();
   return oss;
 }
@@ -62,7 +62,7 @@ String KissFFT::__repr__() const
 /* String converter */
 String KissFFT::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << "class=" << KissFFT::GetClassName();
   return oss;
 }
