@@ -3,7 +3,7 @@
  *  @file  PenalizedLeastSquaresAlgorithm.cxx
  *  @brief This Penalized Least Squares Algorithm as a functor class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -146,7 +146,7 @@ void PenalizedLeastSquaresAlgorithm::run()
   // Solve the linear system (least squares solution)
   setCoefficients( basisMatrix.solveLinearSystem( rightHandSide ) );
 
-  const NumericalScalar quadraticResidual( (basisMatrix * getCoefficients() - rightHandSide).norm2() );
+  const NumericalScalar quadraticResidual( (basisMatrix * getCoefficients() - rightHandSide).normSquare() );
 
   // The residual is the mean L2 norm of the fitting
   setResidual( sqrt( quadraticResidual ) / sampleSize );
