@@ -3,7 +3,7 @@
  *  @file  ComparisonOperator.cxx
  *  @brief Abstract top-level class for all ComparisonOperator
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(ComparisonOperator);
 
 /* Default constructor */
@@ -47,7 +45,8 @@ ComparisonOperator::ComparisonOperator(const ComparisonOperatorImplementation &
 
 
 /* Return true if comparison succeeds */
-Bool ComparisonOperator::operator()(NumericalScalar a, NumericalScalar b) const
+Bool ComparisonOperator::operator()(const NumericalScalar a,
+                                    const NumericalScalar b) const
 {
   return (*getImplementation())(a, b);
 }
