@@ -3,7 +3,7 @@
  *  @file  ComparisonOperatorImplementation.cxx
  *  @brief Abstract top-level class for all ComparisonOperatorImplementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,14 +21,15 @@
  *  @author schueller
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
+#include "PersistentObjectFactory.hxx"
 #include "ComparisonOperatorImplementation.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(ComparisonOperatorImplementation);
 
+static Factory<ComparisonOperatorImplementation> RegisteredFactory("ComparisonOperatorImplementation");
+
 /* Default constructor */
 ComparisonOperatorImplementation::ComparisonOperatorImplementation()
   : PersistentObject()
@@ -36,6 +37,19 @@ ComparisonOperatorImplementation::ComparisonOperatorImplementation()
   // Nothing to do
 }
 
+/* Virtual constructor */
+ComparisonOperatorImplementation * ComparisonOperatorImplementation::clone() const
+{
+  return new ComparisonOperatorImplementation(*this);
+}
+
+/* Evaluation operator */
+Bool ComparisonOperatorImplementation::operator() (const NumericalScalar a,
+    const NumericalScalar b) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* String converter */
 String ComparisonOperatorImplementation::__repr__() const
 {
