@@ -3,7 +3,7 @@
  *  @file  Greater.cxx
  *  @brief Abstract top-level class for all Greater
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(Greater);
 
 static Factory<Greater> RegisteredFactory("Greater");
@@ -56,7 +54,8 @@ Greater * Greater::clone() const
 }
 
 /* Return true if comparison succeeds */
-Bool Greater::operator() (NumericalScalar a, NumericalScalar b) const
+Bool Greater::operator() (const NumericalScalar a,
+                          const NumericalScalar b) const
 {
   return (a > b);
 }
