@@ -3,7 +3,7 @@
  *  @file  GreaterOrEqual.cxx
  *  @brief Abstract top-level class for all GreaterOrEqual
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(GreaterOrEqual);
 
 static Factory<GreaterOrEqual> RegisteredFactory("GreaterOrEqual");
@@ -56,7 +54,8 @@ GreaterOrEqual * GreaterOrEqual::clone() const
 }
 
 /* Return true if comparison succeeds */
-Bool GreaterOrEqual::operator() (NumericalScalar a, NumericalScalar b) const
+Bool GreaterOrEqual::operator() (const NumericalScalar a,
+                                 const NumericalScalar b) const
 {
   return (a >= b);
 }
