@@ -3,7 +3,7 @@
  *  @file  LessOrEqual.cxx
  *  @brief Abstract top-level class for all LessOrEqual
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(LessOrEqual);
 
 static Factory<LessOrEqual> RegisteredFactory("LessOrEqual");
@@ -56,7 +54,8 @@ LessOrEqual * LessOrEqual::clone() const
 }
 
 /* Return true if comparison succeeds */
-Bool LessOrEqual::operator() (NumericalScalar a, NumericalScalar b) const
+Bool LessOrEqual::operator() (const NumericalScalar a,
+                              const NumericalScalar b) const
 {
   return (a <= b);
 }
