@@ -3,7 +3,7 @@
  *  @file  Object.cxx
  *  @brief The class Object is the top-most class of Open TURNS
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,7 @@ Object::~Object()
 /* String converter */
 String Object::__repr__() const
 {
-  return OSS() << "class=" << getClassName();
+  return OSS(true) << "class=" << getClassName();
 }
 
 /* Pretty string converter */
