@@ -3,7 +3,7 @@
  *  @file  Os.cxx
  *  @brief This class provides operating system specific variables
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,12 +26,9 @@
 #include "Log.hxx"
 #include "OSS.hxx"
 
-#ifdef WIN32
-#include <windows.h> // For CreateProcess
+#include "OTwindows.h" // For CreateProcess
 #include "ResourceMap.hxx" // For ResourceMap
-#else
 #include <cstdlib>   // for system(3)
-#endif
 
 BEGIN_NAMESPACE_OPENTURNS
 
