@@ -3,7 +3,7 @@
  *  @file  Path.cxx
  *  @brief This class provides all the treatments for wrapper file manipulation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,11 +25,11 @@
 #include <string>                 // for std::string
 #include <cstdlib>                // for getenv
 #include <cstring>                // for strcpy
+
 #ifdef WIN32
 #include <fstream>                // for ofstream
-#include <windows.h>              // for GetTempFileName, GetModuleFileName
+#include "OTwindows.h"            // for GetTempFileName, GetModuleFileName
 #include <libgen.h>               // for dirname
-#undef ERROR
 #endif
 #include <sys/types.h>            // for stat
 #include <sys/stat.h>             // for stat
@@ -48,7 +48,7 @@
 #error "INSTALL_PATH is NOT defined. Check configuration."
 #endif
 
-#ifdef HAVE_DIRENT_H
+#ifdef OPENTURNS_HAVE_DIRENT_H
 #include <dirent.h>
 #endif
 
@@ -68,10 +68,6 @@
 #error "OPENTURNS_HOME_ENV_VAR is NOT defined. Check configuration."
 #endif
 
-#ifdef WIN32
-static pthread_mutex_t temporaryDirectoryMutex = PTHREAD_MUTEX_INITIALIZER;
-#endif
-
 BEGIN_NAMESPACE_OPENTURNS
 
 
@@ -510,23 +506,31 @@ String Path::CreateTemporaryDirectory (const FileName & directoryPrefix)
   const String finalTempDirName(tempDirName);
   free(tempDirName);
 #else
-  // fixme: no error check
   char temporaryDirName[MAX_PATH];
-  GetTempFileName(GetTemporaryDirectory().c_str(),             // directory for tmp files
-                  TEXT((directoryPrefix + "_XXXXXX").c_str()), // temp file name prefix
-                  0,                                           // create unique name
-                  temporaryDirName);                           // buffer for name
+  int ret = 0;
+  for (int retry = 10000; retry >= 0; --retry)
+  {
+    ret = GetTempFileName(GetTemporaryDirectory().c_str(),       // directory for tmp files
+                          TEXT((directoryPrefix + "abc").c_str()),     // temp file name prefix (only 3 characters are used)
+                          0,                                           // create unique name
+                          temporaryDirName);                           // buffer for name
+    if (0 == ret)
+    {
+      ret = -1;
+      continue;
+    }
+    DeleteFile(temporaryDirName);
+    ret = mkdir(temporaryDirName);
+    if (0 == ret) break;
+  }
+  if (0 != ret)
+  {
+    LOGERROR(OSS() << "Can't create temporary directory.");
+    temporaryDirName[0] = '\0';
+  }
+
   const String finalTempDirName(temporaryDirName);
 
-  pthread_mutex_lock(&temporaryDirectoryMutex);
-
-  unlink(finalTempDirName.c_str());
-  // Possible race condition in between these two functions !
-  // The mutex only avoid the problem inside the openturns processus.
-  // It can still happen if other processus create the same tempDirName after unlink but before mkdir call.
-  mkdir(finalTempDirName.c_str());
-
-  pthread_mutex_unlock(&temporaryDirectoryMutex);
 #endif
 
   return finalTempDirName;
