@@ -3,7 +3,7 @@
  *  @file  ResourceMap.cxx
  *  @brief ResourceMap defines top-most resourceMap strategies
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,11 +33,8 @@
 #include "Log.hxx"
 #include "XMLToolbox.hxx"
 
-
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 static const char * ConfigurationFileName = "openturns.conf";
 #if defined HAVE_LIBXML2
 static const char * RootElementName = "openturns-configuration";
@@ -362,6 +359,10 @@ void ResourceMap::loadDefaultConfiguration()
   // Collection parameters
   setAsUnsignedLong( "Collection-size-visible-in-str-from", 10 );
 
+  // SpecFunc parameters
+  setAsUnsignedLong( "SpecFunc-MaximumIteration", 1000 );
+  setAsNumericalScalar( "SpecFunc-Precision", 2.0e-16 );
+
   // KFold parameters
   setAsUnsignedLong( "KFold-DefaultK", 10 );
 
@@ -377,8 +378,11 @@ void ResourceMap::loadDefaultConfiguration()
   // NonCenteredFiniteDifferenceGradient parameters //
   setAsNumericalScalar( "NonCenteredFiniteDifferenceGradient-DefaultEpsilon", 1.0e-7 );
 
-  // SpecFunc parameters //
-  setAsNumericalScalar( "SpecFunc-Precision", 1.0e-12 );
+  // PiecewiseHermiteEvaluationImplementation parameters //
+  setAsNumericalScalar( "PiecewiseHermiteEvaluationImplementation-EpsilonRegular", 1.0e-12 );
+
+  // PiecewiseLinearEvaluationImplementation parameters //
+  setAsNumericalScalar( "PiecewiseLinearEvaluationImplementation-EpsilonRegular", 1.0e-12 );
 
   // UniVariatePolynomialImplementation parameters //
   setAsUnsignedLong( "UniVariatePolynomialImplementation-SmallDegree", 400 );
@@ -436,7 +440,7 @@ void ResourceMap::loadDefaultConfiguration()
 
   // NearestPointAlgorithmImplementation parameters //
   setAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultLevelValue", 0.0 );
-  setAsUnsignedLong( "NearestPointAlgorithmImplementation-DefaultMaximumIterationsNumber", 100 );
+  setAsUnsignedLong( "NearestPointAlgorithmImplementation-DefaultMaximumIteration", 100 );
   setAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumAbsoluteError", 1.0e-5 );
   setAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumRelativeError", 1.0e-5 );
   setAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumResidualError", 1.0e-5 );
@@ -451,6 +455,10 @@ void ResourceMap::loadDefaultConfiguration()
   setAsNumericalScalar( "SolverImplementation-DefaultResidualError",  1.0e-8 );
   setAsUnsignedLong( "SolverImplementation-DefaultMaximumFunctionEvaluation", 100 );
 
+  // GaussKronrod parameters //
+  setAsUnsignedLong( "GaussKronrod-MaximumSubIntervals", 100 );
+  setAsNumericalScalar( "GaussKronrod-MaximumError",  1.0e-12 );
+
   // LinearModelFactory parameters //
   setAsNumericalScalar( "LinearModelFactory-DefaultLevelValue", 0.95 );
 
@@ -485,17 +493,18 @@ void ResourceMap::loadDefaultConfiguration()
   // RandomGenerator parameters //
   setAsUnsignedLong( "RandomGenerator-InitialSeed", 0 );
 
-  // TimeSeries parameters //
-  setAsNumericalScalar( "TimeSeries-DefaultEpsilonValue", 1.0e-10 );
-
-  // Collection parameters
-  setAsUnsignedLong( "Collection-size-visible-in-str-from", 10 );
+  // FieldImplementation parameters //
+  setAsUnsignedLong( "FieldImplementation-LevelNumber", 30 );
 
   // NumericalSampleImplementation parameters
-  setAsUnsignedLong( "NumericalSampleImplementation-SmallKendallTau", 40 );
+  setAsUnsignedLong( "NumericalSampleImplementation-SmallKendallTau", 23 );
+
+  // DomainImplementation parameters
+  setAsNumericalScalar( "DomainImplementation-SmallVolume",   1.0e-12 );
 
   // Mesh parameters
-  setAsNumericalScalar( "Mesh-SmallVolume", 1.0e-12 );
+  setAsNumericalScalar( "Mesh-VertexEpsilon", 1.0e-12 );
+  setAsUnsignedLong( "Mesh-LargeSize", 5000 );
 
   // Matrix parameters
   setAsUnsignedLong( "Matrix-size-visible-in-str-from", 5 );
@@ -532,6 +541,14 @@ void ResourceMap::loadDefaultConfiguration()
   setAsNumericalScalar( "GeneralizedParetoFactory-MaximumObjectiveError", 1.0e-10 );
   setAsNumericalScalar( "GeneralizedParetoFactory-MaximumConstraintError", 1.0e-10 );
 
+  // InverseNormalFactory parameters //
+  set( "InverseNormalFactory-Method", "MLE" );
+
+  // KernelMixture parameters //
+  setAsUnsignedLong( "KernelMixture-SmallSize", 50 );
+  setAsUnsignedLong( "KernelMixture-LargeSize", 20 );
+  setAsUnsignedLong( "KernelMixture-PDFCDFDiscretization", 1000 );
+
   // KernelSmoothing parameters //
   setAsUnsignedLong( "KernelSmoothing-SmallSize", 250 );
   setAsUnsignedLong( "KernelSmoothing-BinNumber", 256 );
@@ -552,8 +569,19 @@ void ResourceMap::loadDefaultConfiguration()
   setAsNumericalScalar( "LogNormalFactory-ResidualPrecision", 1.0e-12 );
   setAsUnsignedLong( "LogNormalFactory-MaximumIteration", 50 );
 
+  // Meixner parameters //
+  setAsUnsignedLong( "MeixnerDistribution-CDFIntegrationNodesNumber", 32 );
+  setAsUnsignedLong( "MeixnerDistribution-CDFDiscretization", 10000 );
+  setAsNumericalScalar( "MeixnerDistribution-MaximumAbsoluteError", 1.0e-12 );
+  setAsNumericalScalar( "MeixnerDistribution-MaximumRelativeError", 1.0e-12 );
+  setAsNumericalScalar( "MeixnerDistribution-MaximumConstraintError", 1.0e-12 );
+  setAsNumericalScalar( "MeixnerDistribution-MaximumObjectiveError", 1.0e-12 );
+
   // Mixture parameters //
   setAsNumericalScalar( "Mixture-SmallWeight", 1.0e-12 );
+  setAsUnsignedLong( "Mixture-SmallSize", 50 );
+  setAsUnsignedLong( "Mixture-LargeSize", 20 );
+  setAsUnsignedLong( "Mixture-PDFCDFDiscretization", 1000 );
 
   // Multinomial parameters //
   setAsUnsignedLong( "Multinomial-smallA", 10 );
@@ -582,7 +610,7 @@ void ResourceMap::loadDefaultConfiguration()
   // TrapezoidalFactory parameters //
   setAsNumericalScalar( "TrapezoidalFactory-RhoBeg", 0.1 );
   setAsNumericalScalar( "TrapezoidalFactory-RhoEnd", 1.0e-5 );
-  setAsUnsignedLong( "TrapezoidalFactory-MaximumIterationsNumber", 10000 );
+  setAsUnsignedLong( "TrapezoidalFactory-MaximumIteration", 10000 );
 
   // TruncatedDistribution parameters //
   setAsNumericalScalar( "TruncatedDistribution-DefaultThresholdRealization", 0.5 );
@@ -590,7 +618,7 @@ void ResourceMap::loadDefaultConfiguration()
   // TruncatedNormalFactory parameters //
   setAsNumericalScalar( "TruncatedNormalFactory-RhoBeg", 0.1 );
   setAsNumericalScalar( "TruncatedNormalFactory-RhoEnd", 1.0e-5 );
-  setAsUnsignedLong( "TruncatedNormalFactory-MaximumIterationsNumber", 100000 );
+  setAsUnsignedLong( "TruncatedNormalFactory-MaximumIteration", 100000 );
 
   // Student parameters //
   setAsUnsignedLong( "Student-MaximumNumberOfPoints", 10000000 );
@@ -670,6 +698,19 @@ void ResourceMap::loadDefaultConfiguration()
   // FunctionalChaosAlgorithm parameters //
   setAsNumericalScalar( "FunctionalChaosAlgorithm-DefaultMaximumResidual", 1.0e-6 );
 
+  // TemporalNormalProcess parameters //
+  setAsNumericalScalar( "KrigingAlgorithm-StartingScaling", 1.0e-13 );
+  setAsNumericalScalar( "KrigingAlgorithm-MaximalScaling", 1.0e5 );
+
+  // SquaredExponential parameters //
+  setAsNumericalScalar( "SquaredExponential-DefaultTheta", 1.0e-1 );
+
+  // AbsoluteExponential parameters //
+  setAsNumericalScalar( "AbsoluteExponential-DefaultTheta", 1.0e-1 );
+
+  // GeneralizedExponential parameters //
+  setAsNumericalScalar( "GeneralizedExponential-DefaultTheta", 1.0e-1 );
+
   // WeightedExperiment parameters //
   setAsUnsignedLong( "WeightedExperiment-DefaultSize", 100 );
 
@@ -681,6 +722,7 @@ void ResourceMap::loadDefaultConfiguration()
 
   // MarginalTransformationEvaluation parameters //
   setAsNumericalScalar( "MarginalTransformationEvaluation-DefaultTailThreshold", 0.99 );
+  setAsUnsignedLong( "MarginalTransformationEvaluation-Simplify", 1 );
 
   // DistributionImplementation parameters //
   setAsUnsignedLong( "DistributionImplementation-DefaultPointNumber", 129 );
@@ -693,10 +735,10 @@ void ResourceMap::loadDefaultConfiguration()
   setAsUnsignedLong( "DistributionImplementation-DefaultIntegrationNodesNumber", 255 );
   setAsUnsignedLong( "DistributionImplementation-DefaultLevelNumber", 10 );
   setAsUnsignedLong( "DistributionImplementation-DefaultQuantileCacheSize", 128 );
-  setAsUnsignedLong( "DistributionImplementation-parallel", 0 );
+  setAsUnsignedLong( "DistributionImplementation-Parallel", 0 );
 
   // ContinuousDistribution parameters //
-  setAsUnsignedLong( "ContinuousDistribution-DefaultIntegrationNodesNumber", 51 );
+  setAsUnsignedLong( "ContinuousDistribution-DefaultIntegrationNodesNumber", 256 );
 
   // DiscreteDistribution parameters //
   setAsNumericalScalar( "DiscreteDistribution-SupportEpsilon", 1.0e-14 );
