@@ -3,7 +3,7 @@
  *  @file  StorageManager.cxx
  *  @brief StorageManager provides an interface for different storage classes
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include "Study.hxx"
 #include "OSS.hxx"
 #include "Log.hxx"
+#include "OTconfig.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -152,7 +153,7 @@ void StorageManager::addAttribute(Pointer<InternalObject> & p_obj, const String
   // Nothing to do
 }
 
-#ifndef __LP64__
+#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
 /* Add an attribute to an internal object */
 void StorageManager::addAttribute(Pointer<InternalObject> & p_obj, const String & name, Unsigned64BitsInteger value)
 {
@@ -209,7 +210,7 @@ void StorageManager::addIndexedValue(Pointer<InternalObject> & p_obj, UnsignedLo
   // Nothing to do
 }
 
-#ifndef __LP64__
+#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
 /* Add an indexed value to an internal object */
 void StorageManager::addIndexedValue(Pointer<InternalObject> & p_obj, UnsignedLong index, Unsigned64BitsInteger value)
 {
@@ -265,7 +266,7 @@ void StorageManager::readAttribute(Pointer<InternalObject> & p_obj, const String
   // Nothing to do
 }
 
-#ifndef __LP64__
+#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
 /* Read an attribute */
 void StorageManager::readAttribute(Pointer<InternalObject> & p_obj, const String & name, Unsigned64BitsInteger & value)
 {
@@ -317,7 +318,7 @@ void StorageManager::readIndexedValue(Pointer<InternalObject> & p_obj, UnsignedL
   // Nothing to do
 }
 
-#ifndef __LP64__
+#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
 /* Read an indexed value */
 void StorageManager::readIndexedValue(Pointer<InternalObject> & p_obj, UnsignedLong index, Unsigned64BitsInteger & value)
 {
