@@ -3,7 +3,7 @@
  *  @file  Study.cxx
  *  @brief Study keeps all PersistentObjects in a file
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -87,12 +87,12 @@ String Study::__repr__() const
 /* String converter */
 String Study::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   const char * separator = "  ";
   for(Map::const_iterator it = map_.begin(); it != map_.end(); ++it, separator = "\n  ")
   {
     oss << separator << (*it).first << " => " << ((*it).second)->getClassName() << "\n"
-        << ((*it).second)->__str__( String( 7 + int( log10((*it).first) ), ' ') );
+        << ((*it).second)->__str__( String( 7 + int( ((*it).first != 0 ? log10((*it).first) : 1) ), ' ') );
   }
   oss << "\n";
   separator = "  ";
