@@ -3,7 +3,7 @@
  * @file  WrapperCommon.cxx
  * @brief This file provides objects and functions commonly used by wrappers
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,6 +25,8 @@
 #define _XOPEN_SOURCE 600 // for strerror_r
 #endif
 
+#include "OTwindows.h" // for GetTempFileName
+
 #if defined(__APPLE__)
 #define _DARWIN_C_SOURCE
 #endif
@@ -33,7 +35,7 @@
 #include <sys/types.h> // for select(2)
 #include <sys/stat.h>
 #include <ctype.h>
-#if !defined(__APPLE__)
+#ifdef OPENTURNS_HAVE_MALLOC_H
 #include <malloc.h>
 #endif
 #include <unistd.h>    // for select(2)
@@ -389,14 +391,6 @@ extern void wrapper_printWrapperExchangedData(const char * functionName,
                        platform->retries_,
                        (platform->command_path_ ? platform->command_path_ : "(nil)") );
 
-      /* Print the framework data */
-      struct FrameworkData * framework = p_exchangedData->framework_;
-      printToLogDebug( "(%s) Framework (studyid='%d' studycase='%s' componentname='%s')",
-                       functionName,
-                       framework->studyid_,
-                       framework->studycase_,
-                       framework->componentname_ );
-
     }
   }
 }
@@ -498,22 +492,22 @@ extern void wrapper_printSample(const char * functionName,
 
 
 
-/* Print out the content of a timeseries structure */
-extern void wrapper_printTimeSeries(const char * functionName,
-                                    const struct timeseries * p_timeseries)
+/* Print out the content of a field structure */
+extern void wrapper_printField(const char * functionName,
+                               const struct field * p_field)
 {
   if (Log::HasDebug())
   {
-    if (p_timeseries != NULL)
+    if (p_field != NULL)
     {
       char SZ[64];
       char DIM[64];
-      sprintf( SZ,  "%lu", p_timeseries->size_      );
-      sprintf( DIM, "%lu", p_timeseries->dimension_ );
+      sprintf( SZ,  "%lu", p_field->size_      );
+      sprintf( DIM, "%lu", p_field->dimension_ );
       String msg;
       msg += "(";
       msg += functionName;
-      msg += ") struct timeseries {size=";
+      msg += ") struct field {size=";
       msg += SZ;
       msg += ", dimension=";
       msg += DIM;
@@ -522,12 +516,12 @@ extern void wrapper_printTimeSeries(const char * functionName,
       char DATA[128];
       const char * seps = "[";
       const char * sepp = "";
-      for (int i = 0; i < static_cast<int>(p_timeseries->size_); ++i, seps = "],[")
+      for (int i = 0; i < static_cast<int>(p_field->size_); ++i, seps = "],[")
       {
         msg += seps;
         sepp = "";
-        const double * tab = &(p_timeseries->data_[i * p_timeseries->size_]);
-        for (int j = 0; j < static_cast<int>(p_timeseries->dimension_ + 1); ++j, sepp = ",")
+        const double * tab = &(p_field->data_[i * p_field->size_]);
+        for (int j = 0; j < static_cast<int>(p_field->dimension_ + 1); ++j, sepp = ",")
         {
           sprintf( DATA, "%s%.16g", sepp, tab[j] );
           msg += DATA;
@@ -678,8 +672,6 @@ extern long wrapper_copyWrapperExchangedData(struct WrapperExchangedData ** p_p_
   struct       WrapperConfiguration  *  new_parameters              = NULL;
   struct       PlatformConfiguration *  platform                    = NULL;
   struct       PlatformConfiguration *  new_platform                = NULL;
-  struct       FrameworkData         *  framework                   = NULL;
-  struct       FrameworkData         *  new_framework               = NULL;
 
 
   /* Copy the file list */
@@ -816,23 +808,6 @@ extern long wrapper_copyWrapperExchangedData(struct WrapperExchangedData ** p_p_
   new_platform->command_path_ = (platform->command_path_ != NULL) ? strdup(platform->command_path_) : NULL;
 
 
-
-
-  /* Copy the framework data */
-  p_new_exchangedData->framework_ = NULL;
-  framework     = p_exchangedData->framework_;
-  new_framework = (struct FrameworkData *) malloc(sizeof(struct FrameworkData));
-  if (!new_framework) goto ERR;
-  p_new_exchangedData->framework_ = new_framework;
-
-  new_framework->studyid_ = framework->studyid_;
-
-  new_framework->studycase_ = strdup(framework->studycase_);
-  if (!new_framework->studycase_) goto ERR;
-
-  new_framework->componentname_ = strdup(framework->componentname_);
-  if (!new_framework->componentname_) goto ERR;
-
   /* The new exchanged data uses the same lock */
   p_new_exchangedData->p_lock_ = p_exchangedData->p_lock_;
 
@@ -901,11 +876,6 @@ extern void wrapper_freeWrapperExchangedData(struct WrapperExchangedData * p_exc
     free(p_exchangedData->platform_->command_path_);
     free(p_exchangedData->platform_);
 
-    /* Free the framework */
-    free(p_exchangedData->framework_->studycase_);
-    free(p_exchangedData->framework_->componentname_);
-    free(p_exchangedData->framework_);
-
     /* Free the embedding structure */
     free(p_exchangedData);
   }
@@ -950,6 +920,9 @@ extern char * wrapper_createTemporaryDirectory(const char * tempDirPrefix,
   const char sfx[] = "_XXXXXX";
   ssize_t len = 0;
   int myerrno UNUSED;
+#ifdef WIN32
+  int ret = 0;
+#endif
 
   if ( (tempDirPrefix == 0) || (strlen(tempDirPrefix) == 0) )
   {
@@ -1006,18 +979,32 @@ extern char * wrapper_createTemporaryDirectory(const char * tempDirPrefix,
 
 #else /* WIN32 */
 
-  int ret;
   char temporaryDirName[MAX_PATH];
   // no GetTempPathName found on windows :-(
-  ret = GetTempFileName(p_exchangedData->platform_->generalTemporaryDirectory_, // directory for tmp files
-                        TEXT((String(tempDirPrefix) + sfx).c_str()),        // temp file name prefix
-                        0,                                                      // create unique name
-                        temporaryDirName);                                      // buffer for name
-  if (ret == 0)
+  // Possible race condition between calls to GetTempFileName and mkdir, hence this loop
+  for (int retry = 10000; retry >= 0; --retry)
   {
-    wrapper_setError( p_error, "(createTemporaryDirectory) Can't create temp filename from template %s", tempDirPrefix );
+    ret = GetTempFileName(p_exchangedData->platform_->generalTemporaryDirectory_, // directory for tmp files
+                          TEXT((String(tempDirPrefix) + sfx).c_str()),        // temp file name prefix
+                          0,                                                      // create unique name
+                          temporaryDirName);                                      // buffer for name
+    if (ret == 0)
+    {
+      ret = -1;
+      continue;
+    }
+    DeleteFile(temporaryDirName);
+    ret = mkdir(temporaryDirName);
+    if (ret == 0) break;
+
+    // There has been a name collision, retry
+  }
+  if (ret != 0)
+  {
+    wrapper_setError( p_error, "(createTemporaryDirectory) Can't create temporary directory" );
     goto ERR;
   }
+
   tempDirName = strdup(temporaryDirName);
   if (tempDirName == NULL)
   {
@@ -1025,28 +1012,6 @@ extern char * wrapper_createTemporaryDirectory(const char * tempDirPrefix,
     goto ERR;
   }
 
-  pthread_mutex_lock(&FileSystemMutex);
-
-  ret = unlink(tempDirName);
-  if (ret != 0)
-  {
-    wrapper_setError( p_error, "(createTemporaryDirectory) Can't delete temp filename %s", tempDirName );
-    pthread_mutex_unlock(&FileSystemMutex);
-    goto ERR;
-  }
-  // Possible race condition in between these two functions !
-  // The mutex only avoid the problem inside the openturns processus.
-  // It can still happen if other processus create the same tempDirName after unlink but before mkdir call.
-  ret = mkdir(tempDirName);
-  if (ret != 0)
-  {
-    wrapper_setError( p_error, "(createTemporaryDirectory) Can't create directory %s", tempDirName );
-    pthread_mutex_unlock(&FileSystemMutex);
-    goto ERR;
-  }
-
-  pthread_mutex_unlock(&FileSystemMutex);
-
 #endif /* WIN32 */
 
   printToLogDebug( "(createTemporaryDirectory) temporary dir %s created", tempDirName );
@@ -1690,8 +1655,7 @@ extern const char * wrapper_getUserPrefix(const struct WrapperExchangedData * p_
 extern long wrapper_getStudyId(const struct WrapperExchangedData * p_exchangedData)
 {
   assert(p_exchangedData);
-  assert(p_exchangedData->framework_);
-  return p_exchangedData->framework_->studyid_;
+  return 0;
 }
 
 
@@ -1701,8 +1665,7 @@ extern long wrapper_getStudyId(const struct WrapperExchangedData * p_exchangedDa
 extern const char * wrapper_getStudyCase(const struct WrapperExchangedData * p_exchangedData)
 {
   assert(p_exchangedData);
-  assert(p_exchangedData->framework_);
-  return p_exchangedData->framework_->studycase_;
+  return "";
 }
 
 
@@ -1712,8 +1675,7 @@ extern const char * wrapper_getStudyCase(const struct WrapperExchangedData * p_e
 extern const char * wrapper_getComponentName(const struct WrapperExchangedData * p_exchangedData)
 {
   assert(p_exchangedData);
-  assert(p_exchangedData->framework_);
-  return p_exchangedData->framework_->componentname_;
+  return "";
 }
 
 
