@@ -3,7 +3,7 @@
  * @file  WrapperCommonFunctions.cxx
  * @brief This file provides function tools for the wrapper library
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,6 +25,8 @@
 #define _XOPEN_SOURCE 600 // for strerror_r
 #endif
 
+#include "OTwindows.h" // for Sleep
+
 #include <stdarg.h>    // for variadic args functions
 #include <cstring>
 #include <cstdlib>     // for system(3)
@@ -189,10 +191,10 @@ static void printToLog(void (*func)(const OT::String & msg),
 {
   OT::OSS newfmt;
   newfmt << "[tid=" <<
-#ifndef WIN32
-         pthread_self()
-#else
+#ifdef PTW32_VERSION          // pthreads-win32
          pthread_self().p
+#else                         // winpthreads
+         pthread_self()
 #endif
          << "] " << format;
   char * msg = vnewFormattedString( newfmt.str().c_str(), args );
@@ -345,10 +347,10 @@ OT::String getWrapperError(void * p_error)
 
 /* Some functions that help debugging memory allocation */
 /* Allocate SIZE bytes of memory.  */
-__malloc_ptr_t dbg_malloc __MALLOC_P ((int line,
-                                       size_t __size))
+void* dbg_malloc __MALLOC_P ((int line,
+                              size_t __size))
 {
-  __malloc_ptr_t ptr = malloc(__size);
+  void* ptr = malloc(__size);
   if (ptr) memset(ptr, 0, __size);
 #ifdef DEBUG
   printToLogDebug( "(malloc) line %d : ptr=%d size=%d", line, ptr, __size );
@@ -360,11 +362,11 @@ __malloc_ptr_t dbg_malloc __MALLOC_P ((int line,
 
 
 /* Allocate NMEMB elements of SIZE bytes each, all initialized to 0.  */
-__malloc_ptr_t dbg_calloc __MALLOC_P ((int line,
-                                       size_t __nmemb,
-                                       size_t __size))
+void* dbg_calloc __MALLOC_P ((int line,
+                              size_t __nmemb,
+                              size_t __size))
 {
-  __malloc_ptr_t ptr = calloc(__nmemb, __size);
+  void* ptr = calloc(__nmemb, __size);
   if (ptr) memset(ptr, 0, __nmemb * __size);
   if (Log::HasDebug()) printToLogDebug( "(calloc) line %d : ptr=%p nmemb=%d size=%d", line, ptr, __nmemb, __size );
   return ptr;
@@ -375,11 +377,11 @@ __malloc_ptr_t dbg_calloc __MALLOC_P ((int line,
 
 /* Re-allocate the previously allocated block in __ptr, making the new
    block SIZE bytes long.  */
-__malloc_ptr_t dbg_realloc __MALLOC_P ((int line,
-                                        __malloc_ptr_t __ptr,
-                                        size_t __size))
+void* dbg_realloc __MALLOC_P ((int line,
+                               void* __ptr,
+                               size_t __size))
 {
-  __malloc_ptr_t ptr = realloc(__ptr, __size);
+  void* ptr = realloc(__ptr, __size);
   if (Log::HasDebug()) printToLogDebug( "(realloc) line %d : ptr=%p __ptr=%p size=%d", line, ptr, __ptr, __size );
   return ptr;
 }
@@ -389,7 +391,7 @@ __malloc_ptr_t dbg_realloc __MALLOC_P ((int line,
 
 /* Free a block allocated by `malloc', `realloc' or `calloc'.  */
 void dbg_free __MALLOC_P ((int line,
-                           __malloc_ptr_t __ptr))
+                           void* __ptr))
 {
   if (Log::HasDebug()) printToLogDebug( "(free) line %d : ptr=%p", line, __ptr );
   free(__ptr);
