@@ -79,8 +79,8 @@ extern void wrapper_printPoint(const char * functionName, const struct point * p
 /* Print out the content of a sample structure */
 extern void wrapper_printSample(const char * functionName, const struct sample * p_sample);
 
-/* Print out the content of a timeseries structure */
-extern void wrapper_printTimeSeries(const char * functionName, const struct timeseries * p_timeseries);
+/* Print out the content of a field structure */
+extern void wrapper_printField(const char * functionName, const struct field * p_field);
 
 /* Print out the content of a matrix structure */
 extern void wrapper_printMatrix(const char * functionName, const struct matrix * p_matrix);
@@ -117,13 +117,13 @@ extern const char * wrapper_getCommand(const struct WrapperExchangedData * p_exc
 /* Get the user prefix from the exchanged data structure */
 extern const char * wrapper_getUserPrefix(const struct WrapperExchangedData * p_exchangedData);
 
-/* Get the study id from the exchanged data structure */
+/* DEPRECATED: Get the study id from the exchanged data structure */
 extern long wrapper_getStudyId(const struct WrapperExchangedData * p_exchangedData);
 
-/* Get the study case from the exchanged data structure */
+/* DEPRECATED: Get the study case from the exchanged data structure */
 extern const char * wrapper_getStudyCase(const struct WrapperExchangedData * p_exchangedData);
 
-/* Get the component name from the exchanged data structure */
+/* DEPRECATED: Get the component name from the exchanged data structure */
 extern const char * wrapper_getComponentName(const struct WrapperExchangedData * p_exchangedData);
 
 /* Get the number of virtual CPUs from the exchanged data structure */
