@@ -47,7 +47,7 @@
   BIND_ACTION(void, printWrapperInformation, (const char * functionName, const struct WrapperInformation * p_info)) \
   BIND_ACTION(void, printPoint, (const char * functionName, const struct point * p_point)) \
   BIND_ACTION(void, printSample, (const char * functionName, const struct sample * p_sample)) \
-  BIND_ACTION(void, printTimeSeries, (const char * functionName, const struct timeseries * p_timeseries)) \
+  BIND_ACTION(void, printField, (const char * functionName, const struct field * p_field)) \
   BIND_ACTION(void, printMatrix, (const char * functionName, const struct matrix * p_matrix)) \
   BIND_ACTION(void, printTensor, (const char * functionName, const struct tensor * p_tensor)) \
   BIND_ACTION(unsigned long, getNumberOfVariables, (const struct WrapperExchangedData * p_exchangedData, unsigned long type)) \
