@@ -21,10 +21,10 @@
 #include "OTdebug.h"
 #include "OTconfig.hxx"
 
-#ifdef HAVE_PTHREAD_H
+#ifdef OPENTURNS_HAVE_PTHREAD_H
 #include "OTthread.hxx"
 #include <signal.h>
-#endif /* HAVE_PTHREAD_H */
+#endif /* OPENTURNS_HAVE_PTHREAD_H */
 
 BEGIN_C_DECLS
 
@@ -102,9 +102,9 @@ struct sample {
 
 
 /**
- * @struct timeseries
+ * @struct field
  *
- * This structure holds the timeseries that is consumed or produced
+ * This structure holds the field that is consumed or produced
  * by the internal function.
  * Remember to allocate or free the data_ pointer. The memory management
  * policy is : When you allocate memory, you have to deallocate it !
@@ -112,10 +112,10 @@ struct sample {
  * to a function, the function should not free the memory when called,
  * so you MUST free it when the function returns. OK ?
  */
-struct timeseries {
+struct field {
   unsigned long size_;      /* size of data sample */
-  unsigned long dimension_; /* dimension of data sample. Important note: see TimeSeries.hxx */
-  double * data_;           /* data of the timeseries ordered as a vector */
+  unsigned long dimension_; /* dimension of data sample. Important note: see Field.hxx */
+  double * data_;           /* data of the field ordered as a vector */
 };
 
 
@@ -264,18 +264,6 @@ struct PlatformConfiguration {
 };
 
 
-/**
- * @struct FrameworkData
- *
- * This structure contains some information needed by an possible englobing framework (like Salome).
- */
-struct FrameworkData {
-  long studyid_; /* The id of the study */
-  char * studycase_; /* The entry of the case in the study designated by its id */
-  char * componentname_; /* The name of the solver component */
-};
-
-
 /**
  * @struct WrapperExchangedData
  *
@@ -287,7 +275,6 @@ struct WrapperExchangedData {
   struct WrapperVariableList   * variableList_; /* A chained list of variables for the wrapper */
   struct WrapperConfiguration  * parameters_;   /* The configuration of the wrapper */
   struct PlatformConfiguration * platform_;     /* The configuration of the platform */
-  struct FrameworkData         * framework_;    /* The data needed by an englobing framework */
   pthread_mutex_t              * p_lock_;       /* The mutex that locks this structure */
 };
 
@@ -339,10 +326,10 @@ typedef const struct WrapperExchangedData *  EXCHANGEDDATA;
 typedef       struct WrapperInformation   *  INFORMATION;
 typedef const struct point                *  INPOINT;
 typedef const struct sample               *  INSAMPLE;
-typedef const struct timeseries           *  INTIMESERIES;
+typedef const struct field           *  INFIELD;
 typedef       struct point                *  OUTPOINT;
 typedef       struct sample               *  OUTSAMPLE;
-typedef       struct timeseries           *  OUTTIMESERIES;
+typedef       struct field           *  OUTFIELD;
 typedef       struct matrix               *  OUTMATRIX;
 typedef       struct tensor               *  OUTTENSOR;
 
@@ -354,7 +341,7 @@ typedef RETURNCODE ( * GetWrapperInformationFunctionPointer )(     STATE, INFORM
 typedef RETURNCODE ( * InitializationFunctionPointer        )(     STATE,                              EXCHANGEDDATA, ERROR );
 typedef RETURNCODE ( * ExecutionFunctionPointer             )(     STATE, INPOINT,      OUTPOINT,      EXCHANGEDDATA, ERROR );
 typedef RETURNCODE ( * ExecutionSampleFunctionPointer       )(     STATE, INSAMPLE,     OUTSAMPLE,     EXCHANGEDDATA, ERROR );
-typedef RETURNCODE ( * ExecutionTimeSeriesFunctionPointer   )(     STATE, INTIMESERIES, OUTTIMESERIES, EXCHANGEDDATA, ERROR );
+typedef RETURNCODE ( * ExecutionFieldFunctionPointer   )(     STATE, INFIELD, OUTFIELD, EXCHANGEDDATA, ERROR );
 typedef RETURNCODE ( * GradientFunctionPointer              )(     STATE, INPOINT,      OUTMATRIX,     EXCHANGEDDATA, ERROR );
 typedef RETURNCODE ( * HessianFunctionPointer               )(     STATE, INPOINT,      OUTTENSOR,     EXCHANGEDDATA, ERROR );
 typedef RETURNCODE ( * FinalizationFunctionPointer          )(     STATE,                              EXCHANGEDDATA, ERROR );
