@@ -22,8 +22,9 @@
 #include <stdlib.h>
 #include <assert.h>
 #include "OTdebug.h"
+#include "OTconfig.hxx"
 
-#ifdef HAVE_PTHREAD_H
+#ifdef OPENTURNS_HAVE_PTHREAD_H
 #include "OTthread.hxx"
 #include <signal.h>
 #define CHECK_MULTITHREAD
@@ -163,20 +164,20 @@
 #define INSAMPLE_VALUES( i )  (&(inSample->data_[  (i) * inSample->size_  ]))
 #define OUTSAMPLE_VALUES( i ) (&(outSample->data_[ (i) * outSample->size_ ]))
 
-#define INTIMESERIES_ARRAY  (inTimeSeries->data_)
-#define OUTTIMESERIES_ARRAY (outTimeSeries->data_)
+#define INFIELD_ARRAY  (inField->data_)
+#define OUTFIELD_ARRAY (outField->data_)
 
-#define INTIMESERIES_TIME( i )  (inTimeSeries->data_[  (i) * inTimeSeries->size_  ])
-#define OUTTIMESERIES_TIME( i ) (outTimeSeries->data_[ (i) * outTimeSeries->size_ ])
+#define INFIELD_TIME( i )  (inField->data_[  (i) * inField->size_  ])
+#define OUTFIELD_TIME( i ) (outField->data_[ (i) * outField->size_ ])
 
-#define INTIMESERIES_VALUES( i )  (&(inTimeSeries->data_[  (i) * inTimeSeries->size_  + 1 ]))
-#define OUTTIMESERIES_VALUES( i ) (&(outTimeSeries->data_[ (i) * outTimeSeries->size_ + 1 ]))
+#define INFIELD_VALUES( i )  (&(inField->data_[  (i) * inField->size_  + 1 ]))
+#define OUTFIELD_VALUES( i ) (&(outField->data_[ (i) * outField->size_ + 1 ]))
 
-#define INTIMESERIES_SIZE  (inTimeSeries->size_)
-#define OUTTIMESERIES_SIZE (outTimeSeries->size_)
+#define INFIELD_SIZE  (inField->size_)
+#define OUTFIELD_SIZE (outField->size_)
 
-#define INTIMESERIES_DIMENSION  (inTimeSeries->dimension_)
-#define OUTTIMESERIES_DIMENSION (outTimeSeries->dimension_)
+#define INFIELD_DIMENSION  (inField->dimension_)
+#define OUTFIELD_DIMENSION (outField->dimension_)
 
 
 /***************************************************************************************
@@ -374,23 +375,23 @@
   }
 
 
-#define FUNC_EXEC_TIMESERIES( name , code )     FUNC_EXEC_TIMESERIES_DEF( name, code )
-#define FUNC_EXEC_TIMESERIES_DEF( name , code )                         \
+#define FUNC_EXEC_FIELD( name , code )     FUNC_EXEC_FIELD_DEF( name, code )
+#define FUNC_EXEC_FIELD_DEF( name , code )                         \
   C_DECL                                                                \
-  RETURNCODE func_exec_timeseries_ ## name (STATE p_state,              \
-                                            INTIMESERIES inTimeSeries,  \
-                                            OUTTIMESERIES outTimeSeries, \
-                                            EXCHANGEDDATA p_exchangedData, \
-                                            ERROR p_error)              \
+  RETURNCODE func_exec_field_ ## name (STATE p_state,              \
+				       INFIELD inField,		   \
+				       OUTFIELD outField,		\
+				       EXCHANGEDDATA p_exchangedData,	\
+				       ERROR p_error)			\
   {                                                                     \
-    const char FUNCTIONNAME[] UNUSED = "func_exec_timeseries_" #name ;  \
+    const char FUNCTIONNAME[] UNUSED = "func_exec_field_" #name ;  \
     dbg_printEntrance(FUNCTIONNAME);                                    \
     dbg_printState(FUNCTIONNAME, p_state);                              \
-    dbg_printTimeseries(FUNCTIONNAME, inTimeSeries);                    \
+    dbg_printField(FUNCTIONNAME, inField);                    \
                                                                         \
     code ;                                                              \
                                                                         \
-    dbg_printTimeseries(FUNCTIONNAME, outTimeSeries);                   \
+    dbg_printField(FUNCTIONNAME, outField);                   \
     dbg_printExit(FUNCTIONNAME);                                        \
                                                                         \
     return WRAPPER_OK;                                                  \
