@@ -3,7 +3,7 @@
  *  @file  XMLStorageManager.cxx
  *  @brief XMLStorageManager provides an interface for different storage classes
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,7 @@
 #include "Log.hxx"
 #include "XMLToolbox.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "OTconfig.hxx"
 
 #ifndef WIN32
 #ifndef SWIG
@@ -136,7 +137,7 @@ struct XMLStorageManagerState : public StorageManager::InternalObject
   }
   virtual String __repr__() const
   {
-    return OSS() << "XMLStorageManagerState { root = <" << root_
+    return OSS(true) << "XMLStorageManagerState { root = <" << root_
            << ">, current_ = <" << current_ << ">}";
   }
   virtual String __str__(const String & offset) const
@@ -742,7 +743,7 @@ void XMLStorageManager::readIndexedValue(Pointer<InternalObject> & p_obj,
 }
 
 
-#ifndef __LP64__
+#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
 /************ Type = Unsigned64BitsInteger ************/
 
 /* Add an attribute to an internal object */
