@@ -5,7 +5,7 @@
  *         form a numerical math evaluation implementation by using centered
  *         finite difference formula.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,11 +30,8 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(CenteredFiniteDifferenceGradient);
 
-
 static Factory<CenteredFiniteDifferenceGradient> RegisteredFactory("CenteredFiniteDifferenceGradient");
 
 /* Default constructor */
@@ -77,7 +74,7 @@ CenteredFiniteDifferenceGradient * CenteredFiniteDifferenceGradient::clone() con
 /* String converter */
 String CenteredFiniteDifferenceGradient::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << CenteredFiniteDifferenceGradient::GetClassName()
       << " name=" << getName()
       << " epsilon=" << getEpsilon().__repr__()
