@@ -5,7 +5,7 @@
  *         form a numerical math evaluation implementation by using centered
  *         finite difference formula.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,7 +34,6 @@ CLASSNAMEINIT(CenteredFiniteDifferenceHessian);
 
 static Factory<CenteredFiniteDifferenceHessian> RegisteredFactory("CenteredFiniteDifferenceHessian");
 
-
 /* Default constructor */
 CenteredFiniteDifferenceHessian::CenteredFiniteDifferenceHessian()
   : FiniteDifferenceHessian()
@@ -81,7 +80,7 @@ Bool CenteredFiniteDifferenceHessian::operator ==(const CenteredFiniteDifference
 /* String converter */
 String CenteredFiniteDifferenceHessian::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << CenteredFiniteDifferenceHessian::GetClassName()
       << " name=" << getName()
       << " epsilon=" << getEpsilon().__repr__()
@@ -140,6 +139,7 @@ SymmetricTensor CenteredFiniteDifferenceHessian::hessian(const NumericalPoint &
   SymmetricTensor result(inputDimension, outputDimension);
   UnsignedLong diagonalOffset(2 * inputDimension * (inputDimension - 1));
   NumericalScalar scale;
+  UnsignedLong offDiagonalOffset(0);
   for (UnsignedLong i = 0; i < inputDimension; ++i)
   {
     // Diagonal term
@@ -150,7 +150,6 @@ SymmetricTensor CenteredFiniteDifferenceHessian::hessian(const NumericalPoint &
       result(i, i, k) = scale * (gridValues[diagonalOffset + 2 * i][k] - 2.0 * center[k] + gridValues[diagonalOffset + 2 * i + 1][k]);
     } // k
     // Compute only the upper part of each sheet, as the hessian is symmetric
-    UnsignedLong offDiagonalOffset(2 * i * (i - 1));
     for (UnsignedLong j = 0; j < i; ++j)
     {
       scale = 1.0 / (4.0 * step[i] * step[j]);
@@ -158,6 +157,7 @@ SymmetricTensor CenteredFiniteDifferenceHessian::hessian(const NumericalPoint &
         /* result(i, j, k) = (f_k(x + e_i + e_j) - f_k(x + e_i - e_j) + f_k(x - e_i - e_j) - f_k(x - e_i + e_j)) / (4 * e_i * e_j) ~ d2f_k / dx_idx_j */
         result(i, j, k) = scale * (gridValues[offDiagonalOffset + 4 * j][k] - gridValues[offDiagonalOffset + 4 * j + 1][k] + gridValues[offDiagonalOffset + 4 * j + 2][k] - gridValues[offDiagonalOffset + 4 * j + 3][k]);
     } // j
+    offDiagonalOffset += 4 * i;
   } // i
   return result;
 }
