@@ -11,41 +11,31 @@
 #ifndef __EV3COMMONH__
 #define __EV3COMMONH__
 
-#define RCS12 "$Id: common.h,v 1.2 2006/07/30 05:36:44 liberti Exp liberti $"
-
 #define NOVARIABLE -1
 #define LARGE 1E10
+#define NOTVARNAME "_var_not_found_"
 
-#include <cassert>
+namespace Ev3
+{
+typedef int Int;
 
-#ifdef WIN32
-/* windows.h define a huge numbre of macro... */
-#undef DIFFERENCE
-#undef CONST
-#undef ERROR
-#undef interface
-#undef NONE
-#endif
+// various operator types
+enum OperatorType
+{
+  SUM, DIFFERENCE, PRODUCT, FRACTION, POWER,
+  PLUS, MINUS, SIN, COS, TAN, ASIN, ACOS,
+  ATAN, SINH, COSH, TANH, ASINH, ACOSH,
+  ATANH, LOG2, LOG10, LOG, LN, LNGAMMA,
+  GAMMA, EXP, ERF, ERFC, SQRT, CBRT,
+  BESSELJ0, BESSELJ1, BESSELY0, BESSELY1,
+  SIGN, RINT, ABS, COT, COTH,
+  VAR, CONST,
+  ERROR
+};
 
-namespace Ev3 {
-  typedef int Int;
-
-  // various operator types
-  enum OperatorType {
-    SUM, DIFFERENCE, PRODUCT, FRACTION, POWER,
-    PLUS, MINUS, SIN, COS, TAN, ASIN, ACOS,
-    ATAN, SINH, COSH, TANH, ASINH, ACOSH,
-    ATANH, LOG2, LOG10, LOG, LN, LNGAMMA,
-    GAMMA, EXP, ERF, ERFC, SQRT, CBRT,
-    BESSELJ0, BESSELJ1, BESSELY0, BESSELY1,
-    SIGN, RINT, ABS, COT, COTH,
-    VAR, CONST,
-    ERROR
-  };
-
-  // utility functions
-  extern double Ev3NearZero(void);
-  extern double Ev3Infinity(void);
+// utility functions
+extern double Ev3NearZero(void);
+extern double Ev3Infinity(void);
 
 } /* namespace Ev3 */
 #endif /* __EV3COMMONH__ */
