@@ -5,7 +5,7 @@
  *         form a numerical math evaluation implementation by using centered
  *         finite difference formula.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,10 +30,9 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(FiniteDifferenceGradient);
 
+static Factory<FiniteDifferenceGradient> RegisteredFactory("FiniteDifferenceGradient");
 
 /* Default constructor */
 FiniteDifferenceGradient::FiniteDifferenceGradient()
@@ -46,9 +45,9 @@ FiniteDifferenceGradient::FiniteDifferenceGradient()
 FiniteDifferenceGradient::FiniteDifferenceGradient(
   const NumericalPoint & epsilon,
   const EvaluationImplementation & p_evaluation)
-  : NumericalMathGradientImplementation(),
-    p_evaluation_(p_evaluation),
-    finiteDifferenceStep_(epsilon)
+  : NumericalMathGradientImplementation()
+  , p_evaluation_(p_evaluation)
+  , finiteDifferenceStep_(epsilon)
 {
   /* Check if the dimension of the constant term is compatible with the linear and quadratic terms */
   if (epsilon.getDimension() != p_evaluation->getInputDimension())
@@ -65,24 +64,22 @@ FiniteDifferenceGradient::FiniteDifferenceGradient(
 /* SecondParameter constructor */
 FiniteDifferenceGradient::FiniteDifferenceGradient(const NumericalScalar epsilon,
     const EvaluationImplementation & p_evaluation)
-  :
-  NumericalMathGradientImplementation(),
-  p_evaluation_(p_evaluation),
-  finiteDifferenceStep_(NumericalPoint(p_evaluation->getInputDimension(), epsilon))
+  : NumericalMathGradientImplementation()
+  , p_evaluation_(p_evaluation)
+  , finiteDifferenceStep_(NumericalPoint(p_evaluation->getInputDimension(), epsilon))
 {
   // Check if epsilon is exactly zero
   if (epsilon == 0.0)
     throw InvalidArgumentException(HERE) << "The given scalar epsilon is equal to 0.0";
 }
 
-/*  Parameter constructor  with FiniteDifferenceStep*/
+/*  Parameter constructor with FiniteDifferenceStep*/
 FiniteDifferenceGradient::FiniteDifferenceGradient(
   const FiniteDifferenceStep & finiteDifferenceStep,
   const EvaluationImplementation & p_evaluation)
-  :
-  NumericalMathGradientImplementation(),
-  p_evaluation_(p_evaluation),
-  finiteDifferenceStep_(finiteDifferenceStep)
+  : NumericalMathGradientImplementation()
+  , p_evaluation_(p_evaluation)
+  , finiteDifferenceStep_(finiteDifferenceStep)
 {
   NumericalPoint epsilon(getEpsilon());
   //Check if the dimension of the constant term is compatible with the linear and quadratic terms
@@ -97,6 +94,12 @@ FiniteDifferenceGradient::FiniteDifferenceGradient(
   }
 }
 
+/* Virtual constructor */
+FiniteDifferenceGradient * FiniteDifferenceGradient::clone() const
+{
+  return new FiniteDifferenceGradient(*this);
+}
+
 /* Comparison operator */
 Bool FiniteDifferenceGradient::operator ==(const FiniteDifferenceGradient & other) const
 {
@@ -148,6 +151,12 @@ FiniteDifferenceStep FiniteDifferenceGradient::getFiniteDifferenceStep() const
   return finiteDifferenceStep_;
 }
 
+/* Evaluation method */
+Matrix FiniteDifferenceGradient::gradient(const NumericalPoint & inP) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* Method save() stores the object through the StorageManager */
 void FiniteDifferenceGradient::save(Advocate & adv) const
 {
