@@ -5,7 +5,7 @@
  *         form a numerical math evaluation implementation by using centered
  *         finite difference formula.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,6 +32,8 @@ BEGIN_NAMESPACE_OPENTURNS
 
 CLASSNAMEINIT(FiniteDifferenceHessian);
 
+static Factory<FiniteDifferenceHessian> RegisteredFactory("FiniteDifferenceHessian");
+
 /* Default constructor */
 FiniteDifferenceHessian::FiniteDifferenceHessian()
   : NumericalMathHessianImplementation()
@@ -67,7 +69,7 @@ FiniteDifferenceHessian::FiniteDifferenceHessian(const NumericalScalar epsilon,
   if (epsilon == 0.0) throw InvalidArgumentException(HERE) << "The given scalar epsilon is equal to 0.0";
 }
 
-/*  Parameter constructor  with FiniteDifferenceStep*/
+/*  Parameter constructor with FiniteDifferenceStep*/
 FiniteDifferenceHessian::FiniteDifferenceHessian(
   const FiniteDifferenceStep & finiteDifferenceStep,
   const EvaluationImplementation & p_evaluation)
@@ -84,6 +86,12 @@ FiniteDifferenceHessian::FiniteDifferenceHessian(
     if (epsilon[i] == 0.0) throw InvalidArgumentException(HERE) << "At least one of the components of epsilon is equal to 0.0, namely component " << i;
 }
 
+/* Virtual constructor */
+FiniteDifferenceHessian * FiniteDifferenceHessian::clone() const
+{
+  return new FiniteDifferenceHessian(*this);
+}
+
 /* Comparison operator */
 Bool FiniteDifferenceHessian::operator ==(const FiniteDifferenceHessian & other) const
 {
@@ -137,6 +145,12 @@ FiniteDifferenceStep FiniteDifferenceHessian::getFiniteDifferenceStep() const
   return finiteDifferenceStep_;
 }
 
+/* Evaluation method */
+SymmetricTensor FiniteDifferenceHessian::hessian(const NumericalPoint & inP) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* Method save() stores the object through the StorageManager */
 void FiniteDifferenceHessian::save(Advocate & adv) const
 {
