@@ -3,7 +3,7 @@
  *  @file  FiniteDifferenceStepImplementation.cxx
  *  @brief Implementation of finite difference step
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,30 +28,39 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(FiniteDifferenceStepImplementation);
 
-//       static Factory<FiniteDifferenceStepImplementation> RegisteredFactory("FiniteDifferenceStepImplementation");
+static Factory<FiniteDifferenceStepImplementation> RegisteredFactory("FiniteDifferenceStepImplementation");
 
+/* Default constructor */
 FiniteDifferenceStepImplementation::FiniteDifferenceStepImplementation()
   : PersistentObject()
+  , epsilon_(1.0)
 {
+  // Nothing to do
 }
 
+/* Parameters constructor */
 FiniteDifferenceStepImplementation::FiniteDifferenceStepImplementation(const NumericalPoint & epsilon)
-  : PersistentObject(),
-    epsilon_(epsilon)
+  : PersistentObject()
+  , epsilon_(epsilon)
 {
+  // Nothing to do
 }
 
+/* Virtual constructor */
+FiniteDifferenceStepImplementation * FiniteDifferenceStepImplementation::clone() const
+{
+  return new FiniteDifferenceStepImplementation(*this);
+}
+
+/* Epsilon accessor */
 void FiniteDifferenceStepImplementation::setEpsilon(const NumericalPoint & epsilon)
 {
   const UnsignedLong dimension( epsilon.getDimension() );
   for (UnsignedLong i = 0; i < dimension; ++ i)
   {
-    if (epsilon[i] < SpecFunc::MinNumericalScalar ) throw InvalidArgumentException(HERE) << "Nul epsilon for component " << i;
+    if (epsilon[i] < SpecFunc::MinNumericalScalar ) throw InvalidArgumentException(HERE) << "Null epsilon for component " << i;
   }
   epsilon_ = epsilon;
 }
@@ -61,6 +70,12 @@ NumericalPoint FiniteDifferenceStepImplementation::getEpsilon() const
   return epsilon_;
 }
 
+/* Evaluation operator */
+NumericalPoint FiniteDifferenceStepImplementation::operator()(const NumericalPoint & inP) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* String converter */
 String FiniteDifferenceStepImplementation::__repr__() const
 {
