@@ -5,7 +5,7 @@
  *         form a numerical math evaluation implementation by using noncentered
  *         finite difference formula.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,14 +28,10 @@
 #include "NonCenteredFiniteDifferenceGradient.hxx"
 #include "PersistentObjectFactory.hxx"
 
-
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(NonCenteredFiniteDifferenceGradient);
 
-
 static Factory<NonCenteredFiniteDifferenceGradient> RegisteredFactory("NonCenteredFiniteDifferenceGradient");
 
 /* Default constructor */
@@ -77,7 +73,7 @@ NonCenteredFiniteDifferenceGradient * NonCenteredFiniteDifferenceGradient::clone
 /* String converter */
 String NonCenteredFiniteDifferenceGradient::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NonCenteredFiniteDifferenceGradient::GetClassName()
       << " name=" << getName()
       << " epsilon=" << getEpsilon()
