@@ -3,7 +3,7 @@
  *  @file  AggregatedEvaluationImplementation.cxx
  *  @brief The evaluation part of an aggregation of functions from R^n to R^p_1,...,R^n to R^p_k
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,9 +36,9 @@ static Factory<AggregatedNumericalMathEvaluationImplementation> RegisteredFactor
 
 /* Default constructor */
 AggregatedNumericalMathEvaluationImplementation::AggregatedNumericalMathEvaluationImplementation()
-  : NumericalMathEvaluationImplementation(),
-    functionsCollection_(0),
-    outputDimension_(0)
+  : NumericalMathEvaluationImplementation()
+  , functionsCollection_(0)
+  , outputDimension_(0)
 {
   // Nothing to do
 }
@@ -46,9 +46,9 @@ AggregatedNumericalMathEvaluationImplementation::AggregatedNumericalMathEvaluati
 
 /* Parameters constructor */
 AggregatedNumericalMathEvaluationImplementation::AggregatedNumericalMathEvaluationImplementation(const NumericalMathFunctionCollection & functionsCollection)
-  : NumericalMathEvaluationImplementation(),
-    functionsCollection_(0),
-    outputDimension_(0)
+  : NumericalMathEvaluationImplementation()
+  , functionsCollection_(0)
+  , outputDimension_(0)
 {
   setFunctionsCollection(functionsCollection);
 }
@@ -64,13 +64,13 @@ AggregatedNumericalMathEvaluationImplementation * AggregatedNumericalMathEvaluat
 /* String converter */
 String AggregatedNumericalMathEvaluationImplementation::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " functions=" << functionsCollection_;
 }
 
 String AggregatedNumericalMathEvaluationImplementation::__str__(const String & offset) const
 {
-  return OSS() << functionsCollection_.__str__(offset);
+  return OSS(false) << functionsCollection_.__str__(offset);
 }
 
 
@@ -224,13 +224,43 @@ UnsignedLong AggregatedNumericalMathEvaluationImplementation::getOutputDimension
 /* Gradient according to the marginal parameters */
 Matrix AggregatedNumericalMathEvaluationImplementation::parametersGradient(const NumericalPoint & inP) const
 {
-  throw NotYetImplementedException(HERE);
+  Matrix result(getParameters().getDimension(), getOutputDimension());
+  const UnsignedLong size(functionsCollection_.getSize());
+  UnsignedLong rowShift(0);
+  UnsignedLong columnShift(0);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    const Matrix currentGradient(functionsCollection_[i].parametersGradient(functionsCollection_[i].getParameters()));
+    const UnsignedLong currentRowDim(currentGradient.getNbRows());
+    const UnsignedLong currentColumnDim(currentGradient.getNbColumns());
+    for (UnsignedLong j = 0; j < currentRowDim; ++j)
+      for (UnsignedLong k = 0; k < currentColumnDim; ++k)
+        result(rowShift + j, columnShift + k) = currentGradient(j, k);
+    rowShift += currentRowDim;
+    columnShift += currentColumnDim;
+  }
+  return result;
 }
 
 /* Parameters value and description accessor */
 NumericalPointWithDescription AggregatedNumericalMathEvaluationImplementation::getParameters() const
 {
-  throw NotYetImplementedException(HERE);
+  NumericalPointWithDescription parametersValues(0);
+  Description parametersDescription(0);
+  const UnsignedLong size(functionsCollection_.getSize());
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    const NumericalPointWithDescription currentParameters(functionsCollection_[i].getParameters());
+    const Description currentDescription(currentParameters.getDescription());
+    const UnsignedLong dimension(currentParameters.getDimension());
+    for (UnsignedLong j = 0; j < dimension; ++j)
+    {
+      parametersValues.add(currentParameters[j]);
+      parametersDescription.add(currentDescription[j]);
+    }
+  }
+  parametersValues.setDescription(parametersDescription);
+  return parametersValues;
 }
 
 /* Method save() stores the object through the StorageManager */
