@@ -3,7 +3,7 @@
  * @file  AnalyticalNumericalMathEvaluationImplementation.cxx
  * @brief The class that implements the evaluation of an analytical function.
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -19,6 +19,7 @@
 #include "AnalyticalNumericalMathEvaluationImplementation.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Os.hxx"
+#include "OTconfig.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -29,13 +30,13 @@ static Factory<AnalyticalNumericalMathEvaluationImplementation> RegisteredFactor
 
 /* Default constructor */
 AnalyticalNumericalMathEvaluationImplementation::AnalyticalNumericalMathEvaluationImplementation()
-  : NumericalMathEvaluationImplementation(),
-    isInitialized_(false),
-    inputVariables_(0),
-    inputVariablesNames_(),
-    outputVariablesNames_(),
-    formulas_(),
-    parsers_(0)
+  : NumericalMathEvaluationImplementation()
+  , isInitialized_(false)
+  , inputVariables_(0, 0)
+  , inputVariablesNames_()
+  , outputVariablesNames_()
+  , formulas_()
+  , parsers_(0)
 {
   // Nothing to do
 } // AnalyticalNumericalMathEvaluationImplementation
@@ -44,26 +45,22 @@ AnalyticalNumericalMathEvaluationImplementation::AnalyticalNumericalMathEvaluati
 AnalyticalNumericalMathEvaluationImplementation::AnalyticalNumericalMathEvaluationImplementation(const Description & inputVariablesNames,
     const Description & outputVariablesNames,
     const Description & formulas)
-  : NumericalMathEvaluationImplementation(),
-    isInitialized_(false),
-    inputVariables_(NumericalPoint(inputVariablesNames.getSize()).getCollection()),
-    inputVariablesNames_(inputVariablesNames),
-    outputVariablesNames_(outputVariablesNames),
-    formulas_(formulas),
-    parsers_(ParserCollection(outputVariablesNames_.getSize()))
+  : NumericalMathEvaluationImplementation()
+  , isInitialized_(false)
+  , inputVariables_(inputVariablesNames.getSize(), 0)
+  , inputVariablesNames_(inputVariablesNames)
+  , outputVariablesNames_(outputVariablesNames)
+  , formulas_(formulas)
+  , parsers_(ParserCollection(outputVariablesNames_.getSize()))
 {
   if (outputVariablesNames.getSize() != formulas.getSize())
     throw InvalidDimensionException(HERE) << "The number of outputVariablesNames (" << outputVariablesNames.getSize()
                                           << ") does not match the number of formulas (" << formulas.getSize() << ")";
 
   // Call the initialize() method in order to check the parameters w.r.t. muParser
-  initialize();
-  Description description(inputVariablesNames_);
-  const UnsignedLong outputSize(outputVariablesNames_.getSize());
-  for (UnsignedLong outputVariableIndex = 0; outputVariableIndex < outputSize; ++outputVariableIndex)
-    description.add(outputVariablesNames_[outputVariableIndex]);
-  // Set the description
-  setDescription(description);
+  initialize(1);
+  setInputDescription(inputVariablesNames_);
+  setOutputDescription(outputVariablesNames_);
 } // AnalyticalNumericalMathEvaluationImplementation
 
 
@@ -85,7 +82,7 @@ Bool AnalyticalNumericalMathEvaluationImplementation::operator ==(const Analytic
 /* String converter */
 String AnalyticalNumericalMathEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << AnalyticalNumericalMathEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " inputVariablesNames=" << inputVariablesNames_
@@ -126,23 +123,36 @@ String AnalyticalNumericalMathEvaluationImplementation::__str__(const String & o
 }
 
 /* Must initialize the parser at the first call to operator() as the
-   reference associated with the variables may have change after the construction */
-void AnalyticalNumericalMathEvaluationImplementation::initialize() const
+   reference associated with the variables may have change after the construction.
+   Initializing is necessary when the arguments size is different between two calls to operator().
+   inputSize is the number of values of each input variables.
+   So, if operator() method has a NumericalPoint as argument, inputSize is 1*/
+void AnalyticalNumericalMathEvaluationImplementation::initialize(UnsignedLong inputSize) const
 {
+  if (inputSize > inputVariables_.getDimension()) isInitialized_ = false;
   if (isInitialized_) return;
-  const UnsignedLong inputSize(inputVariablesNames_.getSize());
+  const UnsignedLong inputDimension(inputVariablesNames_.getSize());
   const UnsignedLong outputSize(outputVariablesNames_.getSize());
   try
   {
+    // inputVariables_ is the transposed sample (resp. NumericalPoint) of the operator() method sample
+    // (resp. NumericalPoint) argument.
+    inputVariables_ = NumericalSample(inputDimension, inputSize);
     // For each parser of a formula, do
     for (UnsignedLong outputVariableIndex = 0; outputVariableIndex < outputSize; ++outputVariableIndex)
     {
       // First, define all the variable names and associate them
       // to the corresponding component of the input vector
-      for(UnsignedLong inputVariableIndex = 0; inputVariableIndex < inputSize; ++inputVariableIndex)
+      for(UnsignedLong inputVariableIndex = 0; inputVariableIndex < inputDimension; ++inputVariableIndex)
       {
-        parsers_[outputVariableIndex].DefineVar(inputVariablesNames_[inputVariableIndex].c_str(), &inputVariables_[inputVariableIndex]);
+        // DefineVar defines all the values given to variables
+        parsers_[outputVariableIndex].DefineVar(inputVariablesNames_[inputVariableIndex].c_str(), &inputVariables_[inputVariableIndex][0]);
       }
+    }
+
+    // For each parser of a formula, do
+    for (UnsignedLong outputVariableIndex = 0; outputVariableIndex < outputSize; ++outputVariableIndex)
+    {
       // Second, define the several formulas
       parsers_[outputVariableIndex].SetExpr(formulas_[outputVariableIndex].c_str());
     }
@@ -158,10 +168,12 @@ void AnalyticalNumericalMathEvaluationImplementation::initialize() const
 NumericalPoint AnalyticalNumericalMathEvaluationImplementation::operator() (const NumericalPoint & inP) const
 {
   if (inP.getDimension() != getInputDimension()) throw InvalidArgumentException(HERE) << "Error: trying to evaluate a NumericalMathFunction with an argument of invalid dimension";
-  if (!isInitialized_) initialize();
+  initialize(1);
   NumericalPoint result(getOutputDimension());
-  ++callsNumber_;
-  for (UnsignedLong i = 0; i < inP.getDimension(); ++i) inputVariables_[i] = inP[i];
+  ++ callsNumber_;
+
+  for (UnsignedLong i = 0; i < inP.getDimension(); ++i) inputVariables_[i][0] = inP[i];
+
   try
   {
     for (UnsignedLong index = 0; index < result.getDimension(); ++index) result[index] = parsers_[index].Eval();
@@ -178,6 +190,38 @@ NumericalPoint AnalyticalNumericalMathEvaluationImplementation::operator() (cons
   return result;
 }
 
+/* Operator () */
+NumericalSample AnalyticalNumericalMathEvaluationImplementation::operator() (const NumericalSample & inS) const
+{
+  const UnsignedLong inputDimension(getInputDimension());
+  if (inS.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given sample has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inS.getDimension();
+  const UnsignedLong size(inS.getSize());
+  NumericalSample outSample(size, getOutputDimension());
+#ifdef OPENTURNS_HAVE_MUPARSER2
+  initialize(size);
+  callsNumber_ += size;
+  for(UnsignedLong inputVariableIndex = 0; inputVariableIndex < inputDimension; ++inputVariableIndex)
+  {
+    for (UnsignedLong i = 0; i < size; ++i) inputVariables_[inputVariableIndex][i] = inS[i][inputVariableIndex];
+  }
+  NumericalPoint evalResult(size);
+  for (UnsignedLong outputVariableIndex = 0; outputVariableIndex < getOutputDimension(); ++outputVariableIndex)
+  {
+    parsers_[outputVariableIndex].Eval(&evalResult[0], size);
+    for (UnsignedLong i = 0; i < size; ++i) outSample[i][outputVariableIndex] = evalResult[i];
+  }
+  if (isHistoryEnabled_)
+  {
+    inputStrategy_.store(inS);
+    outputStrategy_.store(outSample);
+  }
+#else
+  for (UnsignedLong i = 0; i < size; ++i) outSample[i] = operator()(inS[i]);
+#endif
+  outSample.setDescription(getOutputDescription());
+  return outSample;
+}
+
 /* Accessor for input point dimension */
 UnsignedLong AnalyticalNumericalMathEvaluationImplementation::getInputDimension() const
 {
