@@ -3,7 +3,7 @@
  * @file  AnalyticalNumericalMathGradientImplementation.cxx
  * @brief The class that implements the gradient of an analytical function.
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -74,7 +74,7 @@ Bool AnalyticalNumericalMathGradientImplementation::operator ==(const Analytical
 /* String converter */
 String AnalyticalNumericalMathGradientImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << AnalyticalNumericalMathGradientImplementation::GetClassName()
       << " name=" << getName()
       << " evaluation=" << evaluation_;
@@ -98,18 +98,17 @@ String AnalyticalNumericalMathGradientImplementation::__str__(const String & off
       const Description inputVariablesNames(evaluation_.getInputVariablesNames());
       const Description outputVariablesNames(evaluation_.getOutputVariablesNames());
       UnsignedLong length(0);
-      for (UnsignedLong i = 0; i < getInputDimension(); ++i)
+      const UnsignedLong iMax(getInputDimension());
+      const UnsignedLong jMax(getOutputDimension());
+      for (UnsignedLong i = 0; i < iMax; ++i)
       {
-        const UnsignedLong lI(inputVariablesNames[i].length());
-        for (UnsignedLong j = 0; j < getOutputDimension(); ++j)
-        {
-          const UnsignedLong l(lI + outputVariablesNames[j].length() + 8);
-          if (l > length) length = l;
-        }
+        const UnsignedLong lengthI(inputVariablesNames[i].length());
+        for (UnsignedLong j = 0; j < jMax; ++j)
+          length = std::max(length, lengthI + static_cast<UnsignedLong>(outputVariablesNames[j].length()) + 8);
       }
-      for (UnsignedLong j = 0; j < getOutputDimension(); ++j)
+      for (UnsignedLong j = 0; j < jMax; ++j)
       {
-        for (UnsignedLong i = 0; i < getInputDimension(); ++i)
+        for (UnsignedLong i = 0; i < iMax; ++i)
         {
           oss << offset << "| " << std::setw(length) << ("d(" + outputVariablesNames[j] + ") / d(" + inputVariablesNames[i] + ")") << " = " << getFormula(i, j) << Os::GetEndOfLine();
         }
@@ -146,7 +145,15 @@ void AnalyticalNumericalMathGradientImplementation::initialize() const
       Ev3::ExpressionParser ev3Parser;
       // Initialize the variable indices in order to match the order of OpenTURNS in Ev3
       for (UnsignedLong inputVariableIndex = 0; inputVariableIndex < inputSize; ++inputVariableIndex) ev3Parser.SetVariableID(evaluation_.inputVariablesNames_[inputVariableIndex], inputVariableIndex);
-      Ev3::Expression ev3Expression(ev3Parser.Parse(evaluation_.formulas_[columnIndex].c_str(), nerr));
+      Ev3::Expression ev3Expression;
+      try
+      {
+        ev3Expression = ev3Parser.Parse(evaluation_.formulas_[columnIndex].c_str(), nerr);
+      }
+      catch (Ev3::ErrBase & exc)
+      {
+        throw InternalException(HERE) << exc.description_;
+      }
       if (nerr != 0) throw InvalidArgumentException(HERE) << "Error: cannot parse " << evaluation_.formulas_[columnIndex] << " with Ev3. No analytical gradient.";
       //                Ev3::Simplify(&ev3Expression);
       for (UnsignedLong rowIndex = 0; rowIndex < inputSize; ++rowIndex)
