@@ -3,7 +3,7 @@
  * @file  AnalyticalNumericalMathHessianImplementation.cxx
  * @brief The class that implements the Hessian of analytical functions.
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -76,7 +76,7 @@ Bool AnalyticalNumericalMathHessianImplementation::operator ==(const AnalyticalN
 /* String converter */
 String AnalyticalNumericalMathHessianImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << AnalyticalNumericalMathHessianImplementation::GetClassName()
       << " name=" << getName()
       << " evaluation=" << evaluation_;
@@ -100,23 +100,22 @@ String AnalyticalNumericalMathHessianImplementation::__str__(const String & offs
       const Description inputVariablesNames(evaluation_.getInputVariablesNames());
       const Description outputVariablesNames(evaluation_.getOutputVariablesNames());
       UnsignedLong length(0);
-      for (UnsignedLong k = 0; k < getOutputDimension(); ++k)
+      const UnsignedLong iMax(getInputDimension());
+      const UnsignedLong kMax(getOutputDimension());
+      for (UnsignedLong k = 0; k < kMax; ++k)
       {
-        const UnsignedLong lK(outputVariablesNames[k].length());
-        for (UnsignedLong i = 0; i < getInputDimension(); ++i)
+        const UnsignedLong lengthK(outputVariablesNames[k].length());
+        for (UnsignedLong i = 0; i < iMax; ++i)
         {
-          const UnsignedLong lI(inputVariablesNames[i].length());
+          const UnsignedLong lengthI(inputVariablesNames[i].length());
           // The diagonal term is always shorter than one of the off-diagonal terms
           for (UnsignedLong j = 0; j < i; ++j)
-          {
-            const UnsignedLong l(lI + lK + inputVariablesNames[k].length() + 14);
-            if (l > length) length = l;
-          }
+            length = std::max(length, lengthI + lengthK + static_cast<UnsignedLong>(inputVariablesNames[j].length()) + 14);
         } // For i
       } // For k
-      for (UnsignedLong k = 0; k < getOutputDimension(); ++k)
+      for (UnsignedLong k = 0; k < kMax; ++k)
       {
-        for (UnsignedLong i = 0; i < getInputDimension(); ++i)
+        for (UnsignedLong i = 0; i < iMax; ++i)
         {
           for (UnsignedLong j = 0; j < i; ++j)
           {
@@ -157,7 +156,15 @@ void AnalyticalNumericalMathHessianImplementation::initialize() const
       Ev3::ExpressionParser ev3Parser;
       // Initialize the variable indices in order to match the order of OpenTURNS in Ev3
       for (UnsignedLong inputVariableIndex = 0; inputVariableIndex < inputSize; ++inputVariableIndex) ev3Parser.SetVariableID(evaluation_.inputVariablesNames_[inputVariableIndex], inputVariableIndex);
-      Ev3::Expression ev3Expression = ev3Parser.Parse(evaluation_.formulas_[sheetIndex].c_str(), nerr);
+      Ev3::Expression ev3Expression;
+      try
+      {
+        ev3Expression = ev3Parser.Parse(evaluation_.formulas_[sheetIndex].c_str(), nerr);
+      }
+      catch (Ev3::ErrBase & exc)
+      {
+        throw InternalException(HERE) << exc.description_;
+      }
       if (nerr != 0) throw InvalidArgumentException(HERE) << "Error: cannot parse " << evaluation_.formulas_[sheetIndex] << " with Ev3. No analytical hessian.";
       //                Ev3::Simplify(&ev3Expression);
       for (UnsignedLong rowIndex = 0; rowIndex < inputSize; ++rowIndex)
