@@ -3,7 +3,7 @@
  *  @file  Basis.cxx
  *  @brief A collection of numerical math function
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,8 +27,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(Basis);
 
 static Factory<Basis> RegisteredFactory("Basis");
@@ -47,10 +45,16 @@ Basis::Basis(const Collection<NumericalMathFunction> & coll)
   // Nothing to do
 }
 
+/* Virtual constructor */
+Basis * Basis::clone() const
+{
+  return new Basis(*this);
+}
+
 /* String converter */
 String Basis::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " coll=" << PersistentCollection<NumericalMathFunction>::__repr__();
 }
 
