@@ -3,7 +3,7 @@
  *  @file  BasisSequence.cxx
  *  @brief A sequence of numerical math function collection
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -84,7 +84,7 @@ BasisSequence::operator PersistentCollection<Indices> () const
 /* String converter */
 String BasisSequence::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " implementation=" << getImplementation()->__repr__();
 }
 
