@@ -3,7 +3,7 @@
  *  @file  BasisSequenceFactoryImplementation.cxx
  *  @brief A factory for building BasisSequence objects
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,33 +21,37 @@
  *  @author schueller
  *  @date   2010-11-09 13:44:00 +0100 (Tue, 09 Nov 2010)
  */
+#include <limits>
 
 #include "BasisSequenceFactoryImplementation.hxx"
+#include "PersistentObjectFactory.hxx"
 #include "Exception.hxx"
-#include <limits>
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(BasisSequenceFactoryImplementation);
 
-
-
+static Factory<BasisSequenceFactoryImplementation> RegisteredFactory("BasisSequenceFactoryImplementation");
 
 /* Default constructor */
 BasisSequenceFactoryImplementation::BasisSequenceFactoryImplementation(const Bool verbose)
-  : PersistentObject(),
-    verbose_(verbose),
-    maximumRelativeConvergence_( std::numeric_limits< NumericalScalar >::min() )
+  : PersistentObject()
+  , verbose_(verbose)
+  , maximumRelativeConvergence_( std::numeric_limits< NumericalScalar >::min() )
 {
   // Nothing to do
 }
 
+/* Virtual constructor */
+BasisSequenceFactoryImplementation * BasisSequenceFactoryImplementation::clone() const
+{
+  return new BasisSequenceFactoryImplementation(*this);
+}
+
 /* String converter */
 String BasisSequenceFactoryImplementation::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " verbose=" << verbose_ ;
 }
 
