@@ -3,7 +3,7 @@
  *  @file  BasisSequenceImplementation.cxx
  *  @brief A sequence of numerical math function collection
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -65,7 +65,7 @@ BasisSequenceImplementation * BasisSequenceImplementation::clone() const
 /* String converter */
 String BasisSequenceImplementation::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " collection=" << PersistentCollection<Indices>::__repr__()
          << " masterBasis=" << masterBasis_;
 }
