@@ -3,7 +3,7 @@
  * @file  BoxCoxEvaluationImplementation.cxx
  * @brief Class for a Box cox implementation
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -68,7 +68,7 @@ Bool BoxCoxEvaluationImplementation::operator ==(const BoxCoxEvaluationImplement
 /* String converter */
 String BoxCoxEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << BoxCoxEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " dimension=" << getInputDimension()
@@ -81,8 +81,8 @@ String BoxCoxEvaluationImplementation::__repr__() const
 String BoxCoxEvaluationImplementation::__str__(const String & offset) const
 {
   OSS oss (false);
-  oss << "BoxCox(lambda=" << lambda_.__str__(offset)
-      << ", shift=" << shift_.__str__(offset)
+  oss << "BoxCox(lambda=" << lambda_
+      << ", shift=" << shift_
       << ")";
   return oss;
 }
