@@ -4,7 +4,7 @@
  * @brief The class that implements the composition between numerical
  *        math functions implementations
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -74,7 +74,7 @@ ComposedNumericalMathEvaluationImplementation::Implementation ComposedNumericalM
 /* String converter */
 String ComposedNumericalMathEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ComposedNumericalMathEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " leftFunction=" << p_leftFunction_->__repr__()
