@@ -3,7 +3,7 @@
  *  @file  ComposedNumericalMathFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,18 +31,15 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(ComposedNumericalMathFunction);
 
 static Factory<ComposedNumericalMathFunction> RegisteredFactory("ComposedNumericalMathFunction");
 
 /* Default constructor */
 ComposedNumericalMathFunction::ComposedNumericalMathFunction()
-  : NumericalMathFunctionImplementation(),
-    p_leftFunction_(),
-    p_rightFunction_()
+  : NumericalMathFunctionImplementation()
+  , p_leftFunction_()
+  , p_rightFunction_()
 {
   // Nothing to do
 }
@@ -52,9 +49,9 @@ ComposedNumericalMathFunction::ComposedNumericalMathFunction(const Implementatio
     const Implementation & p_right)
   : NumericalMathFunctionImplementation(new ComposedNumericalMathEvaluationImplementation(p_left->getEvaluationImplementation(), p_right->getEvaluationImplementation()),
                                         new NoNumericalMathGradientImplementation(),
-                                        new NoNumericalMathHessianImplementation()),
-  p_leftFunction_(p_left),
-  p_rightFunction_(p_right)
+                                        new NoNumericalMathHessianImplementation())
+  , p_leftFunction_(p_left)
+  , p_rightFunction_(p_right)
 {
   try
   {
@@ -72,7 +69,7 @@ ComposedNumericalMathFunction::ComposedNumericalMathFunction(const Implementatio
     HessianImplementation p_hessianImplementation(new ComposedNumericalMathHessianImplementation(p_left->getGradientImplementation(), p_left->getHessianImplementation(), p_right->getEvaluationImplementation(), p_right->getGradientImplementation(), p_right->getHessianImplementation()));
     setInitialHessianImplementation(p_hessianImplementation);
     setHessianImplementation(p_hessianImplementation);
-    setUseDefaultGradientImplementation(p_left->getUseDefaultHessianImplementation() || p_right->getUseDefaultHessianImplementation());
+    setUseDefaultHessianImplementation(p_left->getUseDefaultHessianImplementation() || p_right->getUseDefaultHessianImplementation());
   }
   catch(InvalidArgumentException & ex)
   {
@@ -85,9 +82,9 @@ ComposedNumericalMathFunction::ComposedNumericalMathFunction(const NumericalMath
     const NumericalMathFunction & right)
   : NumericalMathFunctionImplementation(new ComposedNumericalMathEvaluationImplementation(left.getEvaluationImplementation(), right.getEvaluationImplementation()),
                                         new NoNumericalMathGradientImplementation(),
-                                        new NoNumericalMathHessianImplementation()),
-  p_leftFunction_(left.getImplementation()),
-  p_rightFunction_(right.getImplementation())
+                                        new NoNumericalMathHessianImplementation())
+  , p_leftFunction_(left.getImplementation())
+  , p_rightFunction_(right.getImplementation())
 {
   try
   {
@@ -105,7 +102,7 @@ ComposedNumericalMathFunction::ComposedNumericalMathFunction(const NumericalMath
     HessianImplementation p_hessianImplementation(new ComposedNumericalMathHessianImplementation(left.getGradientImplementation(), left.getHessianImplementation(), right.getEvaluationImplementation(), right.getGradientImplementation(), right.getHessianImplementation()));
     setInitialHessianImplementation(p_hessianImplementation);
     setHessianImplementation(p_hessianImplementation);
-    setUseDefaultGradientImplementation(left.getUseDefaultHessianImplementation() || right.getUseDefaultHessianImplementation());
+    setUseDefaultHessianImplementation(left.getUseDefaultHessianImplementation() || right.getUseDefaultHessianImplementation());
   }
   catch(InvalidArgumentException & ex)
   {
