@@ -104,7 +104,7 @@ Bool ComputedNumericalMathEvaluationImplementation::operator ==(const ComputedNu
 /* String converter */
 String ComputedNumericalMathEvaluationImplementation::__repr__() const
 {
-  return OSS() << "class=" << ComputedNumericalMathEvaluationImplementation::GetClassName()
+  return OSS(true) << "class=" << ComputedNumericalMathEvaluationImplementation::GetClassName()
          << " name=" << getName();
 }
 
@@ -193,60 +193,76 @@ ComputedNumericalMathEvaluationImplementation::operator() (const NumericalSample
     NumericalSample outS( size, getOutputDimension() );
     // First, initialize the external code on first invocation
     if (callsNumber_ == 0) p_function_->initialize( p_state_ );
+    const bool useCache = p_cache_->isEnabled();
 
-
-    std::set<NumericalPoint> sortedValues;
-    for (UnsignedLong i = 0; i < size; ++ i )
+    NumericalSample toDo(0, getInputDimension());
+    if ( useCache )
     {
-      if ( p_cache_->isEnabled() )
+      std::set<NumericalPoint> uniqueValues;
+      for (UnsignedLong i = 0; i < size; ++ i )
       {
-        CacheKeyType inKey( inS[i].getCollection() );
-        if ( p_cache_->hasKey( inKey ) )
+        if ( useCache )
         {
-          outS[i] = NumericalPoint::ImplementationType( p_cache_->find( inKey ) );
+          CacheKeyType inKey( inS[i].getCollection() );
+          if ( p_cache_->hasKey( inKey ) )
+          {
+            outS[i] = NumericalPoint::ImplementationType( p_cache_->find( inKey ) );
+          }
+          else
+          {
+            uniqueValues.insert( inS[i] );
+          }
         }
         else
         {
-          sortedValues.insert( inS[i] );
+          uniqueValues.insert( inS[i] );
         }
       }
-      else
+      for(std::set<NumericalPoint>::const_iterator it = uniqueValues.begin(); it != uniqueValues.end(); ++it)
       {
-        sortedValues.insert( inS[i] );
+        // store unique values
+        toDo.add( *it );
       }
     }
-
-    NumericalSample toDo( 0, getInputDimension() );
-    for(std::set<NumericalPoint>::const_iterator it = sortedValues.begin(); it != sortedValues.end(); ++it)
+    else
     {
-      toDo.add( *it );
+      // compute all values, including duplicates
+      toDo = inS;
     }
 
+
     UnsignedLong toDoSize = toDo.getSize();
     CacheType tempCache( toDoSize );
-    tempCache.enable();
+    if ( useCache ) tempCache.enable();
 
     if ( toDoSize > 0 )
     {
       callsNumber_ += toDoSize;
       NumericalSample newOut(p_function_->execute( p_state_, toDo ));
-      for(UnsignedLong i = 0; i < toDoSize; ++i)
+      if ( useCache )
       {
-        tempCache.add( toDo[i].getCollection(), newOut[i].getCollection() );
+        for(UnsignedLong i = 0; i < toDoSize; ++i)
+        {
+          tempCache.add( toDo[i].getCollection(), newOut[i].getCollection() );
+        }
+      }
+      else
+      {
+        outS = newOut;
       }
     }
 
-    for( UnsignedLong i = 0; i < size; ++i )
+    if ( useCache )
     {
-      CacheKeyType inKey( inS[i].getCollection() );
-      if ( tempCache.hasKey( inKey ) )
+      // fill all the output values
+      for( UnsignedLong i = 0; i < size; ++i )
       {
-        outS[i] = NumericalPoint::ImplementationType( tempCache.find( inKey ) );
+        CacheKeyType inKey( inS[i].getCollection() );
+        if ( tempCache.hasKey( inKey ) )
+        {
+          outS[i] = NumericalPoint::ImplementationType( tempCache.find( inKey ) );
+        }
       }
-    }
-
-    if ( p_cache_->isEnabled() )
-    {
       p_cache_->merge( tempCache );
     }
 
