@@ -3,7 +3,7 @@
  *  @file  ComputedNumericalMathHessianImplementation.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -100,7 +100,7 @@ Bool ComputedNumericalMathHessianImplementation::operator ==(const ComputedNumer
 /* String converter */
 String ComputedNumericalMathHessianImplementation::__repr__() const
 {
-  return OSS() << "class=" << ComputedNumericalMathHessianImplementation::GetClassName()
+  return OSS(true) << "class=" << ComputedNumericalMathHessianImplementation::GetClassName()
          << " name=" << getName();
 }
 
