@@ -3,7 +3,7 @@
  *  @file  ConstantNumericalMathGradientImplementation.cxx
  *  @brief Class for a constant numerical math gradient implementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ Bool ConstantNumericalMathGradientImplementation::operator ==(const ConstantNume
 /* String converter */
 String ConstantNumericalMathGradientImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ConstantNumericalMathGradientImplementation::GetClassName()
       << " name=" << getName()
       << " constant=" << constant_;
@@ -78,7 +78,7 @@ String ConstantNumericalMathGradientImplementation::__str__(const String & offse
   const UnsignedLong inputDimension(getInputDimension());
   Description description(getDescription());
   if (description.getSize() == 0) for (UnsignedLong i = 0; i < inputDimension; ++i) description.add(OSS() << "x" << i);
-  if (hasVisibleName()) oss << offset << getName() << ":" << Os::GetEndOfLine();
+  if (hasVisibleName()) oss << offset << getName() << ":\n";
   for (UnsignedLong i = 0; i < inputDimension; ++i)
   {
     if (i == 0) oss << offset << "  (";
@@ -86,7 +86,7 @@ String ConstantNumericalMathGradientImplementation::__str__(const String & offse
     if (i == inputDimension - 1) oss << ")";
     else oss << ", ";
   }
-  oss << " ->" << Os::GetEndOfLine();
+  oss << " ->\n";
   oss << constant_.__str__(offset + "  ");
   return oss;
 }
