@@ -3,7 +3,7 @@
  *  @file  ConstantNumericalMathHessianImplementation.cxx
  *  @brief Class for a constant numerical math hessian implementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ Bool ConstantNumericalMathHessianImplementation::operator ==(const ConstantNumer
 /* String converter */
 String ConstantNumericalMathHessianImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ConstantNumericalMathHessianImplementation::GetClassName()
       << " name=" << getName()
       << " constant=" << constant_;
