@@ -3,7 +3,7 @@
  *  @file  DatabaseNumericalMathEvaluationImplementation.cxx
  *  @brief An implementation from samples
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -74,7 +74,7 @@ Bool DatabaseNumericalMathEvaluationImplementation::operator ==(const DatabaseNu
 /* String converter */
 String DatabaseNumericalMathEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << DatabaseNumericalMathEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " inputSample=" << inputSample_
@@ -84,7 +84,7 @@ String DatabaseNumericalMathEvaluationImplementation::__repr__() const
 
 String DatabaseNumericalMathEvaluationImplementation::__str__( const String & offset ) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << DatabaseNumericalMathEvaluationImplementation::GetClassName() << Os::GetEndOfLine()
       << offset << "  input sample :" << Os::GetEndOfLine() << inputSample_.__str__(offset) << Os::GetEndOfLine()
       << offset << "  output sample :" << Os::GetEndOfLine() << outputSample_.__str__(offset);
