@@ -3,7 +3,7 @@
  *  @file  DualLinearCombinationEvaluationImplementation.cxx
  *  @brief The evaluation part of functional linear combination of vectors
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -99,7 +99,7 @@ DualLinearCombinationEvaluationImplementation::Implementation DualLinearCombinat
 /* String converter */
 String DualLinearCombinationEvaluationImplementation::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " functions=" << functionsCollection_
          << " coefficients=" << coefficients_.__repr__();
 }
