@@ -3,7 +3,7 @@
  *  @file  DynamicalFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,7 +72,7 @@ Bool DynamicalFunction::operator ==(const DynamicalFunction & other) const
 /* String converter */
 String DynamicalFunction::__repr__() const
 {
-  return OSS() << "class=" << DynamicalFunction::GetClassName()
+  return OSS(true) << "class=" << DynamicalFunction::GetClassName()
          << " name=" << getName()
          << " implementation=" << getImplementation()->__repr__();
 }
@@ -114,9 +114,15 @@ NumericalPoint DynamicalFunction::operator() (const NumericalScalar timeStamp,
   return getImplementation()->operator()(timeStamp, inP);
 }
 
-TimeSeries DynamicalFunction::operator() (const TimeSeries & inTS) const
+NumericalPoint DynamicalFunction::operator() (const NumericalPoint & location,
+    const NumericalPoint & inP) const
 {
-  return getImplementation()->operator()(inTS);
+  return getImplementation()->operator()(location, inP);
+}
+
+Field DynamicalFunction::operator() (const Field & inFld) const
+{
+  return getImplementation()->operator()(inFld);
 }
 
 /* Operator () */
