@@ -3,7 +3,7 @@
  *  @file  DynamicalFunctionImplementation.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -57,7 +57,7 @@ Bool DynamicalFunctionImplementation::operator ==(const DynamicalFunctionImpleme
 /* String converter */
 String DynamicalFunctionImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << DynamicalFunctionImplementation::GetClassName()
       << " name=" << getName()
       << " input description=" << inputDescription_
@@ -112,15 +112,16 @@ Description DynamicalFunctionImplementation::getOutputDescription() const
 NumericalPoint DynamicalFunctionImplementation::operator() (const NumericalScalar timeStamp,
     const NumericalPoint & inP) const
 {
-  const UnsignedLong inputDimension(getInputDimension());
-  if (inP.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given point an invalid dimension. Expect a dimension " << inputDimension << ", got " << inP.getDimension() << ". Remember that the first component of the point is the time stamp.";
-  // Convert the point into a TimeSeries
-  const TimeSeries inTS(RegularGrid(timeStamp, 0.0, 1), NumericalSample(1, inP));
-  return operator()(inTS).getSample()[0];
+  return (*this)(NumericalPoint(1, timeStamp), inP);
 }
 
-/* Operator () */
-TimeSeries DynamicalFunctionImplementation::operator() (const TimeSeries & inTS) const
+NumericalPoint DynamicalFunctionImplementation::operator() (const NumericalPoint & location,
+    const NumericalPoint & inP) const
+{
+  return (*this)(Field(Mesh(NumericalSample(1, location), Collection<Indices>(0)), NumericalSample(1, inP))).getValues()[0];
+}
+
+Field DynamicalFunctionImplementation::operator() (const Field & inFld) const
 {
   throw NotYetImplementedException(HERE);
 }
@@ -131,11 +132,11 @@ ProcessSample DynamicalFunctionImplementation::operator() (const ProcessSample &
   if (inPS.getDimension() != getInputDimension()) throw InvalidArgumentException(HERE) << "Error: the given process sample has an invalid dimension. Expect a dimension " << getInputDimension() << ", got " << inPS.getDimension();
   const UnsignedLong size(inPS.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: the given process sample has a size of 0.";
-  ProcessSample outSample(computeOutputTimeGrid(inPS[0].getTimeGrid()), size, getOutputDimension());
+  ProcessSample outSample(computeOutputMesh(inPS.getField(0).getMesh()), size, getOutputDimension());
   // Simple loop over the evaluation operator based on time series
   // The calls number is updated by these calls
   for (UnsignedLong i = 0; i < size; ++i)
-    outSample[i] = operator()(inPS[i]);
+    outSample.setField(i, operator()(inPS.getField(i)));
   return outSample;
 }
 
@@ -157,10 +158,10 @@ UnsignedLong DynamicalFunctionImplementation::getCallsNumber() const
   return callsNumber_;
 }
 
-/* Compute the output time grid based on a given input time grid */
-RegularGrid DynamicalFunctionImplementation::computeOutputTimeGrid(const RegularGrid & inputTimeGrid) const
+/* Compute the output mesh based on a given input mesh */
+Mesh DynamicalFunctionImplementation::computeOutputMesh(const Mesh & mesh) const
 {
-  return inputTimeGrid;
+  return mesh;
 }
 
 /* Method save() stores the object through the StorageManager */
