@@ -3,7 +3,7 @@
  * @file  InverseBoxCoxEvaluationImplementation.cxx
  * @brief Class for the inverse Box cox function
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -68,21 +68,21 @@ Bool InverseBoxCoxEvaluationImplementation::operator ==(const InverseBoxCoxEvalu
 /* String converter */
 String InverseBoxCoxEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << InverseBoxCoxEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " dimension=" << getInputDimension()
-      << " lambda=" << lambda_.__repr__()
-      << " shift=" << shift_.__repr__();
+      << " lambda=" << lambda_
+      << " shift=" << shift_;
   return oss;
 }
 
 /* String converter __str__ */
 String InverseBoxCoxEvaluationImplementation::__str__(const String & offset) const
 {
-  OSS oss (false);
-  oss << "InverseBoxCox(lambda=" << lambda_.__str__(offset)
-      << ", shift=" << shift_.__str__(offset)
+  OSS oss(false);
+  oss << "InverseBoxCox(lambda=" << lambda_
+      << ", shift=" << shift_
       << ")";
   return oss;
 }
