@@ -3,7 +3,7 @@
  * @file  InverseTrendEvaluationImplementation.cxx
  * @brief Class for a Box cox implementation
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -62,7 +62,7 @@ Bool InverseTrendEvaluationImplementation::operator ==(const InverseTrendEvaluat
 /* String converter */
 String InverseTrendEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << InverseTrendEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " function=" << function_.__repr__();
