@@ -3,7 +3,7 @@
  *  @file  InverseTrendTransform.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -45,8 +45,6 @@ InverseTrendTransform::InverseTrendTransform()
 InverseTrendTransform::InverseTrendTransform(const NumericalMathFunction & function)
   : TemporalFunction()
 {
-  if (function.getInputDimension() != 1)
-    throw InvalidDimensionException(HERE) << "NumericalMathFunction input dimension should be 1 for trend" ;
   p_evaluation_ = function.getEvaluationImplementation() ;
   // Set the descriptions
   setInputDescription(p_evaluation_->getInputDescription());
@@ -57,21 +55,16 @@ InverseTrendTransform::InverseTrendTransform(const NumericalMathFunction & funct
 InverseTrendTransform::InverseTrendTransform(const EvaluationImplementation & p_evaluation)
   : TemporalFunction()
 {
-  if (p_evaluation->getInputDimension() != 1)
-    throw InvalidDimensionException(HERE) << "NumericalMathFunction input dimension should be 1 for trend" ;
   p_evaluation_ = p_evaluation;
   // Set the descriptions
   setInputDescription(p_evaluation_->getInputDescription());
   setOutputDescription(p_evaluation_->getOutputDescription());
-
 }
 
 /* Parameter constructor */
 InverseTrendTransform::InverseTrendTransform(const NumericalMathEvaluationImplementation & evaluation)
   : TemporalFunction()
 {
-  if (evaluation.getInputDimension() != 1)
-    throw InvalidDimensionException(HERE) << "NumericalMathFunction input dimension should be 1 for trend" ;
   p_evaluation_ = evaluation.clone();
 }
 
@@ -87,16 +80,10 @@ Bool InverseTrendTransform::operator ==(const InverseTrendTransform & other) con
   return (getEvaluation() == other.getEvaluation());
 }
 
-/* Inverse accessor */
-TrendTransform InverseTrendTransform::getInverse() const
-{
-  return TrendTransform(p_evaluation_);
-}
-
 /* String converter */
 String InverseTrendTransform::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << InverseTrendTransform::GetClassName()
       << " evaluation=" << p_evaluation_->__repr__();
   return oss;
@@ -109,37 +96,21 @@ String InverseTrendTransform::__str__(const String & offset) const
 }
 
 /* Operator () */
-TimeSeries InverseTrendTransform::operator() (const TimeSeries & inTS) const
+Field InverseTrendTransform::operator() (const Field & inFld) const
 {
-  // the considered \phi function should from from R to R^n
-  // the check will be done later
-  // since the TimeSeriesImplementation is not available, we have to check some features carefully
-
-  // 0 : Rework the timeSeries ==> for huge timeSeries, it is better to extract information from the ts
-  // without using the asNumericalSample method
-  // first we extract the timeGrid as a NumericalSample
-  NumericalSample timeGridAsSample(inTS.getSize() , 1);
-
-  for (UnsignedLong k = 0; k < timeGridAsSample.getSize(); ++k)
-  {
-    timeGridAsSample[k][0] = inTS[k][0];
-  }
-
-  // then we evaluation the function on the previous grid
-  // result is a NumericalSample of dimension d = function.getOutputDimension()
-  NumericalSample outputSample((*p_evaluation_)(timeGridAsSample));
-  const UnsignedLong dimension(outputSample.getDimension());
+  if (inFld.getMeshDimension() != p_evaluation_->getInputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with mesh dimension=" << p_evaluation_->getInputDimension() << ", got mesh dimension=" << inFld.getMeshDimension();
+  if (inFld.getDimension() != p_evaluation_->getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with dimension=" << p_evaluation_->getOutputDimension() << ", got dimension=" << inFld.getDimension();
+  NumericalSample outputSample((*p_evaluation_)(inFld.getMesh().getVertices()));
   // finally as the function adds a trend, result
-  for (UnsignedLong k = 0; k < timeGridAsSample.getSize(); ++k)
-  {
-    for (UnsignedLong d = 0; d < dimension; ++d)
-    {
-      // NumericalPoint should be compatible
-      outputSample[k][d] = inTS[k][d + 1] - outputSample[k][d];
-    }
-  }
+  for (UnsignedLong k = 0; k < outputSample.getSize(); ++k) outputSample[k] = inFld.getValueAtIndex(k) - outputSample[k];
   ++callsNumber_;
-  return TimeSeries(inTS.getTimeGrid(), outputSample);
+  return Field(inFld.getMesh(), outputSample);
+}
+
+/* Inverse accessor */
+TrendTransform InverseTrendTransform::getInverse() const
+{
+  return TrendTransform(p_evaluation_);
 }
 
 /* Method save() stores the object through the StorageManager */
