@@ -3,7 +3,7 @@
  *  @file  LAR.cxx
  *  @brief Least Angle Regression Algorithm
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -58,6 +58,7 @@ BasisSequence LAR::build(const NumericalSample & x,
   const UnsignedLong sampleSize( x.getSize() );
   const UnsignedLong basisSize( psi.getSize() );
 
+  if ( sampleSize == 0 ) throw InvalidArgumentException( HERE ) << "Output sample cannot be empty.";
   if ( y.getDimension() != 1 ) throw InvalidArgumentException( HERE ) << "Output sample should be unidimensional (dim=" << y.getDimension() << ").";
   if ( y.getSize() != sampleSize ) throw InvalidArgumentException( HERE ) << "Samples should be equally sized (in=" << sampleSize << " out=" << y.getSize() << ").";
   if ( x.getDimension() != psi.getDimension() ) throw InvalidArgumentException( HERE ) << "Sample dimension (" << x.getDimension() << ") does not match basis dimension (" << psi.getDimension() << ").";
@@ -81,7 +82,7 @@ BasisSequence LAR::build(const NumericalSample & x,
   NumericalPoint mu( sampleSize );
 
   // list of indices of the active set
-  Indices predictors;
+  Indices predictors(0);
 
 
   // main loop
@@ -114,10 +115,11 @@ BasisSequence LAR::build(const NumericalSample & x,
 
     // add the predictor index
     predictors.add( candidatePredictor );
-
+    // Starting from here, predictors has a size at least equal to 1
     // store the sign of the correlation
-    NumericalPoint s( predictors.getSize() );
-    for ( UnsignedLong j = 0; j < predictors.getSize(); ++ j ) s[j] = (c[predictors[j]] < 0.0 ? -1.0 : 1.0);
+    UnsignedLong predictorsSize(predictors.getSize());
+    NumericalPoint s( predictorsSize );
+    for ( UnsignedLong j = 0; j < predictorsSize; ++ j ) s[j] = (c[predictors[j]] < 0.0 ? -1.0 : 1.0);
 
     // store correlations of the inactive set
     NumericalPoint cI;
@@ -126,7 +128,9 @@ BasisSequence LAR::build(const NumericalSample & x,
         cI.add( c[j] );
 
     // matrix of elements of the inactive set
-    Matrix mPsiAc ( sampleSize, basisSize - predictors.getSize() );
+    // Here, basisSize >= predictorsSize as we perform a maximum
+    // of min(basisSize, sampleSize-1) iterations and predictorsSize <= sampleSize
+    Matrix mPsiAc ( sampleSize, basisSize - predictorsSize );
     UnsignedLong acIndex(0);
     for ( UnsignedLong j = 0; j < basisSize; ++ j )
       if ( ! predictors.__contains__(j) )
@@ -140,9 +144,9 @@ BasisSequence LAR::build(const NumericalSample & x,
 
     if ( getVerbose() ) LOGINFO( OSS() << "matrix of elements of the inactive set built.");
 
-    Matrix mPsiAk( sampleSize, predictors.getSize() - 1 );
+    Matrix mPsiAk( sampleSize, predictorsSize - 1 );
     for ( UnsignedLong i = 0; i < sampleSize; ++ i )
-      for ( UnsignedLong j = 0; j < predictors.getSize() - 1; ++ j )
+      for ( UnsignedLong j = 0; j < predictorsSize - 1; ++ j )
         mPsiAk(i, j) = mPsiX(i, predictors[j]);
 
     if ( getVerbose() ) LOGINFO( OSS() << "matrix of elements of the active set built.");
@@ -159,11 +163,11 @@ BasisSequence LAR::build(const NumericalSample & x,
     {
       // solve upper triangular system R*rk=xk'*A to get the extra column
       NumericalPoint colk( ( (xk.transpose() * mPsiAk).transpose()) * NumericalPoint( 1, 1.0 ) ) ;
-      NumericalPoint rk( predictors.getSize() - 1 );
-      for (UnsignedLong i = 0; i < predictors.getSize() - 1; ++ i)
+      NumericalPoint rk( predictorsSize - 1, 0.0 );
+      for (UnsignedLong i = 0; i < predictorsSize - 1; ++ i)
       {
         NumericalScalar sum( colk[i] );
-        for ( SignedInteger j = i - 1; j >= 0; -- j )
+        for ( UnsignedLong j = 0; j < i; ++ j )
           sum -= squareRootGramMatrix( j, i ) * rk[j];
         rk[i] = sum / squareRootGramMatrix( i, i );
       }
@@ -172,13 +176,13 @@ BasisSequence LAR::build(const NumericalSample & x,
       const NumericalScalar rkk( sqrt( diagk - dot( rk, rk ) ) );
 
       // reconstitute the whole decomposition matrix
-      SquareMatrix newSquareRootGramMatrix( predictors.getSize() );
-      for ( UnsignedLong i = 0; i < predictors.getSize() - 1; ++ i )
-        for ( UnsignedLong j = 0; j < predictors.getSize() - 1; ++ j )
+      SquareMatrix newSquareRootGramMatrix( predictorsSize );
+      for ( UnsignedLong i = 0; i < predictorsSize - 1; ++ i )
+        for ( UnsignedLong j = 0; j < predictorsSize - 1; ++ j )
           newSquareRootGramMatrix(i, j) = squareRootGramMatrix( i, j );
-      for ( UnsignedLong i = 0; i < predictors.getSize() - 1; ++ i )
-        newSquareRootGramMatrix(i, predictors.getSize() - 1 ) = rk[i];
-      newSquareRootGramMatrix( predictors.getSize() - 1, predictors.getSize() - 1 ) = rkk;
+      for ( UnsignedLong i = 0; i < predictorsSize - 1; ++ i )
+        newSquareRootGramMatrix(i, predictorsSize - 1 ) = rk[i];
+      newSquareRootGramMatrix( predictorsSize - 1, predictorsSize - 1 ) = rkk;
       squareRootGramMatrix = newSquareRootGramMatrix;
     } // if ( squareRootGramMatrix.getNbRows() > 0 )
     else squareRootGramMatrix = SquareMatrix( 1, NumericalScalarCollection( 1, sqrt( diagk ) ) );
@@ -186,17 +190,17 @@ BasisSequence LAR::build(const NumericalSample & x,
     if ( getVerbose() ) LOGINFO( OSS() << "Cholesky factor updated.");
 
     // compute ga1 = AA'^-1*s using the cholesky decomposition
-    NumericalPoint ga1( predictors.getSize() );
-    for ( UnsignedLong i = 0; i < predictors.getSize(); ++ i )
+    NumericalPoint ga1( predictorsSize );
+    for ( UnsignedLong i = 0; i < predictorsSize; ++ i )
     {
       NumericalScalar sum( s[i] );
-      for ( SignedInteger j = i - 1; j >= 0; -- j ) sum -= squareRootGramMatrix( j, i ) * ga1[j];
+      for ( UnsignedLong j = 0; j < i; ++ j ) sum -= squareRootGramMatrix( j, i ) * ga1[j];
       ga1[i] = sum / squareRootGramMatrix( i, i );
     }
-    for ( SignedInteger i = predictors.getSize() - 1; i >= 0; -- i )
+    for ( SignedInteger i = predictorsSize - 1; i >= 0; -- i )
     {
       NumericalScalar sum( ga1[i] );
-      for ( UnsignedLong j = i + 1; j < predictors.getSize(); ++ j )
+      for ( UnsignedLong j = i + 1; j < predictorsSize; ++ j )
         sum -= squareRootGramMatrix( i, j ) * ga1[j];
       ga1[i] = sum / squareRootGramMatrix( i, i );
     }
@@ -207,9 +211,9 @@ BasisSequence LAR::build(const NumericalSample & x,
     NumericalScalar cNorm( 1.0 / sqrt( dot( s, ga1 ) ) );
 
     // update the Matrix of elements of the active set
-    mPsiAk = Matrix ( sampleSize, predictors.getSize() );
+    mPsiAk = Matrix ( sampleSize, predictorsSize );
     for ( UnsignedLong i = 0; i < sampleSize; ++ i )
-      for ( UnsignedLong j = 0; j < predictors.getSize(); ++ j )
+      for ( UnsignedLong j = 0; j < predictorsSize; ++ j )
         mPsiAk( i, j ) = mPsiX( i, predictors[j] );
 
     // descent direction
@@ -219,7 +223,7 @@ BasisSequence LAR::build(const NumericalSample & x,
 
     // compute step
     NumericalScalar step( cMax / cNorm );
-    for ( UnsignedLong j = 0; j < basisSize - predictors.getSize(); ++ j )
+    for ( UnsignedLong j = 0; j < basisSize - predictorsSize; ++ j )
     {
       NumericalScalar lhs( (cMax - cI[j]) / (cNorm - d[j]) );
       NumericalScalar rhs( (cMax + cI[j]) / (cNorm + d[j]) );
@@ -235,7 +239,7 @@ BasisSequence LAR::build(const NumericalSample & x,
     // update coefficients
     oldCoefficientsL1Norm = coefficientsL1Norm;
     coefficientsL1Norm = 0.0;
-    for ( UnsignedLong j = 0; j < predictors.getSize(); ++ j )
+    for ( UnsignedLong j = 0; j < predictorsSize; ++ j )
     {
       coefficients[predictors[j]] += step * descentDirectionAk[j];
       coefficientsL1Norm += fabs( coefficients[predictors[j]] );
@@ -259,7 +263,7 @@ BasisSequence LAR::build(const NumericalSample & x,
 /* String converter */
 String LAR::__repr__() const
 {
-  return OSS() << "class=" << getClassName();
+  return OSS(true) << "class=" << getClassName();
 }
 
 String LAR::__str__(const String & offset) const
