@@ -3,7 +3,7 @@
  *  @file  Library.cxx
  *  @brief A Library object points to an actual shared library
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,7 @@
  */
 #include "OTconfig.hxx"
 #include "OTdebug.h"
-#ifdef HAVE_LIBDL
+#ifdef OPENTURNS_HAVE_LIBDL
 BEGIN_C_DECLS
 #include <dlfcn.h>               // for dlopen, dlsym, dlclose, dlerror
 END_C_DECLS
@@ -63,7 +63,7 @@ Bool Library::operator ==(const Library & other) const
 /* String converter */
 String Library::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " name=" << getName()
          << " path=" << path_
          << " handle=" << handle_;
@@ -79,7 +79,7 @@ String Library::__str__(const String & offset) const
 /* Library symbol accessor */
 LibrarySymbol Library::getSymbol(String symbolName) const
 {
-#ifdef HAVE_LIBDL
+#ifdef OPENTURNS_HAVE_LIBDL
   // We first clear any previous error
   dlerror();
 
@@ -95,9 +95,9 @@ LibrarySymbol Library::getSymbol(String symbolName) const
   LOGDEBUG(OSS() << "Found symbol '" << symbolName << "' (" << symbol << ") in library located at '" << path_ << "'");
 
   return symbol;
-#else /* HAVE_LIBDL */
+#else
   throw NotYetImplementedException(HERE) << "Library::getSymbol() need libdl";
-#endif /* HAVE_LIBDL */
+#endif
 }
 
 
