@@ -3,7 +3,7 @@
  *  @file  LibraryLoader.cxx
  *  @brief The class LibraryLoader loads ans manages all dynamic libraries
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,7 @@
  */
 #include "OTconfig.hxx"
 #include "OTdebug.h"
-#ifdef HAVE_LIBDL
+#ifdef OPENTURNS_HAVE_LIBDL
 BEGIN_C_DECLS
 #include <dlfcn.h>               // for dlopen, dlsym, dlclose, dlerror
 END_C_DECLS
@@ -63,7 +63,7 @@ LibraryLoader::LibraryLoader(const LibraryLoader & other ///< The copied Library
 /* Destructor */
 LibraryLoader::~LibraryLoader()
 {
-#ifdef HAVE_LIBDL
+#ifdef OPENTURNS_HAVE_LIBDL
   Lock lock(this);
 
   // We close all libraries one after another
@@ -77,9 +77,9 @@ LibraryLoader::~LibraryLoader()
                                           << (*iterator).first << "'. Reason : "
                                           << dlerror();
   } /* end for */
-#else /* HAVE_LIBDL */
+#else /* OPENTURNS_HAVE_LIBDL */
   throw NotYetImplementedException(HERE) << "LibraryLoader::~LibraryLoader() need libdl";
-#endif /* HAVE_LIBDL */
+#endif /* OPENTURNS_HAVE_LIBDL */
 }
 
 
@@ -93,7 +93,7 @@ LibraryLoader & LibraryLoader::operator =(const LibraryLoader & other)
 /* String converter */
 String LibraryLoader::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=LibraryLoader"
       << " catalog=[";
 
@@ -140,7 +140,7 @@ LibraryLoader & LibraryLoader::GetInstance()
  */
 Library LibraryLoader::load(const FileName & path)
 {
-#ifdef HAVE_LIBDL
+#ifdef OPENTURNS_HAVE_LIBDL
   Lock lock(this);
 
   CatalogType::const_iterator foundLibraryIterator = libraryCatalog_.find(path);
@@ -176,9 +176,9 @@ Library LibraryLoader::load(const FileName & path)
   {
     return Library((*foundLibraryIterator).second, (*foundLibraryIterator).first);
   } /* end if */
-#else /* HAVE_LIBDL */
+#else /* OPENTURNS_HAVE_LIBDL */
   throw NotYetImplementedException(HERE) << "LibraryLoader::load() need libdl";
-#endif /* HAVE_LIBDL */
+#endif /* OPENTURNS_HAVE_LIBDL */
 }
 
 
