@@ -3,7 +3,7 @@
  *  @file  LinearCombinationEvaluationImplementation.cxx
  *  @brief The evaluation part of linear combination of polynomials
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,9 +71,9 @@ LinearCombinationEvaluationImplementation * LinearCombinationEvaluationImplement
 /* String converter */
 String LinearCombinationEvaluationImplementation::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " functions=" << functionsCollection_
-         << " coefficients=" << coefficients_.__repr__();
+         << " coefficients=" << coefficients_;
 }
 
 String LinearCombinationEvaluationImplementation::__str__(const String & offset) const
