@@ -3,7 +3,7 @@
  *  @file  LinearCombinationHessianImplementation.cxx
  *  @brief The hessian part of linear combination of polynomials
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -96,7 +96,7 @@ UnsignedLong LinearCombinationHessianImplementation::getOutputDimension() const
 /* String converter */
 String LinearCombinationHessianImplementation::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " evaluation=" << evaluation_;
 }
 
