@@ -6,16 +6,23 @@
  *        dim(x) numerical point, linear a dim(x) by dim(y) matrix
  *        and  <linear, x - c> means Transpose(linear).(x - c)
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
- * Permission to copy, use, modify, sell and distribute this software
- * is granted provided this copyright notice appears in all copies.
- * This software is provided "as is" without express or implied
- * warranty, and with no claim as to its suitability for any purpose.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
  *
- * @author schueller
- * @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
+ *  You should have received a copy of the GNU Lesser General Public
+ *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ *  @author schueller
+ *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 
 #include "LinearNumericalMathEvaluationImplementation.hxx"
@@ -80,11 +87,22 @@ Bool LinearNumericalMathEvaluationImplementation::operator ==(const LinearNumeri
 /* String converter */
 String LinearNumericalMathEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << LinearNumericalMathEvaluationImplementation::GetClassName()
       << " name=" << getName()
-      << " center=" << center_.__repr__()
-      << " constant=" << constant_.__repr__()
+      << " center=" << center_
+      << " constant=" << constant_
+      << " linear=" << linear_.transpose();
+  return oss;
+}
+
+String LinearNumericalMathEvaluationImplementation::__str__(const String & offset) const
+{
+  OSS oss(false);
+  oss << "class=" << LinearNumericalMathEvaluationImplementation::GetClassName()
+      << " name=" << getName()
+      << " center=" << center_
+      << " constant=" << constant_
       << " linear=" << linear_.transpose();
   return oss;
 }
