@@ -3,7 +3,7 @@
  *  @file  LinearNumericalMathFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,11 +22,12 @@
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include "LinearNumericalMathFunction.hxx"
+#include "LinearNumericalMathEvaluationImplementation.hxx"
+#include "ConstantNumericalMathGradientImplementation.hxx"
+#include "ConstantNumericalMathHessianImplementation.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(LinearNumericalMathFunction);
 
 /* Default constructor */
@@ -49,11 +50,20 @@ Bool LinearNumericalMathFunction::operator ==(const LinearNumericalMathFunction
 /* String converter */
 String LinearNumericalMathFunction::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << LinearNumericalMathFunction::GetClassName()
       << " name=" << getName()
       << " implementation=" << getImplementation()->__repr__();
   return oss;
 }
 
+String LinearNumericalMathFunction::__str__(const String & offset) const
+{
+  OSS oss(false);
+  oss << "class=" << LinearNumericalMathFunction::GetClassName()
+      << " name=" << getName()
+      << " implementation=" << getImplementation()->__str__();
+  return oss;
+}
+
 END_NAMESPACE_OPENTURNS
