@@ -3,7 +3,7 @@
  *  @file  LinearNumericalMathGradientImplementation.cxx
  *  @brief Class for a quadratic numerical math gradient implementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include "LinearNumericalMathGradientImplementation.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "Os.hxx"
 
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -70,7 +71,7 @@ Bool LinearNumericalMathGradientImplementation::operator ==(const LinearNumerica
 /* String converter */
 String LinearNumericalMathGradientImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << LinearNumericalMathGradientImplementation::GetClassName()
       << " name=" << getName()
       << " center=" << center_.__repr__()
@@ -79,6 +80,16 @@ String LinearNumericalMathGradientImplementation::__repr__() const
   return oss;
 }
 
+String LinearNumericalMathGradientImplementation::__str__(const String & offset) const
+{
+  OSS oss(false);
+  oss << offset << LinearNumericalMathGradientImplementation::GetClassName() << Os::GetEndOfLine()
+      << offset << "  center :"  << Os::GetEndOfLine() << center_.__str__(offset + "  ") << Os::GetEndOfLine()
+      << offset << "  constant :" << Os::GetEndOfLine() << constant_.__str__(offset + "  ") << Os::GetEndOfLine()
+      << offset << "  linear :" << Os::GetEndOfLine() << linear_.__str__(offset + "  ") << Os::GetEndOfLine();
+  return oss;
+}
+
 /* Accessor for the center */
 NumericalPoint LinearNumericalMathGradientImplementation::getCenter() const
 {
