@@ -3,7 +3,7 @@
  * @file  NumericalMathEvaluationImplementation.cxx
  * @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,11 @@
 
 #include "NumericalMathEvaluationImplementation.hxx"
 #include "ComposedNumericalMathEvaluationImplementation.hxx"
+#include "OTconfig.hxx"
+#ifdef OPENTURNS_HAVE_MUPARSER
 #include "AnalyticalNumericalMathEvaluationImplementation.hxx"
+#endif
+#include "LinearNumericalMathEvaluationImplementation.hxx"
 #include "Exception.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Full.hxx"
@@ -46,7 +50,7 @@ static Factory<NumericalMathEvaluationImplementationCache> RegisteredFactory_Cac
 /* We should be careful because they may interfere with other definitions placed elsewhere */
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<UnsignedLong>);
 static Factory<PersistentCollection<UnsignedLong> > RegisteredFactory_alt1("PersistentCollection<UnsignedLong>");
-#ifndef __LP64__
+#ifndef OPENTURNS_UNSIGNEDLONG_SAME_AS_UINT64
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<Unsigned64BitsInteger>);
 static Factory<PersistentCollection<Unsigned64BitsInteger> > RegisteredFactory_alt1b("PersistentCollection<Unsigned64BitsInteger>");
 #endif
@@ -92,7 +96,7 @@ Bool NumericalMathEvaluationImplementation::operator ==(const NumericalMathEvalu
 /* String converter */
 String NumericalMathEvaluationImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NumericalMathEvaluationImplementation::GetClassName()
       << " name=" << getName()
       << " input description=" << inputDescription_
@@ -168,7 +172,7 @@ NumericalSample NumericalMathEvaluationImplementation::operator() (const Numeric
   if (inSample.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given sample has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inSample.getDimension();
 
   const UnsignedLong size(inSample.getSize());
-  NumericalSample outSample(size, NumericalPoint(getOutputDimension()));
+  NumericalSample outSample(size, getOutputDimension());
   // Simple loop over the evaluation operator based on point
   // The calls number is updated by these calls
   for (UnsignedLong i = 0; i < size; ++i) outSample[i] = operator()(inSample[i]);
@@ -178,11 +182,11 @@ NumericalSample NumericalMathEvaluationImplementation::operator() (const Numeric
 
 
 /* Operator () */
-TimeSeries NumericalMathEvaluationImplementation::operator() (const TimeSeries & inTimeSeries) const
+Field NumericalMathEvaluationImplementation::operator() (const Field & inField) const
 {
   const UnsignedLong inputDimension(getInputDimension());
-  if (inTimeSeries.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given time series has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inTimeSeries.getDimension();
-  return TimeSeries(inTimeSeries.getTimeGrid(), operator()(inTimeSeries.getSample()));
+  if (inField.getDimension() != inputDimension) throw InvalidArgumentException(HERE) << "Error: the given time series has an invalid dimension. Expect a dimension " << inputDimension << ", got " << inField.getDimension();
+  return Field(inField.getMesh(), operator()(inField.getValues()));
 }
 
 
@@ -332,11 +336,12 @@ NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImp
   // with formula Yk = Xindices[k] for k=1,...,p
   // Build non-ambigous names for the inputs. We cannot simply use the output description, as it must be valid muParser identifiers
   const UnsignedLong inputDimension(getOutputDimension());
+  const UnsignedLong outputDimension(indices.getSize());
+#ifdef OPENTURNS_HAVE_MUPARSER
   Description input(inputDimension);
   for (UnsignedLong index = 0; index < inputDimension; ++index)
     input[index] = OSS() << "x" << index;
   // Extract the components
-  const UnsignedLong outputDimension(indices.getSize());
   Description output(outputDimension);
   Description formulas(outputDimension);
   Description currentOutputDescription(getOutputDescription());
@@ -346,7 +351,20 @@ NumericalMathEvaluationImplementation::Implementation NumericalMathEvaluationImp
     formulas[index] = input[indices[index]];
   }
   const AnalyticalNumericalMathEvaluationImplementation left(input, output, formulas);
-  return new ComposedNumericalMathEvaluationImplementation(left.clone(), clone());
+#else
+  NumericalPoint center(inputDimension);
+  Matrix linear(inputDimension, outputDimension);
+  for ( UnsignedLong index = 0; index < outputDimension; ++ index )
+    linear(indices[index], index) = 1.0;
+  NumericalPoint constant(outputDimension);
+  const LinearNumericalMathEvaluationImplementation left(center, constant, linear);
+#endif
+  ComposedNumericalMathEvaluationImplementation marginal(left.clone(), clone());
+  if (isHistoryEnabled())
+  {
+    marginal.enableHistory();
+  }
+  return marginal.clone();
 }
 
 /* Get the number of calls to operator() */
