@@ -3,7 +3,7 @@
  *  @file  NumericalMathFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -201,7 +201,7 @@ Bool NumericalMathFunction::operator ==(const NumericalMathFunction & other) con
 /* String converter */
 String NumericalMathFunction::__repr__() const
 {
-  return OSS() << "class=" << NumericalMathFunction::GetClassName()
+  return OSS(true) << "class=" << NumericalMathFunction::GetClassName()
          << " name=" << getName()
          << " implementation=" << getImplementation()->__repr__();
 }
@@ -444,9 +444,9 @@ NumericalSample NumericalMathFunction::operator() (const NumericalSample & inSam
 }
 
 /* Operator () */
-TimeSeries NumericalMathFunction::operator() (const TimeSeries & inTimeSeries) const
+Field NumericalMathFunction::operator() (const Field & inField) const
 {
-  return getImplementation()->operator()(inTimeSeries);
+  return getImplementation()->operator()(inField);
 }
 
 /* Method gradient() returns the Jacobian transposed matrix of the function at point */
