@@ -3,7 +3,7 @@
  *  @file  NumericalMathFunctionImplementation.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,9 +29,11 @@
 #include "ComputedNumericalMathEvaluationImplementation.hxx"
 #include "ComputedNumericalMathGradientImplementation.hxx"
 #include "ComputedNumericalMathHessianImplementation.hxx"
+#ifdef OPENTURNS_HAVE_MUPARSER
 #include "AnalyticalNumericalMathEvaluationImplementation.hxx"
 #include "AnalyticalNumericalMathGradientImplementation.hxx"
 #include "AnalyticalNumericalMathHessianImplementation.hxx"
+#endif
 #include "DatabaseNumericalMathEvaluationImplementation.hxx"
 #include "ProductNumericalMathFunction.hxx"
 #include "CenteredFiniteDifferenceGradient.hxx"
@@ -46,9 +48,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(NumericalMathFunctionImplementation);
 
 static Factory<NumericalMathFunctionImplementation> RegisteredFactory("NumericalMathFunctionImplementation");
@@ -61,30 +60,30 @@ Description NumericalMathFunctionImplementation::ValidOperators_;
 
 /* Default constructor */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation()
-  : PersistentObject(),
-    p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation),
-    p_gradientImplementation_(new NoNumericalMathGradientImplementation),
-    p_hessianImplementation_(new NoNumericalMathHessianImplementation),
-    p_initialEvaluationImplementation_(p_evaluationImplementation_),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(false),
-    useDefaultHessianImplementation_(false)
+  : PersistentObject()
+  , p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation)
+  , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
+  , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
+  , p_initialEvaluationImplementation_(p_evaluationImplementation_)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(false)
+  , useDefaultHessianImplementation_(false)
 {
   // Nothing to do
 }
 
 /* Constructor from a wrapper name */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const String & name)
-  : PersistentObject(name),
-    p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation),
-    p_gradientImplementation_(new NoNumericalMathGradientImplementation),
-    p_hessianImplementation_(new NoNumericalMathHessianImplementation),
-    p_initialEvaluationImplementation_(p_evaluationImplementation_),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(false),
-    useDefaultHessianImplementation_(false)
+  : PersistentObject(name)
+  , p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation)
+  , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
+  , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
+  , p_initialEvaluationImplementation_(p_evaluationImplementation_)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(false)
+  , useDefaultHessianImplementation_(false)
 {
   // Read the description file of the wrapper
   WrapperFile wrapperFile = WrapperFile::FindWrapperByName( name );
@@ -95,15 +94,15 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const S
 
 /* Constructor from a wrapper file */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const WrapperFile & wrapperFile)
-  : PersistentObject(wrapperFile.getName()),
-    p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation),
-    p_gradientImplementation_(new NoNumericalMathGradientImplementation),
-    p_hessianImplementation_(new NoNumericalMathHessianImplementation),
-    p_initialEvaluationImplementation_(p_evaluationImplementation_),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(false),
-    useDefaultHessianImplementation_(false)
+  : PersistentObject(wrapperFile.getName())
+  , p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation)
+  , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
+  , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
+  , p_initialEvaluationImplementation_(p_evaluationImplementation_)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(false)
+  , useDefaultHessianImplementation_(false)
 {
   // We set the implementations
   initImplementations( wrapperFile );
@@ -145,16 +144,17 @@ void NumericalMathFunctionImplementation::initImplementations(const WrapperFile
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const Description & inputVariablesNames,
     const Description & outputVariablesNames,
     const Description & formulas)
-  : PersistentObject(),
-    p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation),
-    p_gradientImplementation_(new NoNumericalMathGradientImplementation),
-    p_hessianImplementation_(new NoNumericalMathHessianImplementation),
-    p_initialEvaluationImplementation_(p_evaluationImplementation_),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(true),
-    useDefaultHessianImplementation_(true)
+  : PersistentObject()
+  , p_evaluationImplementation_(new NoNumericalMathEvaluationImplementation)
+  , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
+  , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
+  , p_initialEvaluationImplementation_(p_evaluationImplementation_)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(true)
+  , useDefaultHessianImplementation_(true)
 {
+#ifdef OPENTURNS_HAVE_MUPARSER
   // Try to build an analytical gradient
   AnalyticalNumericalMathEvaluationImplementation evaluation(inputVariablesNames, outputVariablesNames, formulas);
   p_evaluationImplementation_ = evaluation.clone();
@@ -180,19 +180,22 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const D
     p_hessianImplementation_ = new CenteredFiniteDifferenceHessian(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceHessian-DefaultEpsilon" ), p_evaluationImplementation_);
   }
   p_initialHessianImplementation_ = p_hessianImplementation_;
+#else
+  throw NotYetImplementedException(HERE) << "Analytical function requires muParser";
+#endif
 }
 
 
 /* Constructor from a wrapper file */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const NumericalSample & inputSample,
     const NumericalSample & outputSample)
-  : PersistentObject(),
-    p_gradientImplementation_(new NoNumericalMathGradientImplementation),
-    p_hessianImplementation_(new NoNumericalMathHessianImplementation),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(false),
-    useDefaultHessianImplementation_(false)
+  : PersistentObject()
+  , p_gradientImplementation_(new NoNumericalMathGradientImplementation)
+  , p_hessianImplementation_(new NoNumericalMathHessianImplementation)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(false)
+  , useDefaultHessianImplementation_(false)
 {
   p_evaluationImplementation_ = new DatabaseNumericalMathEvaluationImplementation( inputSample, outputSample );
   p_initialEvaluationImplementation_ = p_evaluationImplementation_;
@@ -201,15 +204,15 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const N
 
 /* Single function implementation constructor */
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const EvaluationImplementation & evaluationImplementation)
-  : PersistentObject(),
-    p_evaluationImplementation_(evaluationImplementation),
-    p_gradientImplementation_(new CenteredFiniteDifferenceGradient(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceGradient-DefaultEpsilon" ), p_evaluationImplementation_)),
-    p_hessianImplementation_(new CenteredFiniteDifferenceHessian(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceHessian-DefaultEpsilon" ), p_evaluationImplementation_)),
-    p_initialEvaluationImplementation_(p_evaluationImplementation_),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(true),
-    useDefaultHessianImplementation_(true)
+  : PersistentObject()
+  , p_evaluationImplementation_(evaluationImplementation)
+  , p_gradientImplementation_(new CenteredFiniteDifferenceGradient(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceGradient-DefaultEpsilon" ), p_evaluationImplementation_))
+  , p_hessianImplementation_(new CenteredFiniteDifferenceHessian(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceHessian-DefaultEpsilon" ), p_evaluationImplementation_))
+  , p_initialEvaluationImplementation_(p_evaluationImplementation_)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(true)
+  , useDefaultHessianImplementation_(true)
 {
   // Nothing to do
 }
@@ -218,15 +221,15 @@ NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const E
 NumericalMathFunctionImplementation::NumericalMathFunctionImplementation(const EvaluationImplementation & evaluationImplementation,
     const GradientImplementation & gradientImplementation,
     const HessianImplementation  & hessianImplementation)
-  : PersistentObject(),
-    p_evaluationImplementation_(evaluationImplementation),
-    p_gradientImplementation_(gradientImplementation),
-    p_hessianImplementation_(hessianImplementation),
-    p_initialEvaluationImplementation_(p_evaluationImplementation_),
-    p_initialGradientImplementation_(p_gradientImplementation_),
-    p_initialHessianImplementation_(p_hessianImplementation_),
-    useDefaultGradientImplementation_(false),
-    useDefaultHessianImplementation_(false)
+  : PersistentObject()
+  , p_evaluationImplementation_(evaluationImplementation)
+  , p_gradientImplementation_(gradientImplementation)
+  , p_hessianImplementation_(hessianImplementation)
+  , p_initialEvaluationImplementation_(p_evaluationImplementation_)
+  , p_initialGradientImplementation_(p_gradientImplementation_)
+  , p_initialHessianImplementation_(p_hessianImplementation_)
+  , useDefaultGradientImplementation_(false)
+  , useDefaultHessianImplementation_(false)
 {
   // Nothing to do
 }
@@ -247,7 +250,7 @@ Bool NumericalMathFunctionImplementation::operator ==(const NumericalMathFunctio
 /* String converter */
 String NumericalMathFunctionImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NumericalMathFunctionImplementation::GetClassName()
       << " name=" << getName()
       << " description=" << getDescription()
@@ -260,11 +263,13 @@ String NumericalMathFunctionImplementation::__repr__() const
 /* String converter */
 String NumericalMathFunctionImplementation::__str__(const String & offset) const
 {
-  return OSS(false) << offset << "input  : " << getInputDescription() << Os::GetEndOfLine()
-         << offset << "output : " << getOutputDescription() << Os::GetEndOfLine()
-         << offset << "evaluation : " << p_evaluationImplementation_->__str__(offset) << Os::GetEndOfLine()
-         << offset << "gradient   : " << p_gradientImplementation_->__str__(offset) << Os::GetEndOfLine()
-         << offset << "hessian    : " << p_hessianImplementation_->__str__(offset);
+  OSS oss(false);
+  oss << offset << "input  : " << getInputDescription() << Os::GetEndOfLine()
+      << offset << "output : " << getOutputDescription() << Os::GetEndOfLine()
+      << offset << "evaluation : " << p_evaluationImplementation_->__str__(offset) << Os::GetEndOfLine()
+      << offset << "gradient   : " << p_gradientImplementation_->__str__(offset) << Os::GetEndOfLine()
+      << offset << "hessian    : " << p_hessianImplementation_->__str__(offset);
+  return oss;
 }
 
 /* Description Accessor */
@@ -500,9 +505,9 @@ NumericalSample NumericalMathFunctionImplementation::operator() (const Numerical
 }
 
 /* Operator () */
-TimeSeries NumericalMathFunctionImplementation::operator() (const TimeSeries & inTimeSeries) const
+Field NumericalMathFunctionImplementation::operator() (const Field & inField) const
 {
-  return p_evaluationImplementation_->operator()(inTimeSeries);
+  return p_evaluationImplementation_->operator()(inField);
 }
 
 /* Method gradient() returns the Jacobian transposed matrix of the function at point */
