@@ -3,7 +3,7 @@
  *  @file  NumericalMathGradientImplementation.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,12 @@
  */
 #include "NumericalMathGradientImplementation.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "OTconfig.hxx"
+#ifdef OPENTURNS_HAVE_MUPARSER
 #include "AnalyticalNumericalMathEvaluationImplementation.hxx"
+#else
+#include "LinearNumericalMathEvaluationImplementation.hxx"
+#endif
 #include "ConstantNumericalMathGradientImplementation.hxx"
 #include "ComposedNumericalMathGradientImplementation.hxx"
 
@@ -61,7 +66,7 @@ Bool NumericalMathGradientImplementation::operator ==(const NumericalMathGradien
 /* String converter */
 String NumericalMathGradientImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NumericalMathGradientImplementation::GetClassName()
       << " name=" << getName()
       << " description=" << description_;
@@ -137,16 +142,23 @@ NumericalMathGradientImplementation::Implementation NumericalMathGradientImpleme
   // have access to f here but only to Df, we build an arbitrary cheap evaluation with the proper dimension in order to reuse the
   // generic implementation of the chain rule for the gradients. We choose to build a null function using an analytical function.
   // Fake f
-  const UnsignedLong inputDimension(getInputDimension());
+  const UnsignedLong inputDimension = getInputDimension();
+  const UnsignedLong outputDimension = getOutputDimension();
+#ifdef OPENTURNS_HAVE_MUPARSER
   Description input(inputDimension);
   for (UnsignedLong index = 0; index < inputDimension; ++index)
     input[index] = OSS() << "x" << index;
-  const UnsignedLong outputDimension(getOutputDimension());
   Description output(outputDimension);
   for (UnsignedLong index = 0; index < outputDimension; ++index)
     output[index] = OSS() << "y" << index;
   const Description formulas(outputDimension, "0.0");
   const AnalyticalNumericalMathEvaluationImplementation right(input, output, formulas);
+#else
+  NumericalPoint center(inputDimension);
+  Matrix linear(inputDimension, outputDimension);
+  NumericalPoint constant(outputDimension);
+  const LinearNumericalMathEvaluationImplementation right(center, constant, linear);
+#endif
   // A
   const UnsignedLong marginalOutputDimension(indices.getSize());
   Matrix gradientExtraction(outputDimension, marginalOutputDimension);
