@@ -3,7 +3,7 @@
  *  @file  NumericalMathHessianImplementation.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,12 @@
 #include "NumericalMathHessianImplementation.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Matrix.hxx"
+#include "OTconfig.hxx"
+#ifdef OPENTURNS_HAVE_MUPARSER
 #include "AnalyticalNumericalMathEvaluationImplementation.hxx"
+#else
+#include "LinearNumericalMathEvaluationImplementation.hxx"
+#endif
 #include "ConstantNumericalMathGradientImplementation.hxx"
 #include "ConstantNumericalMathHessianImplementation.hxx"
 #include "ComposedNumericalMathHessianImplementation.hxx"
@@ -63,7 +68,7 @@ Bool NumericalMathHessianImplementation::operator ==(const NumericalMathHessianI
 /* String converter */
 String NumericalMathHessianImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NumericalMathHessianImplementation::GetClassName()
       << " name=" << getName()
       << " description=" << description_;
@@ -145,16 +150,23 @@ NumericalMathHessianImplementation::Implementation NumericalMathHessianImplement
   // As we don't have access to f and Df here but only to D2f, we build an arbitrary cheap evaluation with the proper dimension in order to reuse the
   // generic implementation of the chain rule for the hessians. We choose to build a null function using an analytical function.
   // Fake f
-  const UnsignedLong inputDimension(getInputDimension());
+  const UnsignedLong inputDimension = getInputDimension();
+  const UnsignedLong outputDimension = getOutputDimension();
+#ifdef OPENTURNS_HAVE_MUPARSER
   Description input(inputDimension);
   for (UnsignedLong index = 0; index < inputDimension; ++index)
     input[index] = OSS() << "x" << index;
-  const UnsignedLong outputDimension(getOutputDimension());
   Description output(outputDimension);
   for (UnsignedLong index = 0; index < outputDimension; ++index)
     output[index] = OSS() << "y" << index;
   const Description formulas(outputDimension, "0.0");
   const AnalyticalNumericalMathEvaluationImplementation right(input, output, formulas);
+#else
+  NumericalPoint center(inputDimension);
+  Matrix linear(inputDimension, outputDimension);
+  NumericalPoint constant(outputDimension);
+  const LinearNumericalMathEvaluationImplementation right(center, constant, linear);
+#endif
   // Fake DF
   const ConstantNumericalMathGradientImplementation rightGradient(Matrix(inputDimension, outputDimension));
   // Dg = A
