@@ -3,7 +3,7 @@
  *  @file  ProductNumericalMathFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,7 +78,7 @@ Bool ProductNumericalMathFunction::operator ==(const ProductNumericalMathFunctio
 /* String converter */
 String ProductNumericalMathFunction::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ProductNumericalMathFunction::GetClassName()
       << " name=" << getName()
       << " description=" << getDescription()
@@ -93,8 +93,8 @@ String ProductNumericalMathFunction::__str__(const String & offset) const
   oss << "class=" << ProductNumericalMathFunction::GetClassName()
       << " name=" << getName()
       << " description=" << getDescription()
-      << " left function=" << p_leftFunction_->__repr__()
-      << " right function=" << p_rightFunction_->__repr__();
+      << " left function=" << p_leftFunction_->__str__()
+      << " right function=" << p_rightFunction_->__str__();
   return oss;
 }
 
