@@ -3,7 +3,7 @@
  *  @file  ProductPolynomialEvaluationImplementation.cxx
  *  @brief This is a nD polynomial build as a product of n 1D polynomial
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,7 +71,7 @@ ProductPolynomialEvaluationImplementation * ProductPolynomialEvaluationImplement
 /* String converter */
 String ProductPolynomialEvaluationImplementation::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << ", polynomials=" << polynomials_;
 }
 
