@@ -9,7 +9,7 @@
  *        means Transpose(linear).x, <quadratic, x> means
  *        Transpose_kj(quadratic).x
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -23,6 +23,7 @@
 
 #include "QuadraticNumericalMathEvaluationImplementation.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "Os.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -85,6 +86,17 @@ String QuadraticNumericalMathEvaluationImplementation::__repr__() const
   return oss;
 }
 
+String QuadraticNumericalMathEvaluationImplementation::__str__(const String & offset) const
+{
+  OSS oss;
+  oss << offset << QuadraticNumericalMathEvaluationImplementation::GetClassName() << Os::GetEndOfLine()
+      << offset << "  center :"  << Os::GetEndOfLine() << center_.__str__(offset + "  ") << Os::GetEndOfLine()
+      << offset << "  constant :" << Os::GetEndOfLine() << constant_.__str__(offset + "  ") << Os::GetEndOfLine()
+      << offset << "  linear :" << Os::GetEndOfLine() << linear_.transpose().__str__(offset + "  ") << Os::GetEndOfLine()
+      << offset << "  quadratic :" << Os::GetEndOfLine() << quadratic_.__str__(offset + "  ") << Os::GetEndOfLine();
+  return oss;
+}
+
 /* Accessor for the center */
 NumericalPoint QuadraticNumericalMathEvaluationImplementation::getCenter() const
 {
