@@ -3,7 +3,7 @@
  *  @file  SpatialFunction.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -87,7 +87,7 @@ Bool SpatialFunction::operator ==(const SpatialFunction & other) const
 /* String converter */
 String SpatialFunction::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << SpatialFunction::GetClassName()
       << " evaluation=" << p_evaluation_->__repr__();
   return oss;
@@ -100,10 +100,10 @@ String SpatialFunction::__str__(const String & offset) const
 }
 
 /* Operator () */
-TimeSeries SpatialFunction::operator() (const TimeSeries & inTS) const
+Field SpatialFunction::operator() (const Field & inTS) const
 {
   ++callsNumber_;
-  return TimeSeries(inTS.getTimeGrid(), (*p_evaluation_)(inTS.getSample()));
+  return Field(inTS.getTimeGrid(), (*p_evaluation_)(inTS.getSample()));
 }
 
 /* Get the i-th marginal function */
