@@ -3,7 +3,7 @@
  *  @file  SpecFunc.cxx
  *  @brief OpenTURNS wrapper to a library of special functions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,12 +27,10 @@
 #include <iostream>
 
 #include "SpecFunc.hxx"
-//#undef USE_DCDFLIB
-#define USE_DCDFLIB
-#ifdef USE_DCDFLIB
-#include "Dcdflib.hxx"
-#endif
+#include "GammaFunctions.hxx"
+#include "BetaFunctions.hxx"
 #include "Debye.hxx"
+#include "Faddeeva.hh"
 #include "Exception.hxx"
 #include "ResourceMap.hxx"
 
@@ -40,6 +38,10 @@ BEGIN_NAMESPACE_OPENTURNS
 
 // 0.39894228040143267 = 1 / sqrt(2.pi)
 const NumericalScalar SpecFunc::ISQRT2PI              = 0.39894228040143267;
+// 2.5066282746310005024 = sqrt(2.pi)
+const NumericalScalar SpecFunc::SQRT2PI               = 2.5066282746310005024;
+// 0.91893853320467274177 = log(sqrt(2.pi))
+const NumericalScalar SpecFunc::LOGSQRT2PI            = 0.91893853320467274177;
 // 0.57721566490153286 = Euler constant gamma
 const NumericalScalar SpecFunc::EulerConstant         = 0.57721566490153286;
 // 1.64493406684822643 = pi^2 / 6
@@ -62,16 +64,18 @@ const NumericalScalar SpecFunc::LogMinNumericalScalar = log(MinNumericalScalar);
 const NumericalScalar SpecFunc::MaxNumericalScalar    = std::numeric_limits<NumericalScalar>::max();
 const NumericalScalar SpecFunc::LogMaxNumericalScalar = log(MaxNumericalScalar);
 const NumericalScalar SpecFunc::NumericalScalarEpsilon = std::numeric_limits<NumericalScalar>::epsilon();
+// Maximum number of iterations for the algorithms
+const UnsignedLong SpecFunc::MaximumIteration = ResourceMap::GetAsUnsignedLong("SpecFunc-MaximumIteration");
+const NumericalScalar SpecFunc::Precision = ResourceMap::GetAsNumericalScalar("SpecFunc-Precision");
 
 // Modified first kind Bessel function of order 0: BesselI0(x) = \sum_{m=0}\infty\frac{1}{m!^2}\left(\frac{x}{2}\right)^{2m}
 NumericalScalar SpecFunc::SmallCaseBesselI0(const NumericalScalar x)
 {
   const NumericalScalar x2(x * x);
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
   NumericalScalar value(1.0);
   NumericalScalar r(1.0);
   UnsignedLong k(1);
-  while (fabs(r / value) >= precision)
+  while ((fabs(r / value) > 0.0) && (k < SpecFunc::MaximumIteration))
   {
     r *= 0.25 * x2 / (k * k);
     value += r;
@@ -127,11 +131,10 @@ NumericalScalar SpecFunc::LogBesselI0(const NumericalScalar x)
 NumericalScalar SpecFunc::SmallCaseBesselI1(const NumericalScalar x)
 {
   const NumericalScalar x2(x * x);
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
   NumericalScalar value(1.0);
   NumericalScalar r(1.0);
   UnsignedLong k(1);
-  while (fabs(r / value) >= precision)
+  while ((fabs(r / value) > 0.0) && (k < SpecFunc::MaximumIteration))
   {
     r *= 0.25 * x2 / (k * (k + 1));
     value += r;
@@ -191,7 +194,20 @@ NumericalScalar SpecFunc::LogBesselI1(const NumericalScalar x)
 NumericalScalar SpecFunc::LnBeta(const NumericalScalar a,
                                  const NumericalScalar b)
 {
-  return lgamma(a) - lgamma(a + b) + lgamma(b);
+  const NumericalScalar first(std::min(a, b));
+  if (first <= 0.0) throw InvalidArgumentException(HERE) << "Error: cannot compute the LogBeta function when a or b is nonpositive, a=" << a << ", b=" << b;
+  const NumericalScalar second(std::max(a, b));
+  const NumericalScalar sum(a + b);
+  // Common case: a and b small
+  if (second < 7.75) return lgamma(first) - lgamma(sum) + lgamma(second);
+  const NumericalScalar ratio(first / sum);
+  const NumericalScalar correctionSecond(GammaCorrection(second));
+  const NumericalScalar correctionSum(GammaCorrection(sum));
+  const NumericalScalar log1pRatio(log1p(-ratio));
+  // Case a and b large
+  if (first >= 7.75) return -0.5 * log(second) + SQRT2PI + GammaCorrection(first) + correctionSecond - correctionSum + (first + 0.5) * log(ratio) + second * log1pRatio;
+  // Case one of a,b large, the other small
+  return LogGamma(first) + correctionSecond - correctionSum + first * (1.0 - log(sum)) + (second - 0.5) * log1pRatio;
 }
 
 // LogBeta = LnBeta
@@ -209,63 +225,50 @@ NumericalScalar SpecFunc::Beta(const NumericalScalar a,
 }
 
 // Incomplete Beta function: BetaInc(a, b, x) = \int_0^x t^{a-1}(1-t)^{b-1} dt
-NumericalScalar SpecFunc::BetaInc(const NumericalScalar a,
-                                  const NumericalScalar b,
-                                  const NumericalScalar x)
+NumericalScalar SpecFunc::IncompleteBeta(const NumericalScalar a,
+    const NumericalScalar b,
+    const NumericalScalar x,
+    const Bool tail)
 {
-  return BetaRatioInc(a, b, x) * Beta(a, b);
+  return IncompleteBeta(a, b, x, tail) * Beta(a, b);
 }
 
 // Incomplete Beta function inverse
-NumericalScalar SpecFunc::BetaIncInv(const NumericalScalar a,
-                                     const NumericalScalar b,
-                                     const NumericalScalar x)
-{
-  return BetaRatioIncInv(a, b, x / Beta(a, b));
-}
-
-// Incomplete Beta Ratio function: BetaRatioInc(a, b, x) = 1/beta(a, b) * \int_0^x t^{a-1}(1-t)^{b-1} dt
-NumericalScalar SpecFunc::BetaRatioInc(const NumericalScalar a,
-                                       const NumericalScalar b,
-                                       const NumericalScalar x)
-{
-  if (x <= 0.0) return 0.0;
-  if (x >= 1.0) return 1.0;
-#ifdef USE_DCDFLIB
-  NumericalScalar inf(a);
-  NumericalScalar sup(b);
-  NumericalScalar t(x);
-  NumericalScalar y(1.0 - x);
-  NumericalScalar w;
-  NumericalScalar w1;
-  int ierr;
-  DCDFLIB::beta_inc(&inf, &sup, &t, &y, &w, &w1, &ierr);
-  return w;
-#else
-  throw NotYetImplementedException(HERE);
-#endif
-}
-
-// Incomplete Beta Ratio Function inverse
-NumericalScalar SpecFunc::BetaRatioIncInv(const NumericalScalar a,
+NumericalScalar SpecFunc::IncompleteBetaInverse(const NumericalScalar a,
     const NumericalScalar b,
-    const NumericalScalar x)
+    const NumericalScalar x,
+    const Bool tail)
 {
-#ifdef USE_DCDFLIB
-  int which(2);
-  NumericalScalar inf(a);
-  NumericalScalar sup(b);
-  NumericalScalar p(x);
-  NumericalScalar q(1.0 - x);
-  NumericalScalar X;
-  NumericalScalar Y;
-  int status;
-  NumericalScalar bound;
-  DCDFLIB::cdfbet(&which, &p, &q, &X, &Y, &inf, &sup, &status, &bound);
-  return X;
-#else
-  throw NotYetImplementedException(HERE);
-#endif
+  return RegularizedIncompleteBetaInverse(a, b, x / Beta(a, b), tail);
+}
+
+// Regularized Incomplete Beta function: RegularizedIncompleteBeta(a, b, x) = 1/beta(a, b) * \int_0^x t^{a-1}(1-t)^{b-1} dt
+NumericalScalar SpecFunc::RegularizedIncompleteBeta(const NumericalScalar a,
+    const NumericalScalar b,
+    const NumericalScalar x,
+    const Bool tail)
+{
+  return BetaFunctions::RegularizedIncompleteBeta(a, b, x, tail);
+}
+
+// Regularized incomplete Beta Function inverse
+NumericalScalar SpecFunc::RegularizedIncompleteBetaInverse(const NumericalScalar a,
+    const NumericalScalar b,
+    const NumericalScalar x,
+    const Bool tail)
+{
+  return BetaFunctions::RegularizedIncompleteBetaInverse(a, b, x, tail);
+}
+
+// Dawson function: Dawson(x) = \exp(-x^2) * \int_0^x \exp(t^2) dt
+NumericalScalar SpecFunc::Dawson(const NumericalScalar x)
+{
+  return Faddeeva::Dawson(x);
+}
+
+NumericalComplex SpecFunc::Dawson(const NumericalComplex & z)
+{
+  return Faddeeva::Dawson(z);
 }
 
 // Debye function of order n: DebyeN(x, n) = n / x^n \int_0^x t^n/(\exp(t)-1) dt
@@ -279,258 +282,46 @@ NumericalScalar SpecFunc::Debye(const NumericalScalar x,
   return debyen(x, static_cast<int>(n)) * n / pow(x, n);
 }
 
-// Dawson function: Dawson(x) = \exp(-x^2) * \int_0^x \exp(t^2) dt
-NumericalScalar SpecFunc::Dawson (NumericalScalar x)
+// DiLog function: DiLog(x) = -\int_0^x \log(1-t)/t dt
+NumericalScalar SpecFunc::DiLog(const NumericalScalar x)
 {
-  //----------------------------------------------------------------------
-  // Coefficients for R(9,9) approximation for  |x| < 2.5
-  //----------------------------------------------------------------------
-  static NumericalScalar p1[10] =
+  // Special case for 0
+  if (x == 0.0) return 0.0;
+  // No real value on (1, \infty)
+  if (x > 1.0) throw InvalidArgumentException(HERE) << "Error: the DiLog function does not take real values for arguments greater than 1.";
+  // Use DiLog(x) = -DiLog(1 / x) - \pi^2 / 6 - \log^2(-x) / 2
+  // to map (-\infty, -1) into (-1, 0) for the argument
+  if (x < -1.0) return -DiLog(1.0 / x) - SpecFunc::PI2_6  - 0.5 * pow(log(-x), 2);
+  // Use DiLog(x) = \pi^2 / 6 - DiLog(1 - x) - \log(x)\log(1-x)
+  // to map (1/2, 1] into [0, 1/2)
+  if (x > 0.5) return SpecFunc::PI2_6 - DiLog(1.0 - x) - log(x) * log1p(-x);
+  // Use DiLog(x) = DiLog(x^2) / 2 - DiLog(-x)
+  // to map [-1, 0) into (0, 1]
+  if (x < 0.0) return 0.5 * DiLog(x * x) - DiLog(-x);
+  // Use the definition of DiLog in terms of series
+  // DiLog(x)=\sum_{k=1}^{\infty} x^k/k^2
+  // for (0, 1/2)
+  // This upper bound is an easy-to compute tight upper bound of the number of iterations
+  const UnsignedLong nMax(static_cast<UnsignedLong>(round(8 + 68 * x)));
+  NumericalScalar value(0.0);
+  NumericalScalar powerX(1.0);
+  for (UnsignedLong n = 1; n <= nMax; ++n)
   {
-    -2.6902039878870478241e-12, 4.18572065374337710778e-10,
-    -1.34848304455939419963e-8, 9.28264872583444852976e-7,
-    -1.23877783329049120592e-5, 4.07205792429155826266e-4,
-    -0.00284388121441008500446, 0.0470139022887204722217,
-    -0.138868086253931995101,   1.00000000000000000004
-  };
-
-  static NumericalScalar q1[10] =
-  {
-    1.71257170854690554214e-10, 1.19266846372297253797e-8,
-    4.32287827678631772231e-7,  1.03867633767414421898e-5,
-    1.7891096528424624934e-4,   0.00226061077235076703171,
-    0.0207422774641447644725,   0.132212955897210128811,
-    0.527798580412734677256,    1.0
-  };
-
-  //----------------------------------------------------------------------
-  // Coefficients for R(9,9) approximation in J-fraction form
-  // for  x in [2.5, 3.5)
-  //----------------------------------------------------------------------
-
-  static NumericalScalar p2[10] =
-  {
-    -1.7095380470085549493,  -37.9258977271042880786,
-    26.1935631268825992835,   12.5808703738951251885,
-    -22.7571829525075891337,    4.56604250725163310122,
-    -7.3308008989640287075,   46.5842087940015295573,
-    -17.3717177843672791149,    0.500260183622027967838
-  };
-
-  static NumericalScalar q2[9] =
-  {
-    1.82180093313514478378, 1100.67081034515532891,
-    -7.08465686676573000364,  453.642111102577727153,
-    40.6209742218935689922,   302.890110610122663923,
-    170.641269745236227356,    951.190923960381458747,
-    0.206522691539642105009
-  };
-
-  //----------------------------------------------------------------------
-  // Coefficients for R(9,9) approximation in J-fraction form
-  // for  x in [3.5, 5.0]
-  //----------------------------------------------------------------------
-
-  static NumericalScalar p3[10] =
-  {
-    -4.55169503255094815112,  -18.6647123338493852582,
-    -7.36315669126830526754,  -66.8407240337696756838,
-    48.450726508149145213,     26.9790586735467649969,
-    -33.5044149820592449072,     7.50964459838919612289,
-    -1.48432341823343965307,    0.499999810924858824981
-  };
-
-  static NumericalScalar q3[9] =
-  {
-    44.7820908025971749852,    99.8607198039452081913,
-    14.0238373126149385228,  3488.17758822286353588,
-    -9.18871385293215873406, 1240.18500009917163023,
-    -68.8024952504512254535,    -2.3125157538514514307,
-    0.250041492369922381761
-  };
-
-  //----------------------------------------------------------------------
-  // Coefficients for R(9,9) approximation in J-fraction form
-  // for  |x| > 5.0
-  //----------------------------------------------------------------------
-
-  static NumericalScalar p4[10] =
-  {
-    -8.11753647558432685797,  -38.404388247745445343,
-    -22.3787669028751886675,   -28.8301992467056105854,
-    -5.99085540418222002197,  -11.3867365736066102577,
-    -6.5282872752698074159,    -4.50002293000355585708,
-    -2.50000000088955834952,    0.5000000000000004884
-  };
-
-  static NumericalScalar q4[9] =
-  {
-    269.382300417238816428,     50.4198958742465752861,
-    61.1539671480115846173,   208.210246935564547889,
-    19.7325365692316183531,   -12.2097010558934838708,
-    -6.99732735041547247161,   -2.49999970104184464568,
-    0.749999999999027092188
-  };
-
-  const NumericalScalar ax(fabs(x));
-  // Underflow for large argument
-  if (ax > 0.5 / MinNumericalScalar) return 0.0;
-  // Simple asymptotic expression for large argument
-  if (ax > 1.0 / sqrt(0.5 * MinNumericalScalar)) return 0.5 / x;
-  // Simple serie for small argument
-  if (ax < sqrt(0.5 * MinNumericalScalar)) return x;
-  const NumericalScalar  y(x * x);
-  // First range
-  if (y < 6.25)
-  {
-    NumericalScalar sump(p1[0]);
-    NumericalScalar sumq(q1[0]);
-    for (UnsignedLong i = 1; i < 10; ++i)
-    {
-      sump = sump * y + p1[i];
-      sumq = sumq * y + q1[i];
-    }
-    return x * sump / sumq;
+    powerX *= x;
+    value += powerX / (n * n);
   }
-  // Second range
-  if (y < 12.25)
-  {
-    NumericalScalar frac(0.0);
-    for (UnsignedLong i = 0; i < 9; ++i) frac = q2[i] / (p2[i] + y + frac);
-    return (p2[9] + frac) / x;
-  }
-  // Third range
-  if (y <= 25.0)
-  {
-    NumericalScalar frac(0.0);
-    for (UnsignedLong i = 0; i < 9; ++i) frac = q3[i] / (p3[i] + y + frac);
-    return (p3[9] + frac) / x;
-  }
-  // Fourth and last range
-  NumericalScalar frac(0.0);
-  for (UnsignedLong i = 0; i < 9; ++i) frac = q4[i] / (p4[i] + y + frac);
-  return (0.5 + 0.5 * (p4[9] + frac) / y) / x;
+  return value;
 }
 
 // Complex Faddeeva function: faddeeva(z) = \exp(-z^2)\erfc(-I*z)
 NumericalComplex SpecFunc::Faddeeva(const NumericalComplex & z)
 {
-  static const NumericalScalar factor(1.12837916709551257388);
-  const NumericalScalar xI(z.real());
-  const NumericalScalar yI(z.imag());
-  NumericalScalar u(0.0);
-  NumericalScalar v(0.0);
-  NumericalScalar u2(0.0);
-  NumericalScalar v2(0.0);
-  const NumericalScalar xAbs(fabs(xI));
-  const NumericalScalar yAbs(fabs(yI));
-  const NumericalScalar x(xAbs / 6.3);
-  const NumericalScalar y(yAbs / 4.4);
-  NumericalScalar qRho(x * x + y * y);
-  NumericalScalar xQuad(xAbs * xAbs - yAbs * yAbs);
-  NumericalScalar yQuad(2.0 * xAbs * yAbs);
-  Bool a(qRho < 0.085264);
-  // Power series for small magnitude argument
-  if (a)
-  {
-    qRho = (1.0 - 0.85 * y) * sqrt(qRho);
-    UnsignedLong n(static_cast<UnsignedLong>(round(6 + 72 * qRho)));
-    UnsignedLong j(2 * n + 1);
-    NumericalScalar xSum(1.0 / j);
-    NumericalScalar ySum(0.0);
-    for (UnsignedLong i = n; i > 0; --i)
-    {
-      j -= 2;
-      NumericalScalar xAux((xSum * xQuad - ySum * yQuad) / i);
-      ySum = (xSum * yQuad + ySum * xQuad) / i;
-      xSum = xAux + 1.0 / j;
-    }
-    NumericalScalar u1(-factor * (xSum * yAbs + ySum * xAbs) + 1.0);
-    NumericalScalar v1(factor * (xSum * xAbs - ySum * yAbs));
-    NumericalScalar dAux(exp(-xQuad));
-    u2 = dAux * cos(yQuad);
-    v2 = -dAux * sin(yQuad);
-    u = u1 * u2 - v1 * v2;
-    v = u1 * v2 + v1 * u2;
-  }
-  // Laplace continued fraction for large argument, truncated Taylor expansion for intermediate argument
-  else
-  {
-    NumericalScalar h(0.0);
-    UnsignedLong kApn(0);
-    UnsignedLong nu(0);
-    NumericalScalar h2(0.0);
-    if (qRho > 1.0)
-    {
-      qRho = sqrt(qRho);
-      nu = static_cast<UnsignedLong>(round(3 + (1442 / (26 * qRho + 77))));
-    }
-    else
-    {
-      qRho = (1.0 - y) * sqrt(1.0 - qRho);
-      h = 1.88 * qRho;
-      h2 = 2.0 * h;
-      kApn = static_cast<UnsignedLong>(round(7 + 34 * qRho));
-      nu = static_cast<UnsignedLong>(round(16 + 26 * qRho));
-    }
-    Bool b(h > 0.0);
-    NumericalScalar qLambda(0.0);
-    if (b) qLambda = pow(h2, kApn);
-    NumericalScalar rX(0.0);
-    NumericalScalar rY(0.0);
-    NumericalScalar sX(0.0);
-    NumericalScalar sY(0.0);
-    for (UnsignedLong n = nu + 1; n > 0; --n)
-    {
-      NumericalScalar tX(yAbs + h + n * rX);
-      NumericalScalar tY(xAbs - n * rY);
-      NumericalScalar c(0.5 / (tX * tX + tY * tY));
-      rX = c * tX;
-      rY = c * tY;
-      if (b && (n <= kApn + 1))
-      {
-        tX = qLambda + sX;
-        sX = rX * tX - rY * sY;
-        sY = rY * tX + rX * sY;
-        qLambda /= h2;
-      }
-    }
-    if (h == 0.0)
-    {
-      u = factor * rX;
-      v = factor * rY;
-    }
-    else
-    {
-      u = factor * sX;
-      v = factor * sY;
-    }
-    if (yAbs == 0.0) u = exp(-xAbs * xAbs);
-  }
-  // Deal with the other quadrants
-  if (yI < 0.0)
-  {
-    if (a)
-    {
-      u2 *= 2.0;
-      v2 *= 2.0;
-    }
-    else
-    {
-      xQuad = -xQuad;
-      NumericalScalar w1(2.0 * exp(xQuad));
-      u2 = w1 * cos(yQuad);
-      v2 = -w1 * sin(yQuad);
-    }
-    u = u2 - u;
-    v = v2 - v;
-    if (xI > 0.0) v = -v;
-  }
-  else
-  {
-    if (xI < 0.0) v = -v;
-  }
-  return NumericalComplex(u, v);
+  return Faddeeva::w(z);
+}
+
+NumericalScalar SpecFunc::FaddeevaIm(const NumericalScalar x)
+{
+  return Faddeeva::w_im(x);
 }
 
 // Gamma function: Gamma(a) = \int_0^{\infty} t^{a-1}\exp(-t) dt
@@ -539,6 +330,38 @@ NumericalScalar SpecFunc::Gamma(const NumericalScalar a)
   return tgamma(a);
 }
 
+// igamma1pm1(a) = 1 / Gamma(1 + a) - 1
+NumericalScalar SpecFunc::IGamma1pm1(const NumericalScalar a)
+{
+  if (a < -0.5) return a + IGamma1pm1(a + 1.0);
+  if (a > 0.5) return (IGamma1pm1(a - 1.0) - a) / (1.0 + a);
+  return a * (0.55840397973848040460 +    (-0.28693519326375203685 +
+              (-0.28661639813928077048 +     (0.56469202267873782108e-2 +
+                  (0.12419086997568707715e-1 + (-0.28455238049924868708e-2 +
+                      (-0.11632361891621759586e-3 +   0.43452535150473018757e-4 * a) * a) * a) * a) * a) * a) * a) /
+         (0.967409607349687017271 +    (0.602145048219053169110 +
+                                        (0.258051013832915714221 +    (0.677000815494264186575e-1 +
+                                            (0.142113296913915958898e-1 + (0.183821175266489590252e-2 +
+                                                0.192078142776918599109e-3 * a) * a) * a) * a) * a) * a);
+}
+
+// GammaCorrection(a) = LogGamma(a) - log(sqrt(2.Pi)) + a - (a - 1/2) log(a)
+NumericalScalar SpecFunc::GammaCorrection(const NumericalScalar a)
+{
+  if (a <= 0.0) throw InvalidArgumentException(HERE) << "Error: cannot compute GammaCorrection for nonpositive a, here a=" << a;
+  // Use an asymptotic series for large argument
+  if (a > 7.7490453948312251620)
+  {
+    const NumericalScalar ia2(1.0 / (a * a));
+    return (0.83333333333333333333e-1 + (-0.27777777777777777778e-2 +
+                                         (0.79365079365079365079e-3 + (-0.59523809523809523810e-3 +
+                                             (0.84175084175084175084e-3 + (-0.19175269175269175269e-2 +
+                                                 (0.64102564102564102564e-2 + (-0.29550653594771241830e-1 +
+                                                     (0.17964437236883057316e0 - 0.13924322169059011164e1 * ia2) * ia2) * ia2) * ia2) * ia2) * ia2) * ia2) * ia2) * ia2) / a;
+  }
+  return LogGamma(a) + a - (a - 0.5) * log(a) - LOGSQRT2PI;
+}
+
 // Complex gamma function: Gamma(a) = \int_0^{\infty} t^{a-1}\exp(-t) dt,
 // Computed using Lanczos approximation, using a C++ translation of
 // Paul Godfrey's matlab implementation
@@ -546,6 +369,12 @@ NumericalScalar SpecFunc::Gamma(const NumericalScalar a)
 NumericalComplex SpecFunc::Gamma(const NumericalComplex & a)
 {
   if (a.imag() == 0.0) return Gamma(a.real());
+  return exp(LogGamma(a));
+}
+
+NumericalComplex SpecFunc::LogGamma(const NumericalComplex & a)
+{
+  if (a.imag() == 0.0) return LogGamma(a.real());
   const NumericalScalar sqrt2Pi(sqrt(2.0 * M_PI));
   NumericalComplex z(a);
   Bool flip(false);
@@ -575,56 +404,73 @@ NumericalComplex SpecFunc::Gamma(const NumericalComplex & a)
   }
   s += coefficients[0];
   s = log(s * sqrt2Pi) + (z - 0.5) * log(ss) - ss;
-  NumericalComplex f(exp(s));
-  if (flip) f = -M_PI / (a * f * sin(M_PI * a));
+  NumericalComplex f(s);
+  if (flip) f = f + Log1p(-M_PI * exp(-f) / (a * f * sin(M_PI * a)));
   return f;
 }
 
 // Natural logarithm of the Gamma function
 NumericalScalar SpecFunc::LnGamma(const NumericalScalar a)
 {
-  return lgamma(a);
+  return LogGamma(a);
 }
 
 // LogGamma = LnGamma
 NumericalScalar SpecFunc::LogGamma(const NumericalScalar a)
 {
-  return LnGamma(a);
+  return lgamma(a);
 }
 
-// Incomplete Gamma function: GammaInc(a, x) = \int_0^x t^{a-1}\exp(-t) dt
-NumericalScalar SpecFunc::GammaInc(const NumericalScalar a,
-                                   const NumericalScalar x)
+NumericalScalar SpecFunc::LogGamma1p(const NumericalScalar a)
 {
-#ifdef USE_DCDFLIB
-  NumericalScalar k(a);
-  NumericalScalar t(x);
-  NumericalScalar ans;
-  NumericalScalar qans;
-  int ind(0);
-  DCDFLIB::gamma_inc(&k, &t, &ans, &qans, &ind);
-  return ans * SpecFunc::Gamma(a);
-#else
-  throw NotYetImplementedException(HERE);
-#endif
+  return (fabs(a) < 0.5 ? -a * (0.34229051727072805652 +
+                                (0.75305954018877769214 +
+                                 (0.25594427350421023219 +
+                                  (-0.54867134418632830931 +
+                                   (-0.57006260085649768851 +
+                                    (-0.20361938002564003637 +
+                                     (-0.27922966566918143201e-1 -
+                                      0.10180389882069314488e-2 * a) * a) * a) * a) * a) * a) * a) /
+          (0.59300282040876235168 +
+           (0.21496034951064079616e1 +
+            (0.30947091018029240660e1 +
+             (0.22448538584537209829e1 +
+              (0.85741167089803858333 +
+               (0.16321946228463159159 +
+                (0.12893353820029086191e-1 +
+                 0.24787923059095734273e-3 * a) * a) * a) * a) * a) * a) * a) : LogGamma(a - 1.0));
+}
+
+// Incomplete Gamma function: IncompleteGamma(a, x) = \int_0^x t^{a-1}\exp(-t) dt
+NumericalScalar SpecFunc::IncompleteGamma(const NumericalScalar a,
+    const NumericalScalar x,
+    const Bool tail)
+{
+  return GammaFunctions::IncompleteGamma(a, x, tail);
 }
 
 // Incomplete Gamma function inverse with respect to x
-NumericalScalar SpecFunc::GammaIncInv(const NumericalScalar a,
-                                      const NumericalScalar x)
+NumericalScalar SpecFunc::IncompleteGammaInverse(const NumericalScalar a,
+    const NumericalScalar x,
+    const Bool tail)
 {
-#ifdef USE_DCDFLIB
-  NumericalScalar k(a);
-  NumericalScalar X;
-  NumericalScalar X0(0.0);
-  NumericalScalar p(x);
-  NumericalScalar q(1.0 - x);
-  int ierr;
-  DCDFLIB::gamma_inc_inv(&k, &X, &X0, &p, &q, &ierr);
-  return X;
-#else
-  throw NotYetImplementedException(HERE);
-#endif
+  return GammaFunctions::IncompleteGammaInverse(a, x, tail);
+}
+
+// Regularized incomplete Gamma function: RegularizedIncompleteGamma(a, x) = \int_0^x t^{a-1}\exp(-t) dt / \Gamma(a)
+NumericalScalar SpecFunc::RegularizedIncompleteGamma(const NumericalScalar a,
+    const NumericalScalar x,
+    const Bool tail)
+{
+  return GammaFunctions::RegularizedIncompleteGamma(a, x, tail);
+}
+
+// Regularized incomplete Gamma function inverse with respect to x
+NumericalScalar SpecFunc::RegularizedIncompleteGammaInverse(const NumericalScalar a,
+    const NumericalScalar x,
+    const Bool tail)
+{
+  return GammaFunctions::RegularizedIncompleteGammaInverse(a, x, tail);
 }
 
 // Digamma function: Psi(x) = ((dgamma/dx) / gamma)(x)
@@ -635,7 +481,7 @@ NumericalScalar SpecFunc::DiGamma(const NumericalScalar x)
   if ((x <= 0.0) && (x == round(x))) throw InvalidArgumentException(HERE) << "Error: the argument of the DiGamma function cannot be a non positive integer.";
   // Approximation for small arguments
   // Here, 0.025 is a bound that insure NumericalScalar precision approximation
-  if ( fabs(x) <= 0.025 ) return -1.0 / x - .57721566490153286 + (1.6449340668482264 + (-1.2020569031595943 + (1.0823232337111381 + (-1.0369277551433699 + (1.0173430619844491 + (-1.0083492773819228 + (1.0040773561979442 + (-1.0020083928260822 + 1.0009945751278180 * x) * x) * x) * x) * x) * x) * x) * x) * x;
+  if ( fabs(x) <= 0.025 ) return -1.0 / x - 0.57721566490153286 + (1.6449340668482264 + (-1.2020569031595943 + (1.0823232337111381 + (-1.0369277551433699 + (1.0173430619844491 + (-1.0083492773819228 + (1.0040773561979442 + (-1.0020083928260822 + 1.0009945751278180 * x) * x) * x) * x) * x) * x) * x) * x) * x;
   // If the argument is negative, use the reflexion formula
   if (x < 0.0) return -M_PI / tan(M_PI * x) + DiGamma(1.0 - x);
   // Shift the argument until it reaches the asymptotic expansion region
@@ -662,15 +508,14 @@ NumericalScalar SpecFunc::DiGammaInv(const NumericalScalar a)
 {
   // Initialization using an asymptotic approximation of the DiGamma function
   NumericalScalar x( a < -2.22 ? -1.0 / (a - EulerConstant) : exp(a) + 0.5);
-  // Use a Newton scheme with six iterations
+  // Use a Newton scheme
   NumericalScalar d(0.0);
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
-  do
+  for (UnsignedLong k = 0; k < 6; ++k)
   {
     d = (DiGamma(x) - a) / TriGamma(x);
+    if (d == 0.0) break;
     x -= d;
   }
-  while (fabs(d) > precision);
   return x;
 }
 
@@ -718,7 +563,7 @@ NumericalScalar SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
   NumericalScalar factorial(1.0);
   NumericalScalar sum(term);
   NumericalScalar eps;
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
+  UnsignedLong k(0);
   do
   {
     term *= pochhammerP1 * t / (pochhammerQ1 * factorial);
@@ -727,8 +572,9 @@ NumericalScalar SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
     ++factorial;
     sum += term;
     eps = fabs(term / sum);
+    ++k;
   }
-  while (eps > precision);
+  while ((eps > 0.0) && (k < SpecFunc::MaximumIteration));
   return sum;
 }
 
@@ -743,7 +589,7 @@ NumericalComplex SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
   NumericalComplex term(1.0);
   NumericalComplex sum(term);
   NumericalComplex eps(0.0);
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
+  UnsignedLong k(0);
   do
   {
     term *= pochhammerP1 * x / (pochhammerQ1 * factorial);
@@ -752,8 +598,9 @@ NumericalComplex SpecFunc::HyperGeom_1_1(const NumericalScalar p1,
     ++factorial;
     sum += term;
     eps = term / sum;
+    ++k;
   }
-  while (abs(eps) > precision);
+  while ((abs(eps) > 0.0) && (k < SpecFunc::MaximumIteration));
   return sum;
 }
 
@@ -770,7 +617,7 @@ NumericalScalar SpecFunc::HyperGeom_2_1(const NumericalScalar p1,
   NumericalScalar term(1.0);
   NumericalScalar sum(term);
   NumericalScalar eps(0.0);
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
+  UnsignedLong k(0);
   do
   {
     term *= pochhammerP1 * pochhammerP2 * x / (pochhammerQ1 * factorial);
@@ -780,8 +627,9 @@ NumericalScalar SpecFunc::HyperGeom_2_1(const NumericalScalar p1,
     ++factorial;
     sum += term;
     eps = fabs(term / sum);
+    ++k;
   }
-  while (eps > precision);
+  while ((eps > 0.0) && (k < SpecFunc::MaximumIteration));
   return sum;
 }
 
@@ -804,7 +652,7 @@ NumericalScalar SpecFunc::HyperGeom_2_2(const NumericalScalar p1,
   const NumericalScalar logX(log(fabs(x)));
   NumericalScalar signX(x > 0.0 ? 1.0 : -1.0);
   NumericalScalar signTerm(1.0);
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
+  UnsignedLong k(0);
   do
   {
     term += log(pochhammerP1) + log(pochhammerP2) + logX - log(pochhammerQ1) - log(pochhammerQ2) - log(factorial);
@@ -816,25 +664,59 @@ NumericalScalar SpecFunc::HyperGeom_2_2(const NumericalScalar p1,
     sum += signTerm * exp(term);
     signTerm *= signX;
     eps = fabs(term / sum);
+    ++k;
   }
-  while (eps > precision);
+  while ((eps > 0.0) && (k < SpecFunc::MaximumIteration));
   return sum;
 }
 
 // Erf function Erf(x) = 2 / sqrt(Pi) . \int_0^x \exp(-t^2) dt
 NumericalScalar SpecFunc::Erf(const NumericalScalar x)
 {
-  return erf(x);
+  return Faddeeva::erf(x);
 }
 
-// Erfc function ErfC(x) = 1 - Erf(x)
+NumericalComplex SpecFunc::Erf(const NumericalComplex & z)
+{
+  return Faddeeva::erf(z);
+}
+
+// Erf function ErfI(x) = -i.erf(ix)
+NumericalScalar SpecFunc::ErfI(const NumericalScalar x)
+{
+  return Faddeeva::erfi(x);
+}
+
+NumericalComplex SpecFunc::ErfI(const NumericalComplex & z)
+{
+  return Faddeeva::erfi(z);
+}
+
+// Erf function ErfC(x) = 1 - Erf(x)
 NumericalScalar SpecFunc::ErfC(const NumericalScalar x)
 {
-  return erfc(x);
+  return Faddeeva::erfc(x);
+}
+
+NumericalComplex SpecFunc::ErfC(const NumericalComplex & z)
+{
+  return Faddeeva::erfc(z);
+}
+
+// Erf function ErfCX(x) = exp(x^2).erfC(x)
+NumericalScalar SpecFunc::ErfCX(const NumericalScalar x)
+{
+  return Faddeeva::erfcx(x);
+}
+
+NumericalComplex SpecFunc::ErfCX(const NumericalComplex & z)
+{
+  return Faddeeva::erfcx(z);
 }
 
 // Inverse of the Erf function
-NumericalScalar SpecFunc::ErfInv(const NumericalScalar x)
+// We use a rational approximation followed by one Halley's iteration (higher order Newton iteration)
+NumericalScalar SpecFunc::ErfInverse(const NumericalScalar x)
 {
   NumericalScalar p(0.5 * (x + 1.0));
   static const NumericalScalar a[6] =
@@ -889,7 +771,7 @@ NumericalScalar SpecFunc::ErfInv(const NumericalScalar x)
   return (p > 0.5 ? -M_SQRT1_2 * u : M_SQRT1_2 * u);
 }
 
-/* Evaluation of the principal barnch of Lambert W function.
+/* Evaluation of the principal branch of Lambert W function.
    Based on formulas exposed in:
    Robert M. Corless, G. H. Gonnet, D. E. G. Hare, D. J. Jeffrey, and D. E. Knuth, "On the Lambert W Function", Advances in Computational Mathematics, volume 5, 1996, pp. 329--359
 */
@@ -903,10 +785,7 @@ NumericalScalar SpecFunc::LambertW(const NumericalScalar x,
   if (principal)
   {
     if (x == 0) return 0.0;
-    if(x < 6.46)
-    {
-      w = x * (3.0 + 4.0 * x) / (3.0 + x * (7.0 + 2.5 * x));
-    }
+    if(x < 6.46) w = x * (3.0 + 4.0 * x) / (3.0 + x * (7.0 + 2.5 * x));
     // Large argument, use asymptotic expansion, formula 4.18
     else
     {
@@ -918,10 +797,7 @@ NumericalScalar SpecFunc::LambertW(const NumericalScalar x,
   else
   {
     if (x >= 0.0) return -INFINITY;
-    if (x < -0.1)
-    {
-      w = -2.0;
-    }
+    if (x < -0.1) w = -2.0;
     else
     {
       const NumericalScalar t1(log(-x));
@@ -929,18 +805,32 @@ NumericalScalar SpecFunc::LambertW(const NumericalScalar x,
     }
   }
   // Halley's iteration
-  const NumericalScalar precision(ResourceMap::GetAsNumericalScalar( "SpecFunc-Precision" ));
   for (UnsignedLong i = 0; i < 3; ++i)
   {
     const NumericalScalar expW(exp(w));
     const NumericalScalar numerator(w * expW - x);
     const NumericalScalar dw(numerator / (expW * (w + 1.0) - 0.5 * (w + 2.0) * numerator / (w + 1.0)));
     w -= dw;
-    if (fabs(dw) < precision) break;
   }
   return w;
 }
 
+// Accurate evaluation of log(1+z) for |z|<<1
+NumericalComplex SpecFunc::Log1p(const NumericalComplex & z)
+{
+  if (std::norm(z) < 1e-5) return z * (1.0 + z * (-0.5 + z / 3.0));
+  return log(1.0 + z);
+}
+
+// Accurate evaluation of log(1-exp(-x)) for all x > 0
+NumericalComplex SpecFunc::Log1MExp(const NumericalScalar x)
+{
+  if (x <= 0.0) throw InvalidArgumentException(HERE) << "Error: x must be positive";
+  if (x <= M_LN2) return log(-expm1(-x));
+  return log1p(-exp(-x));
+}
+
+// Compute the smallest power of two greater or equal to the given n
 UnsignedLong SpecFunc::NextPowerOfTwo(const UnsignedLong n)
 {
   UnsignedLong powerOfTwo(1);
