@@ -3,7 +3,7 @@
  *  @file  TrendTransform.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -45,8 +45,6 @@ TrendTransform::TrendTransform()
 TrendTransform::TrendTransform(const NumericalMathFunction & function)
   : TemporalFunction()
 {
-  if (function.getInputDimension() != 1)
-    throw InvalidDimensionException(HERE) << "NumericalMathFunction input dimension should be 1 for trend" ;
   p_evaluation_ = function.getEvaluationImplementation() ;
   // Set the descriptions
   setInputDescription(p_evaluation_->getInputDescription());
@@ -57,8 +55,6 @@ TrendTransform::TrendTransform(const NumericalMathFunction & function)
 TrendTransform::TrendTransform(const EvaluationImplementation & p_evaluation)
   : TemporalFunction()
 {
-  if (p_evaluation->getInputDimension() != 1)
-    throw InvalidDimensionException(HERE) << "NumericalMathFunction input dimension should be 1 for trend" ;
   p_evaluation_ = p_evaluation;
   // Set the descriptions
   setInputDescription(p_evaluation_->getInputDescription());
@@ -69,8 +65,6 @@ TrendTransform::TrendTransform(const EvaluationImplementation & p_evaluation)
 TrendTransform::TrendTransform(const NumericalMathEvaluationImplementation & evaluation)
   : TemporalFunction()
 {
-  if (evaluation.getInputDimension() != 1)
-    throw InvalidDimensionException(HERE) << "NumericalMathFunction input dimension should be 1 for trend" ;
   p_evaluation_ = evaluation.clone();
 }
 
@@ -89,7 +83,7 @@ Bool TrendTransform::operator ==(const TrendTransform & other) const
 /* String converter */
 String TrendTransform::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << TrendTransform::GetClassName()
       << " evaluation=" << p_evaluation_->__repr__();
   return oss;
@@ -102,25 +96,15 @@ String TrendTransform::__str__(const String & offset) const
 }
 
 /* Operator () */
-TimeSeries TrendTransform::operator() (const TimeSeries & inTS) const
+Field TrendTransform::operator() (const Field & inFld) const
 {
-  // The underlying function is from R to R^n
-
-  // first we extract the timeGrid as a NumericalSample
-  const UnsignedLong n(inTS.getSize());
-  NumericalSample timeGridAsSample(n, 1);
-
-  for (UnsignedLong k = 0; k < n; ++k) timeGridAsSample[k][0] = inTS[k][0];
-
-  // then we evaluate the function on the previous grid
-  // result is a NumericalSample of dimension d = function.getOutputDimension()
-  NumericalSample outputSample((*p_evaluation_)(timeGridAsSample));
-  const UnsignedLong dimension(outputSample.getDimension());
+  if (inFld.getMeshDimension() != p_evaluation_->getInputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with mesh dimension=" << p_evaluation_->getInputDimension() << ", got mesh dimension=" << inFld.getMeshDimension();
+  if (inFld.getDimension() != p_evaluation_->getOutputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a Field with dimension=" << p_evaluation_->getOutputDimension() << ", got dimension=" << inFld.getDimension();
+  NumericalSample outputSample((*p_evaluation_)(inFld.getMesh().getVertices()));
   // finally as the function adds a trend, result
-  for (UnsignedLong k = 0; k < n; ++k)
-    for (UnsignedLong d = 0; d < dimension; ++d) outputSample[k][d] += inTS[k][d + 1];
+  for (UnsignedLong k = 0; k < outputSample.getSize(); ++k) outputSample[k] = inFld.getValueAtIndex(k) + outputSample[k];
   ++callsNumber_;
-  return TimeSeries(inTS.getTimeGrid(), outputSample);
+  return Field(inFld.getMesh(), outputSample);
 }
 
 /* Inverse accessor */
