@@ -3,7 +3,7 @@
  *  @file  UniVariatePolynomial.cxx
  *  @brief This is a 1D polynomial
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,13 +71,13 @@ UniVariatePolynomial::UniVariatePolynomial(UniVariatePolynomialImplementation *
 /* String converter */
 String UniVariatePolynomial::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " coefficients=" << getImplementation()->getCoefficients().__repr__();
 }
 
 String UniVariatePolynomial::__str__(const String & offset) const
 {
-  return OSS() << getImplementation()->__str__("X", offset);
+  return OSS(false) << getImplementation()->__str__("X", offset);
 }
 
 String UniVariatePolynomial::__str__(const String & variableName,
