@@ -3,7 +3,7 @@
  *  @file  UniVariatePolynomialImplementation.cxx
  *  @brief This is a 1D polynomial
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -70,7 +70,7 @@ UniVariatePolynomialImplementation * UniVariatePolynomialImplementation::clone()
 /* String converter */
 String UniVariatePolynomialImplementation::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " coefficients=" << coefficients_.__repr__();
 }
 
@@ -82,7 +82,7 @@ String UniVariatePolynomialImplementation::__str__(const String & offset) const
 String UniVariatePolynomialImplementation::__str__(const String & variableName,
     const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   const UnsignedLong size(coefficients_.getSize());
   // Specific case for empty polynomial
   if (size == 0) return oss;
@@ -91,7 +91,7 @@ String UniVariatePolynomialImplementation::__str__(const String & variableName,
   {
     const NumericalScalar aI(coefficients_[i]);
     // Only deal with non-zero coefficients
-    if (String(OSS() << fabs(aI)) != "0")
+    if (String(OSS(false) << fabs(aI)) != "0")
     {
       // Special case for the first term: no + sign, no leading blank and no trailing blank for the - sign
       if (firstTerm)
@@ -104,7 +104,7 @@ String UniVariatePolynomialImplementation::__str__(const String & variableName,
         else
         {
           // Print the coefficient only if its absolute value is not 1
-          if (String(OSS() << fabs(aI)) != "1") oss << fabs(aI) << " * ";
+          if (String(OSS(false) << fabs(aI)) != "1") oss << fabs(aI) << " * ";
           oss << variableName;
           // Print the exponent only if it is > 1
           if (i > 1) oss << "^" << i;
@@ -117,7 +117,7 @@ String UniVariatePolynomialImplementation::__str__(const String & variableName,
         // Here, i > 0
         if (aI > 0.0) oss << " + ";
         else oss << " - ";
-        if (String(OSS() << fabs(aI)) != "1") oss << fabs(aI) << " * ";
+        if (String(OSS(false) << fabs(aI)) != "1") oss << fabs(aI) << " * ";
         oss << variableName;
         // Print the exponent only if it is > 1
         if (i > 1) oss << "^" << i;
