@@ -3,7 +3,7 @@
  *  @file  WrapperData.cxx
  *  @brief This class declares the wrapper data that are exchanged with the platform
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,7 +66,7 @@ WrapperFunctionDescription::WrapperFunctionDescription()
 
 String WrapperFunctionDescription::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "name="      << name_
       << " provided=" << wrapper_getProvidedAsString( provided_ );
   return oss;
@@ -74,7 +74,7 @@ String WrapperFunctionDescription::__repr__() const
 
 String WrapperFunctionDescription::__str__(const String & offset) const
 {
-  if (provided_) return OSS() << name_;
+  if (provided_) return OSS(false) << name_;
   else return "Not provided";
 }
 
@@ -119,37 +119,6 @@ String WrapperDataFile::__str__(const String & offset) const
 
 
 
-WrapperFrameworkData::WrapperFrameworkData()
-  : studyid_(0),
-    studycase_(),
-    componentname_()
-{
-  // Nothing to do
-}
-
-String WrapperFrameworkData::__repr__() const
-{
-  OSS oss;
-  oss << "studyid="        << studyid_
-      << " studycase="     << studycase_
-      << " componentname=" << componentname_;
-  return oss;
-}
-
-String WrapperFrameworkData::__str__(const String & offset) const
-{
-  OSS oss;
-  oss << offset << "studyid       : " << studyid_ << "\n"
-      << offset << "studycase     : " << studycase_ << "\n"
-      << offset << "componentname : " << componentname_;
-  return oss;
-}
-
-
-
-
-
-
 WrapperDataVariable::WrapperDataVariable()
   : id_(),
     comment_(),
@@ -257,8 +226,7 @@ WrapperData::WrapperData()
     hessian_(),
     p_fileList_(new WrapperData::FileListType),
     p_variableList_(new WrapperData::VariableListType),
-    p_parameters_(new WrapperParameter),
-    p_framework_(new WrapperFrameworkData)
+    p_parameters_(new WrapperParameter)
 {
   // Nothing to do
 }
@@ -273,8 +241,7 @@ WrapperData::WrapperData(const struct WrapperExchangedData * p_exchangedData)
     hessian_(),
     p_fileList_(new WrapperData::FileListType),
     p_variableList_(new WrapperData::VariableListType),
-    p_parameters_(new WrapperParameter),
-    p_framework_(new WrapperFrameworkData)
+    p_parameters_(new WrapperParameter)
 {
   if ( p_exchangedData )
   {
@@ -356,7 +323,6 @@ String WrapperData::__repr__() const
   std::copy( p_variableList_->begin(), p_variableList_->end(), OSS_iterator<WrapperDataVariable>(oss, ", ") );
 
   oss << "] parameters={" << *p_parameters_
-      << "} framework={" << *p_framework_
       << "}";
   return oss;
 
@@ -384,8 +350,7 @@ String WrapperData::__str__(const String & offset) const
              String(",\n") + offset_vl) );
 
   oss << "]/" << p_variableList_->getSize() << "\n"
-      << offset << "parameters :\n" << p_parameters_->__str__( offset + "            " ) << "\n"
-      << offset << "framework :\n"  << p_framework_->__str__( offset + "           " );
+      << offset << "parameters :\n" << p_parameters_->__str__( offset + "            " );
   return oss;
 
 }
@@ -623,42 +588,6 @@ void WrapperData::FreeParametersForCInterface(const struct WrapperConfiguration
 }
 
 
-
-
-/* Accessor */
-void WrapperData::setFrameworkData(const WrapperFrameworkData & framework)
-{
-  p_framework_.reset(new WrapperFrameworkData(framework));
-}
-
-const WrapperFrameworkData & WrapperData::getFrameworkData() const
-{
-  return *p_framework_;
-}
-
-
-/* Conversion method for C interface */
-struct FrameworkData * WrapperData::getNewFrameworkForCInterface() const
-{
-  struct FrameworkData * framework = newC<FrameworkData>();
-
-  framework->studyid_       = p_framework_->studyid_;
-  framework->studycase_     = strdup( p_framework_->studycase_.c_str() );
-  framework->componentname_ = strdup( p_framework_->componentname_.c_str() );
-
-  return framework;
-}
-
-/* Frees the memory allocated by getNewFrameworkForCInterface() method */
-void WrapperData::FreeFrameworkForCInterface(const struct FrameworkData * framework)
-{
-  free( framework->studycase_ );
-  free( framework->componentname_ );
-  deleteC( framework );
-}
-
-
-
 /* Builds a newly allocated WrapperExchangedData structure */
 struct WrapperExchangedData * WrapperData::getNewWrapperExchangedDataForCInterface() const
 {
@@ -669,7 +598,6 @@ struct WrapperExchangedData * WrapperData::getNewWrapperExchangedDataForCInterfa
   p_exchangedData->variableList_ = getNewVariableListForCInterface();
   p_exchangedData->parameters_   = getNewParametersForCInterface();
   p_exchangedData->platform_     = newC<PlatformConfiguration>();
-  p_exchangedData->framework_    = getNewFrameworkForCInterface();
 
   p_exchangedData->platform_->generalTemporaryDirectory_ = strdup( Path::GetTemporaryDirectory().c_str() );;
   p_exchangedData->platform_->realRegexpShortcut_        = ResourceMap::GetAsNewCharArray("real-regexp-shortcut");
@@ -708,9 +636,6 @@ void WrapperData::FreeWrapperExchangedDataForCInterface(const struct WrapperExch
   free( exchangedData->platform_->command_path_ ); // free() here because command_path_ allocated in C
   deleteC( exchangedData->platform_ );
 
-  // ... framework
-  WrapperData::FreeFrameworkForCInterface( exchangedData->framework_ );
-
   // Destroy the embedded mutex
   destroyMutex( exchangedData );
 
