@@ -3,7 +3,7 @@
  *  @file  WrapperFile.cxx
  *  @brief This class provides all the treatments for wrapper file manipulation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -95,7 +95,7 @@ WrapperFile * WrapperFile::clone() const
 /* String converter */
 String WrapperFile::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << getClassName()
       << " path=" << getDescriptionFilePath()
       << " version=" << version_
