@@ -3,7 +3,7 @@
  *  @file  WrapperFile_version1.cxx
  *  @brief This class provides the elementary functions for wrapper file management (version 1)
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,6 +28,7 @@
 #include "Path.hxx"
 #include "Os.hxx"
 #include "WrapperCommon_extern.h"
+#include "XMLToolbox.hxx"
 
 #ifdef XML_SUPPORTED
 #include "XMLTags.hxx"
@@ -219,7 +220,6 @@ WrapperData ParseDocument_version1(const XMLDoc & doc)
   XML::Node externalCodeElt = XML::FindElementByName( wrapperElt, XMLTag_external_code );
   XML::Node dataElt         = XML::FindElementByName( externalCodeElt, XMLTag_data );
   WrapperData::FileListType fileList;
-  WrapperFrameworkData framework;
   Bool hasOneOrMoreInputFiles  = false;
   Bool hasOneOrMoreOutputFiles = false;
   if (XML::IsElement(dataElt))
@@ -274,28 +274,11 @@ WrapperData ParseDocument_version1(const XMLDoc & doc)
       }
       else if (XML::IsElement(current, XMLTag_framework))
       {
-        XML::Node studyidElt                    = XML::FindElementByName( current, XMLTag_study_id );
-        if (studyidElt)
-        {
-          std::istringstream iss( XML::GetNodeValue( studyidElt ) );
-          iss >> framework.studyid_;
-        }
-
-        XML::Node studycaseElt                  = XML::FindElementByName( current, XMLTag_study_case );
-        if (studycaseElt) framework.studycase_  = XML::GetNodeValue( studycaseElt );
-
-        XML::Node componentnameElt              = XML::FindElementByName( current, XMLTag_component_name );
-        if (componentnameElt) framework.componentname_  = XML::GetNodeValue( componentnameElt );
-
-        LOGDEBUG(OSS() << "Read data framework studyid           : " << framework.studyid_);
-        LOGDEBUG(OSS() << "                ... studycase         : " << framework.studycase_);
-        LOGDEBUG(OSS() << "                ... component name    : " << framework.componentname_);
+        LOGWARN( OSS() << "The framework tag is deprecated" );
       }
     }
   }
   data.setFileList( fileList );
-  data.setFrameworkData( framework );
-
 
   WrapperParameter parameters;
   XML::Node wrapModeElt = XML::FindElementByName( externalCodeElt, XMLTag_wrap_mode );
@@ -520,23 +503,6 @@ XMLDoc MakeDocument_version1(const WrapperFile & wrapperFile)
     }
   } /* end for ( it = fList.begin() ; ... ) */
 
-  // Create <framework> node
-  XML::Node framework = XML::NewNode( XMLTag_framework );
-  XML::AddChild( data, framework );
-
-  // Create <study-id> node
-  const WrapperFrameworkData frameworkData = theData.getFrameworkData();
-  XML::Node studyId = XML::NewNode( XMLTag_study_id, OSS() << frameworkData.studyid_ );
-  XML::AddChild( framework, studyId );
-
-  // Create <study-case> node
-  XML::Node studyCase = XML::NewNode( XMLTag_study_case, frameworkData.studycase_ );
-  XML::AddChild( framework, studyCase );
-
-  // Create <component-name> node
-  XML::Node componentName = XML::NewNode( XMLTag_component_name, frameworkData.componentname_ );
-  XML::AddChild( framework, componentName );
-
   // Create <wrap-mode> node
   const WrapperParameter & parameters = theData.getParameters();
   XML::Node wrapMode = XML::NewNode( XMLTag_wrap_mode );
