@@ -3,7 +3,7 @@
  *  @file  WrapperFile_version2.cxx
  *  @brief This class provides the elementary functions for wrapper file management (version 2)
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,6 +28,7 @@
 #include "Path.hxx"
 #include "Os.hxx"
 #include "WrapperCommon_extern.h"
+#include "XMLToolbox.hxx"
 
 #ifdef XML_SUPPORTED
 #include "XMLTags.hxx"
@@ -260,7 +261,6 @@ WrapperData ParseDocument_version2(const XMLDoc & doc)
   XML::Node externalCodeElt = XML::FindElementByName( wrapperElt, XMLTag_external_code );
   XML::Node dataElt         = XML::FindElementByName( externalCodeElt, XMLTag_data );
   WrapperData::FileListType fileList;
-  WrapperFrameworkData framework;
   Bool hasOneOrMoreInputFiles  = false;
   Bool hasOneOrMoreOutputFiles = false;
   if (XML::IsElement(dataElt))
@@ -315,14 +315,11 @@ WrapperData ParseDocument_version2(const XMLDoc & doc)
       }
       else if (XML::IsElement(current, XMLTag_framework))
       {
-        String link = XML::GetAttributeByName( current, XMLTag_link );
-
-        LOGDEBUG(OSS() << "Read data framework link              : " << link);
+        LOGWARN( OSS() << "The framework tag is deprecated" );
       }
     }
   }
   data.setFileList( fileList );
-  data.setFrameworkData( framework );
 
 
   WrapperParameter parameters;
@@ -548,23 +545,6 @@ XMLDoc MakeDocument_version2(const WrapperFile & wrapperFile)
     }
   } /* end for ( it = fList.begin() ; ... ) */
 
-  // Create <framework> node
-  XML::Node framework = XML::NewNode( XMLTag_framework );
-  XML::AddChild( data, framework );
-
-  // Create <study-id> node
-  const WrapperFrameworkData frameworkData = theData.getFrameworkData();
-  XML::Node studyId = XML::NewNode( XMLTag_study_id, OSS() << frameworkData.studyid_ );
-  XML::AddChild( framework, studyId );
-
-  // Create <study-case> node
-  XML::Node studyCase = XML::NewNode( XMLTag_study_case, frameworkData.studycase_ );
-  XML::AddChild( framework, studyCase );
-
-  // Create <component-name> node
-  XML::Node componentName = XML::NewNode( XMLTag_component_name, frameworkData.componentname_ );
-  XML::AddChild( framework, componentName );
-
   // Create <wrap-mode> node
   const WrapperParameter & parameters = theData.getParameters();
   XML::Node wrapMode = XML::NewNode( XMLTag_wrap_mode );
