@@ -3,7 +3,7 @@
  *  @file  WrapperObject.cxx
  *  @brief A WrapperObject binds a dynamic library symbol to itself
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,7 @@
 #include <sstream>               // for std::istringstream
 #include <algorithm>             // for std::min
 #include <signal.h>
+#include "OTconfig.hxx"
 #include "WrapperObject.hxx"
 #include "LibraryLoader.hxx"
 #include "OSS.hxx"
@@ -36,6 +37,7 @@
 #include "WrapperCommonFunctions.hxx"
 #include "WrapperMacros.h"
 #include "TBB.hxx"
+#include "FieldImplementation.hxx"
 #ifdef WIN32
 #include <sys/time.h> // gettimeofday
 #endif
@@ -68,7 +70,7 @@ WrapperObject::FunctionPrefix::FunctionPrefix()
   ref_me[WrapperObject::INITIALIZATION]       = "init_";
   ref_me[WrapperObject::EXECUTION]            = "exec_";
   ref_me[WrapperObject::EXECUTION_SAMPLE]     = "exec_sample_";
-  ref_me[WrapperObject::EXECUTION_TIMESERIES] = "exec_timeseries_";
+  ref_me[WrapperObject::EXECUTION_FIELD]      = "exec_field_";
   ref_me[WrapperObject::FINALIZATION]         = "finalize_";
 }
 
@@ -121,7 +123,7 @@ struct WrapperSymbols : public Object
   InitializationFunctionPointer initSymbol_;
   ExecutionFunctionPointer execSymbol_;
   ExecutionSampleFunctionPointer execSampleSymbol_;
-  ExecutionTimeSeriesFunctionPointer execTimeSeriesSymbol_;
+  ExecutionFieldFunctionPointer execFieldSymbol_;
   GradientFunctionPointer gradSymbol_;
   HessianFunctionPointer hessSymbol_;
   FinalizationFunctionPointer finalizeSymbol_;
@@ -132,7 +134,7 @@ struct WrapperSymbols : public Object
       initSymbol_(0),
       execSymbol_(0),
       execSampleSymbol_(0),
-      execTimeSeriesSymbol_(0),
+      execFieldSymbol_(0),
       gradSymbol_(0),
       hessSymbol_(0),
       finalizeSymbol_(0),
@@ -464,8 +466,8 @@ struct WrapperSymbols : public Object
         args->count += Atomic::FetchAndAdd( (int*) & (func_exec_args[i].index), 0 ); /* Get the shared local counters */
 
 
-      double ratio = 100. * args->count / args->size;
-      int width = static_cast<int>( ceil( log10( args->size ) ) );
+      double ratio = 100.0 * args->count / args->size;
+      int width = static_cast<int>( (args->size != 0 ? ceil( log10( args->size ) ) : 1) );
       LOGINFO( OSS() << "Progression : "
                << std::setw(7) << ratio << "% ( "
                << std::setw(width) << args->count << " / "
@@ -764,9 +766,9 @@ OK:
 #endif /* HAVE_TBB */
   }
 
-  enum WrapperErrorCode defaultWrapperExecTimeSeriesFunction(void * p_state,
-      const struct timeseries * inTimeSeries,
-      struct timeseries * outTimeSeries,
+  enum WrapperErrorCode defaultWrapperExecFieldFunction(void * p_state,
+      const struct field * inField,
+      struct field * outField,
       const struct WrapperExchangedData * p_exchangedData,
       void * p_error) const
   {
@@ -858,8 +860,8 @@ WrapperObject::WrapperObject(const FileName & libraryPath,
       getSymbol(getFunctionName(EXECUTION), optional, notDefFunc) );
   wrapperSymbols_->execSampleSymbol_     = REINTERPRET_CAST(ExecutionSampleFunctionPointer,
       getSymbol(getFunctionName(EXECUTION_SAMPLE), optional, 0) );
-  wrapperSymbols_->execTimeSeriesSymbol_ = REINTERPRET_CAST(ExecutionTimeSeriesFunctionPointer,
-      getSymbol(getFunctionName(EXECUTION_TIMESERIES), optional, 0) );
+  wrapperSymbols_->execFieldSymbol_ = REINTERPRET_CAST(ExecutionFieldFunctionPointer,
+                                      getSymbol(getFunctionName(EXECUTION_FIELD), optional, 0) );
 
   // Bind symbols in wrapper so wrapper can call back internal functions.
   // Compute the number of methods to bind in order to size the array
@@ -914,7 +916,7 @@ WrapperObject::WrapperObject(const WrapperObject & other)
 /* String converter */
 String WrapperObject::__repr__() const
 {
-  return OSS() << "class=" << WrapperObject::GetClassName()
+  return OSS(true) << "class=" << WrapperObject::GetClassName()
          << " name=" << getName()
          << " handle=" << handle_
          << " type_=" << type_;
@@ -923,7 +925,7 @@ String WrapperObject::__repr__() const
 /* String converter */
 String WrapperObject::__str__(const String & offset) const
 {
-  return OSS(false) << offset << getName() << " -> " << handle_.__str__();
+  return OSS(false) << offset << getName() << " -> " << handle_;
 }
 
 
@@ -1110,60 +1112,57 @@ NumericalSample WrapperObject::execute(void * p_state,
 }
 
 
-/* Method execute actually realizes the desired treatment */
-/* TODO: MAKE THIS ROUTINE THREAD-SAFE */
-TimeSeries WrapperObject::execute(void * p_state,
-                                  const TimeSeries & inTS) const
+Field WrapperObject::execute(void * p_state,
+                             const Field & inFld) const
 {
   const UnsignedLong inDimension = getInNumericalPointDimension(p_state);
-  // Check the inTS argument
-  if (inTS.getDimension() != inDimension)
+  // Check the inFld argument
+  if (inFld.getDimension() != inDimension)
     throw InvalidArgumentException(HERE)
-        << "Argument 'inTS' has incorrect dimension (" << inTS.getDimension()
+        << "Argument 'inFld' has incorrect dimension (" << inFld.getDimension()
         << "). Expected = " << inDimension;
 
-  const UnsignedLong size = inTS.getSize();
-  const TimeSeriesImplementation & inTSi = * inTS.getImplementation();
+  const UnsignedLong size = inFld.getSize();
 
   // We create a point structure to embed the in NumericalPoint passed as argument
-  struct timeseries inTimeSeries;
-  inTimeSeries.size_      = size;
-  inTimeSeries.dimension_ = inDimension;
-  inTimeSeries.data_      = const_cast<NumericalScalar *>( &inTSi[0][0] );
-
+  struct field inField;
+  inField.size_      = size;
+  inField.dimension_ = inDimension;
+  // TO BE IMPLEMENTED
+  //  inField.data_      = const_cast<NumericalScalar *>( &inFieldi->getValues()[0] );
+  //  inField.vertices_  = const_cast<UnsignedScalar *>( &inFieldi->getMesh().
   // We create the output sample
   const UnsignedLong outDimension = getOutNumericalPointDimension(p_state);
-  TimeSeries outTS(size, outDimension);
-  TimeSeriesImplementation & outTSi = * outTS.getImplementation();
+  Field outFld;
 
   // We create a point structure to embed the returned outS NumericalSample
-  struct timeseries outTimeSeries;
-  outTimeSeries.size_      = size;
-  outTimeSeries.dimension_ = outDimension;
-  outTimeSeries.data_      = &outTSi[0][0];
+  struct field outField;
+  outField.size_      = size;
+  outField.dimension_ = outDimension;
+  // outField.data_      = &outTSi[0][0];
 
 
   // Then we call the wrapper execution function for a sample
   enum WrapperErrorCode returnCode = WRAPPER_OK;
   try
   {
-    returnCode = (wrapperSymbols_->execTimeSeriesSymbol_ != 0) ?
-                 (*(wrapperSymbols_->execTimeSeriesSymbol_))( p_state, & inTimeSeries, & outTimeSeries, p_exchangedData_, error_.get() ) :
-                 wrapperSymbols_->defaultWrapperExecTimeSeriesFunction( p_state, & inTimeSeries, & outTimeSeries, p_exchangedData_, error_.get() ) ;
+    returnCode = (wrapperSymbols_->execFieldSymbol_ != 0) ?
+                 (*(wrapperSymbols_->execFieldSymbol_))( p_state, & inField, & outField, p_exchangedData_, error_.get() ) :
+                 wrapperSymbols_->defaultWrapperExecFieldFunction( p_state, & inField, & outField, p_exchangedData_, error_.get() ) ;
     if (returnCode != WRAPPER_OK)
       throw WrapperInternalException(HERE) << "Wrapper function '"
-                                           << getFunctionName(EXECUTION_TIMESERIES)
+                                           << getFunctionName(EXECUTION_FIELD)
                                            << "' returned error Message: "
                                            << wrapper_getErrorAsString(returnCode)
                                            << ". Reason: " << getWrapperError( error_.get() );
   }
   catch (WrapperInternalException & ex)
   {
-    LOGINFO(OSS() << "Time series evaluation function returned an error. Reason: " << ex ) ;
+    LOGINFO(OSS() << "Field evaluation function returned an error. Reason: " << ex ) ;
     throw ex;
   }
 
-  return outTS;
+  return outFld;
 }
 
 
