@@ -3,7 +3,7 @@
  *  @file  Mesh.cxx
  *  @brief Mesh is defined as a collection of n-D vertices and simplices
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,8 @@
 #include "Curve.hxx"
 #include "Polygon.hxx"
 #include "SpecFunc.hxx"
+#include "TBB.hxx"
+#include "PlatformInfo.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -43,18 +45,10 @@ static Factory<Mesh> RegisteredFactory("Mesh");
 /* Default constructor */
 Mesh::Mesh(const UnsignedLong dimension)
   : DomainImplementation(dimension)
-  , vertices_()
+  , vertices_(1, dimension) // At least one point
   , simplices_()
-  , volume_(0.0)
-  , isAlreadyComputedVolume_(false)
 {
-  // Build a unique standard simplex
-  // First, the vertices
-  vertices_ = NumericalSample(dimension + 1, dimension);
-  for (UnsignedLong i = 0; i < dimension; ++i) vertices_[i + 1][i] = 1.0;
-  // Second, the connections
-  simplices_ = IndicesCollection(1, Indices(dimension + 1));
-  simplices_[0].fill();
+  // Nothing to do
 }
 
 /* Parameters constructor, simplified interface for 1D case */
@@ -63,8 +57,6 @@ Mesh::Mesh(const NumericalSample & vertices,
   : DomainImplementation(vertices.getDimension())
   , vertices_(vertices)
   , simplices_(simplices)
-  , volume_(0.0)
-  , isAlreadyComputedVolume_(false)
 {
   // Nothing to do
 }
@@ -75,7 +67,13 @@ Mesh * Mesh::clone() const
   return new Mesh(*this);
 }
 
-/** Vertices accessor */
+/* Description of the vertices accessor */
+Description Mesh::getDescription() const
+{
+  return vertices_.getDescription();
+}
+
+/* Vertices accessor */
 NumericalSample Mesh::getVertices() const
 {
   return vertices_;
@@ -90,7 +88,7 @@ void Mesh::setVertices(const NumericalSample & vertices)
 /* Vertex accessor */
 NumericalPoint Mesh::getVertex(const UnsignedLong index) const
 {
-  if (index >= vertices_.getSize()) throw InvalidArgumentException(HERE) << "Error: the vertex index=" << index << " must be less than the number of vertices=" << vertices_.getSize();
+  if (index >= getVerticesNumber()) throw InvalidArgumentException(HERE) << "Error: the vertex index=" << index << " must be less than the number of vertices=" << getVerticesNumber();
   return vertices_[index];
 }
 
@@ -115,28 +113,10 @@ void Mesh::setSimplices(const IndicesCollection & simplices)
 /* Simplex accessor */
 Indices Mesh::getSimplex(const UnsignedLong index) const
 {
-  if (index >= simplices_.getSize()) throw InvalidArgumentException(HERE) << "Error: the simplex index=" << index << " must be less than the number of simplices=" << simplices_.getSize();
+  if (index >= getSimplicesNumber()) throw InvalidArgumentException(HERE) << "Error: the simplex index=" << index << " must be less than the number of simplices=" << getSimplicesNumber();
   return simplices_[index];
 }
 
-/* Check if the mesh is empty, i.e if its numerical volume is zero */
-Bool Mesh::isEmpty() const
-{
-  return isNumericallyEmpty();
-}
-
-/* Check if the mesh is empty, i.e if its numerical volume is zero */
-Bool Mesh::isNumericallyEmpty() const
-{
-  return getVolume() <= ResourceMap::GetAsNumericalScalar("Mesh-SmallVolume");
-}
-
-/* Check if the given point is inside of the closed mesh */
-Bool Mesh::contains(const NumericalPoint & point) const
-{
-  return numericallyContains(point);
-}
-
 /* Check the mesh validity */
 Bool Mesh::isValid() const
 {
@@ -146,10 +126,10 @@ Bool Mesh::isValid() const
   return true;
 }
 
-/* Check if the given point is numerically inside of the closed mesh, i.e. using only the bounds part of the mesh */
-Bool Mesh::numericallyContains(const NumericalPoint & point) const
+/* Check if the given point is in the mesh */
+Bool Mesh::contains(const NumericalPoint & point) const
 {
-  const UnsignedLong simplicesSize(simplices_.getSize());
+  const UnsignedLong simplicesSize(getSimplicesNumber());
   for (UnsignedLong i = 0; i < simplicesSize; ++i) if (checkPointInSimplex(point, i)) return true;
   return false;
 }
@@ -157,7 +137,7 @@ Bool Mesh::numericallyContains(const NumericalPoint & point) const
 /* Check if the given point is in the given simplex */
 SquareMatrix Mesh::buildSimplexMatrix(const UnsignedLong index) const
 {
-  if (index >= simplices_.getSize()) throw InvalidArgumentException(HERE) << "Error: the simplex index=" << index << " must be less than the number of simplices=" << simplices_.getSize();
+  if (index >= getSimplicesNumber()) throw InvalidArgumentException(HERE) << "Error: the simplex index=" << index << " must be less than the number of simplices=" << getSimplicesNumber();
   SquareMatrix matrix(dimension_ + 1);
   const Indices vertexIndices(simplices_[index]);
   // Loop over the vertices of the simplex
@@ -182,17 +162,64 @@ Bool Mesh::checkPointInSimplex(const NumericalPoint & point,
   return true;
 }
 
-/* Get the numerical volume of the mesh */
-NumericalScalar Mesh::getVolume() const
+/* Get the number of vertices */
+UnsignedLong Mesh::getVerticesNumber() const
 {
-  if (!isAlreadyComputedVolume_) computeVolume();
-  return volume_;
+  return vertices_.getSize();
 }
 
-/* Get the numerical volume of the mesh */
-NumericalScalar Mesh::getNumericalVolume() const
+/* Get the number of simplices */
+UnsignedLong Mesh::getSimplicesNumber() const
 {
-  return getVolume();
+  return simplices_.getSize();
+}
+
+/* TBB functor to speed-up nearest index computation */
+struct NearestFunctor
+{
+  const Mesh & mesh_;
+  const NumericalPoint & point_;
+  NumericalScalar minDistance_;
+  UnsignedLong minIndex_;
+
+  NearestFunctor(const Mesh & mesh, const NumericalPoint & point)
+    : mesh_(mesh), point_(point), minDistance_(SpecFunc::MaxNumericalScalar), minIndex_(0) {}
+
+  NearestFunctor(const NearestFunctor & other, TBB::Split)
+    : mesh_(other.mesh_), point_(other.point_), minDistance_(SpecFunc::MaxNumericalScalar), minIndex_(0) {}
+
+  void operator() (const TBB::BlockedRange<UnsignedLong> & r)
+  {
+    for (UnsignedLong i = r.begin(); i != r.end(); ++i)
+    {
+      const NumericalScalar d((point_ - mesh_.getVertices()[i]).normSquare());
+      if (d < minDistance_)
+      {
+        minDistance_ = d;
+        minIndex_ = i;
+      }
+    }
+  }
+
+  void join(const NearestFunctor & other)
+  {
+    if (other.minDistance_ < minDistance_)
+    {
+      minDistance_ = other.minDistance_;
+      minIndex_ = other.minIndex_;
+    }
+  }
+
+}; /* end struct NearestFunctor */
+
+/* Get the index of the nearest vertex */
+UnsignedLong Mesh::getNearestVertexIndex(const NumericalPoint & point) const
+{
+  if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: expected a point of dimension " << getDimension() << ", got a point of dimension " << point.getDimension();
+
+  NearestFunctor functor( *this, point );
+  TBB::ParallelReduce( 0, getVerticesNumber(), functor );
+  return functor.minIndex_;
 }
 
 /* Compute the volume of a given simplex */
@@ -203,14 +230,57 @@ NumericalScalar Mesh::computeSimplexVolume(const UnsignedLong index) const
   return exp(matrix.computeLogAbsoluteDeterminant(sign, false) - SpecFunc::LogGamma(dimension_ + 1));
 }
 
+/* TBB functor to speed-up volume computation */
+struct VolumeFunctor
+{
+  const Mesh & mesh_;
+  NumericalScalar accumulator_;
+
+  VolumeFunctor(const Mesh & mesh)
+    : mesh_(mesh), accumulator_(0.0) {}
+
+  VolumeFunctor(const VolumeFunctor & other, TBB::Split)
+    : mesh_(other.mesh_), accumulator_(0.0) {}
+
+  void operator() (const TBB::BlockedRange<UnsignedLong> & r)
+  {
+    for (UnsignedLong i = r.begin(); i != r.end(); ++i) accumulator_ += mesh_.computeSimplexVolume(i);
+  }
+
+  void join(const VolumeFunctor & other)
+  {
+    accumulator_ += other.accumulator_;
+  }
+
+}; /* end struct VolumeFunctor */
+
 /* Compute the volume of the mesh */
 void Mesh::computeVolume() const
 {
-  volume_ = 0.0;
-  for (UnsignedLong i = 0; i < simplices_.getSize(); ++i) volume_ += computeSimplexVolume(i);
+  VolumeFunctor functor( *this );
+  TBB::ParallelReduce( 0, getSimplicesNumber(), functor );
+  volume_ = functor.accumulator_;
   isAlreadyComputedVolume_ = true;
 }
 
+/* Tells if the mesh is regular */
+Bool Mesh::isRegular() const
+{
+  // For now, only 1D regular meshes are considered
+  if (getDimension() != 1) return false;
+  const UnsignedLong size(getSimplicesNumber());
+  if (size <= 1) return true;
+  Bool regular(true);
+  const NumericalScalar epsilon(ResourceMap::GetAsNumericalScalar("Mesh-VertexEpsilon"));
+  const NumericalScalar step(vertices_[simplices_[0][1]][0] - vertices_[simplices_[0][0]][0]);
+  for (UnsignedLong i = 1; i < size; ++i)
+  {
+    regular = regular && (abs(vertices_[simplices_[i][1]][0] - vertices_[simplices_[i][0]][0] - step) < epsilon);
+    if (!regular) break;
+  }
+  return regular;
+}
+
 /* Comparison operator */
 Bool Mesh::operator == (const Mesh & other) const
 {
@@ -221,7 +291,7 @@ Bool Mesh::operator == (const Mesh & other) const
 /* String converter */
 String Mesh::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " name=" << getName()
          << " dimension=" << getDimension()
          << " vertices=" << vertices_.__repr__()
@@ -237,22 +307,18 @@ String Mesh::__str__(const String & offset) const
 Graph Mesh::draw() const
 {
   if (dimension_ > 3) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh of dimension > 3.";
-  const UnsignedLong verticesSize(vertices_.getSize());
-  const UnsignedLong simplicesSize(simplices_.getSize());
-  if ((verticesSize == 0) || (simplicesSize == 0)) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex or no simplex.";
-  Graph graph;
-  if (dimension_ == 1) graph = draw1D();
-  if (dimension_ == 2) graph = draw2D();
-  if (dimension_ == 3) graph = draw3D();
-  return graph;
+  if (dimension_ == 1) return draw1D();
+  if (dimension_ == 2) return draw2D();
+  if (dimension_ == 3) return draw3D();
+  return Graph();
 }
 
 Graph Mesh::draw1D() const
 {
   if (dimension_ != 1) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh of dimension different from 1 with the draw1D() method.";
-  const UnsignedLong verticesSize(vertices_.getSize());
-  const UnsignedLong simplicesSize(simplices_.getSize());
-  if ((verticesSize == 0) || (simplicesSize == 0)) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex or no simplex.";
+  const UnsignedLong verticesSize(getVerticesNumber());
+  const UnsignedLong simplicesSize(getSimplicesNumber());
+  if (verticesSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex.";
   Graph graph(String(OSS() << "Mesh " << getName()), "x", "y", true, "topright");
   // The vertices
   Cloud vertices(vertices_, NumericalSample(verticesSize, NumericalPoint(1, 0.0)));
@@ -275,13 +341,14 @@ Graph Mesh::draw1D() const
 
 Graph Mesh::draw2D() const
 {
-  const UnsignedLong verticesSize(vertices_.getSize());
-  const UnsignedLong simplicesSize(simplices_.getSize());
-  if ((verticesSize == 0) || (simplicesSize == 0)) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex or no simplex.";
+  const UnsignedLong verticesSize(getVerticesNumber());
+  const UnsignedLong simplicesSize(getSimplicesNumber());
+  if (verticesSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex.";
   Graph graph(String(OSS() << "Mesh " << getName()), "x", "y", true, "topright");
   // The vertices
   Cloud vertices(vertices_);
   vertices.setColor("red");
+  if (vertices_.getSize() > ResourceMap::GetAsUnsignedLong("Mesh-LargeSize")) vertices.setPointStyle("dot");
   vertices.setLegend(String(OSS() << verticesSize << " node" << (verticesSize > 1 ? "s" : "")));
   // The simplices
   for (UnsignedLong i = 0; i < simplicesSize; ++i)
@@ -308,9 +375,9 @@ Graph Mesh::draw3D(const Bool drawEdge,
   // First, check if the matrix is a rotation matrix of R^3
   if (rotation.getDimension() != 3) throw InvalidArgumentException(HERE) << "Error: the matrix is not a 3d square matrix.";
   if (NumericalPoint((rotation * rotation.transpose() - IdentityMatrix(3)).getImplementation()).norm() > 1e-5) throw InvalidArgumentException(HERE) << "Error: the matrix is not a rotation matrix.";
-  const UnsignedLong verticesSize(vertices_.getSize());
-  const UnsignedLong simplicesSize(simplices_.getSize());
-  if ((verticesSize == 0) || (simplicesSize == 0)) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex or no simplex.";
+  const UnsignedLong verticesSize(getVerticesNumber());
+  const UnsignedLong simplicesSize(getSimplicesNumber());
+  if (verticesSize == 0) throw InvalidArgumentException(HERE) << "Error: cannot draw a mesh with no vertex or no simplex.";
   // We use a basic Painter algorithm for the visualization
   // Second, transform the vertices if needed
   NumericalSample visuVertices(vertices_);
@@ -480,50 +547,61 @@ Mesh Mesh::ImportFromMSHFile(const String & fileName)
 }
 
 /* VTK export */
-void Mesh::exportToVTKFile(const String & fileName)
+String Mesh::streamToVTKFormat() const
 {
-  if (dimension_ > 3) throw InvalidDimensionException(HERE) << "Error: cannot export a mesh of dimension=" << dimension_ << " into the VTK format. Maximu dimension is 3.";
-  std::ofstream file(fileName.c_str(), std::ios::out);
-  if (!file) throw FileNotFoundException(HERE) << "Error: can't open file " << fileName;
+  if (dimension_ > 3) throw InvalidDimensionException(HERE) << "Error: cannot export a mesh of dimension=" << dimension_ << " into the VTK format. Maximum dimension is 3.";
+  const UnsignedLong oldPrecision(PlatformInfo::GetNumericalPrecision());
+  PlatformInfo::SetNumericalPrecision(16);
+  OSS oss;
   // First, the file version and identifier
-  file << "# vtk DataFile Version 3.0\n";
+  oss << "# vtk DataFile Version 3.0\n";
   // Second, the header
-  file << getName() << "\n";
+  oss << getName() << "\n";
   // Third, the format
-  file << "ASCII\n";
-  file << "\n";
+  oss << "ASCII\n";
+  oss << "\n";
   // Fourth, the data set
-  file << "DATASET UNSTRUCTURED_GRID\n";
+  oss << "DATASET UNSTRUCTURED_GRID\n";
   // Fifth, the geometrical and topological data
   // The vertices
-  file << "POINTS " << vertices_.getSize() << " float\n";
-  for (UnsignedLong i = 0; i < vertices_.getSize(); ++i)
+  oss << "POINTS " << getVerticesNumber() << " float\n";
+  for (UnsignedLong i = 0; i < getVerticesNumber(); ++i)
   {
     String separator("");
     for (UnsignedLong j = 0; j < dimension_; ++j, separator = " ")
-      file << separator << vertices_[i][j];
+      oss << separator << vertices_[i][j];
     for (UnsignedLong j = dimension_; j < 3; ++j)
-      file << separator << "0.0";
-    file << "\n";
+      oss << separator << "0.0";
+    oss << "\n";
   }
   // The simplices
-  file << "\n";
-  file << "CELLS " << simplices_.getSize() << " " << (dimension_ + 2) * simplices_.getSize() << "\n";
-  for (UnsignedLong i = 0; i < simplices_.getSize(); ++i)
+  oss << "\n";
+  oss << "CELLS " << getSimplicesNumber() << " " << (dimension_ + 2) * getSimplicesNumber() << "\n";
+  for (UnsignedLong i = 0; i < getSimplicesNumber(); ++i)
   {
-    file << dimension_ + 1;
+    oss << dimension_ + 1;
     for (UnsignedLong j = 0; j <= dimension_; ++j)
-      file << " " << simplices_[i][j];
-    file << "\n";
+      oss << " " << simplices_[i][j];
+    oss << "\n";
   }
-  file << "\n";
-  file << "CELL_TYPES " << simplices_.getSize() << "\n";
+  oss << "\n";
+  oss << "CELL_TYPES " << getSimplicesNumber() << "\n";
   UnsignedLong cellType;
   if (dimension_ == 1) cellType = 3;
   if (dimension_ == 2) cellType = 5;
   if (dimension_ == 3) cellType = 10;
-  for (UnsignedLong i = 0; i < simplices_.getSize(); ++i)
-    file << cellType << "\n";
+  for (UnsignedLong i = 0; i < getSimplicesNumber(); ++i)
+    oss << cellType << "\n";
+  PlatformInfo::SetNumericalPrecision(oldPrecision);
+  return oss;
+}
+
+void Mesh::exportToVTKFile(const String & fileName) const
+{
+  std::ofstream file(fileName.c_str(), std::ios::out);
+  if (!file) throw FileNotFoundException(HERE) << "Error: can't open file " << fileName;
+  const String content(streamToVTKFormat());
+  file << content;
   file.close();
 }
 
