@@ -3,7 +3,7 @@
  *  @file  BarPlot.cxx
  *  @brief BarPlot class for barplots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,9 +35,9 @@ static Factory<BarPlot> RegisteredFactory("BarPlot");
 /* Default constructor */
 BarPlot::BarPlot(const NumericalSample & data,
                  const NumericalScalar origin,
-                 const String & legend):
-  DrawableImplementation(data, legend),
-  origin_(origin)
+                 const String & legend)
+  : DrawableImplementation(data, legend)
+  , origin_(origin)
 {
   // Check data validity
   setData(data);
@@ -51,8 +51,8 @@ BarPlot::BarPlot(const NumericalSample & data,
                  const String & lineStyle,
                  const UnsignedLong lineWidth,
                  const String & legend)
-  : DrawableImplementation(data, legend),
-    origin_(origin)
+  : DrawableImplementation(data, legend)
+  , origin_(origin)
 {
   // Check data validity
   setData(data);
@@ -69,8 +69,8 @@ BarPlot::BarPlot(const NumericalSample & data,
                  const String & fillStyle,
                  const String & lineStyle,
                  const String & legend)
-  : DrawableImplementation(data, legend),
-    origin_(origin)
+  : DrawableImplementation(data, legend)
+  , origin_(origin)
 {
   // Check data validity
   setData(data);
