@@ -3,7 +3,7 @@
  *  @file  Cloud.cxx
  *  @brief Cloud class for cloud plots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,7 +42,7 @@ Cloud::Cloud(const NumericalSample & data,
 /* Constructor from complex numbers */
 Cloud::Cloud(const NumericalComplexCollection & data,
              const String & legend)
-  : DrawableImplementation(NumericalSample(2, 0), legend)
+  : DrawableImplementation(NumericalSample(0, 2), legend)
 {
   // Convert the complex numbers into a NumericalSample
   const UnsignedLong size(data.getSize());
@@ -60,7 +60,7 @@ Cloud::Cloud(const NumericalComplexCollection & data,
 Cloud::Cloud(const NumericalSample & dataX,
              const NumericalSample & dataY,
              const String & legend):
-  DrawableImplementation(NumericalSample(2, 0), legend)
+  DrawableImplementation(NumericalSample(0, 2), legend)
 {
   const UnsignedLong size(dataX.getSize());
   if (dataY.getSize() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a Cloud based on two numerical samples with different size.";
@@ -75,6 +75,23 @@ Cloud::Cloud(const NumericalSample & dataX,
   setData(dataFull);
 }
 
+Cloud::Cloud(const NumericalPoint & dataX,
+             const NumericalPoint & dataY,
+             const String & legend):
+  DrawableImplementation(NumericalSample(0, 2), legend)
+{
+  const UnsignedLong size(dataX.getDimension());
+  if (dataY.getDimension() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a Cloud based on two numerical points with different dimension.";
+  NumericalSample dataFull(size, 2);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    dataFull[i][0] = dataX[i];
+    dataFull[i][1] = dataY[i];
+  }
+  // Check data validity
+  setData(dataFull);
+}
+
 /* Constructor with parameters */
 Cloud::Cloud(const NumericalSample & data,
              const String & color,
