@@ -3,7 +3,7 @@
  *  @file  Contour.cxx
  *  @brief Contour class for contourchart plots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,12 +39,12 @@ Contour::Contour(const UnsignedLong dimX,
                  const UnsignedLong dimY,
                  const NumericalSample & data,
                  const String & legend)
-  : DrawableImplementation(data, legend),
-    x_(NumericalSample(dimX, 1)),
-    y_(NumericalSample(dimY, 1)),
-    levels_(NumericalPoint(ResourceMap::GetAsUnsignedLong( "Contour-DefaultLevelsNumber" ))),
-    labels_(ResourceMap::GetAsUnsignedLong( "Contour-DefaultLevelsNumber" )),
-    drawLabels_(true)
+  : DrawableImplementation(data, legend)
+  , x_(NumericalSample(dimX, 1))
+  , y_(NumericalSample(dimY, 1))
+  , levels_(NumericalPoint(ResourceMap::GetAsUnsignedLong( "Contour-DefaultLevelsNumber" )))
+  , labels_(ResourceMap::GetAsUnsignedLong( "Contour-DefaultLevelsNumber" ))
+  , drawLabels_(true)
 {
   if (dimX < 2) throw InvalidArgumentException(HERE) << "Error: the x dimension must be greater or equal to 2";
   if (dimY < 2) throw InvalidArgumentException(HERE) << "Error: the y dimension must be greater or equal to 2";
@@ -69,12 +69,12 @@ Contour::Contour(const NumericalSample & x,
                  const Description & labels,
                  const Bool drawLabels,
                  const String & legend)
-  : DrawableImplementation(data, legend),
-    x_(x),
-    y_(y),
-    levels_(levels),
-    labels_(labels),
-    drawLabels_(drawLabels)
+  : DrawableImplementation(data, legend)
+  , x_(x)
+  , y_(y)
+  , levels_(levels)
+  , labels_(labels)
+  , drawLabels_(drawLabels)
 {
   if (levels.getDimension() == 0) buildDefaultLevels();
   if (drawLabels && (labels.getSize() == 0)) buildDefaultLabels();
