@@ -3,7 +3,7 @@
  *  @file  Curve.cxx
  *  @brief Curve class for curve plots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,7 +33,7 @@ static Factory<Curve> RegisteredFactory("Curve");
 
 /* Default constructor */
 Curve::Curve(const String & legend)
-  : DrawableImplementation(NumericalSample(2, 0), legend)
+  : DrawableImplementation(NumericalSample(0, 2), legend)
 {
   // Nothing to do
   setPointStyle("none");
@@ -42,7 +42,7 @@ Curve::Curve(const String & legend)
 /* Default constructor */
 Curve::Curve(const NumericalSample & data,
              const String & legend)
-  : DrawableImplementation(NumericalSample(2, 0), legend)
+  : DrawableImplementation(NumericalSample(0, 2), legend)
 {
   NumericalSample dataFull;
   // If data is unidimensional, assume that it means Y values with indices as X values
@@ -66,7 +66,7 @@ Curve::Curve(const NumericalSample & data,
 Curve::Curve(const NumericalSample & dataX,
              const NumericalSample & dataY,
              const String & legend)
-  : DrawableImplementation(NumericalSample(2, 0), legend)
+  : DrawableImplementation(NumericalSample(0, 2), legend)
 {
   const UnsignedLong size(dataX.getSize());
   if (dataY.getSize() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a Curve based on two numerical samples with different size.";
@@ -82,13 +82,32 @@ Curve::Curve(const NumericalSample & dataX,
   setPointStyle("none");
 }
 
+/* Contructor from 2 data sets */
+Curve::Curve(const NumericalPoint & dataX,
+             const NumericalPoint & dataY,
+             const String & legend)
+  : DrawableImplementation(NumericalSample(0, 2), legend)
+{
+  const UnsignedLong size(dataX.getDimension());
+  if (dataY.getDimension() != size) throw InvalidArgumentException(HERE) << "Error: cannot build a Curve based on two numerical points with different dimension.";
+  NumericalSample dataFull(size, 2);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    dataFull[i][0] = dataX[i];
+    dataFull[i][1] = dataY[i];
+  }
+  // Check data validity
+  setData(dataFull);
+  setPointStyle("none");
+}
+
 /* Constructor with parameters */
 Curve::Curve(const NumericalSample & data,
              const String & color,
              const String & lineStyle,
              const UnsignedLong lineWidth,
              const String & legend)
-  : DrawableImplementation(NumericalSample(2, 0), legend)
+  : DrawableImplementation(NumericalSample(0, 2), legend)
 {
   NumericalSample dataFull;
   // If data is unidimensional, assume that it means Y values with indices as X values
@@ -162,18 +181,6 @@ void Curve::checkData(const NumericalSample & data) const
   }
 }
 
-/* Show points accessors */
-void Curve::setShowPoints(const Bool showPoints)
-{
-  LOGWARN(OSS() << "The setShowPoints() method is deprecated and will be removed in the next release. Use the \"none\" point style to suppress marker");
-}
-
-Bool Curve::getShowPoints() const
-{
-  LOGWARN("The getShowPoints() method is deprecated and will be removed in the next release.");
-  return pointStyle_ == "none";
-}
-
 /* Method save() stores the object through the StorageManager */
 void Curve::save(Advocate & adv) const
 {
