@@ -3,7 +3,7 @@
  *  @file  Drawable.cxx
  *  @brief Abstract top-level class for all Drawable
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(Drawable);
 
 /* Default constructor */
@@ -62,19 +60,6 @@ NumericalPoint Drawable::getBoundingBox() const
   return getImplementation()->getBoundingBox();
 }
 
-/* Accessor for legend name */
-String Drawable::getLegendName() const
-{
-  return getImplementation()->getLegendName();
-}
-
-/* Accessor for legend name */
-void Drawable::setLegendName(const String & legendName)
-{
-  copyOnWrite();
-  getImplementation()->setLegendName(legendName);
-}
-
 /* Accessor for legend */
 String Drawable::getLegend() const
 {
