@@ -3,7 +3,7 @@
  *  @file  Graph.cxx
  *  @brief Graph implements graphic devices for plotting through R
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ Graph::Graph(const String & title,
 /* String converter */
 String Graph::__repr__() const
 {
-  return OSS() << "class=" << GetClassName()
+  return OSS(true) << "class=" << GetClassName()
          << " name=" << getName()
          << " implementation=" << getImplementation()->__repr__();
 }
@@ -129,14 +129,21 @@ void Graph::setDrawable(const Drawable & drawable,
 
 
 /* Global color accessor */
+Description Graph::getColors() const
+{
+  return getImplementation()->getColors();
+}
+
 void Graph::setColors(const Description & colors)
 {
   copyOnWrite();
   getImplementation()->setColors(colors);
 }
-Description Graph::getColors() const
+
+void Graph::setDefaultColors()
 {
-  return getImplementation()->getColors();
+  copyOnWrite();
+  getImplementation()->setDefaultColors();
 }
 
 /* Global legend accessor */
