@@ -3,7 +3,7 @@
  *  @file  GraphImplementation.cxx
  * @brief Graph implements graphic devices for plotting through R
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,22 +66,22 @@ void GraphImplementation::initializeValidLegendPositions()
 }
 
 /* Default constructor */
-GraphImplementation::GraphImplementation(const String & title):
-  PersistentObject(),
-  title_(title),
-  legendPosition_(),
-  legendFontSize_(ResourceMap::GetAsNumericalScalar("GraphImplementation-DefaultLegendFontSize")),
-  xTitle_(),
-  yTitle_(),
-  showAxes_(false),
-  logScale_(NONE),
-  showGrid_(false),
-  gridColor_("lightgray"),
-  automaticBoundingBox_(true),
-  boundingBox_(4),
-  drawablesCollection_(0),
-  path_(),
-  fileName_()
+GraphImplementation::GraphImplementation(const String & title)
+  : PersistentObject()
+  , title_(title)
+  , legendPosition_()
+  , legendFontSize_(ResourceMap::GetAsNumericalScalar("GraphImplementation-DefaultLegendFontSize"))
+  , xTitle_()
+  , yTitle_()
+  , showAxes_(false)
+  , logScale_(NONE)
+  , showGrid_(false)
+  , gridColor_("gray")
+  , automaticBoundingBox_(true)
+  , boundingBox_(4)
+  , drawablesCollection_(0)
+  , path_()
+  , fileName_()
 {
   if(IsFirstInitialization)
   {
@@ -98,20 +98,20 @@ GraphImplementation::GraphImplementation(const String & title,
     const String & legendPosition,
     const NumericalScalar legendFontSize,
     const LogScale logScale)
-  : PersistentObject(title),
-    title_(title),
-    legendFontSize_(legendFontSize),
-    xTitle_(xTitle),
-    yTitle_(yTitle),
-    showAxes_(showAxes),
-    logScale_(logScale),
-    showGrid_(true),
-    gridColor_("lightgray"),
-    automaticBoundingBox_(true),
-    boundingBox_(4),
-    drawablesCollection_(0),
-    path_(),
-    fileName_()
+  : PersistentObject(title)
+  , title_(title)
+  , legendFontSize_(legendFontSize)
+  , xTitle_(xTitle)
+  , yTitle_(yTitle)
+  , showAxes_(showAxes)
+  , logScale_(logScale)
+  , showGrid_(true)
+  , gridColor_("gray")
+  , automaticBoundingBox_(true)
+  , boundingBox_(4)
+  , drawablesCollection_(0)
+  , path_()
+  , fileName_()
 {
   if(IsFirstInitialization)
   {
@@ -222,6 +222,12 @@ void GraphImplementation::setColors(const Description & colors)
   for (UnsignedLong i = 0; i < size; ++i) drawablesCollection_[i].setColor(colors[i % inputSize]);
 }
 
+void GraphImplementation::setDefaultColors()
+{
+  const UnsignedLong size(drawablesCollection_.getSize());
+  setColors(Drawable::BuildDefaultPalette(size));
+}
+
 /** Global legend accessor */
 Description GraphImplementation::getLegends() const
 {
