@@ -3,7 +3,7 @@
  *  @file  Pairs.cxx
  *  @brief Pairs class for contourchart plots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,11 +32,8 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(Pairs);
 
-
 static Factory<Pairs> RegisteredFactory("Pairs");
 
 /* Default constructor */
@@ -52,9 +49,9 @@ Pairs::Pairs(const NumericalSample & data,
 /* Constructor with parameters*/
 Pairs::Pairs(const NumericalSample & data,
              const String & title,
-             const Description labels,
-             const String color,
-             const String pointStyle)
+             const Description & labels,
+             const String & color,
+             const String & pointStyle)
   : DrawableImplementation(data)
 {
   checkData(data);
