@@ -3,7 +3,7 @@
  *  @file  Pie.cxx
  *  @brief Pie class for piechart plots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -48,20 +48,6 @@ Pie::Pie(const NumericalPoint & data)
   buildDefaultLabels();
 }
 
-Pie::Pie(const NumericalSample & data)
-  : DrawableImplementation()
-  , palette_(0)
-  , radius_(1.0)
-  , center_(2, 0.0)
-  , labels_(0)
-{
-  LOGUSER(OSS() << "In classPie, constructor Pie(const NumericalSample & data) is deprecated in favor of Pie(const NumericalPoint & data).");
-  // Check data validity
-  setData(data);
-  buildDefaultPalette();
-  buildDefaultLabels();
-}
-
 /* Constructor with parameters */
 Pie::Pie(const NumericalPoint & data,
          const Description & labels)
@@ -94,24 +80,6 @@ Pie::Pie(const NumericalPoint & data,
   palette_ = palette;
 }
 
-Pie::Pie(const NumericalSample & data,
-         const Description & labels,
-         const NumericalPoint & center,
-         const NumericalScalar & radius,
-         const Description & palette)
-  : DrawableImplementation()
-  , palette_()
-  , radius_(radius)
-  , center_(center)
-  , labels_(labels)
-{
-  LOGUSER(OSS() << "In classPie, constructor Pie(const NumericalSample & data, const Description & labels, const NumericalPoint & center, const NumericalScalar & radius, const Description & palette) is deprecated in favor of Pie(const NumericalPoint & data, const Description & labels, const NumericalPoint & center, const NumericalScalar & radius, const Description & palette).");
-  if(!IsValidColorPalette(palette)) throw InvalidArgumentException(HERE) << "Given color palette = " << palette << " is incorrect";
-  // Check data validity
-  setData(data);
-  palette_ = palette;
-}
-
 /* String converter */
 String Pie::__repr__() const
 {
@@ -230,19 +198,6 @@ Bool Pie::IsValidColorPalette(const Description & palette)
   return IsValid;
 }
 
-/* Check for data validity */
-void Pie::checkData(const NumericalSample & data) const
-{
-  if (data.getDimension() != 1)
-  {
-    throw InvalidDimensionException(HERE) << "Expected sample of dimension 1: got " << data.getDimension();
-  }
-  const UnsignedLong size(data.getSize());
-  NumericalPoint newData(size);
-  for (UnsignedLong i = 0; i < size; ++i) newData[i] = data[i][0];
-  checkData(newData);
-}
-
 void Pie::checkData(const NumericalPoint & data) const
 {
   const UnsignedLong size(data.getSize());
