@@ -3,7 +3,7 @@
  *  @file  Staircase.cxx
  *  @brief Staircase class for staircase plots
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,18 +33,18 @@ CLASSNAMEINIT(Staircase);
 static Factory<Staircase> RegisteredFactory("Staircase");
 
 /* Default constructor */
-Staircase::Staircase():
-  DrawableImplementation(),
-  pattern_()
+Staircase::Staircase()
+  : DrawableImplementation()
+  , pattern_()
 {
   // Nothing to do
 }
 
 /* Constructor with parameters */
 Staircase::Staircase(const NumericalSample & data,
-                     const String & legend):
-  DrawableImplementation(data, legend),
-  pattern_(ResourceMap::Get("DrawableImplementation-DefaultPattern"))
+                     const String & legend)
+  : DrawableImplementation(data, legend)
+  , pattern_(ResourceMap::Get("DrawableImplementation-DefaultPattern"))
 {
   // Check data validity
   setData(data);
