@@ -3,7 +3,7 @@
  *  @file  QuadraticLeastSquares.cxx
  *  @brief Second order polynomial response surface by least square
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,9 +22,8 @@
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include "QuadraticLeastSquares.hxx"
-#include "QuadraticNumericalMathEvaluationImplementation.hxx"
-#include "LinearNumericalMathGradientImplementation.hxx"
-#include "ConstantNumericalMathHessianImplementation.hxx"
+#include "QuadraticNumericalMathFunction.hxx"
+
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -165,10 +164,7 @@ void QuadraticLeastSquares::run()
     } // quadratic term
   } // output components
   const NumericalPoint center(inputDimension, 0.0);
-  /* Build the several implementations and set them into the response surface */
-  responseSurface_.setEvaluationImplementation(new QuadraticNumericalMathEvaluationImplementation(center, constant_, linear_, quadratic_));
-  responseSurface_.setGradientImplementation(new LinearNumericalMathGradientImplementation(center, linear_, quadratic_));
-  responseSurface_.setHessianImplementation(new ConstantNumericalMathHessianImplementation(quadratic_));
+  responseSurface_ = QuadraticNumericalMathFunction(center, constant_, linear_, quadratic_);
 }
 
 /* DataIn accessor */
