@@ -3,7 +3,7 @@
  *  @file  QuadraticTaylor.cxx
  *  @brief Second order polynomial response surface by Taylor expansion
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,9 +22,7 @@
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
 #include "QuadraticTaylor.hxx"
-#include "QuadraticNumericalMathEvaluationImplementation.hxx"
-#include "LinearNumericalMathGradientImplementation.hxx"
-#include "ConstantNumericalMathHessianImplementation.hxx"
+#include "QuadraticNumericalMathFunction.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -79,9 +77,7 @@ void QuadraticTaylor::run()
   linear_ = inputFunction_.gradient(center_);
   quadratic_ = inputFunction_.hessian(center_);
   /* Build the several implementations and set it into the response surface */
-  responseSurface_.setEvaluationImplementation(new QuadraticNumericalMathEvaluationImplementation(center_, constant_, linear_, quadratic_));
-  responseSurface_.setGradientImplementation(new LinearNumericalMathGradientImplementation(center_, linear_, quadratic_));
-  responseSurface_.setHessianImplementation(new ConstantNumericalMathHessianImplementation(quadratic_));
+  responseSurface_ = QuadraticNumericalMathFunction(center_, constant_, linear_, quadratic_);
   responseSurface_.setDescription(inputFunction_.getDescription());
 }
 
