@@ -3,7 +3,7 @@
  *  @file  Cobyla.cxx
  *  @brief Cobyla is an actual implementation for
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -187,7 +187,7 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
   NumericalPoint inPoint((UnsignedLong)n);
   for(UnsignedLong index = 0; index < (UnsignedLong)(n); ++index) inPoint[index] = x[index];
   /* Compute the level function at inPoint */
-  *f = 0.5 * inPoint.norm2();
+  *f = 0.5 * inPoint.normSquare();
   /* Compute the constraints at inPoint */
   NumericalPoint constraintValue;
   try
