@@ -3,7 +3,7 @@
  *  @file  NearestPointAlgorithm.cxx
  *  @brief NearestPointAlgorithm implements an algorithm for finding the
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -168,7 +168,7 @@ void NearestPointAlgorithm::setMaximumConstraintError(const NumericalScalar maxi
 /* String converter */
 String NearestPointAlgorithm::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NearestPointAlgorithm::GetClassName()
       << " implementation=" << getImplementation()->__repr__();
   return oss;
