@@ -3,7 +3,7 @@
  *  @file  NearestPointAlgorithmImplementation.cxx
  *  @brief NearestPointAlgorithmImplementation implements an algorithm for finding the
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,11 +35,10 @@ CLASSNAMEINIT(NearestPointAlgorithmImplementation);
 /* Default constructor */
 NearestPointAlgorithmImplementation::NearestPointAlgorithmImplementation() :
   PersistentObject(),
-  Threadable(),
   levelFunction_(NumericalMathFunction()),
   startingPoint_(NumericalPoint(0)),
   levelValue_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultLevelValue" )),
-  maximumIterationsNumber_(ResourceMap::GetAsUnsignedLong( "NearestPointAlgorithmImplementation-DefaultMaximumIterationsNumber" )),
+  maximumIterationsNumber_(ResourceMap::GetAsUnsignedLong( "NearestPointAlgorithmImplementation-DefaultMaximumIteration" )),
   maximumAbsoluteError_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumAbsoluteError" )),
   maximumRelativeError_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumRelativeError" )),
   maximumResidualError_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumResidualError" )),
@@ -56,11 +55,10 @@ NearestPointAlgorithmImplementation::NearestPointAlgorithmImplementation() :
 NearestPointAlgorithmImplementation::NearestPointAlgorithmImplementation(const NumericalMathFunction & levelFunction,
     const Bool verbose):
   PersistentObject(),
-  Threadable(),
   levelFunction_(levelFunction),
   startingPoint_(NumericalPoint(levelFunction.getInputDimension(), 0.0)),
   levelValue_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultLevelValue" )),
-  maximumIterationsNumber_(ResourceMap::GetAsUnsignedLong( "NearestPointAlgorithmImplementation-DefaultMaximumIterationsNumber" )),
+  maximumIterationsNumber_(ResourceMap::GetAsUnsignedLong( "NearestPointAlgorithmImplementation-DefaultMaximumIteration" )),
   maximumAbsoluteError_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumAbsoluteError" )),
   maximumRelativeError_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumRelativeError" )),
   maximumResidualError_(ResourceMap::GetAsNumericalScalar( "NearestPointAlgorithmImplementation-DefaultMaximumResidualError" )),
