@@ -3,7 +3,7 @@
  *  @file  NearestPointAlgorithmImplementationResult.cxx
  *  @brief NearestPointAlgorithmImplementationResult stores the result of a NearestPointAlgorithmImplementationResult
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -273,7 +273,7 @@ void NearestPointAlgorithmImplementationResult::store(const NumericalPoint & x,
   outputHistory_.store(y);
 }
 
-Graph NearestPointAlgorithmImplementationResult::getErrorHistory() const
+Graph NearestPointAlgorithmImplementationResult::drawErrorHistory() const
 {
   Graph result("Error history", "Iteration number", "Error value", true, "topright", 1.0, GraphImplementation::LOGY);
   result.setGrid(true);
