@@ -4,7 +4,7 @@
  *  @brief SQP is an actual implementation for
  *         NearestPointAlgorithm using the SQP algorithm.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -86,7 +86,7 @@ NumericalScalar SQP::computeLineSearch()
   /* Actualize sigma */
   currentSigma_ = std::max(currentSigma_ + 1.0, smooth * currentPoint_.norm() / currentGradient_.norm());
   /* Compute penalized scalar objective function at current point */
-  NumericalScalar currentTheta(0.5 * currentPoint_.norm2() + currentSigma_ * fabs(currentLevelValue_ - levelValue));
+  NumericalScalar currentTheta(0.5 * currentPoint_.normSquare() + currentSigma_ * fabs(currentLevelValue_ - levelValue));
   /* Min bound for step */
   const NumericalScalar minStep(getMaximumAbsoluteError() / currentDirection_.norm());
   /* Minimum decrease for the penalized objective function */
@@ -103,7 +103,7 @@ NumericalScalar SQP::computeLineSearch()
     currentStepPoint = currentPoint_ + step * currentDirection_;
     currentStepLevelValue = levelFunction(currentStepPoint)[0];
 
-    currentStepTheta = 0.5 * currentStepPoint.norm2() + currentSigma_ * fabs(currentStepLevelValue - levelValue);
+    currentStepTheta = 0.5 * currentStepPoint.normSquare() + currentSigma_ * fabs(currentStepLevelValue - levelValue);
     if (getVerbose()) LOGINFO(OSS() << "line search step=" << step << " currentStepPoint=" << currentStepPoint << " currentStepLevelValue=" << currentStepLevelValue << " currentStepTheta=" << currentStepTheta);
     step *= tau;
   }
@@ -163,7 +163,7 @@ void SQP::run()
     /* Compute the level function gradient at the current point -> Grad(G) */
     currentGradient_ = levelFunction.gradient(currentPoint_) * NumericalPoint(1, 1.0);
     /* Compute the current Lagrange multiplier */
-    const NumericalScalar normGradientSquared(currentGradient_.norm2());
+    const NumericalScalar normGradientSquared(currentGradient_.normSquare());
     /* In case of a null gradient, throw an internal exception */
 
     if (normGradientSquared == 0)
