@@ -3,7 +3,7 @@
  *  @file  CauchyModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,7 @@
 #include "CauchyModel.hxx"
 #include "Exception.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "TimeSeries.hxx"
+#include "Field.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -119,7 +119,7 @@ CauchyModel * CauchyModel::clone() const
 }
 
 /* Computation of the spectral density function */
-HermitianMatrix CauchyModel::computeSpectralDensity(const NumericalScalar frequency) const
+HermitianMatrix CauchyModel::operator() (const NumericalScalar frequency) const
 {
   const NumericalScalar scaledFrequencySquared(pow(2.0 * M_PI * fabs(frequency), 2));
   HermitianMatrix spectralDensityMatrix(dimension_);
@@ -136,7 +136,7 @@ HermitianMatrix CauchyModel::computeSpectralDensity(const NumericalScalar freque
 /* String converter */
 String CauchyModel::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << CauchyModel::GetClassName();
   oss << " amplitude=" << amplitude_
       << " scale=" << scale_
@@ -148,10 +148,10 @@ String CauchyModel::__repr__() const
 /* String converter */
 String CauchyModel::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << "class=" << CauchyModel::GetClassName();
-  oss << " amplitude=" << amplitude_.__str__(offset)
-      << " scale=" << scale_.__str__(offset);
+  oss << " amplitude=" << amplitude_
+      << " scale=" << scale_;
   if (!isDiagonal_)
     oss << " spatial correlation=\n" << spatialCorrelation_.__str__(offset);
   else
