@@ -3,7 +3,7 @@
  *  @file  Compact.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -123,11 +123,11 @@ String Compact::__repr__() const
 {
   OSS oss;
   oss << "class=" << Compact::GetClassName();
-  oss << " sample_= " << sample_;
-  oss << " halfMaximumSize_ " << halfMaximumSize_;
-  oss << " index_ " << index_;
-  oss << " step_ " << step_;
-  oss << " throwingCounter_ " << throwingCounter_;
+  oss << " sample_=" << sample_;
+  oss << " halfMaximumSize_=" << halfMaximumSize_;
+  oss << " index_=" << index_;
+  oss << " step_=" << step_;
+  oss << " throwingCounter_=" << throwingCounter_;
   return oss;
 }
 
