@@ -3,7 +3,7 @@
  *  @file  CovarianceModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,19 +78,79 @@ CovarianceMatrix CovarianceModel::computeCovariance(const NumericalScalar s,
   return getImplementation()->computeCovariance(s, t);
 }
 
-/* Computation of the covariance function */
+CovarianceMatrix CovarianceModel::computeCovariance(const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  return getImplementation()->computeCovariance(s, t);
+}
+
 CovarianceMatrix CovarianceModel::computeCovariance(const NumericalScalar tau) const
 {
   return getImplementation()->computeCovariance(tau);
 }
 
-/* Discretize the covariance function on a given TimeGrid */
+CovarianceMatrix CovarianceModel::computeCovariance(const NumericalPoint & tau) const
+{
+  return getImplementation()->computeCovariance(tau);
+}
+
+CovarianceMatrix CovarianceModel::operator() (const NumericalScalar s,
+    const NumericalScalar t) const
+{
+  return getImplementation()->operator() (s, t);
+}
+
+CovarianceMatrix CovarianceModel::operator() (const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  return getImplementation()->operator() (s, t);
+}
+
+CovarianceMatrix CovarianceModel::operator() (const NumericalScalar tau) const
+{
+  return getImplementation()->operator() (tau);
+}
+
+CovarianceMatrix CovarianceModel::operator() (const NumericalPoint & tau) const
+{
+  return getImplementation()->operator() (tau);
+}
+
+/* Gradient */
+SymmetricTensor CovarianceModel::partialGradient(const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  return getImplementation()->partialGradient(s, t);
+}
+
+/* Discretize the covariance function on a given TimeGrid/Mesh */
 CovarianceMatrix CovarianceModel::discretizeCovariance(const RegularGrid & timeGrid) const
 {
   return getImplementation()->discretizeCovariance(timeGrid);
 }
 
-/* Is the underlying a stationary covariance model ? */
+CovarianceMatrix CovarianceModel::discretizeCovariance(const Mesh & mesh) const
+{
+  return getImplementation()->discretizeCovariance(mesh);
+}
+
+CovarianceMatrix CovarianceModel::discretize(const RegularGrid & timeGrid) const
+{
+  return getImplementation()->discretize(timeGrid);
+}
+
+CovarianceMatrix CovarianceModel::discretize(const Mesh & mesh) const
+{
+  return getImplementation()->discretize(mesh);
+}
+
+/* Partial discretization with respect to the second argument */
+Basis CovarianceModel::getPartialDiscretization(const NumericalSample & secondLocation) const
+{
+  return getImplementation()->getPartialDiscretization(secondLocation);
+}
+
+/* Is it a stationary covariance model ? */
 Bool CovarianceModel::isStationary() const
 {
   return getImplementation()->isStationary();
@@ -108,4 +168,15 @@ String CovarianceModel::__str__(const String & offset) const
   return getImplementation()->__str__(offset);
 }
 
+void CovarianceModel::setParameters(const NumericalPointWithDescription& parameters)
+{
+  getImplementation()->setParameters(parameters);
+}
+
+NumericalPointWithDescription CovarianceModel::getParameters() const
+{
+  return getImplementation()->getParameters();
+}
+
+
 END_NAMESPACE_OPENTURNS
