@@ -3,7 +3,7 @@
  *  @file  CovarianceModelImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include "CovarianceModelImplementation.hxx"
 #include "Exception.hxx"
+#include "Log.hxx"
 #include "PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -37,8 +38,8 @@ static Factory<CovarianceModelImplementation> RegisteredFactory("CovarianceModel
 
 /* Constructor without parameters */
 CovarianceModelImplementation::CovarianceModelImplementation(const String & name)
-  : PersistentObject(name),
-    dimension_(0)
+  : PersistentObject(name)
+  , dimension_(0)
 {
   // Nothing to do
 }
@@ -46,8 +47,8 @@ CovarianceModelImplementation::CovarianceModelImplementation(const String & name
 /* Constructor with dimension parameter */
 CovarianceModelImplementation::CovarianceModelImplementation(const UnsignedLong dimension,
     const String & name)
-  : PersistentObject(name),
-    dimension_(dimension)
+  : PersistentObject(name)
+  , dimension_(dimension)
 {
   // Nothing to do
 }
@@ -68,21 +69,83 @@ UnsignedLong CovarianceModelImplementation::getDimension() const
 CovarianceMatrix CovarianceModelImplementation::computeCovariance(const NumericalScalar s,
     const NumericalScalar t) const
 {
-  throw NotYetImplementedException(HERE);
+  LOGUSER(OSS() << "The computeCovariance(const NumericalScalar s, const NumericalScalar t) method is deprecated in favor of the operator() (const NumericalScalar s, const NumericalScalar t) method");
+  return operator() (s, t);
+}
+
+CovarianceMatrix CovarianceModelImplementation::computeCovariance(const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  LOGUSER(OSS() << "The computeCovariance(const NumericalPoint & s, const NumericalPoint & t) method is deprecated in favor of the operator() (const NumericalPoint & s, const NumericalPoint & t) method");
+  return operator() (s, t);
 }
 
 /* Computation of the covariance function */
 CovarianceMatrix CovarianceModelImplementation::computeCovariance(const NumericalScalar tau) const
 {
-  return computeCovariance(0.0, tau);
+  LOGUSER(OSS() << "The computeCovariance(const NumericalScalar tau) method is deprecated in favor of the operator() (const NumericalScalar tau) method");
+  return operator() (tau);
 }
 
-/* Discretize the covariance function on a given TimeGrid */
+CovarianceMatrix CovarianceModelImplementation::computeCovariance(const NumericalPoint & tau) const
+{
+  LOGUSER(OSS() << "The computeCovariance(const NumericalPoint & tau) method is deprecated in favor of the operator() (const NumericalPoint & tau) method");
+  return operator() (NumericalPoint(tau.getDimension()), tau);
+}
+
+CovarianceMatrix CovarianceModelImplementation::operator() (const NumericalScalar s,
+    const NumericalScalar t) const
+{
+  return operator() (NumericalPoint(1, s), NumericalPoint(1, t));
+}
+
+CovarianceMatrix CovarianceModelImplementation::operator() (const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
+/* Computation of the covariance function */
+CovarianceMatrix CovarianceModelImplementation::operator() (const NumericalScalar tau) const
+{
+  return operator() (NumericalPoint(1, tau));
+}
+
+CovarianceMatrix CovarianceModelImplementation::operator() (const NumericalPoint & tau) const
+{
+  return operator() (NumericalPoint(tau.getDimension()), tau);
+}
+
+/* Gradient */
+SymmetricTensor CovarianceModelImplementation::partialGradient (const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
+/* Discretize the covariance function on a given TimeGrid/Mesh */
 CovarianceMatrix CovarianceModelImplementation::discretizeCovariance(const RegularGrid & timeGrid) const
 {
-  const UnsignedLong size(timeGrid.getN());
+  LOGUSER(OSS() << "The discretizeCovariance(const RegularGrid & timeGrid) method is deprecated in favor of the discretize(const RegularGrid & timeGrid) method");
+  return discretize(timeGrid);
+}
+
+CovarianceMatrix CovarianceModelImplementation::discretizeCovariance(const Mesh & mesh) const
+{
+  LOGUSER(OSS() << "The discretizeCovariance(const Mesh & mesh) method is deprecated in favor of the discretize(const Mesh & mesh) method");
+  return discretize(mesh);
+}
+
+CovarianceMatrix CovarianceModelImplementation::discretize(const RegularGrid & timeGrid) const
+{
+  return discretize(Mesh(timeGrid));
+}
+
+CovarianceMatrix CovarianceModelImplementation::discretize(const Mesh & mesh) const
+{
+  const NumericalSample vertices(mesh.getVertices());
+  const UnsignedLong size(vertices.getSize());
   const UnsignedLong fullSize(size * dimension_);
-  const NumericalScalar timeStep(timeGrid.getStep());
   CovarianceMatrix covarianceMatrix(fullSize);
 
   // Fill-in the matrix by blocks
@@ -91,7 +154,7 @@ CovarianceMatrix CovarianceModelImplementation::discretizeCovariance(const Regul
     // Only the lower part has to be filled-in
     for (UnsignedLong columnIndex = 0; columnIndex < rowIndex; ++columnIndex)
     {
-      const CovarianceMatrix localCovarianceMatrix(computeCovariance( rowIndex * timeStep,  columnIndex * timeStep) );
+      const CovarianceMatrix localCovarianceMatrix(operator()( vertices[rowIndex],  vertices[columnIndex] ));
       // We fill the covariance matrix using the previous local one
       // The full local covariance matrix has to be copied as it is
       // not copied on a symmetric position
@@ -107,6 +170,12 @@ CovarianceMatrix CovarianceModelImplementation::discretizeCovariance(const Regul
   return covarianceMatrix;
 }
 
+/* Partial discretization with respect to the second argument */
+Basis CovarianceModelImplementation::getPartialDiscretization(const NumericalSample & secondLocation) const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* Is it a stationary model ? */
 Bool CovarianceModelImplementation::isStationary() const
 {
@@ -116,7 +185,7 @@ Bool CovarianceModelImplementation::isStationary() const
 /* String converter */
 String CovarianceModelImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class= " << CovarianceModelImplementation::GetClassName();
   return oss;
 }
@@ -125,10 +194,20 @@ String CovarianceModelImplementation::__repr__() const
 String CovarianceModelImplementation::__str__(const String & offset) const
 {
   OSS oss(false);
-  oss << "class= " << CovarianceModelImplementation::GetClassName();
+  oss << offset << "class= " << CovarianceModelImplementation::GetClassName();
   return oss;
 }
 
+void CovarianceModelImplementation::setParameters(const NumericalPointWithDescription& parameters)
+{
+  throw NotYetImplementedException(HERE);
+}
+
+NumericalPointWithDescription CovarianceModelImplementation::getParameters() const
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* Method save() stores the object through the StorageManager */
 void CovarianceModelImplementation::save(Advocate & adv) const
 {
