@@ -3,7 +3,7 @@
  *  @file  ExponentialCauchy.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,7 +78,7 @@ ExponentialCauchy * ExponentialCauchy::clone() const
 /* String converter */
 String ExponentialCauchy::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ExponentialCauchy::GetClassName()
       << " derived from " << SecondOrderModelImplementation::__repr__();
   return oss;
@@ -87,11 +87,11 @@ String ExponentialCauchy::__repr__() const
 /* String converter */
 String ExponentialCauchy::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << "class=" << ExponentialCauchy::GetClassName();
-  oss << " amplitude=" << getAmplitude().__str__(offset)
-      << " scale=" << getScale().__str__(offset)
-      << " spatial correlation=" << getSpatialCorrelation().__str__(offset);
+  oss << " amplitude=" << getAmplitude()
+      << " scale=" << getScale()
+      << " spatial correlation=" << getSpatialCorrelation();
   return oss;
 }
 
