@@ -3,7 +3,7 @@
  *  @file  ExponentialModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 #include "ExponentialModel.hxx"
 #include "Exception.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "TimeSeries.hxx"
+#include "Field.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -121,11 +121,11 @@ ExponentialModel * ExponentialModel::clone() const
  * C_{i,j}(tau) = amplitude_i * exp(-scale_i * |tau|) * R_{i,j} * amplitude_j * exp(-scale_j|tau|)
  * C_{i,i}(tau) = amplitude_i^2 * exp(-scale_i * |tau|)
  */
-CovarianceMatrix ExponentialModel::computeCovariance(const NumericalScalar tau) const
+CovarianceMatrix ExponentialModel::operator() (const NumericalPoint & tau) const
 {
   CovarianceMatrix covarianceMatrix(dimension_);
   // Absolute value of tau
-  const NumericalScalar absTau(fabs(tau));
+  const NumericalScalar absTau(tau.norm());
   NumericalPoint exponentialTerms(dimension_);
   for (UnsignedLong i = 0; i < dimension_; ++i)
   {
@@ -141,7 +141,7 @@ CovarianceMatrix ExponentialModel::computeCovariance(const NumericalScalar tau)
 }
 
 /* Discretize the covariance function on a given TimeGrid */
-CovarianceMatrix ExponentialModel::discretizeCovariance(const RegularGrid & timeGrid) const
+CovarianceMatrix ExponentialModel::discretize(const RegularGrid & timeGrid) const
 {
   const UnsignedLong size(timeGrid.getN());
   const UnsignedLong fullSize(size * dimension_);
@@ -154,7 +154,7 @@ CovarianceMatrix ExponentialModel::discretizeCovariance(const RegularGrid & time
   // Fill the matrix by block-diagonal
   // The main diagonal has a specific treatment as only its lower triangular part
   // has to be copied
-  const CovarianceMatrix covTau0( computeCovariance( 0.0 ) );
+  const CovarianceMatrix covTau0( operator()( 0.0 ) );
 
   // Loop over the main diagonal block
   for (UnsignedLong block = 0; block < size; ++block)
@@ -173,7 +173,7 @@ CovarianceMatrix ExponentialModel::discretizeCovariance(const RegularGrid & time
   // Loop over the remaining diagonal blocks
   for (UnsignedLong diag = 1; diag < size; ++diag)
   {
-    const CovarianceMatrix covTau( computeCovariance( diag * timeStep ) );
+    const CovarianceMatrix covTau( operator()( diag * timeStep ) );
 
     // Loop over the main block diagonal
     for (UnsignedLong block = 0; block < size - diag; ++block)
@@ -199,6 +199,18 @@ CovarianceMatrix ExponentialModel::discretizeCovariance(const RegularGrid & time
   return cov;
 }
 
+/* Partial discretization with respect to the second argument */
+/* Computation of the covariance function, stationary interface
+ * C_{i,j}(tau) = amplitude_i * exp(-scale_i * |tau|) * R_{i,j} * amplitude_j * exp(-scale_j|tau|)
+ * C_{i,i}(tau) = amplitude_i^2 * exp(-scale_i * |tau|)
+ */
+Basis ExponentialModel::getPartialDiscretization(const NumericalSample & secondLocation) const
+{
+  Basis basis;
+  throw NotYetImplementedException(HERE) << "ExponentialModel::getPartialDiscretization";
+  return basis;
+}
+
 /* Is it a stationary model ? */
 Bool ExponentialModel::isStationary() const
 {
@@ -208,7 +220,7 @@ Bool ExponentialModel::isStationary() const
 /* String converter */
 String ExponentialModel::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ExponentialModel::GetClassName();
   oss << " amplitude=" << amplitude_
       << " scale=" << scale_
@@ -220,10 +232,10 @@ String ExponentialModel::__repr__() const
 /* String converter */
 String ExponentialModel::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << "class=" << ExponentialModel::GetClassName();
-  oss << " amplitude=" << amplitude_.__str__(offset)
-      << " scale=" << scale_.__str__(offset);
+  oss << " amplitude=" << amplitude_
+      << " scale=" << scale_;
   if (!isDiagonal_)
     oss << " spatial correlation=\n" << spatialCorrelation_.__str__(offset);
   else
