@@ -3,7 +3,7 @@
  *  @file  FilteringWindowsImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -69,7 +69,7 @@ NumericalScalar FilteringWindows::operator()(const NumericalScalar t) const
 /* String converter */
 String FilteringWindows::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << FilteringWindows::GetClassName()
       << " implementation=" << getImplementation()->__repr__();
   return oss;
@@ -78,7 +78,7 @@ String FilteringWindows::__repr__() const
 /* String converter */
 String FilteringWindows::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << "class=" << FilteringWindows::GetClassName()
       << " implementation=" << getImplementation()->__str__(offset);
   return oss;
