@@ -3,7 +3,7 @@
  *  @file  FilteringWindowsImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,7 +56,7 @@ NumericalScalar FilteringWindowsImplementation::operator()(const NumericalScalar
 /* String converter */
 String FilteringWindowsImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class= " << FilteringWindowsImplementation::GetClassName();
   return oss;
 }
