@@ -3,7 +3,7 @@
  *  @file  HaltonSequence.cxx
  *  @brief Implementation of the Halton' sequence
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -84,7 +84,7 @@ NumericalPoint HaltonSequence::generate()
 /* String converter */
 String HaltonSequence::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << HaltonSequence::GetClassName()
       << " derived from " << LowDiscrepancySequenceImplementation::__repr__()
       << " base=" << base_
