@@ -3,7 +3,7 @@
  *  @file  Hamming.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,7 @@ Hamming * Hamming::clone() const
 /* String converter */
 String Hamming::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Hamming::GetClassName();
   return oss;
 }
@@ -59,8 +59,8 @@ String Hamming::__repr__() const
 /* String converter */
 String Hamming::__str__(const String & offset) const
 {
-  OSS oss;
-  oss << "class=" << Hamming::GetClassName();
+  OSS oss(false);
+  oss << offset << "class=" << Hamming::GetClassName();
   return oss;
 }
 
