@@ -3,7 +3,7 @@
  *  @file  Hanning.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -50,7 +50,7 @@ Hanning * Hanning::clone() const
 /* String converter */
 String Hanning::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Hanning::GetClassName();
   return oss;
 }
@@ -58,7 +58,7 @@ String Hanning::__repr__() const
 /* String converter */
 String Hanning::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << "class=" << Hanning::GetClassName();
   return oss;
 }
