@@ -3,7 +3,7 @@
  *  @file  HaselgroveSequence.cxx
  *  @brief Implementation of the Haselgrove' sequence
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -79,7 +79,7 @@ NumericalPoint HaselgroveSequence::generate()
 /* String converter */
 String HaselgroveSequence::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << HaselgroveSequence::GetClassName()
       << " derived from " << LowDiscrepancySequenceImplementation::__repr__()
       << " base=" << base_
