@@ -3,7 +3,7 @@
  *  @file  NumericalSample.cxx
  *  @brief The class NumericalSample implements blank free samples
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,26 +27,29 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(NumericalSample);
 
-
 /* Factory of NumericalSample from CSV file */
 NumericalSample NumericalSample::ImportFromCSVFile(const FileName & fileName,
     const String & csvSeparator)
 {
   NumericalSample sample(NumericalSampleImplementation::BuildFromCSVFile(fileName, csvSeparator));
-  sample.setName(fileName);
+  return sample;
+}
+
+/* Factory of NumericalSample from Text file */
+NumericalSample NumericalSample::ImportFromTextFile(const FileName & fileName,
+    const String & separator)
+{
+  NumericalSample sample(NumericalSampleImplementation::BuildFromTextFile(fileName, separator));
   return sample;
 }
 
 /* Save to CSV file */
 void NumericalSample::exportToCSVFile(const FileName & filename,
-                                      const String & csvSeparator,
-                                      const Bool withDescription) const
+                                      const String & csvSeparator) const
 {
-  getImplementation()->exportToCSVFile(filename, csvSeparator, withDescription);
+  getImplementation()->exportToCSVFile(filename, csvSeparator);
 }
 
 
@@ -99,6 +102,20 @@ NumericalSample::NumericalSample(const UnsignedLong size,
   // Nothing to do
 }
 
+/* Constructor from a collection of NumericalPoint */
+NumericalSample::NumericalSample(const Collection<NumericalPoint> & coll)
+  : TypedInterfaceObject<NumericalSampleImplementation>(new NumericalSampleImplementation(coll))
+{
+  // Nothing to do
+}
+
+/* Constructor from a collection of Indices */
+NumericalSample::NumericalSample(const Collection<Indices> & coll)
+  : TypedInterfaceObject<NumericalSampleImplementation>(new NumericalSampleImplementation(coll))
+{
+  // Nothing to do
+}
+
 /* Comparison operator */
 Bool NumericalSample::operator ==(const NumericalSample & other) const
 {
@@ -221,7 +238,7 @@ Bool NumericalSample::__contains__(const NumericalPoint & val) const
 /* String converter */
 String NumericalSample::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " name=" << getName()
          << " description=" << getDescription()
          << " implementation=" << getImplementation()->__repr__();
@@ -299,6 +316,13 @@ void NumericalSample::add(const NumericalSample & sample)
   getImplementation()->add(*sample.getImplementation());
 }
 
+/* Stack another sample to the current sample */
+void NumericalSample::stack(const NumericalSample & sample)
+{
+  copyOnWrite();
+  getImplementation()->stack(*sample.getImplementation());
+}
+
 
 void NumericalSample::erase(const UnsignedLong first,
                             const UnsignedLong last)
@@ -417,6 +441,11 @@ NumericalPoint NumericalSample::computeStandardDeviationPerComponent() const
 /*
  * Method computePearsonCorrelation() gives the Pearson correlation matrix of the sample
  */
+CorrelationMatrix NumericalSample::computeLinearCorrelation() const
+{
+  return getImplementation()->computeLinearCorrelation();
+}
+
 CorrelationMatrix NumericalSample::computePearsonCorrelation() const
 {
   return getImplementation()->computePearsonCorrelation();
@@ -487,6 +516,14 @@ NumericalPoint NumericalSample::computeCenteredMomentPerComponent(const Unsigned
   return getImplementation()->computeCenteredMomentPerComponent(k);
 }
 
+/*
+ * Gives the raw moment of order k of the sample (by component)
+ */
+NumericalPoint NumericalSample::computeRawMomentPerComponent(const UnsignedLong k) const
+{
+  return getImplementation()->computeRawMomentPerComponent(k);
+}
+
 /*
  * Method computeQuantilePerComponent() gives the quantile per component of the sample
  */
@@ -537,6 +574,13 @@ NumericalSample & NumericalSample::operator += (const NumericalPoint & translati
   return *this;
 }
 
+NumericalSample & NumericalSample::operator += (const NumericalSample & translation)
+{
+  copyOnWrite();
+  getImplementation()->operator +=(*translation.getImplementation());
+  return *this;
+}
+
 NumericalSample & NumericalSample::operator -= (const NumericalPoint & translation)
 {
   copyOnWrite();
@@ -544,6 +588,37 @@ NumericalSample & NumericalSample::operator -= (const NumericalPoint & translati
   return *this;
 }
 
+NumericalSample & NumericalSample::operator -= (const NumericalSample & translation)
+{
+  copyOnWrite();
+  getImplementation()->operator -=(*translation.getImplementation());
+  return *this;
+}
+
+NumericalSample NumericalSample::operator + (const NumericalPoint & translation) const
+{
+  NumericalSample sample(getImplementation()->operator + (translation));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator + (const NumericalSample & translation) const
+{
+  NumericalSample sample(getImplementation()->operator + (*translation.getImplementation()));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator - (const NumericalPoint & translation) const
+{
+  NumericalSample sample(getImplementation()->operator - (translation));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator - (const NumericalSample & translation) const
+{
+  NumericalSample sample(getImplementation()->operator - (*translation.getImplementation()));
+  return sample;
+}
+
 /*
  * Scale realizations componentwise in-place
  */
@@ -566,6 +641,13 @@ NumericalSample & NumericalSample::operator *= (const NumericalPoint & scaling)
   return *this;
 }
 
+NumericalSample & NumericalSample::operator /= (const NumericalPoint & scaling)
+{
+  copyOnWrite();
+  getImplementation()->operator /=(scaling);
+  return *this;
+}
+
 NumericalSample & NumericalSample::operator *= (const SquareMatrix & scaling)
 {
   copyOnWrite();
@@ -573,6 +655,37 @@ NumericalSample & NumericalSample::operator *= (const SquareMatrix & scaling)
   return *this;
 }
 
+NumericalSample & NumericalSample::operator /= (const SquareMatrix & scaling)
+{
+  copyOnWrite();
+  getImplementation()->operator /=(scaling);
+  return *this;
+}
+
+NumericalSample NumericalSample::operator * (const NumericalPoint & scaling)
+{
+  NumericalSample sample(getImplementation()->operator * (scaling));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator / (const NumericalPoint & scaling)
+{
+  NumericalSample sample(getImplementation()->operator / (scaling));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator * (const SquareMatrix & scaling)
+{
+  NumericalSample sample(getImplementation()->operator * (scaling));
+  return sample;
+}
+
+NumericalSample NumericalSample::operator / (const SquareMatrix & scaling)
+{
+  NumericalSample sample(getImplementation()->operator / (scaling));
+  return sample;
+}
+
 /* Ranked sample */
 NumericalSample NumericalSample::rank() const
 {
