@@ -3,7 +3,7 @@
  *  @file  ProcessSample.cxx
  *  @brief ProcessSample Class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,8 +33,8 @@ BEGIN_NAMESPACE_OPENTURNS
 
 
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<ProcessSample>);
-TEMPLATE_CLASSNAMEINIT(PersistentCollection<TimeSeries>);
-static Factory<PersistentCollection<TimeSeries> > RegisteredFactory1("PersistentCollection<TimeSeries>");
+TEMPLATE_CLASSNAMEINIT(PersistentCollection<Field>);
+static Factory<PersistentCollection<Field> > RegisteredFactory1("PersistentCollection<Field>");
 
 
 CLASSNAMEINIT(ProcessSample);
@@ -43,8 +43,7 @@ static Factory<ProcessSample> RegisteredFactory("ProcessSample");
 
 ProcessSample::ProcessSample()
   : PersistentObject(),
-    dimension_(1),
-    timeGrid_(),
+    mesh_(),
     data_(0)
 {
   // Nothing to do
@@ -52,37 +51,24 @@ ProcessSample::ProcessSample()
 
 /* Default constructor */
 ProcessSample::ProcessSample(const UnsignedLong size,
-                             const TimeSeries & timeSeries)
+                             const Field & field)
   : PersistentObject(),
-    dimension_(timeSeries.getDimension()),
-    timeGrid_(timeSeries.getTimeGrid()),
-    data_(TimeSeriesPersistentCollection(size, timeSeries))
+    mesh_(field.getMesh()),
+    data_(NumericalSampleCollection(size, field.getValues()))
 {
   // Nothing to do
 }
 
-
-ProcessSample::ProcessSample(const RegularGrid & timeGrid,
+ProcessSample::ProcessSample(const Mesh & mesh,
                              const UnsignedLong size,
                              const UnsignedLong dimension)
   : PersistentObject(),
-    dimension_(dimension),
-    timeGrid_(timeGrid),
-    data_(TimeSeriesPersistentCollection(size, TimeSeries(timeGrid, NumericalSample(timeGrid.getN(), dimension))))
+    mesh_(mesh),
+    data_(NumericalSampleCollection(size, NumericalSample(mesh.getVerticesNumber(), mesh.getDimension())))
 {
   // Nothing to do
 }
 
-ProcessSample::ProcessSample(const TimeSeriesCollection & collection)
-  : PersistentObject(),
-    dimension_(0),
-    timeGrid_(),
-    data_(0)
-{
-  const UnsignedLong collectionSize(collection.getSize());
-  for (UnsignedLong i = 0; i < collectionSize; ++i ) add(collection[i]);
-}
-
 /* Virtual constructor */
 ProcessSample * ProcessSample::clone() const
 {
@@ -92,70 +78,91 @@ ProcessSample * ProcessSample::clone() const
 /* String converter */
 String ProcessSample::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ProcessSample::GetClassName()
-      << " timeGrid = " << timeGrid_
-      << " values = " << data_;
+      << " mesh=" << mesh_
+      << " values=" << data_;
   return oss;
 }
 
 String ProcessSample::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << "[";
   String separator("");
-  for (UnsignedLong i = 0; i < data_.getSize(); ++i, separator = "\n") oss << separator << offset << "time series " << i << ":\n" << (*this)[i].__str__(offset);
+  for (UnsignedLong i = 0; i < data_.getSize(); ++i, separator = "\n") oss << separator << offset << "field " << i << ":\n" << getField(i).__str__(offset);
   oss << "]";
   return oss;
 }
 
-void ProcessSample::add(const TimeSeries & timeSeries)
+void ProcessSample::add(const Field & field)
 {
   if (getSize() == 0)
   {
-    data_.add(timeSeries);
-    timeGrid_ = timeSeries.getTimeGrid();
-    dimension_ = timeSeries.getDimension();
+    data_.add(field.getValues());
+    mesh_ = field.getMesh();
   }
-  else if ((dimension_ == timeSeries.getDimension()) && (timeGrid_ == timeSeries.getTimeGrid())) data_.add(timeSeries);
-  else throw InvalidArgumentException(HERE) << "Error; could not add the timeSeries. Either its dimenson or its time grid are incompatible.";
+  else if ((data_[0].getDimension() == field.getDimension()) && (mesh_ == field.getMesh())) data_.add(field.getValues());
+  else throw InvalidArgumentException(HERE) << "Error: could not add the fiels. Either its dimenson or its mesh are incompatible.";
 }
 
 
 /* Operators accessors */
-TimeSeries & ProcessSample::operator [] (const UnsignedLong index)
+Field ProcessSample::getField(const UnsignedLong index) const
 {
-  if (index > getSize() - 1) throw InvalidArgumentException(HERE)  << " Error - index should be between 0 and " << getSize() - 1;
+  if (index >= data_.getSize()) throw InvalidArgumentException(HERE)  << " Error - index should be between 0 and " << data_.getSize() - 1;
+  return Field(mesh_, data_[index]);
+}
+
+void ProcessSample::setField(const UnsignedLong index,
+                             const Field & field)
+{
+  if (index >= data_.getSize()) throw InvalidArgumentException(HERE)  << " Error - index should be between 0 and " << data_.getSize() - 1;
+  if (field.getDimension() != data_[0].getDimension()) throw InvalidArgumentException(HERE) << "Error: expected a field of dimension=" << data_[0].getDimension() << ", got a field of dimension=" << field.getDimension();
+  data_[index] = field.getValues();
+}
+
+NumericalSample & ProcessSample::operator[] (const UnsignedLong index)
+{
+  if (index >= data_.getSize()) throw InvalidArgumentException(HERE)  << " Error - index should be between 0 and " << data_.getSize() - 1;
   return data_[index];
 }
 
-const TimeSeries & ProcessSample::operator [] (const UnsignedLong index) const
+const NumericalSample & ProcessSample::operator[] (const UnsignedLong index) const
 {
+  if (index >= data_.getSize()) throw InvalidArgumentException(HERE)  << " Error - index should be between 0 and " << data_.getSize() - 1;
   return data_[index];
 }
 
 /* Method __getitem__() - Python use */
-TimeSeries ProcessSample::__getitem__ (const UnsignedLong i) const
+Field ProcessSample::__getitem__ (const UnsignedLong i) const
 {
-  return (*this)[i];
+  return getField(i);
 }
 
 /* Method __setitem__() is for Python */
-void ProcessSample::__setitem__(const UnsignedLong i, const TimeSeries & timeSeries)
+void ProcessSample::__setitem__(const UnsignedLong i, const Field & field)
 {
-  (*this)[i] = timeSeries;
+  setField(i, field);
 }
 
 /* Time grid accessors */
 RegularGrid ProcessSample::getTimeGrid() const
 {
-  return timeGrid_;
+  return RegularGrid(mesh_);
+}
+
+/* Mesh accessors */
+Mesh ProcessSample::getMesh() const
+{
+  return mesh_;
 }
 
 /* Dimension accessors */
 UnsignedLong ProcessSample::getDimension() const
 {
-  return dimension_;
+  if (data_.getSize() == 0) return 0;
+  return data_[0].getDimension();
 }
 
 /* Dimension accessors */
@@ -164,57 +171,65 @@ UnsignedLong ProcessSample::getSize() const
   return data_.getSize();
 }
 
-TimeSeries ProcessSample::computeMean() const
+Field ProcessSample::computeMean() const
 {
   const UnsignedLong size(getSize());
-  if (size == 0) return TimeSeries();
-  if (size == 1) return data_[0];
-  TimeSeries result(data_[0]);
-  const UnsignedLong length(result.getSize());
+  if (size == 0) return Field();
+  if (size == 1) return Field(mesh_, data_[0]);
+  Field result(mesh_, data_[0]);
+  const UnsignedLong length(data_[0].getSize());
   // Aggregate the mean on the fly
   for (UnsignedLong k = 1; k < size; ++k)
     for (UnsignedLong t = 0; t < length ; ++t)
-      result.getValueAtIndex(t) += data_[k].getValueAtIndex(t);
+      result.setValueAtIndex(t, result.getValueAtIndex(t) + data_[k][t]);
   // Normalize the result
   const NumericalScalar factor(1.0 / size);
   for (UnsignedLong t = 0; t < length ; ++t)
-    result.getValueAtIndex(t) *= factor;
+    result.setValueAtIndex(t, result.getValueAtIndex(t) * factor);
   return result;
 }
 
-/* Compute the sample of temporal means of each time series */
+/* Compute the sample of spatial means of each field */
 NumericalSample ProcessSample::computeTemporalMean() const
+{
+  if (!mesh_.isRegular() || (mesh_.getDimension() != 1)) throw InvalidArgumentException(HERE) << "Error: the temporal mean is defined only when the mesh is regular and of dimension 1.";
+  return computeSpatialMean();
+}
+
+/* Compute the sample of spatial means of each field */
+NumericalSample ProcessSample::computeSpatialMean() const
 {
   const UnsignedLong size(getSize());
   const UnsignedLong dimension(getDimension());
   NumericalSample result(size, dimension);
-  for (UnsignedLong i = 0; i < size; ++i) result[i] = data_[i].getTemporalMean();
+  for (UnsignedLong i = 0; i < size; ++i) result[i] = data_[i].computeMean();
   return result;
 }
 
 /*
  * Method computeQuantilePerComponent() gives the quantile per component of the sample
  */
-TimeSeries ProcessSample::computeQuantilePerComponent(const NumericalScalar prob) const
+Field ProcessSample::computeQuantilePerComponent(const NumericalScalar prob) const
 {
   const UnsignedLong size(getSize());
-  if (size == 0) return TimeSeries();
-  if (size == 1) return data_[0];
+  if (size == 0) return Field();
+  if (size == 1) return Field(mesh_, data_[0]);
   // This initialization set the correct time grid into result
-  TimeSeries result(timeGrid_, dimension_);
+  const UnsignedLong dimension(data_[0].getDimension());
   const UnsignedLong length(data_[0].getSize());
-  // Loop over the time indices
+  NumericalSample result(length, dimension);
+  // Loop over the location indices
   for (UnsignedLong i = 0; i < length; ++i)
   {
-    NumericalSample dataI(size, dimension_);
+    NumericalSample dataI(size, dimension);
     for (UnsignedLong j = 0; j < size; ++j)
-      dataI[j] = data_[j].getValueAtIndex(i);
-    result.getValueAtIndex(i) = dataI.computeQuantilePerComponent(prob);
+      dataI[j] = data_[j][i];
+    result[i] = dataI.computeQuantilePerComponent(prob);
   }
-  return result;
+  return Field(mesh_, result);
 }
 
-/* Draw a marginal of the ProcessSample, ie the collection of all the TimeSeries marginals */
+/* Draw a marginal of the ProcessSample, ie the collection of all the Field marginals */
 Graph ProcessSample::drawMarginal(const UnsignedLong index) const
 {
   if (index > getDimension() - 1 ) throw InvalidArgumentException(HERE) << "Error : indice should be between [0, " << getDimension() - 1 << "]";
@@ -226,7 +241,7 @@ Graph ProcessSample::drawMarginal(const UnsignedLong index) const
   const Description colors(Drawable::BuildDefaultPalette(size));
   for (UnsignedLong i = 0; i < size; ++i)
   {
-    Drawable drawable(data_[i].drawMarginal(index).getDrawable(0));
+    Drawable drawable(Field(mesh_, data_[i]).drawMarginal(index).getDrawable(0));
     drawable.setColor(colors[i]);
     graph.add(drawable);
   }
@@ -237,8 +252,7 @@ Graph ProcessSample::drawMarginal(const UnsignedLong index) const
 void ProcessSample::save(Advocate & adv) const
 {
   PersistentObject::save(adv);
-  adv.saveAttribute( "dimension_", dimension_);
-  adv.saveAttribute( "timeGrid_", timeGrid_);
+  adv.saveAttribute( "mesh_", mesh_);
   adv.saveAttribute( "data_", data_ );
 }
 
@@ -246,8 +260,7 @@ void ProcessSample::save(Advocate & adv) const
 void ProcessSample::load(Advocate & adv)
 {
   PersistentObject::load(adv);
-  adv.loadAttribute( "dimension_", dimension_);
-  adv.loadAttribute( "timeGrid_", timeGrid_);
+  adv.loadAttribute( "mesh_", mesh_);
   adv.loadAttribute( "data_", data_ );
 }
 
