@@ -3,7 +3,7 @@
  *  @file  RandomGenerator.cxx
  *  @brief RandomGenerator implements methods to control the random generator
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,8 +24,10 @@
 #include <cstdlib>
 #include "dsfmt.h"
 #include "RandomGenerator.hxx"
+#include "RandomGeneratorState.hxx"
 #include "ResourceMap.hxx"
 
+
 BEGIN_NAMESPACE_OPENTURNS
 
 class MersenneTwister : public tutils::dsfmt19937
@@ -44,17 +46,8 @@ MersenneTwister RandomGenerator::Generator(ResourceMap::GetAsUnsignedLong( "Rand
 
 /* Sub-classes methods */
 
-// Stream operator for State objects
-std::ostream & operator << (std::ostream & os, const RandomGeneratorState & state)
-{
-  return os << "state=" << state.state_ << ", index=" << state.index_ << ")";
-}
 
-// Comparison operator for State objects
-Bool operator == (const RandomGeneratorState & lhs, const RandomGeneratorState & rhs)
-{
-  return (lhs.state_ == rhs.state_) && (lhs.index_ == rhs.index_);
-}
+
 
 /* DefaultConstructor */
 RandomGenerator::RandomGenerator()
@@ -72,10 +65,10 @@ void RandomGenerator::SetSeed(const UnsignedLong seed)
 /* State accessor */
 void RandomGenerator::SetState(const RandomGeneratorState & state)
 {
-  UnsignedLong size(state.state_.getSize());
+  UnsignedLong size(state.buffer_.getSize());
   UnsignedLong stateSize(Generator.get_state_length_32());
   /* The unusual case, the given seed is too small. It is completed with 0 */
-  UnsignedLongCollection stateArray(state.state_);
+  Indices stateArray(state.buffer_);
   for (UnsignedLong i = size; i < stateSize; i++) stateArray.add(0);
   // Set the state array
   Generator.set_state(&stateArray[0]);
@@ -90,9 +83,9 @@ RandomGeneratorState RandomGenerator::GetState()
 {
   UnsignedLong size((UnsignedLong)(Generator.get_state_length_32()));
   // Create the state and get the index at the same time
-  RandomGeneratorState state(UnsignedLongCollection(size, 0), (UnsignedLong)(Generator.get_index()));
+  RandomGeneratorState state(Indices(size, 0), (UnsignedLong)(Generator.get_index()));
   // Get the state array
-  Generator.get_state(&state.state_[0]);
+  Generator.get_state(&state.buffer_[0]);
   return state;
 }
 
