@@ -3,7 +3,7 @@
  *  @file  SecondOrderModelImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -119,7 +119,7 @@ CovarianceMatrix SecondOrderModel::discretizeCovariance(const RegularGrid & time
 /* String converter */
 String SecondOrderModel::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << SecondOrderModel::GetClassName()
       << " implementation=" << getImplementation()->__repr__();
   return oss;
@@ -128,8 +128,8 @@ String SecondOrderModel::__repr__() const
 /* String converter */
 String SecondOrderModel::__str__(const String & offset) const
 {
-  OSS oss;
-  oss << "class=" << SecondOrderModel::GetClassName()
+  OSS oss(false);
+  oss << offset << "class=" << SecondOrderModel::GetClassName()
       << " implementation=" << getImplementation()->__str__(offset);
   return oss;
 }
