@@ -3,7 +3,7 @@
  *  @file  SecondOrderModelImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 #include "SecondOrderModelImplementation.hxx"
 #include "Exception.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "TimeSeries.hxx"
+#include "Field.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -38,9 +38,9 @@ static Factory<SecondOrderModelImplementation> RegisteredFactory("SecondOrderMod
 
 /* Constructor without parameters */
 SecondOrderModelImplementation::SecondOrderModelImplementation(const String & name)
-  : PersistentObject(name),
-    covarianceModel_(),
-    spectralModel_()
+  : PersistentObject(name)
+  , covarianceModel_()
+  , spectralModel_()
 {
   // Nothing to do
 }
@@ -71,18 +71,18 @@ UnsignedLong SecondOrderModelImplementation::getDimension() const
 CovarianceMatrix SecondOrderModelImplementation::computeCovariance(const NumericalScalar s,
     const NumericalScalar t) const
 {
-  return covarianceModel_.computeCovariance(s, t);
+  return covarianceModel_(s, t);
 }
 
 CovarianceMatrix SecondOrderModelImplementation::computeCovariance(const NumericalScalar tau) const
 {
-  return covarianceModel_.computeCovariance(tau);
+  return covarianceModel_(tau);
 }
 
 /* Computation of the spectral density function */
 HermitianMatrix SecondOrderModelImplementation::computeSpectralDensity(const NumericalScalar frequency) const
 {
-  return spectralModel_.computeSpectralDensity(frequency);
+  return spectralModel_(frequency);
 }
 
 /* Discretize the covariance function on a given TimeGrid */
