@@ -3,7 +3,7 @@
  * @file  SensitivityAnalysis.cxx
  * @brief SensitivityAnalysis implements the sensitivity analysis methods based on Sobol coefficients
  *
- * Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ * Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  * Permission to copy, use, modify, sell and distribute this software
  * is granted provided this copyright notice appears in all copies.
@@ -171,6 +171,7 @@ void SensitivityAnalysis::computeSobolIndices(const UnsignedLong order) const
 NumericalPoint SensitivityAnalysis::getFirstOrderIndices(const UnsignedLong marginalIndex) const
 {
   if (alreadyComputedOrder_ < 1) computeSobolIndices( 1 );
+  if (marginalIndex >= firstOrderIndice_.getSize()) throw InvalidArgumentException(HERE) << "Output dimension is " << firstOrderIndice_.getSize();
   return firstOrderIndice_[marginalIndex];
 }
 
@@ -178,6 +179,7 @@ NumericalPoint SensitivityAnalysis::getFirstOrderIndices(const UnsignedLong marg
 SymmetricMatrix SensitivityAnalysis::getSecondOrderIndices(const UnsignedLong marginalIndex) const
 {
   if (alreadyComputedOrder_ < 2) computeSobolIndices( 2 );
+  if (marginalIndex >= secondOrderIndice_.getNbSheets()) throw InvalidArgumentException(HERE) << "Output dimension is " << secondOrderIndice_.getNbSheets();
   return secondOrderIndice_.getSheet( marginalIndex );
 }
 
@@ -185,6 +187,7 @@ SymmetricMatrix SensitivityAnalysis::getSecondOrderIndices(const UnsignedLong ma
 NumericalPoint SensitivityAnalysis::getTotalOrderIndices(const UnsignedLong marginalIndex) const
 {
   if (alreadyComputedOrder_ < 1) computeSobolIndices( 1 );
+  if (marginalIndex >= totalOrderIndice_.getSize()) throw InvalidArgumentException(HERE) << "Output dimension is " << totalOrderIndice_.getSize();
   return totalOrderIndice_[marginalIndex];
 }
 
