@@ -3,7 +3,7 @@
  *  @file  SpectralModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -93,6 +93,11 @@ HermitianMatrix SpectralModel::computeSpectralDensity(const NumericalScalar freq
   return getImplementation()->computeSpectralDensity(frequency);
 }
 
+HermitianMatrix SpectralModel::operator() (const NumericalScalar frequency) const
+{
+  return getImplementation()->operator()(frequency);
+}
+
 
 /* String converter */
 String SpectralModel::__repr__() const
