@@ -3,7 +3,7 @@
  *  @file  SpectralModelFactory.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -96,7 +96,7 @@ void SpectralModelFactory::setFFTAlgorithm(FFT & fft)
 /* String converter */
 String SpectralModelFactory::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << SpectralModelFactory::GetClassName()
       << " implementation = " << getImplementation()->__repr__();
   return oss;
@@ -113,7 +113,7 @@ SpectralModel SpectralModelFactory::build(const ProcessSample & sample) const
   return getImplementation()->build(sample);
 }
 
-SpectralModel SpectralModelFactory::build(const TimeSeries & timeSeries) const
+SpectralModel SpectralModelFactory::build(const Field & timeSeries) const
 {
   return getImplementation()->build(timeSeries);
 }
