@@ -3,7 +3,7 @@
  *  @file  SpectralModelFactoryImplementation.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,7 +78,7 @@ void SpectralModelFactoryImplementation::setFFTAlgorithm(const FFT & fft)
 /* String converter */
 String SpectralModelFactoryImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << SpectralModelFactoryImplementation::GetClassName();
   return oss;
 }
@@ -86,7 +86,7 @@ String SpectralModelFactoryImplementation::__repr__() const
 /* String converter */
 String SpectralModelFactoryImplementation::__str__(const String & offset) const
 {
-  return this->getClassName();
+  return OSS(false) << offset << this->getClassName();
 }
 
 /* Here is the interface that all derived class must implement */
@@ -96,7 +96,7 @@ SpectralModelImplementation * SpectralModelFactoryImplementation::build(const Pr
   throw NotYetImplementedException(HERE);
 }
 
-SpectralModelImplementation * SpectralModelFactoryImplementation::build(const TimeSeries & timeSeries) const
+SpectralModelImplementation * SpectralModelFactoryImplementation::build(const Field & timeSeries) const
 {
   throw NotYetImplementedException(HERE);
 }
