@@ -3,7 +3,7 @@
  *  @file  SpectralModelImplementation.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,7 @@
 #include "SpectralModelImplementation.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Exception.hxx"
+#include "Log.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -70,6 +71,12 @@ void SpectralModelImplementation::setFrequencyGrid(const RegularGrid & frequency
 
 /* Computation of the spectral density function */
 HermitianMatrix SpectralModelImplementation::computeSpectralDensity(const NumericalScalar frequency) const
+{
+  LOGUSER(OSS() << "The computeSpectralDensity(const NumericalScalar frequency) method is deprecated in favor of the operator() (const NumericalScalar frequency method");
+  return operator()(frequency);
+}
+
+HermitianMatrix SpectralModelImplementation::operator() (const NumericalScalar frequency) const
 {
   throw NotYetImplementedException(HERE);
 }
@@ -78,7 +85,7 @@ HermitianMatrix SpectralModelImplementation::computeSpectralDensity(const Numeri
 /* String converter */
 String SpectralModelImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << SpectralModelImplementation::GetClassName();
   return oss;
 }
@@ -86,8 +93,8 @@ String SpectralModelImplementation::__repr__() const
 /* String converter */
 String SpectralModelImplementation::__str__(const String & offset) const
 {
-  OSS oss;
-  oss << "class=" << SpectralModelImplementation::GetClassName();
+  OSS oss(false);
+  oss << offset << "class=" << SpectralModelImplementation::GetClassName();
   return oss;
 }
 
