@@ -3,7 +3,7 @@
  *  @file  StationaryCovarianceModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include "StationaryCovarianceModel.hxx"
 #include "Exception.hxx"
+#include "Log.hxx"
 #include "PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -49,20 +50,38 @@ StationaryCovarianceModel * StationaryCovarianceModel::clone() const
 }
 
 /* Computation of the covariance function */
-CovarianceMatrix StationaryCovarianceModel::computeCovariance(const NumericalScalar s,
-    const NumericalScalar t) const
+CovarianceMatrix StationaryCovarianceModel::computeCovariance(const NumericalPoint & s,
+    const NumericalPoint & t) const
 {
-  return computeCovariance(t - s);
+  LOGUSER(OSS() << "The computeCovariance(const NumericalPoint & s, const NumericalPoint & t) method is deprecated in favor of the operator() (const NumericalPoint & s, const NumericalPoint & t) method.");
+  return operator() (t - s);
 }
 
-/* Computation of the covariance function */
-CovarianceMatrix StationaryCovarianceModel::computeCovariance(const NumericalScalar tau) const
+CovarianceMatrix StationaryCovarianceModel::computeCovariance(const NumericalPoint & tau) const
+{
+  LOGUSER(OSS() << "The computeCovariance(const NumericalPoint & tau) method is deprecated in favor of the operator() (const NumericalPoint & tau) method.");
+  return operator() (tau);
+}
+
+CovarianceMatrix StationaryCovarianceModel::operator() (const NumericalPoint & s,
+    const NumericalPoint & t) const
+{
+  return operator() (t - s);
+}
+
+CovarianceMatrix StationaryCovarianceModel::operator() (const NumericalPoint & tau) const
 {
   throw NotYetImplementedException(HERE);
 }
 
 /* Discretize the covariance function on a given TimeGrid */
 CovarianceMatrix StationaryCovarianceModel::discretizeCovariance(const RegularGrid & timeGrid) const
+{
+  LOGUSER(OSS() << "The discretizeCovariance(const RegularGrid & timeGrid) method is deprecated in favor of the discretize(const RegularGrid & timeGrid) method");
+  return discretize(timeGrid);
+}
+
+CovarianceMatrix StationaryCovarianceModel::discretize(const RegularGrid & timeGrid) const
 {
   const UnsignedLong size(timeGrid.getN());
   const NumericalScalar timeStep(timeGrid.getStep());
@@ -75,7 +94,7 @@ CovarianceMatrix StationaryCovarianceModel::discretizeCovariance(const RegularGr
     // Only the lower part has to be filled-in
     for (UnsignedLong columnIndex = 0; columnIndex < rowIndex; ++columnIndex)
     {
-      const CovarianceMatrix localCovarianceMatrix(computeCovariance( rowIndex * timeStep,  columnIndex * timeStep) );
+      const CovarianceMatrix localCovarianceMatrix(operator()( rowIndex * timeStep,  columnIndex * timeStep) );
       // We fill the covariance matrix using the previous local one
       // The full local covariance matrix has to be copied as it is
       // not copied on a symmetric position
@@ -100,7 +119,7 @@ Bool StationaryCovarianceModel::isStationary() const
 /* String converter */
 String StationaryCovarianceModel::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class= " << StationaryCovarianceModel::GetClassName();
   return oss;
 }
