@@ -3,7 +3,7 @@
  *  @file  UserDefinedSpectralModel.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -74,7 +74,7 @@ UserDefinedSpectralModel * UserDefinedSpectralModel::clone() const
 
 
 /* Computation of the spectral density function */
-HermitianMatrix UserDefinedSpectralModel::computeSpectralDensity(const NumericalScalar frequency) const
+HermitianMatrix UserDefinedSpectralModel::operator() (const NumericalScalar frequency) const
 {
   Bool nonNegative(frequency >= 0.0);
   // If the grid size is one , return the spectral function
@@ -91,7 +91,7 @@ HermitianMatrix UserDefinedSpectralModel::computeSpectralDensity(const Numerical
 /* String converter */
 String UserDefinedSpectralModel::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << UserDefinedSpectralModel::GetClassName()
       << " DSPCollection=" << DSPCollection_
       << " frequencyGrid=" << getFrequencyGrid();
@@ -101,9 +101,10 @@ String UserDefinedSpectralModel::__repr__() const
 /* String converter */
 String UserDefinedSpectralModel::__str__(const String & offset) const
 {
-  OSS oss;
-  oss << "frequency =" << frequencyGrid_.__str__(offset)
-      << " dimension = " << dimension_;
+  OSS oss(false);
+  oss << "frequency=" << frequencyGrid_.__str__(offset)
+      << " dimension=" << dimension_
+      << " DSPCollection=" << DSPCollection_.__str__(offset);
   return oss;
 }
 
