@@ -3,7 +3,7 @@
  *  @file  WelchFactory.cxx
  *  @brief Top-level class for all spectral model factories
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -83,7 +83,7 @@ void WelchFactory::setFilteringWindows(const FilteringWindows & window)
 /* String converter */
 String WelchFactory::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << WelchFactory::GetClassName()
       << " window = " << window_
       << " blockNumber = " << blockNumber_
@@ -167,7 +167,7 @@ UserDefinedSpectralModel * WelchFactory::build(const ProcessSample & sample) con
     {
       // Loop over the time stamps
       NumericalComplexCollection zP(N);
-      for (UnsignedLong m = 0; m < N; ++m) zP[m] = alpha[m] * sample[l][m][p + 1]; // The first component of the value of a time series at a given index is the time value
+      for (UnsignedLong m = 0; m < N; ++m) zP[m] = alpha[m] * sample[l][m][p]; // The first component of the value of a time series at a given index is the time value
       // Perform the FFT direct transform of the tapered data
       const NumericalComplexCollection zPHat(fftAlgorithm_.transform(zP));
       // Stores the result. Only the values associated with nonnegative frequency values are stored.
@@ -185,7 +185,7 @@ UserDefinedSpectralModel * WelchFactory::build(const ProcessSample & sample) con
   return UserDefinedSpectralModel(frequencyGrid, DSPCollection).clone();
 }
 
-UserDefinedSpectralModel * WelchFactory::build(const TimeSeries & timeSeries) const
+UserDefinedSpectralModel * WelchFactory::build(const Field & timeSeries) const
 {
   // We split the time series into overlaping blockNumbers that are used as a ProcessSample
   const UnsignedLong size(timeSeries.getSize());
@@ -197,13 +197,13 @@ UserDefinedSpectralModel * WelchFactory::build(const TimeSeries & timeSeries) co
   const UnsignedLong hopSize(blockNumber_ == 1 ? 0 : (size - blockSize) / (blockNumber_ - 1));
   const RegularGrid timeGrid(timeSeries.getTimeGrid());
   // Initialize the equivalent process sample with the correct time grid
-  ProcessSample sample(blockNumber_, TimeSeries(RegularGrid(timeGrid.getStart(), timeGrid.getStep(), blockSize), dimension));
+  ProcessSample sample(blockNumber_, Field(RegularGrid(timeGrid.getStart(), timeGrid.getStep(), blockSize), dimension));
   for (UnsignedLong blockIndex = 0; blockIndex < blockNumber_; ++blockIndex)
   {
     for (UnsignedLong timeIndex = 0; timeIndex < blockSize; ++timeIndex)
     {
-      for (UnsignedLong i = 1; i <= dimension; ++i)
-        sample[blockIndex][timeIndex][i] = timeSeries[blockIndex * hopSize + timeIndex][i];
+      for (UnsignedLong i = 0; i < dimension; ++i)
+        sample[blockIndex][timeIndex][i] = timeSeries.getValues()[blockIndex * hopSize + timeIndex][i];
     } // Loop on the time index
   } // Loop on the blocks
   return build(sample);
