@@ -3,7 +3,7 @@
  *  @file  ComplexMatrix.cxx
  *  @brief ComplexMatrix implements the classical mathematical matrix
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -96,14 +96,14 @@ ComplexMatrix ComplexMatrix::clean(const NumericalScalar threshold) const
 /* String converter */
 String ComplexMatrix::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " implementation=" << getImplementation()->__repr__();
 }
 
 
 String ComplexMatrix::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   const UnsignedLong rows = getNbRows();
   const UnsignedLong cols = getNbColumns();
   if ( (rows >= ResourceMap::GetAsUnsignedLong("Matrix-size-visible-in-str-from")) ||
