@@ -3,7 +3,7 @@
  *  @file  ComplexMatrixImplementation.cxx
  *  @brief ComplexMatrixImplementation implements the classical mathematicalComplexMatrixImplementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -137,7 +137,7 @@ ComplexMatrixImplementation ComplexMatrixImplementation::cleanHerm(const Numeric
 /* String converter */
 String ComplexMatrixImplementation::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " name=" << getName()
          << " rows=" << nbRows_
          << " columns=" << nbColumns_
@@ -146,7 +146,7 @@ String ComplexMatrixImplementation::__repr__() const
 
 String ComplexMatrixImplementation::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   // Special case for empty matrix
   if (nbRows_ == 0 || nbColumns_ == 0) return oss;
   // Special case for matrix with 1 row
