@@ -3,7 +3,7 @@
  *  @file  Description.cxx
  *  @brief Description is a collection of string for human usage
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,8 +25,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(Description);
 
 /* Default constructor */
@@ -75,6 +73,12 @@ Description::Description(const DescriptionImplementation & implementation)
   // Nothing to do
 }
 
+/* Check if the content is blank */
+Bool Description::isBlank() const
+{
+  return getImplementation()->isBlank();
+}
+
 /* Destructor */
 Description::~Description()
 {
