@@ -3,7 +3,7 @@
  *  @file  DescriptionImplementation.cxx
  *  @brief DescriptionImplementation is the active part of Description
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,8 @@
  *  @author schueller
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
+#include <ctype.h> // for isblank
+
 #include "DescriptionImplementation.hxx"
 #include "Log.hxx"
 #include "StorageManager.hxx"
@@ -28,13 +30,9 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(DescriptionImplementation);
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<String>);
 
-
-
 static Factory<DescriptionImplementation> RegisteredFactory1("DescriptionImplementation");
 static Factory<PersistentCollection<String> > RegisteredFactory2("PersistentCollection<String>");
 
@@ -45,7 +43,6 @@ DescriptionImplementation::DescriptionImplementation()
   // Nothing to do
 }
 
-
 /* Constructor with size */
 DescriptionImplementation::DescriptionImplementation(const UnsignedLong size)
   : PersistentCollection<String>(size)
@@ -53,7 +50,6 @@ DescriptionImplementation::DescriptionImplementation(const UnsignedLong size)
   // Nothing to do
 }
 
-
 /* Constructor with size */
 DescriptionImplementation::DescriptionImplementation(const String & value)
   : PersistentCollection<String>(1, value)
@@ -85,11 +81,22 @@ DescriptionImplementation * DescriptionImplementation::clone() const
   return new DescriptionImplementation(*this);
 }
 
+/* Check if the content is blank */
+Bool DescriptionImplementation::isBlank() const
+{
+  for (UnsignedLong i = 0; i < getSize(); ++i)
+  {
+    const UnsignedLong length((*this)[i].size());
+    for (UnsignedLong j = 0; j < length; ++j)
+      if (!isblank((*this)[i][j])) return false;
+  }
+  return true;
+}
 
 /* String converter */
 String DescriptionImplementation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "[";
 
   if (!isEmpty())
