@@ -3,7 +3,7 @@
  *  @file  HermitianMatrix.cxx
  *  @brief HermitianMatrix implements the classical mathematical hermitian matrix
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -61,7 +61,7 @@ HermitianMatrix::HermitianMatrix(const Implementation & i)
 /* String converter */
 String HermitianMatrix::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " dimension=" << this->getDimension()
          << " implementation=" << getImplementation()->__repr__();
 }
@@ -69,7 +69,7 @@ String HermitianMatrix::__repr__() const
 String HermitianMatrix::__str__(const String & offset) const
 {
   checkHermitian();
-  return SquareComplexMatrix::clean(0.0).__str__();
+  return SquareComplexMatrix::clean(0.0).__str__(offset);
 }
 
 /* Get the dimension of the matrix */
