@@ -3,7 +3,7 @@
  *  @file  Indices.cxx
  *  @brief Set of indices defined as a Collection of UnsignedLong class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 /* Check that no value is repeated and no value exceed the given bound */
 Bool Indices::check(const UnsignedLong bound) const
 {
@@ -54,4 +52,4 @@ void Indices::fill(const UnsignedLong initialValue,
   }
 }
 
-} /* Namespace OpenTURNS */
+END_NAMESPACE_OPENTURNS
