@@ -3,7 +3,7 @@
  *  @file  Matrix.cxx
  *  @brief Matrix implements the classical mathematical matrix
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -80,7 +80,7 @@ Matrix::Matrix(const MatrixImplementation & i)
 /* String converter */
 String Matrix::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " implementation=" << getImplementation()->__repr__();
 }
 
@@ -231,6 +231,14 @@ NumericalPoint Matrix::computeSingularValues(Matrix & u,
   return getImplementation()->computeSingularValues(*(u.getImplementation()), *(vT.getImplementation()), fullSVD, keepIntact);
 }
 
+
+/* Build the QR factorization of the matrix */
+Matrix Matrix::computeQR(Matrix & R, const Bool keepIntact)
+{
+  return getImplementation()->computeQR(*(R.getImplementation()), keepIntact);
+}
+
+
 /* Empty returns true if there is no element in the matrix */
 const Bool Matrix::isEmpty() const
 {
