@@ -4,7 +4,7 @@
  *  @file  MatrixImplementation.cxx
  *  @brief MatrixImplementation implements the classical mathematical MatrixImplementation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,6 +32,7 @@
 #include "ResourceMap.hxx"
 #include "SpecFunc.hxx"
 #include "Os.hxx"
+#include "Exception.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -84,7 +85,7 @@ MatrixImplementation * MatrixImplementation::clone() const
 /* String converter */
 String MatrixImplementation::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " name=" << getName()
          << " rows=" << nbRows_
          << " columns=" << nbColumns_
@@ -93,7 +94,7 @@ String MatrixImplementation::__repr__() const
 
 String MatrixImplementation::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   if (nbRows_ == 0 || nbColumns_ == 0) return "[]";
 
   if ( (nbRows_ >= ResourceMap::GetAsUnsignedLong("Matrix-size-visible-in-str-from")) ||
@@ -354,6 +355,36 @@ MatrixImplementation MatrixImplementation::operator/ (const NumericalScalar s) c
   return operator * (1.0 / s);
 }
 
+
+MatrixImplementation MatrixImplementation::triangularProd(const MatrixImplementation & matrix,
+    const char triangularSide,
+    const char upperLower) const
+{
+  if (nbColumns_ != matrix.nbRows_) throw InvalidDimensionException(HERE) << "Invalid dimensions in matrix/matrix product left="
+        << nbRows_ << "x" << nbColumns_
+        << " right=" << matrix.nbRows_ << "x"
+        << matrix.nbColumns_;
+
+  MatrixImplementation mult(matrix);
+  if ((nbRows_ == 0) || (nbColumns_ == 0) || (matrix.nbColumns_ == 0)) return mult;
+  char side(triangularSide);
+  int lside = 1;
+  char uplo(upperLower);
+  int luplo = 1;
+  char trans('N');
+  int ltrans = 1;
+  char diag('N');
+  int ldiag = 1;
+  int m(nbRows_);
+  int n(matrix.nbColumns_);
+
+  NumericalScalar alpha(1.0);
+
+  // Lapack routine
+  DTRMM_F77(&side, &uplo, &trans, &diag, &m, &n, &alpha , const_cast<double*>(&((*this)[0])),  &m, const_cast<double*>(&(mult[0])), &m, &lside, &luplo, &ltrans, &ldiag);
+  return mult;
+}
+
 /* Integer power, general matrix */
 MatrixImplementation MatrixImplementation::genPower(const UnsignedLong n) const
 {
@@ -424,6 +455,20 @@ const Bool MatrixImplementation::isEmpty() const
   return ((nbRows_ == 0)  || (nbColumns_ == 0) || (PersistentCollection<NumericalScalar>::isEmpty()));
 }
 
+/* Returns true if triangular lower or upper */
+const Bool MatrixImplementation::isTriangular(Bool lower) const
+{
+  if ( nbRows_ == nbColumns_ )
+  {
+    for ( UnsignedLong j = 1; j < nbColumns_; ++ j )
+      for ( UnsignedLong i = 0; i < j; ++ i )
+        if ( fabs( (*this)[lower ?  convertPosition(i, j) : convertPosition(j, i)] ) > 0. )
+          return false;
+    return true;
+  }
+  else
+    return false;
+}
 
 /* Comparison operator */
 Bool MatrixImplementation::operator == (const MatrixImplementation & rhs) const
@@ -572,6 +617,62 @@ NumericalPoint MatrixImplementation::solveLinearSystemRect (const NumericalPoint
   return solveLinearSystemRect(MatrixImplementation(m, 1, b), keepIntact);
 }
 
+
+/* Resolution of a linear system : square matrix */
+MatrixImplementation MatrixImplementation::solveLinearSystemTri (const MatrixImplementation & b,
+    const Bool keepIntact,
+    const Bool lower)
+{
+  if (nbColumns_ != b.nbRows_ ) throw InvalidDimensionException(HERE);
+  if ((nbRows_ == 0) || (nbColumns_ == 0) || (b.nbColumns_ == 0)) throw InvalidDimensionException(HERE);
+
+  // We must copy the right-hand side because it will be overwritten by the operation
+  MatrixImplementation B(b);
+  // side tells if we solve M.X = alpha.B or X.M = alpha.B
+  char side('L');
+  int lside = 1;
+  // M must be triangular. uplo tells if it is upper or lower triangular
+  char uplo = lower ? 'L' : 'U';
+  int luplo = 1;
+  // transa tells if M is transposed or not
+  char transa('N');
+  int ltransa = 1;
+  // diag tells if M is unit diagonal or not
+  char diag('N');
+  int ldiag = 1;
+  // the row dimension of M
+  int m(B.nbRows_);
+  // the column dimension of M
+  int n(B.nbColumns_);
+  // we solve the case alpha=1
+  double alpha(1.0);
+  // leading dimension of M
+  int lda(nbRows_);
+  // leading dimension of B
+  int ldb(b.nbRows_);
+  if (keepIntact)
+  {
+    MatrixImplementation A(*this);
+    DTRSM_F77(&side, &uplo, &transa, &diag, &m, &n, &alpha, const_cast<double*>(&(A[0])), &lda, const_cast<double*>(&(B[0])), &ldb, &lside, &luplo, &ltransa, &ldiag);
+  }
+  else DTRSM_F77(&side, &uplo, &transa, &diag, &m, &n, &alpha, const_cast<double*>(&((*this)[0])), &lda, const_cast<double*>(&(B[0])), &ldb, &lside, &luplo, &ltransa, &ldiag);
+  return B;
+}
+
+/* Resolution of a linear system : square matrix */
+NumericalPoint MatrixImplementation::solveLinearSystemTri (const NumericalPoint & b,
+    const Bool keepIntact,
+    const Bool lower)
+{
+  const UnsignedLong m(b.getDimension());
+  if (nbRows_ != m) throw InvalidDimensionException(HERE);
+  if (nbRows_ == 0) throw InvalidDimensionException(HERE);
+  // A MatrixImplementation is also a collection of NumericalScalar, so it is automatically converted into a NumericalPoint
+  return solveLinearSystemTri(MatrixImplementation(m, 1, b), keepIntact, lower);
+}
+
+
+
 /* Resolution of a linear system : square matrix */
 MatrixImplementation MatrixImplementation::solveLinearSystemSquare (const MatrixImplementation & b,
     const Bool keepIntact)
@@ -591,6 +692,7 @@ MatrixImplementation MatrixImplementation::solveLinearSystemSquare (const Matrix
     DGESV_F77(&m, &nrhs, &A[0], &m, &ipiv[0], &B[0], &m, &info);
   }
   else DGESV_F77(&m, &nrhs, &(*this)[0], &m, &ipiv[0], &B[0], &m, &info);
+  if (info != 0) throw NotDefinedException(HERE) << "Error: the matrix is singular.";
   return B;
 }
 
@@ -637,6 +739,7 @@ MatrixImplementation MatrixImplementation::solveLinearSystemSym (const MatrixImp
     NumericalPoint work(lwork);
     DSYSV_F77(&uplo, &n, &nrhs, &(*this)[0], &n, &ipiv[0], &B[0], &n, &work[0], &lwork, &info, &luplo);
   }
+  if (info != 0) throw NotDefinedException(HERE) << "Error: the matrix is singular.";
   return B;
 }
 
@@ -674,6 +777,7 @@ MatrixImplementation MatrixImplementation::solveLinearSystemCov (const MatrixImp
   {
     DPOSV_F77(&uplo, &n, &nrhs, &(*this)[0], &n, &B[0], &n, &info, &luplo);
   }
+  if (info != 0) throw NotDefinedException(HERE) << "Error: the matrix is singular.";
   return B;
 }
 
@@ -721,6 +825,7 @@ NumericalScalar MatrixImplementation::computeLogAbsoluteDeterminant (NumericalSc
     {
       MatrixImplementation A(*this);
       DGETRF_F77(&n, &n, &A[0], &n, &ipiv[0], &info);
+      if (info > 0) return -SpecFunc::MaxNumericalScalar;
       // Determinant computation
       for (UnsignedLong i = 0; i < ipiv.size(); ++i)
       {
@@ -738,6 +843,7 @@ NumericalScalar MatrixImplementation::computeLogAbsoluteDeterminant (NumericalSc
     else
     {
       DGETRF_F77(&n, &n, &(*this)[0], &n, &ipiv[0], &info);
+      if (info > 0) return -SpecFunc::MaxNumericalScalar;
       // Determinant computation
       for (UnsignedLong i = 0; i < ipiv.size(); ++i)
       {
@@ -763,6 +869,7 @@ NumericalScalar MatrixImplementation::computeDeterminant (const Bool keepIntact)
   if (nbRows_ == 2) return (*this)(0, 0) * (*this)(1, 1) - (*this)(0, 1) * (*this)(1, 0);
   NumericalScalar sign(0.0);
   const NumericalScalar logAbsoluteDeterminant(computeLogAbsoluteDeterminant(sign, keepIntact));
+  if (logAbsoluteDeterminant == -SpecFunc::MaxNumericalScalar) return 0.0;
   return sign * exp(logAbsoluteDeterminant);
 }
 
@@ -822,6 +929,7 @@ NumericalScalar MatrixImplementation::computeDeterminantSym (const Bool keepInta
   if (nbRows_ == 2) return (*this)(0, 0) * (*this)(1, 1) - (*this)(1, 0) * (*this)(1, 0);
   NumericalScalar sign(0.0);
   const NumericalScalar logAbsoluteDeterminant(computeLogAbsoluteDeterminant(sign, keepIntact));
+  if (logAbsoluteDeterminant == -SpecFunc::MaxNumericalScalar) return 0.0;
   return sign * exp(logAbsoluteDeterminant);
 }
 
@@ -859,6 +967,7 @@ MatrixImplementation::NumericalComplexCollection MatrixImplementation::computeEi
     NumericalPoint work(lwork);
     DGEEV_F77(&jobvl, &jobvr, &n, &(*this)[0], &n, &wr[0], &wi[0], &vl, &ldvl, &vr, &ldvr, &work[0], &lwork, &info, &ljobvl, &ljobvr);
   }
+  if (info != 0) throw InternalException(HERE) << "Error: the QR algorithm failed to converge.";
   NumericalComplexCollection eigenValues(n);
   for (UnsignedLong i = 0; i < static_cast<UnsignedLong>(n); ++i) eigenValues[i] = NumericalComplex(wr[i], wi[i]);
   return eigenValues;
@@ -903,6 +1012,7 @@ MatrixImplementation::NumericalComplexCollection MatrixImplementation::computeEi
   {
     eigenValues[i] = NumericalComplex(wr[i], wi[i]);
   }
+  if (info != 0) throw InternalException(HERE) << "Error: the QR algorithm failed to converge.";
   // Cast the eigenvectors into OpenTURNS data structures
   v = ComplexMatrixImplementation(n, n);
   UnsignedLong j(0);
@@ -956,6 +1066,7 @@ NumericalPoint MatrixImplementation::computeEigenValuesSym (const Bool keepIntac
     NumericalPoint work(lwork);
     DSYEV_F77(&jobz, &uplo, &n, &(*this)[0], &n, &w[0], &work[0], &lwork, &info, &ljobz, &luplo);
   }
+  if (info != 0) throw InternalException(HERE) << "Error: the QR algorithm failed to converge.";
   return w;
 }
 
@@ -989,6 +1100,7 @@ NumericalPoint MatrixImplementation::computeEigenValuesSym (MatrixImplementation
     DSYEV_F77(&jobz, &uplo, &n, &(*this)[0], &n, &w[0], &work[0], &lwork, &info, &ljobz, &luplo);
     v = *this;
   }
+  if (info != 0) throw InternalException(HERE) << "Error: the QR algorithm failed to converge.";
   return w;
 }
 
@@ -1028,6 +1140,7 @@ NumericalPoint MatrixImplementation::computeSingularValues(const Bool keepIntact
     // Second call to compute the SVD
     DGESDD_F77(&jobz, &m, &n, &(*this)[0], &m, &S[0], &u[0], &ldu, &vT[0], &ldvt, &work[0], &lwork, &iwork[0], &info, &ljobz);
   }
+  if (info != 0) throw InternalException(HERE) << "Error: the updating process failed.";
   return S;
 }
 
@@ -1070,6 +1183,7 @@ NumericalPoint MatrixImplementation::computeSingularValues(MatrixImplementation
     // Second call to compute the SVD
     DGESDD_F77(&jobz, &m, &n, &(*this)[0], &m, &S[0], &u[0], &ldu, &vT[0], &ldvt, &work[0], &lwork, &iwork[0], &info, &ljobz);
   }
+  if (info != 0) throw InternalException(HERE) << "Error: the updating process failed.";
   return S;
 }
 
@@ -1091,6 +1205,40 @@ Bool MatrixImplementation::isPositiveDefinite(const Bool keepIntact)
   return (info == 0) ;
 }
 
+MatrixImplementation::NumericalScalarCollection MatrixImplementation::triangularVectProd(const NumericalScalarCollection & pt,
+    const char side) const
+{
+  char uplo(side);
+  int luplo(1);
+
+  // trans tells if the matrix is transposed or not
+  char trans('N');
+  int ltrans(1);
+
+  // diag tells if M is unit diagonal or not
+  char diag('N');
+  int ldiag(1);
+
+  // the dimension of the matrix
+  int n(nbRows_);
+
+  // leading dimension of M
+  int lda(nbRows_);
+  int one(1);
+
+  NumericalScalarCollection x(nbRows_);
+  for (UnsignedLong i = 0; i < pt.getSize(); ++i) x[i] = pt[i];
+
+  DTRMV_F77(&uplo, &trans, &diag, &n, const_cast<double*>(&((*this)[0])), &lda, const_cast<double*>(&(x[0])), &one, &luplo, &ltrans, &ldiag);
+  return x;
+}
+
+MatrixImplementation::NumericalScalarCollection MatrixImplementation::triangularVectProd(const NumericalPoint & pt,
+    const char side) const
+{
+  return triangularVectProd(pt.getCollection(), side);
+}
+
 /* Build the Cholesky factorization of the matrix */
 MatrixImplementation MatrixImplementation::computeCholesky(const Bool keepIntact)
 {
@@ -1103,12 +1251,10 @@ MatrixImplementation MatrixImplementation::computeCholesky(const Bool keepIntact
   {
     MatrixImplementation A(*this);
     DPOTRF_F77(&uplo, &n, &A[0], &n, &info, &luplo);
+    if (info != 0) throw InternalException(HERE) << "Error: the matrix is not definite positive.";
     for (UnsignedLong j = 0; j < (UnsignedLong)(n); ++j)
       for (UnsignedLong i = 0; i < j; ++i)
         A(i, j) = 0.0;
-    // Check return code from Lapack
-    if(info != 0)
-      throw InvalidArgumentException(HERE) << " Error - Matrix is not positive definite" ;
     A.setName(DefaultName);
     return A;
   }
@@ -1118,9 +1264,78 @@ MatrixImplementation MatrixImplementation::computeCholesky(const Bool keepIntact
     for (UnsignedLong j = 0; j < (UnsignedLong)(n); ++j)
       for (UnsignedLong i = 0; i < (UnsignedLong)(j); ++i)
         (*this)(i, j) = 0.0;
-    // Check if return code is ok
-    if(info != 0)
-      throw InvalidArgumentException(HERE) << " Error - Matrix is not positive definite" ;
+    if (info != 0) throw InternalException(HERE) << "Error: the matrix is not definite positive.";
+    setName(DefaultName);
+    return (*this);
+  }
+}
+
+/* Build the QR factorization of the matrix */
+MatrixImplementation MatrixImplementation::computeQR(MatrixImplementation & R, const Bool keepIntact)
+{
+  int m(nbRows_);
+  int n(nbColumns_);
+  int lda(nbRows_);
+
+  if (n == 0) throw InvalidDimensionException(HERE);
+  int k = std::min(m, n);
+  NumericalPoint tau(k);
+  int lwork = -1;
+  int info = -1;
+  double lwork_d;
+  R = MatrixImplementation(k, n);
+
+  if ( keepIntact )
+  {
+    MatrixImplementation Q(*this);
+
+    DGEQRF_F77(&m, &n, &Q[0], &lda, &tau[0], &lwork_d, &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DGEQRF: error code=" << info;
+    lwork = static_cast<int>(lwork_d);
+    NumericalPoint work(lwork);
+    DGEQRF_F77(&m, &n, &Q[0], &lda, &tau[0], &work[0], &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DGEQRF: error code=" << info;
+
+    // rebuild R
+    for ( UnsignedLong i = 0; i < static_cast<UnsignedLong>(k) ; ++ i )
+      for ( UnsignedLong j = 0; j < static_cast<UnsignedLong>(n); ++ j )
+        R(i, j) = Q(i, j);
+
+    lwork = -1;
+    DORGQR_F77(&m, &n, &k, &Q[0], &lda, &tau[0], &lwork_d, &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DORGQR: error code=" << info;
+    lwork = static_cast<int>(lwork_d);
+    NumericalPoint work2(lwork);
+
+    DORGQR_F77(&m, &n, &k, &Q[0], &lda, &tau[0], &work2[0], &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DORGQR: error code=" << info;
+
+    Q.setName(DefaultName);
+    return Q;
+  }
+  else
+  {
+    DGEQRF_F77(&m, &n, &(*this)[0], &lda, &tau[0], &lwork_d, &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DGEQRF: error code=" << info;
+    lwork = static_cast<int>(lwork_d);
+    NumericalPoint work(lwork);
+    DGEQRF_F77(&m, &n, &(*this)[0], &lda, &tau[0], &work[0], &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DGEQRF: error code=" << info;
+
+    // rebuild R
+    for ( UnsignedLong i = 0; i < static_cast<UnsignedLong>(k) ; ++ i )
+      for ( UnsignedLong j = 0; j < static_cast<UnsignedLong>(n); ++ j )
+        R(i, j) = (*this)(i, j);
+
+    lwork = -1;
+    DORGQR_F77(&m, &n, &k, &(*this)[0], &lda, &tau[0], &lwork_d, &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DORGQR: error code=" << info;
+    lwork = static_cast<int>(lwork_d);
+    NumericalPoint work2(lwork);
+
+    DORGQR_F77(&m, &n, &k, &(*this)[0], &lda, &tau[0], &work2[0], &lwork, &info);
+    if (info != 0) throw InternalException(HERE) << "Lapack DORGQR: error code=" << info;
+
     setName(DefaultName);
     return (*this);
   }
