@@ -3,7 +3,7 @@
  *  @file  NumericalPoint.cxx
  *  @brief NumericalPoint implements the classical mathematical point
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,12 +26,10 @@
 #include "Exception.hxx"
 #include "StorageManager.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "Log.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(NumericalPoint);
 
 static Factory<PersistentCollection<NumericalScalar> > RegisteredFactory_alt1("PersistentCollection<NumericalScalar>");
@@ -96,7 +94,7 @@ const NumericalScalar & NumericalPoint::operator[](const UnsignedLong index) con
 /* String converter */
 String NumericalPoint::__repr__() const
 {
-  return OSS() << "class=" << NumericalPoint::GetClassName()
+  return OSS(true) << "class=" << NumericalPoint::GetClassName()
          << " name=" << getName()
          << " dimension=" << getDimension()
          << " values=" << PersistentCollection<NumericalScalar>::__repr__();
@@ -104,7 +102,7 @@ String NumericalPoint::__repr__() const
 
 String NumericalPoint::__str__(const String & offset) const
 {
-  return PersistentCollection<NumericalScalar>::__str__();
+  return PersistentCollection<NumericalScalar>::__str__(offset);
 }
 
 
@@ -281,16 +279,29 @@ Bool operator <(const NumericalPoint & lhs,
 /*  Norm */
 NumericalScalar NumericalPoint::norm() const
 {
-  return sqrt( norm2() );
+  return sqrt( normSquare() );
 }
 
+/* l1-norm */
+NumericalScalar NumericalPoint::norm1() const
+{
+  NumericalScalar result(0.0);
+  for (UnsignedLong i = 0; i < getDimension(); ++i) result += fabs((*this)[i]);
+  return result;
+}
 
 /*  Norm^2 */
-NumericalScalar NumericalPoint::norm2() const
+NumericalScalar NumericalPoint::normSquare() const
 {
   return dot(*this, *this);
 }
 
+NumericalScalar NumericalPoint::norm2() const
+{
+  LOGUSER(OSS() << "norm2 is deprecated in favor of normSquare");
+  return normSquare();
+}
+
 /*  Normalize */
 NumericalPoint NumericalPoint::normalize() const
 {
@@ -300,15 +311,22 @@ NumericalPoint NumericalPoint::normalize() const
 }
 
 /*  Square normalize */
-NumericalPoint NumericalPoint::normalize2() const
+NumericalPoint NumericalPoint::normalizeSquare() const
 {
-  const NumericalScalar theNorm2(norm2());
-  if (theNorm2 == 0.0) throw InternalException(HERE) << "Error: cannot square normalize a null vector";
+  const NumericalScalar theNormSquare(normSquare());
+  if (theNormSquare == 0.0) throw InternalException(HERE) << "Error: cannot square normalize a null vector";
   NumericalPoint result(getDimension());
-  for (UnsignedLong i = 0; i < getDimension(); ++i) result[i] = pow((*this)[i], 2) / theNorm2;
+  for (UnsignedLong i = 0; i < getDimension(); ++i) result[i] = pow((*this)[i], 2) / theNormSquare;
   return result;
 }
 
+NumericalPoint NumericalPoint::normalize2() const
+{
+  LOGUSER(OSS() << "normalize2 is deprecated in favor of normalizeSquare");
+  return normalizeSquare();
+}
+
+
 /* Method save() stores the object through the StorageManager */
 void NumericalPoint::save(Advocate & adv) const
 {
