@@ -3,7 +3,7 @@
  *  @file  NumericalPointWithDescription.cxx
  *  @brief NumericalPointWithDescription extends the classical mathematical point with a description of the coordinates
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(NumericalPointWithDescription);
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<NumericalPointWithDescription>);
 
@@ -36,8 +34,8 @@ static Factory<PersistentCollection<NumericalPointWithDescription> > RegisteredF
 
 /* Default constructor */
 NumericalPointWithDescription::NumericalPointWithDescription()
-  : NumericalPoint(),
-    description_()
+  : NumericalPoint()
+  , description_()
 {
   // Nothing to do
 }
@@ -45,8 +43,8 @@ NumericalPointWithDescription::NumericalPointWithDescription()
 /* Constructor with size */
 NumericalPointWithDescription::NumericalPointWithDescription(const UnsignedLong size,
     const NumericalScalar value)
-  : NumericalPoint(size, value),
-    description_(size)
+  : NumericalPoint(size, value)
+  , description_(size)
 {
   // Nothing to do
 }
@@ -55,16 +53,16 @@ NumericalPointWithDescription::NumericalPointWithDescription(const UnsignedLong
 
 /* Constructor from a collection */
 NumericalPointWithDescription::NumericalPointWithDescription(const Collection<NumericalScalar> & coll)
-  : NumericalPoint(coll),
-    description_(coll.getSize())
+  : NumericalPoint(coll)
+  , description_(coll.getSize())
 {
   // Nothing to do
 }
 
 /* Constructor from a base class */
 NumericalPointWithDescription::NumericalPointWithDescription(const Pointer<NumericalPoint> & p_base)
-  : NumericalPoint(*p_base),
-    description_(p_base->getSize())
+  : NumericalPoint(*p_base)
+  , description_(p_base->getSize())
 {
   // Nothing to do
 }
