@@ -3,7 +3,7 @@
  *  @file  SymmetricMatrix.cxx
  *  @brief SymmetricMatrix implements the classical mathematical symmetric matrix
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -103,7 +103,7 @@ const Matrix SymmetricMatrix::getColumn(const UnsignedLong columnIndex) const
 /* String converter */
 String SymmetricMatrix::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " dimension=" << this->getDimension()
          << " implementation=" << getImplementation()->__repr__();
 }
