@@ -3,7 +3,7 @@
  *  @file  Tensor.cxx
  *  @brief Tensor implements the classical mathematical tensor
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -69,14 +69,14 @@ Tensor::Tensor(const Implementation & i)
 /* String converter */
 String Tensor::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " implementation=" << getImplementation()->__repr__();
 }
 
 /* String converter */
 String Tensor::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   const UnsignedLong rows   = getNbRows();
   const UnsignedLong cols   = getNbColumns();
   const UnsignedLong sheets = getNbSheets();
