@@ -3,7 +3,7 @@
  *  @file  TensorImplementation.cxx
  *  @brief TensorImplementation implements the Tensor classes
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -86,7 +86,7 @@ TensorImplementation * TensorImplementation::clone() const
 /* String converter */
 String TensorImplementation::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " name=" << getName()
          << " rows=" << getNbRows()
          << " columns=" << getNbColumns()
