@@ -3,7 +3,7 @@
  *  @file  TriangularComplexMatrix.cxx
  *  @brief TriangularComplexMatrix implements the classical mathematical triangluar matrix
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,14 +66,14 @@ TriangularComplexMatrix::TriangularComplexMatrix(const Implementation & i,
 /* String converter */
 String TriangularComplexMatrix::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " dimension=" << this->getDimension()
          << " implementation=" << getImplementation()->__repr__();
 }
 
 String TriangularComplexMatrix::__str__(const String & offset) const
 {
-  return SquareComplexMatrix::__str__();
+  return SquareComplexMatrix::__str__(offset);
 }
 
 /* Get the dimension of the matrix */
