@@ -3,7 +3,7 @@
  *  @file  AnalyticalResult.cxx
  *  @brief Result computes the results of an analytical Algorithm
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -180,7 +180,7 @@ void AnalyticalResult::computeImportanceFactors() const
       const NumericalScalar y(inputDistribution.getMarginal(marginalIndex).computeCDF(NumericalPoint(1, physicalSpaceDesignPoint_[marginalIndex])));
       importanceFactors_[marginalIndex] = standardMarginalDistribution.computeQuantile(y)[0];
     }
-    importanceFactors_ = importanceFactors_.normalize2();
+    importanceFactors_ = importanceFactors_.normalizeSquare();
   }
   /* we give a name to the importance factors vector */
   importanceFactors_.setName("Importance Factors");
@@ -196,8 +196,8 @@ void AnalyticalResult::computeClassicalImportanceFactors() const
   const UnsignedLong dimension(standardSpaceDesignPoint_.getDimension());
   classicalImportanceFactors_ = NumericalPoint(dimension, -1.0);
   /* First, check that the importance factors are well-defined */
-  const NumericalScalar beta2(standardSpaceDesignPoint_.norm2());
-  if (beta2 > 0.0) classicalImportanceFactors_ = standardSpaceDesignPoint_.normalize2();
+  const NumericalScalar beta2(standardSpaceDesignPoint_.normSquare());
+  if (beta2 > 0.0) classicalImportanceFactors_ = standardSpaceDesignPoint_.normalizeSquare();
   /* we give a name to the importance factors vector */
   classicalImportanceFactors_.setName("Classical Importance Factors");
 
@@ -499,7 +499,7 @@ void AnalyticalResult::load(Advocate & adv)
   adv.loadAttribute( "classicalImportanceFactors_", classicalImportanceFactors_ );
   adv.loadAttribute( "hasoferReliabilityIndexSensitivity_", sensitivity );
   adv.loadAttribute( "isAlreadyComputedImportanceFactors_", isAlreadyComputedImportanceFactors_ );
-  adv.loadAttribute( "isAlreadyComputedImportanceFactors_", isAlreadyComputedClassicalImportanceFactors_ );
+  adv.loadAttribute( "isAlreadyComputedClassicalImportanceFactors_", isAlreadyComputedClassicalImportanceFactors_ );
   adv.loadAttribute( "isAlreadyComputedHasoferReliabilityIndexSensitivity_", isAlreadyComputedHasoferReliabilityIndexSensitivity_ );
   adv.loadAttribute( "optimizationResult_", optimizationResult_ );
   hasoferReliabilityIndexSensitivity_ = sensitivity;
