@@ -3,7 +3,7 @@
  *  @file  StrongMaximumTest.cxx
  *  @brief StrongMaxTest implements an algorithm to check if a given design point
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -405,7 +405,7 @@ NumericalScalar StrongMaximumTest::computeHyperSphereSurfaceRatio()
 NumericalScalar StrongMaximumTest::computeDeltaEpsilon()
 {
   /* evaluate the reliability index */
-  const NumericalScalar betaSquare(standardSpaceDesignPoint_.norm2());
+  const NumericalScalar betaSquare(standardSpaceDesignPoint_.normSquare());
 
   /* get the input distribution in the standard space */
   const Implementation p_inputStandardDistribution(event_.getImplementation()->getAntecedent()->getDistribution().getImplementation());
