@@ -3,7 +3,7 @@
  *  @file  AdaptiveStrategy.cxx
  *  @brief This is the interface class for adaptive strategies
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -104,7 +104,7 @@ AdaptiveStrategy::NumericalMathFunctionCollection AdaptiveStrategy::getPsi() con
 /* String converter */
 String AdaptiveStrategy::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " implementation=" << getImplementation()->__repr__();
 }
 
