@@ -3,7 +3,7 @@
  *  @file  FunctionalChaosResult.cxx
  *  @brief The result of a chaos expansion
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -92,7 +92,7 @@ FunctionalChaosResult * FunctionalChaosResult::clone() const
 /* String converter */
 String FunctionalChaosResult::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " derived from " << MetaModelResult::__repr__()
          << " distribution=" << distribution_
          << " transformation=" << transformation_
