@@ -3,7 +3,7 @@
  *  @file  MetaModelResult.cxx
  *  @brief Result of a Meta-model algorithm
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,18 +26,17 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(MetaModelResult);
 
 static Factory<MetaModelResult> RegisteredFactory("MetaModelResult");
 
 /* Default constructor */
 MetaModelResult::MetaModelResult()
-  : PersistentObject(),
-    residuals_(0),
-    relativeErrors_(0)
+  : PersistentObject()
+  , residuals_(0)
+  , relativeErrors_(0)
 {
+  // Nothing to do
 }
 
 /* Standard constructor */
@@ -45,11 +44,11 @@ MetaModelResult::MetaModelResult(const NumericalMathFunction & model,
                                  const NumericalMathFunction & metaModel,
                                  const NumericalPoint & residuals,
                                  const NumericalPoint & relativeErrors)
-  : PersistentObject(),
-    model_(model),
-    metaModel_(metaModel),
-    residuals_(residuals),
-    relativeErrors_(relativeErrors)
+  : PersistentObject()
+  , model_(model)
+  , metaModel_(metaModel)
+  , residuals_(residuals)
+  , relativeErrors_(relativeErrors)
 {
   // Nothing to do
 }
