@@ -3,7 +3,7 @@
  *  @file  EnumerateFunctionImplementation.cxx
  *  @brief The bijective function to select polynomials in the orthogonal basis
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,20 +28,25 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(EnumerateFunctionImplementation);
 
+static Factory<EnumerateFunctionImplementation> RegisteredFactory("EnumerateFunctionImplementation");
 
 /* Parameter constructor */
 EnumerateFunctionImplementation::EnumerateFunctionImplementation(const UnsignedLong dimension)
-  : PersistentObject(),
-    dimension_(dimension)
+  : PersistentObject()
+  , dimension_(dimension)
 {
   if ( dimension == 0 )
     throw InvalidArgumentException ( HERE ) << "Cannot build an EnumerateFunction of dimension 0.";
 }
 
+/* Virtual constructor */
+EnumerateFunctionImplementation * EnumerateFunctionImplementation::clone() const
+{
+  return new EnumerateFunctionImplementation(*this);
+}
+
 /* String converter */
 String EnumerateFunctionImplementation::__repr__() const
 {
@@ -55,12 +60,36 @@ UnsignedLong EnumerateFunctionImplementation::getMaximumDegreeCardinal(const Uns
   return getStrataCumulatedCardinal(getMaximumDegreeStrataIndex(maximumDegree));
 }
 
+/* Evaluation operator */
+Indices EnumerateFunctionImplementation::operator() (const UnsignedLong index) const
+{
+  throw NotYetImplementedException( HERE );
+}
+
 /* The inverse of the association */
 UnsignedLong EnumerateFunctionImplementation::inverse(const Indices & indices) const
 {
   throw NotYetImplementedException( HERE );
 }
 
+/* The cardinal of the given strata */
+UnsignedLong EnumerateFunctionImplementation::getStrataCardinal(const UnsignedLong strateIndex) const
+{
+  throw NotYetImplementedException( HERE );
+}
+
+/* The cardinal of the cumulated strata above or equal to the given strate */
+UnsignedLong EnumerateFunctionImplementation::getStrataCumulatedCardinal(const UnsignedLong strateIndex) const
+{
+  throw NotYetImplementedException( HERE );
+}
+
+/* The index of the strata of degree max <= maximumDegree */
+UnsignedLong EnumerateFunctionImplementation::getMaximumDegreeStrataIndex(const UnsignedLong maximumDegree) const
+{
+  throw NotYetImplementedException( HERE );
+}
+
 /* Dimension accessor */
 void EnumerateFunctionImplementation::setDimension(const UnsignedLong dimension)
 {
