@@ -3,7 +3,7 @@
  *  @file  HyperbolicAnisotropicEnumerateFunction.cxx
  *  @brief The bijective function to select polynomials in the orthogonal basis
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -245,8 +245,7 @@ UnsignedLong HyperbolicAnisotropicEnumerateFunction::getMaximumDegreeStrataIndex
 /* Q accessor */
 void HyperbolicAnisotropicEnumerateFunction::setQ(const NumericalScalar q)
 {
-  if ( (q <= 0.0) || (q > 1.0) )
-    throw InvalidRangeException( HERE ) << "q parameter should be in range ]0, 1]";
+  if (q <= 0.0) throw InvalidRangeException( HERE ) << "q parameter should be positive";
   q_ = q;
 }
 
