@@ -3,7 +3,7 @@
  *  @file  OrthonormalizationAlgorithm.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -84,7 +84,7 @@ void OrthonormalizationAlgorithm::setMeasure(const Distribution & measure)
 /* String converter */
 String OrthonormalizationAlgorithm::__repr__() const
 {
-  return OSS() << "class=" << getClassName()
+  return OSS(true) << "class=" << getClassName()
          << " implementation=" << getImplementation()->__repr__();
 }
 
