@@ -3,7 +3,7 @@
  *  @file  DirectionalSampling.cxx
  *  @brief DirectionalSampling is an implementation of the directional
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,9 +30,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 /*
  * @class DirectionalSampling
  */
@@ -41,12 +38,12 @@ CLASSNAMEINIT(DirectionalSampling);
 
 /* Constructor with parameters */
 DirectionalSampling::DirectionalSampling(const Event & event)
-  : Simulation(event),
-    standardEvent_(StandardEvent(event)),
-    standardFunction_(standardEvent_.getImplementation()->getFunction()),
-    inputDistribution_(standardEvent_.getImplementation()->getAntecedent()->getDistribution().getImplementation()),
-    rootStrategy_(),
-    samplingStrategy_(inputDistribution_->getDimension())
+  : Simulation(event)
+  , standardEvent_(StandardEvent(event))
+  , standardFunction_(standardEvent_.getImplementation()->getFunction())
+  , inputDistribution_(standardEvent_.getImplementation()->getAntecedent()->getDistribution().getImplementation())
+  , rootStrategy_()
+  , samplingStrategy_(inputDistribution_->getDimension())
 {
   // Nothing to do
 }
@@ -55,12 +52,12 @@ DirectionalSampling::DirectionalSampling(const Event & event)
 DirectionalSampling::DirectionalSampling(const Event & event,
     const RootStrategy & rootStrategy,
     const SamplingStrategy & samplingStrategy)
-  : Simulation(event),
-    standardEvent_(StandardEvent(event)),
-    standardFunction_(standardEvent_.getImplementation()->getFunction()),
-    inputDistribution_(standardEvent_.getImplementation()->getAntecedent()->getDistribution().getImplementation()),
-    rootStrategy_(rootStrategy),
-    samplingStrategy_(samplingStrategy)
+  : Simulation(event)
+  , standardEvent_(StandardEvent(event))
+  , standardFunction_(standardEvent_.getImplementation()->getFunction())
+  , inputDistribution_(standardEvent_.getImplementation()->getAntecedent()->getDistribution().getImplementation())
+  , rootStrategy_(rootStrategy)
+  , samplingStrategy_(samplingStrategy)
 {
   // To force the sampling strategy to have the correct dimension
   samplingStrategy_.setDimension(inputDistribution_->getDimension());
