@@ -4,7 +4,7 @@
  *  @brief Simulation is a generic view of simulation methods for computing
  * probabilities and related quantities by sampling and estimation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,7 @@
  *  @author schueller
  *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
  */
+#include "PersistentObjectFactory.hxx"
 #include "Simulation.hxx"
 #include "Log.hxx"
 #include "Curve.hxx"
@@ -30,32 +31,37 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 /*
  * @class Simulation
  */
 
 CLASSNAMEINIT(Simulation);
 
+static Factory<Simulation> RegisteredFactory("Simulation");
+
 /* Constructor with parameters */
 Simulation::Simulation(const Event & event,
                        const Bool verbose,
                        const HistoryStrategy & convergenceStrategy)
-  : PersistentObject(),
-    convergenceStrategy_(convergenceStrategy),
-    blockSize_(ResourceMap::GetAsUnsignedLong( "Simulation-DefaultBlockSize" )),
-    event_(event),
-    result_(),
-    maximumOuterSampling_(ResourceMap::GetAsUnsignedLong( "Simulation-DefaultMaximumOuterSampling" )),
-    maximumCoefficientOfVariation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumCoefficientOfVariation" )),
-    maximumStandardDeviation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumStandardDeviation" )),
-    verbose_(verbose)
+  : PersistentObject()
+  , convergenceStrategy_(convergenceStrategy)
+  , blockSize_(ResourceMap::GetAsUnsignedLong( "Simulation-DefaultBlockSize" ))
+  , event_(event)
+  , result_()
+  , maximumOuterSampling_(ResourceMap::GetAsUnsignedLong( "Simulation-DefaultMaximumOuterSampling" ))
+  , maximumCoefficientOfVariation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumCoefficientOfVariation" ))
+  , maximumStandardDeviation_(ResourceMap::GetAsNumericalScalar( "Simulation-DefaultMaximumStandardDeviation" ))
+  , verbose_(verbose)
 {
   // Nothing to do
 }
 
+/* Virtual constructor */
+Simulation * Simulation::clone() const
+{
+  return new Simulation(*this);
+}
+
 /*  Event accessor */
 Event Simulation::getEvent() const
 {
@@ -226,6 +232,12 @@ void Simulation::run()
   }
 }
 
+/* Compute the block sample and the points that realized the event */
+NumericalSample Simulation::computeBlockSample()
+{
+  throw NotYetImplementedException(HERE);
+}
+
 /* Convergence strategy accessor */
 void Simulation::setConvergenceStrategy(const HistoryStrategy & convergenceStrategy)
 {
@@ -268,13 +280,10 @@ Graph Simulation::drawProbabilityConvergence(const NumericalScalar level) const
   oss << getClassName() << " convergence graph at level " << level;
   Graph convergenceGraph(oss, "outer iteration", "estimate", true, "topright");
   convergenceGraph.add(estimateCurve);
-  if (dataLowerBound.getSize() > 0)
-  {
-    const Curve lowerBoundCurve(dataLowerBound, "green", "solid", 1, "bounds");
-    const Curve upperBoundCurve(dataUpperBound, "green", "solid", 1, "");
-    convergenceGraph.add(lowerBoundCurve);
-    convergenceGraph.add(upperBoundCurve);
-  }
+  const Curve lowerBoundCurve(dataLowerBound, "green", "solid", 1, "bounds");
+  const Curve upperBoundCurve(dataUpperBound, "green", "solid", 1, "");
+  convergenceGraph.add(lowerBoundCurve);
+  convergenceGraph.add(upperBoundCurve);
   return convergenceGraph;
 }
 
