@@ -3,7 +3,7 @@
  *  @file  SimulationResultImplementation.cxx
  *  @brief Implementation of SimulationResult
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,21 +32,18 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(SimulationResultImplementation);
 
-
 static Factory<SimulationResultImplementation> RegisteredFactory("SimulationResultImplementation");
 
 /* Default constructor */
 SimulationResultImplementation::SimulationResultImplementation()
-  : PersistentObject(),
-    event_(),
-    probabilityEstimate_(0.0),
-    varianceEstimate_(0.0),
-    outerSampling_(0),
-    blockSize_(0)
+  : PersistentObject()
+  , event_()
+  , probabilityEstimate_(0.0)
+  , varianceEstimate_(0.0)
+  , outerSampling_(0)
+  , blockSize_(0)
 {
   // Nothing to do
 }
@@ -57,12 +54,12 @@ SimulationResultImplementation::SimulationResultImplementation(const Event & eve
     const NumericalScalar varianceEstimate,
     const UnsignedLong outerSampling,
     const UnsignedLong blockSize)
-  : PersistentObject(),
-    event_(event),
-    probabilityEstimate_(probabilityEstimate),
-    varianceEstimate_(varianceEstimate),
-    outerSampling_(outerSampling),
-    blockSize_(blockSize)
+  : PersistentObject()
+  , event_(event)
+  , probabilityEstimate_(probabilityEstimate)
+  , varianceEstimate_(varianceEstimate)
+  , outerSampling_(outerSampling)
+  , blockSize_(blockSize)
 {
   // Check if the probability estimate is within the range [0, 1]
   if ((probabilityEstimate < 0) || (probabilityEstimate > 1)) LOGINFO("The probability estimate should be in the range [0, 1]");
