@@ -3,7 +3,7 @@
  *  @file  SimulationSensitivityAnalysis.cxx
  *  @brief Implementation of SimulationResult
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -73,6 +73,18 @@ SimulationSensitivityAnalysis::SimulationSensitivityAnalysis(const NumericalSamp
   if (outputSample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given output sample must have a dimension=1, here dimension=" << outputSample.getDimension();
 }
 
+/* Standard constructor */
+SimulationSensitivityAnalysis::SimulationSensitivityAnalysis(const SimulationResult & result)
+  : PersistentObject(),
+    inputSample_(),
+    outputSample_(),
+    transformation_(),
+    comparisonOperator_(),
+    threshold_()
+{
+  *this = SimulationSensitivityAnalysis(result.getEvent());
+}
+
 /* Standard constructor */
 SimulationSensitivityAnalysis::SimulationSensitivityAnalysis(const Event & event)
   : PersistentObject(),
@@ -127,7 +139,7 @@ NumericalPoint SimulationSensitivityAnalysis::computeMeanPointInEventDomain() co
 /* Importance factors computation */
 NumericalPointWithDescription SimulationSensitivityAnalysis::computeImportanceFactors(const NumericalScalar threshold) const
 {
-  NumericalPointWithDescription result(transformation_(computeMeanPointInEventDomain(threshold)).normalize2());
+  NumericalPointWithDescription result(transformation_(computeMeanPointInEventDomain(threshold)).normalizeSquare());
   result.setDescription(inputSample_.getDescription());
   return result;
 }
@@ -263,7 +275,7 @@ Graph SimulationSensitivityAnalysis::drawImportanceFactorsRange(const Bool proba
         // Check if the importance factors are well-defined for the current threshold
         try
         {
-          importanceFactors = transformation_(accumulator / accumulated).normalize2();
+          importanceFactors = transformation_(accumulator / accumulated).normalizeSquare();
           const NumericalPoint ref(computeImportanceFactors(currentThreshold));
           for (UnsignedLong j = 0; j < inputDimension; ++j)
           {
