@@ -3,7 +3,7 @@
  *  @file  MarginalTransformationEvaluation.cxx
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -83,58 +83,60 @@ MarginalTransformationEvaluation::MarginalTransformationEvaluation(const Distrib
     // Third, look for possible simplifications
     for (UnsignedLong i = 0; i < size; ++i)
     {
-      const String xName(getInputDescription()[i]);
-      const String yName(getOutputDescription()[i]);
       const Distribution inputDistribution(inputDistributionCollection[i]);
       const Distribution outputDistribution(outputDistributionCollection[i]);
+      const String xName(getInputDescription()[i]);
+      const String yName(getOutputDescription()[i]);
       const String inputClass(inputDistribution.getImplementation()->getClassName());
       const String outputClass(outputDistribution.getImplementation()->getClassName());
       const NumericalPoint inputParameters(inputDistribution.getParametersCollection()[0]);
       const NumericalPoint outputParameters(outputDistribution.getParametersCollection()[0]);
-      // Normal/Normal simplification
-      if ((inputClass == "Normal") && (outputClass == "Normal"))
+      // The first obvious simplification: the distributions share the same standard representative.
+      if (inputClass == outputClass)
       {
-        const NumericalScalar mu1(inputParameters[0]);
-        const NumericalScalar sigma1(inputParameters[1]);
-        const NumericalScalar mu2(outputParameters[0]);
-        const NumericalScalar sigma2(outputParameters[1]);
-        OSS oss;
-        oss.setPrecision(20);
-        if (mu2 != 0.0) oss << mu2 << " + ";
-        oss << sigma2 / sigma1;
-        if (mu1 == 0.0) oss << " * " << xName;
-        else
+        const Distribution inputStandardDistribution(inputDistribution.getStandardRepresentative());
+        const NumericalPoint inputStandardRepresentativeParameters(inputStandardDistribution.getParametersCollection()[0]);
+        const Distribution outputStandardDistribution(outputDistribution.getStandardRepresentative());
+        const NumericalPoint outputStandardRepresentativeParameters(outputStandardDistribution.getParametersCollection()[0]);
+        if (inputStandardRepresentativeParameters == outputStandardRepresentativeParameters)
         {
-          oss << " * (" << xName;
-          if (mu1 > 0.0) oss << " - " << mu1 << ")";
-          else oss << " + " << -mu1 << ")";
+          // The transformation is the composition of two affine transformations: (input distribution->standard representative of input distribution) and (standard representative of output distribution->output distribution)
+          // The two affine transformations are obtained using quantiles in order to deal with distributions with no moments
+          const NumericalScalar q25Input(inputDistribution.computeQuantile(0.25)[0]);
+          const NumericalScalar q75Input(inputDistribution.computeQuantile(0.75)[0]);
+          const NumericalScalar q25Output(outputDistribution.computeQuantile(0.25)[0]);
+          const NumericalScalar q75Output(outputDistribution.computeQuantile(0.75)[0]);
+          const NumericalScalar a(0.5 * (q75Output + q25Output));
+          // Here, b > 0 by construction
+          const NumericalScalar b((q75Output - q25Output) / (q75Input - q25Input));
+          const NumericalScalar c(-0.5 * (q75Input + q25Input));
+          OSS oss;
+          oss.setPrecision(20);
+          // First case, b = 1: we don't need to center the input variable
+          if (b == 1.0)
+          {
+            const NumericalScalar alpha(a + c);
+            if (alpha != 0.0) oss << alpha << "+";
+            oss << xName;
+          } // b == 1
+          else
+          {
+            if (a != 0.0) oss << a << "+";
+            oss << b << "*";
+            if (c != 0.0)
+            {
+              oss << "(" << xName;
+              if (c > 0.0) oss << "+";
+              if (c < 0.0) oss << "-";
+              oss << fabs(c) << ")";
+            } // |c| != 0
+            else oss << xName;
+          } // b != 1
+          const String formula(oss);
+          expressions_[i] = NumericalMathFunction(xName, formula, yName);
+          simplifications_[i] = 1;
         }
-        const String formula(oss);
-        expressions_[i] = NumericalMathFunction(xName, formula, yName);
-        simplifications_[i] = 1;
-      } // Normal vs Normal
-      // Uniform/Uniform simplification
-      if ((inputClass == "Uniform") && (outputClass == "Uniform"))
-      {
-        const NumericalScalar a1(inputParameters[0]);
-        const NumericalScalar b1(inputParameters[1]);
-        const NumericalScalar a2(outputParameters[0]);
-        const NumericalScalar b2(outputParameters[1]);
-        OSS oss;
-        oss.setPrecision(20);
-        if (a2 != 0.0) oss << a2 << " + ";
-        oss << b2 - a2 << " * ("; // " * max(0.0, min(1.0, ";
-        if (a1 == 0.0) oss << xName << " / " << b1 - a1 << ")"; // "))";
-        else
-        {
-          oss << "(" << xName;
-          if (a1 > 0.0) oss << " - " << a1 << ") / " << b1 - a1 << ")"; // "))";
-          else oss << " + " << -a1 << ") / " << b1 - a1 << ")"; // "))";
-        }
-        const String formula(oss);
-        expressions_[i] = NumericalMathFunction(xName, formula, yName);
-        simplifications_[i] = 1;
-      } // Uniform vs Uniform
+      }
       if (((inputClass == "ChiSquare") || (inputClass == "Exponential") || (inputClass == "Gamma")) &&
           ((outputClass == "ChiSquare") || (outputClass == "Exponential") || (outputClass == "Gamma")))
       {
@@ -198,6 +200,50 @@ MarginalTransformationEvaluation::MarginalTransformationEvaluation(const Distrib
           simplifications_[i] = 1;
         } // k1 == k2
       } // ChiSquare || Exponential || Gamma vs ChiSquare || Exponential || Gamma
+      // Normal -> LogNormal simplification
+      if ((inputClass == "Normal") && (outputClass == "LogNormal"))
+      {
+        const NumericalScalar mu1(inputParameters[0]);
+        const NumericalScalar sigma1(inputParameters[1]);
+        const NumericalScalar muLog2(outputParameters[0]);
+        const NumericalScalar sigmaLog2(outputParameters[1]);
+        const NumericalScalar gamma2(outputParameters[2]);
+        OSS oss;
+        oss.setPrecision(20);
+        if (gamma2 != 0.0) oss << gamma2 << " + ";
+        oss << "exp(";
+        if (muLog2 != 0.0) oss << muLog2 << " + ";
+        if (sigmaLog2 != 1.0) oss << sigmaLog2 << " * ";
+        if (mu1 != 0.0) oss << "(" << xName << " - " << mu1 << ")";
+        else oss << xName;
+        if (sigma1 != 1.0) oss << " / " << sigma1;
+        oss << ")";
+        const String formula(oss);
+        expressions_[i] = NumericalMathFunction(xName, formula, yName);
+        simplifications_[i] = 1;
+      } // Normal -> LogNormal simplification
+      // LogNormal -> Normal simplification
+      if ((inputClass == "LogNormal") && (outputClass == "Normal"))
+      {
+        const NumericalScalar muLog1(inputParameters[0]);
+        const NumericalScalar sigmaLog1(inputParameters[1]);
+        const NumericalScalar gamma1(inputParameters[2]);
+        const NumericalScalar mu2(outputParameters[0]);
+        const NumericalScalar sigma2(outputParameters[1]);
+        OSS oss;
+        oss.setPrecision(20);
+        if (mu2 != 0.0) oss << mu2 << " + ";
+        if (sigma2 != 1.0) oss << sigma2 << " * ";
+        if (muLog1 != 0.0) oss << "(";
+        oss << "log(" << xName;
+        if (gamma1 != 0.0) oss << " - " << gamma1;
+        oss << ")";
+        if (muLog1 != 0.0) oss << " - " << muLog1 << ")";
+        if (sigmaLog1 != 1.0) oss << " / " << sigmaLog1;
+        const String formula(oss);
+        expressions_[i] = NumericalMathFunction(xName, formula, yName);
+        simplifications_[i] = 1;
+      } // LogNormal -> Normal simplification
     } // Loop over the components
   } // Simplifications
 }
@@ -459,7 +505,7 @@ Collection<NumericalMathFunction> MarginalTransformationEvaluation::getExpressio
 /* String converter */
 String MarginalTransformationEvaluation::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << MarginalTransformationEvaluation::GetClassName()
       << " description=" << getDescription()
       << " input marginals=" << inputDistributionCollection_
@@ -471,7 +517,7 @@ String MarginalTransformationEvaluation::__repr__() const
 
 String MarginalTransformationEvaluation::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   const String name(getName());
   if (hasVisibleName()) oss << offset << "Marginal transformation " << getName() << " :\n";
   const Description inputDescription(getInputDescription());
@@ -487,7 +533,7 @@ String MarginalTransformationEvaluation::__str__(const String & offset) const
     oss << offset;
     if (inputDistributionCollection_.getSize() > 1) oss << "| " << std::setw(length) << outputDescription[i] << " = ";
     if (simplifications_[i]) oss << expressions_[i].getEvaluationImplementation()->__str__() << "\n";
-    else oss << inputDistributionCollection_[i].__str__() << " -> " << outputDescription[i] << " : " << outputDistributionCollection_[i].__str__() << "\n";
+    else oss << inputDistributionCollection_[i] << " -> " << outputDescription[i] << " : " << outputDistributionCollection_[i] << "\n";
   }
   return oss;
 }
@@ -512,4 +558,3 @@ void MarginalTransformationEvaluation::load(Advocate & adv)
 }
 
 END_NAMESPACE_OPENTURNS
-
