@@ -3,7 +3,7 @@
  *  @file  MarginalTransformationGradient.cxx
  *  @brief Class for the Nataf transformationGradient evaluation for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,17 +31,17 @@ CLASSNAMEINIT(MarginalTransformationGradient);
 static Factory<MarginalTransformationGradient> RegisteredFactory("MarginalTransformationGradient");
 
 /* ParameterDefault constructor */
-MarginalTransformationGradient::MarginalTransformationGradient():
-  NumericalMathGradientImplementation(),
-  evaluation_()
+MarginalTransformationGradient::MarginalTransformationGradient()
+  : NumericalMathGradientImplementation()
+  , evaluation_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
-MarginalTransformationGradient::MarginalTransformationGradient(const MarginalTransformationEvaluation & evaluation):
-  NumericalMathGradientImplementation(),
-  evaluation_(evaluation)
+MarginalTransformationGradient::MarginalTransformationGradient(const MarginalTransformationEvaluation & evaluation)
+  : NumericalMathGradientImplementation()
+  , evaluation_(evaluation)
 {
   // Nothing to do
 }
@@ -60,21 +60,25 @@ Matrix MarginalTransformationGradient::gradient(const NumericalPoint & inP) cons
   // (G^{-1} o F)' = F' . G^{-1}' o F = F' / (G' o G^{-1} o F)
   for (UnsignedLong i = 0; i < dimension; ++i)
   {
-    const NumericalScalar inputPDF(evaluation_.inputDistributionCollection_[i].computePDF(inP[i]));
-    // Quick rejection step: if the input PDF is zero, the result will be zero, so continue only if the value is > 0
-    if (inputPDF > 0.0)
+    if (evaluation_.getSimplifications()[i] && evaluation_.getExpressions()[i].getGradientImplementation()->getClassName() == "AnalyticalNumericalMathGradientImplementation") result(i, i) = evaluation_.getExpressions()[i].gradient(NumericalPoint(1, inP[i]))(0, 0);
+    else
     {
-      NumericalScalar inputCDF(evaluation_.inputDistributionCollection_[i].computeCDF(inP[i]));
-      // For accuracy reason, check if we are in the upper tail of the distribution
-      const Bool upperTail(inputCDF > 0.5);
-      if (upperTail) inputCDF = evaluation_.inputDistributionCollection_[i].computeComplementaryCDF(inP[i]);
-      // The upper tail CDF is defined by CDF(x, upper) = P(X>x)
-      // The upper tail quantile is defined by Quantile(CDF(x, upper), upper) = x
-      const NumericalPoint  outputQuantile(evaluation_.outputDistributionCollection_[i].computeQuantile(inputCDF, upperTail));
-      const NumericalScalar outputPDF(evaluation_.outputDistributionCollection_[i].computePDF(outputQuantile));
-      // The output PDF should never be zero here, be it can occure due to some strange rounding error
-      if (outputPDF > 0.0) result(i, i) = inputPDF / outputPDF;
-    }
+      const NumericalScalar inputPDF(evaluation_.inputDistributionCollection_[i].computePDF(inP[i]));
+      // Quick rejection step: if the input PDF is zero, the result will be zero, so continue only if the value is > 0
+      if (inputPDF > 0.0)
+      {
+        NumericalScalar inputCDF(evaluation_.inputDistributionCollection_[i].computeCDF(inP[i]));
+        // For accuracy reason, check if we are in the upper tail of the distribution
+        const Bool upperTail(inputCDF > 0.5);
+        if (upperTail) inputCDF = evaluation_.inputDistributionCollection_[i].computeComplementaryCDF(inP[i]);
+        // The upper tail CDF is defined by CDF(x, upper) = P(X>x)
+        // The upper tail quantile is defined by Quantile(CDF(x, upper), upper) = x
+        const NumericalPoint  outputQuantile(evaluation_.outputDistributionCollection_[i].computeQuantile(inputCDF, upperTail));
+        const NumericalScalar outputPDF(evaluation_.outputDistributionCollection_[i].computePDF(outputQuantile));
+        // The output PDF should never be zero here, be it can occure due to some strange rounding error
+        if (outputPDF > 0.0) result(i, i) = inputPDF / outputPDF;
+      } // PDF > 0
+    } // No simplification
   }
   return result;
 }
@@ -94,7 +98,7 @@ UnsignedLong MarginalTransformationGradient::getOutputDimension() const
 /* String converter */
 String MarginalTransformationGradient::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << MarginalTransformationGradient::GetClassName()
       << " evaluation=" << evaluation_;
   return oss;
@@ -102,7 +106,7 @@ String MarginalTransformationGradient::__repr__() const
 
 String MarginalTransformationGradient::__str__(const String & offset) const
 {
-  return OSS() << offset << "Gradient of " << evaluation_.getName();
+  return OSS(false) << offset << "Gradient of " << evaluation_.getName();
 }
 
 /* Method save() stores the object through the StorageManager */
