@@ -3,7 +3,7 @@
  *  @file  MarginalTransformationHessian.cxx
  *  @brief Class for the Nataf transformationHessian evaluation for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -59,26 +59,30 @@ SymmetricTensor MarginalTransformationHessian::hessian(const NumericalPoint & in
   SymmetricTensor result(dimension, dimension);
   for (UnsignedLong i = 0; i < dimension; ++i)
   {
-    // (`@`(-(`@`((D@@2)(G), 1/G))/(`@`(D(G), 1/G))^3, F))*D(F)^2+(`@`(1/(`@`(D(G), 1/G)), F))*(D@@2)(F)
-    const NumericalScalar inputPDF(evaluation_.inputDistributionCollection_[i].computePDF(inP[i]));
-    // Quick rejection step: if the input PDF is zero, the result will be zero, so continue only if the value is > 0
-    if (inputPDF > 0.0)
+    if (evaluation_.getSimplifications()[i] && evaluation_.getExpressions()[i].getHessianImplementation()->getClassName() == "AnalyticalNumericalMathHessianImplementation") result(i, i, i) = evaluation_.getExpressions()[i].hessian(NumericalPoint(1, inP[i]))(0, 0, 0);
+    else
     {
-      NumericalScalar inputCDF(evaluation_.inputDistributionCollection_[i].computeCDF(inP[i]));
-      // For accuracy reason, check if we are in the upper tail of the distribution
-      const Bool upperTail(inputCDF > 0.5);
-      if (upperTail) inputCDF = evaluation_.inputDistributionCollection_[i].computeComplementaryCDF(inP[i]);
-      // The upper tail CDF is defined by CDF(x, upper) = P(X>x)
-      // The upper tail quantile is defined by Quantile(CDF(x, upper), upper) = x
-      const NumericalPoint  outputQuantile(evaluation_.outputDistributionCollection_[i].computeQuantile(inputCDF, upperTail));
-      const NumericalScalar outputPDF(evaluation_.outputDistributionCollection_[i].computePDF(outputQuantile));
-      if (outputPDF > 0.0)
+      // (`@`(-(`@`((D@@2)(G), 1/G))/(`@`(D(G), 1/G))^3, F))*D(F)^2+(`@`(1/(`@`(D(G), 1/G)), F))*(D@@2)(F)
+      const NumericalScalar inputPDF(evaluation_.inputDistributionCollection_[i].computePDF(inP[i]));
+      // Quick rejection step: if the input PDF is zero, the result will be zero, so continue only if the value is > 0
+      if (inputPDF > 0.0)
       {
-        const NumericalScalar inputDDF(evaluation_.inputDistributionCollection_[i].computeDDF(inP[i]));
-        const NumericalScalar outputDDF(evaluation_.outputDistributionCollection_[i].computeDDF(outputQuantile[0]));
-        result(i, i, i) = (inputDDF - outputDDF * pow(inputPDF / outputPDF, 2)) / outputPDF;
-      }
-    }
+        NumericalScalar inputCDF(evaluation_.inputDistributionCollection_[i].computeCDF(inP[i]));
+        // For accuracy reason, check if we are in the upper tail of the distribution
+        const Bool upperTail(inputCDF > 0.5);
+        if (upperTail) inputCDF = evaluation_.inputDistributionCollection_[i].computeComplementaryCDF(inP[i]);
+        // The upper tail CDF is defined by CDF(x, upper) = P(X>x)
+        // The upper tail quantile is defined by Quantile(CDF(x, upper), upper) = x
+        const NumericalPoint  outputQuantile(evaluation_.outputDistributionCollection_[i].computeQuantile(inputCDF, upperTail));
+        const NumericalScalar outputPDF(evaluation_.outputDistributionCollection_[i].computePDF(outputQuantile));
+        if (outputPDF > 0.0)
+        {
+          const NumericalScalar inputDDF(evaluation_.inputDistributionCollection_[i].computeDDF(inP[i]));
+          const NumericalScalar outputDDF(evaluation_.outputDistributionCollection_[i].computeDDF(outputQuantile[0]));
+          result(i, i, i) = (inputDDF - outputDDF * pow(inputPDF / outputPDF, 2)) / outputPDF;
+        } // output PDF > 0
+      } // input PDF > 0
+    } // No simplification
   }
   return result;
 }
@@ -124,4 +128,3 @@ void MarginalTransformationHessian::load(Advocate & adv)
 }
 
 END_NAMESPACE_OPENTURNS
-
