@@ -3,7 +3,7 @@
  *  @file  InverseNatafEllipticalDistributionEvaluation.cxx
  *  @brief Class for the InverseNataf transformation evaluation for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,6 +56,12 @@ InverseNatafEllipticalDistributionEvaluation::InverseNatafEllipticalDistribution
   // Nothing to do
 }
 
+/* Virtual constructor */
+InverseNatafEllipticalDistributionEvaluation * InverseNatafEllipticalDistributionEvaluation::clone() const
+{
+  return new InverseNatafEllipticalDistributionEvaluation(*this);
+}
+
 /* String converter */
 String InverseNatafEllipticalDistributionEvaluation::__repr__() const
 {
