@@ -3,7 +3,7 @@
  *  @file  InverseNatafEllipticalDistributionGradient.cxx
  *  @brief Class for the InverseNataf transformation gradient for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,6 +51,12 @@ InverseNatafEllipticalDistributionGradient::InverseNatafEllipticalDistributionGr
   // Nothing to do
 }
 
+/* Virtual constructor */
+InverseNatafEllipticalDistributionGradient * InverseNatafEllipticalDistributionGradient::clone() const
+{
+  return new InverseNatafEllipticalDistributionGradient(*this);
+}
+
 /* String converter */
 String InverseNatafEllipticalDistributionGradient::__repr__() const
 {
