@@ -3,7 +3,7 @@
  *  @file  InverseNatafEllipticalDistributionHessian.cxx
  *  @brief Class for the InverseNataf transformation hessian for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,6 +52,12 @@ InverseNatafEllipticalDistributionHessian::InverseNatafEllipticalDistributionHes
   // Nothing to do
 }
 
+/* Virtual constructor */
+InverseNatafEllipticalDistributionHessian * InverseNatafEllipticalDistributionHessian::clone() const
+{
+  return new InverseNatafEllipticalDistributionHessian(*this);
+}
+
 /* String converter */
 String InverseNatafEllipticalDistributionHessian::__repr__() const
 {
