@@ -3,7 +3,7 @@
  *  @file  NatafEllipticalDistributionEvaluation.cxx
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,6 +56,12 @@ NatafEllipticalDistributionEvaluation::NatafEllipticalDistributionEvaluation(con
   // Nothing to do
 }
 
+/* Virtual constructor */
+NatafEllipticalDistributionEvaluation * NatafEllipticalDistributionEvaluation::clone() const
+{
+  return new NatafEllipticalDistributionEvaluation(*this);
+}
+
 /* String converter */
 String NatafEllipticalDistributionEvaluation::__repr__() const
 {
