@@ -3,7 +3,7 @@
  *  @file  NatafEllipticalDistributionGradient.cxx
  *  @brief Class for the Nataf transformation gradient for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,6 +51,12 @@ NatafEllipticalDistributionGradient::NatafEllipticalDistributionGradient(const S
   // Nothing to do
 }
 
+/* Virtual constructor */
+NatafEllipticalDistributionGradient * NatafEllipticalDistributionGradient::clone() const
+{
+  return new NatafEllipticalDistributionGradient(*this);
+}
+
 /* String converter */
 String NatafEllipticalDistributionGradient::__repr__() const
 {
