@@ -3,7 +3,7 @@
  *  @file  NatafEllipticalDistributionHessian.cxx
  *  @brief Class for the Nataf transformation hessian for elliptical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,6 +52,12 @@ NatafEllipticalDistributionHessian::NatafEllipticalDistributionHessian(const Uns
   // Nothing to do
 }
 
+/* Virtual constructor */
+NatafEllipticalDistributionHessian * NatafEllipticalDistributionHessian::clone() const
+{
+  return new NatafEllipticalDistributionHessian(*this);
+}
+
 /* String converter */
 String NatafEllipticalDistributionHessian::__repr__() const
 {
