@@ -3,7 +3,7 @@
  *  @file  InverseNatafIndependentCopulaEvaluation.cxx
  *  @brief Class for the InverseNataf transformation evaluation for independent
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,9 +36,9 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(InverseNatafIndependentCopulaEvaluation);
 
 /* Parameter constructor */
-InverseNatafIndependentCopulaEvaluation::InverseNatafIndependentCopulaEvaluation(const UnsignedLong dimension):
-  NumericalMathEvaluationImplementation(),
-  dimension_(dimension)
+InverseNatafIndependentCopulaEvaluation::InverseNatafIndependentCopulaEvaluation(const UnsignedLong dimension)
+  : NumericalMathEvaluationImplementation()
+  , dimension_(dimension)
 {
   Description description;
   for (UnsignedLong i = 0; i < dimension_; ++i)
@@ -81,10 +81,7 @@ String InverseNatafIndependentCopulaEvaluation::__repr__() const
 NumericalPoint InverseNatafIndependentCopulaEvaluation::operator () (const NumericalPoint & inP) const
 {
   NumericalPoint result(dimension_);
-  for (UnsignedLong i = 0; i < dimension_; ++i)
-  {
-    result[i] = DistFunc::pNormal(inP[i]);
-  }
+  for (UnsignedLong i = 0; i < dimension_; ++i) result[i] = DistFunc::pNormal(inP[i]);
   ++callsNumber_;
   if (isHistoryEnabled_)
   {
