@@ -3,7 +3,7 @@
  *  @file  InverseNatafIndependentCopulaGradient.cxx
  *  @brief Class for the InverseNataf transformation evaluation for independent
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,17 +38,17 @@ CLASSNAMEINIT(InverseNatafIndependentCopulaGradient);
 static Factory<InverseNatafIndependentCopulaGradient> RegisteredFactory("InverseNatafIndependentCopulaGradient");
 
 /* Default constructor */
-InverseNatafIndependentCopulaGradient::InverseNatafIndependentCopulaGradient():
-  NumericalMathGradientImplementation(),
-  dimension_()
+InverseNatafIndependentCopulaGradient::InverseNatafIndependentCopulaGradient()
+  : NumericalMathGradientImplementation()
+  , dimension_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
-InverseNatafIndependentCopulaGradient::InverseNatafIndependentCopulaGradient(const UnsignedLong dimension):
-  NumericalMathGradientImplementation(),
-  dimension_(dimension)
+InverseNatafIndependentCopulaGradient::InverseNatafIndependentCopulaGradient(const UnsignedLong dimension)
+  : NumericalMathGradientImplementation()
+  , dimension_(dimension)
 {
   // Nothing to do
 }
@@ -81,7 +81,7 @@ Matrix InverseNatafIndependentCopulaGradient::gradient(const NumericalPoint & in
   Matrix result(dimension_, dimension_);
   for (UnsignedLong i = 0; i < dimension_; ++i)
   {
-    NumericalScalar x(inP[i]);
+    const NumericalScalar x(inP[i]);
     // 0.3989422804014326779399462 = 1/sqrt(2*Pi)
     result(i, i) = 0.3989422804014326779399462 * exp(-0.5 * x * x);
   }
