@@ -3,7 +3,7 @@
  *  @file  NatafIndependentCopulaEvaluation.cxx
  *  @brief Class for the Nataf transformation evaluation for independent
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,17 +39,17 @@ CLASSNAMEINIT(NatafIndependentCopulaEvaluation);
 static Factory<NatafIndependentCopulaEvaluation> RegisteredFactory("NatafIndependentCopulaEvaluation");
 
 /* Default constructor */
-NatafIndependentCopulaEvaluation::NatafIndependentCopulaEvaluation():
-  NumericalMathEvaluationImplementation(),
-  dimension_()
+NatafIndependentCopulaEvaluation::NatafIndependentCopulaEvaluation()
+  : NumericalMathEvaluationImplementation()
+  , dimension_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
-NatafIndependentCopulaEvaluation::NatafIndependentCopulaEvaluation(const UnsignedLong dimension):
-  NumericalMathEvaluationImplementation(),
-  dimension_(dimension)
+NatafIndependentCopulaEvaluation::NatafIndependentCopulaEvaluation(const UnsignedLong dimension)
+  : NumericalMathEvaluationImplementation()
+  , dimension_(dimension)
 {
   Description description;
   for (UnsignedLong i = 0; i < dimension_; ++i)
@@ -94,7 +94,7 @@ NumericalPoint NatafIndependentCopulaEvaluation::operator () (const NumericalPoi
   NumericalPoint result(dimension_);
   for (UnsignedLong i = 0; i < dimension_; ++i)
   {
-    NumericalScalar x(inP[i]);
+    const NumericalScalar x(inP[i]);
     if ((x < 0.0) || (x > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot evaluate the NatafIndependentCopulaEvaluation if all the components are not in [0, 1], here in=" << inP;
     result[i] = DistFunc::qNormal(x);
   }
