@@ -3,7 +3,7 @@
  *  @file  NatafIndependentCopulaGradient.cxx
  *  @brief Class for the Nataf transformation evaluation for independent
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,17 +40,17 @@ CLASSNAMEINIT(NatafIndependentCopulaGradient);
 static Factory<NatafIndependentCopulaGradient> RegisteredFactory("NatafIndependentCopulaGradient");
 
 /* Default constructor */
-NatafIndependentCopulaGradient::NatafIndependentCopulaGradient():
-  NumericalMathGradientImplementation(),
-  dimension_()
+NatafIndependentCopulaGradient::NatafIndependentCopulaGradient()
+  : NumericalMathGradientImplementation()
+  , dimension_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
-NatafIndependentCopulaGradient::NatafIndependentCopulaGradient(const UnsignedLong dimension):
-  NumericalMathGradientImplementation(),
-  dimension_(dimension)
+NatafIndependentCopulaGradient::NatafIndependentCopulaGradient(const UnsignedLong dimension)
+  : NumericalMathGradientImplementation()
+  , dimension_(dimension)
 {
   // Nothing to do
 }
@@ -84,10 +84,10 @@ Matrix NatafIndependentCopulaGradient::gradient(const NumericalPoint & inP) cons
   Matrix result(dimension_, dimension_);
   for (UnsignedLong i = 0; i < dimension_; ++i)
   {
-    NumericalScalar x(inP[i]);
+    const NumericalScalar x(inP[i]);
     if ((x < 0.0) || (x > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot evaluate the NatafIndependentCopulaGradient if all the components are not in [0, 1], here in=" << inP;
     // q = Normal(0,1).computeQuantile(x)
-    NumericalScalar q(DistFunc::qNormal(x));
+    const NumericalScalar q(DistFunc::qNormal(x));
     // 2.506628274631000502415765 = sqrt(2*Pi)
     result(i, i) = 2.506628274631000502415765 * exp(0.5 * q * q);
   }
