@@ -3,7 +3,7 @@
  *  @file  NatafIndependentCopulaHessian.cxx
  *  @brief Class for the Nataf transformation evaluation for independent
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,17 +40,17 @@ CLASSNAMEINIT(NatafIndependentCopulaHessian);
 static Factory<NatafIndependentCopulaHessian> RegisteredFactory("NatafIndependentCopulaHessian");
 
 /* Default constructor */
-NatafIndependentCopulaHessian::NatafIndependentCopulaHessian():
-  NumericalMathHessianImplementation(),
-  dimension_()
+NatafIndependentCopulaHessian::NatafIndependentCopulaHessian()
+  : NumericalMathHessianImplementation()
+  , dimension_()
 {
   // Nothing to do
 }
 
 /* Parameter constructor */
-NatafIndependentCopulaHessian::NatafIndependentCopulaHessian(const UnsignedLong dimension):
-  NumericalMathHessianImplementation(),
-  dimension_(dimension)
+NatafIndependentCopulaHessian::NatafIndependentCopulaHessian(const UnsignedLong dimension)
+  : NumericalMathHessianImplementation()
+  , dimension_(dimension)
 {
   // Nothing to do
 }
@@ -86,7 +86,7 @@ SymmetricTensor NatafIndependentCopulaHessian::hessian(const NumericalPoint & in
     NumericalScalar x(inP[i]);
     if ((x < 0.0) || (x > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot evaluate the NatafIndependentCopulaHessian if all the components are not in [0, 1], here in=" << inP;
     // q = Normal(0,1).computeQuantile(x)
-    NumericalScalar q(DistFunc::qNormal(x));
+    const NumericalScalar q(DistFunc::qNormal(x));
     // factor = 1/Normal(0,1).computePDF(q)
     // 6.283185307179586476925286 = 2Pi
     // quantileSecondDerivative = -Normal(0,1).computeDDF(q) / (Normal(0,1).computePDF(q))^3 = q / (Normal(0,1).computePDF(q))^2
