@@ -3,7 +3,7 @@
  *  @file  BoxCoxFactory.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 #include "BoxCoxFactory.hxx"
 #include "Exception.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "TimeSeries.hxx"
+#include "Field.hxx"
 #include "BoxCoxEvaluationImplementation.hxx"
 #include "SpecFunc.hxx"
 #include "algocobyla.h"
@@ -96,18 +96,18 @@ int BoxCoxFactory::ComputeObjectiveAndConstraint(int n,
 }
 
 /* Build the factory from data */
-BoxCoxTransform BoxCoxFactory::build(const TimeSeries & timeSeries) const
+BoxCoxTransform BoxCoxFactory::build(const Field & timeSeries) const
 {
   return build(timeSeries.getSample());
 }
 
-BoxCoxTransform BoxCoxFactory::build(const TimeSeries & timeSeries,
+BoxCoxTransform BoxCoxFactory::build(const Field & timeSeries,
                                      const NumericalPoint & shift) const
 {
   return build(timeSeries.getSample(), shift);
 }
 
-BoxCoxTransform BoxCoxFactory::build(const TimeSeries & timeSeries,
+BoxCoxTransform BoxCoxFactory::build(const Field & timeSeries,
                                      const NumericalPoint & shift,
                                      Graph & graph) const
 {
@@ -204,6 +204,9 @@ BoxCoxTransform BoxCoxFactory::build(const NumericalSample & sample,
     cloud.setPointStyle("circle");
     cloud.setLegend(String(OSS() << "lambda=" << lambda[d]));
     graph.add(cloud);
+    NumericalPoint bb(graph.getBoundingBox());
+    bb[3] += 0.1 * (bb[3] - bb[2]);
+    graph.setBoundingBox(bb);
   }
   // return result ==> Box Cox transform
   return BoxCoxTransform(lambda);
