@@ -3,7 +3,7 @@
  *  @file  TrendFactory.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,7 +78,7 @@ void TrendFactory::setFittingAlgorithm(const FittingAlgorithm & fittingAlgorithm
 }
 
 /* Build the factory from data */
-TrendTransform TrendFactory::build(const TimeSeries & timeSeries,
+TrendTransform TrendFactory::build(const Field & timeSeries,
                                    const Basis & basis) const
 {
   // size of the collection
@@ -120,7 +120,7 @@ TrendTransform TrendFactory::build(const TimeSeries & timeSeries,
 /* String converter */
 String TrendFactory::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << TrendFactory::GetClassName()
       << " fittingAlgorithm = " << fittingAlgorithm_
       << " basisSequenceFactory = " << basisSequenceFactory_;
