@@ -3,7 +3,7 @@
  *  @file  Arcsine.cxx
  *  @brief The Arcsine distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,8 +29,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(Arcsine);
 
 static Factory<Arcsine> RegisteredFactory("Arcsine");
@@ -38,9 +36,9 @@ static Factory<Arcsine> RegisteredFactory("Arcsine");
 
 /* Default constructor */
 Arcsine::Arcsine()
-  : NonEllipticalDistribution("Arcsine"),
-    a_(-1.0),
-    b_(1.0)
+  : ContinuousDistribution("Arcsine")
+  , a_(-1.0)
+  , b_(1.0)
 {
   setDimension(1);
   computeRange();
@@ -50,9 +48,9 @@ Arcsine::Arcsine()
 Arcsine::Arcsine(const NumericalScalar arg1,
                  const NumericalScalar arg2,
                  const ParameterSet set)
-  : NonEllipticalDistribution("Arcsine"),
-    a_(-1.0),
-    b_(1.0)
+  : ContinuousDistribution("Arcsine")
+  , a_(-1.0)
+  , b_(1.0)
 {
   switch (set)
   {
@@ -80,7 +78,7 @@ Bool Arcsine::operator ==(const Arcsine & other) const
 /* String converter */
 String Arcsine::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Arcsine::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -91,7 +89,7 @@ String Arcsine::__repr__() const
 
 String Arcsine::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(a = " << a_ << ", b = " << b_ << ")";
   return oss;
 }
@@ -155,7 +153,7 @@ NumericalScalar Arcsine::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= a_) return 0.0;
-  if (x > b_) return 1.0;
+  if (x >= b_) return 1.0;
   const NumericalScalar value(asin((x - 0.5 * (a_ + b_)) / (0.5 * (b_ - a_))) / M_PI);
   return 0.5 + value;
 }
@@ -171,6 +169,13 @@ NumericalScalar Arcsine::computeComplementaryCDF(const NumericalPoint & point) c
   return 0.5 - value;
 }
 
+/* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
+NumericalComplex Arcsine::computeCharacteristicFunction(const NumericalScalar x) const
+{
+  //  return exp(NumericalComplex(0.0, a_)) * SpecFunc::HyperGeom_1_1(0.5, 1.0, (b_ - a_) * x);
+  return exp(NumericalComplex(0.0, a_ + 0.5 * (b_ - a_) * x)) * j0(0.5 * (b_ - a_) * x);
+}
+
 /* Get the PDFGradient of the distribution */
 NumericalPoint Arcsine::computePDFGradient(const NumericalPoint & point) const
 {
@@ -210,8 +215,7 @@ NumericalPoint Arcsine::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Arcsine::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   const NumericalScalar proba(tail ? 1.0 - prob : prob);
   const NumericalScalar quantile(0.5 * (b_ - a_) * sin(M_PI * (proba - 0.5)) + 0.5 * (a_ + b_));
@@ -380,7 +384,7 @@ void Arcsine::setMuSigma(const NumericalScalar mu,
 /* Method save() stores the object through the StorageManager */
 void Arcsine::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "a_", a_ );
   adv.saveAttribute( "b_", b_ );
 }
@@ -388,7 +392,7 @@ void Arcsine::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Arcsine::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "a_", a_ );
   adv.loadAttribute( "b_", b_ );
   computeRange();
