@@ -3,7 +3,7 @@
  *  @file  ArcsineFactory.cxx
  *  @brief Factory for Arcsine distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -65,7 +65,9 @@ Arcsine ArcsineFactory::buildAsArcsine(const NumericalSample & sample) const
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a Arcsine distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
   NumericalScalar mean(sample.computeMean()[0]);
   NumericalScalar standardDeviation(sample.computeStandardDeviationPerComponent()[0]);
-  return Arcsine(mean, standardDeviation, Arcsine::MUSIGMA);
+  Arcsine result(mean, standardDeviation, Arcsine::MUSIGMA);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Arcsine ArcsineFactory::buildAsArcsine(const NumericalPointWithDescriptionCollection & parameters) const
