@@ -3,7 +3,7 @@
  *  @file  Bernoulli.cxx
  *  @brief The Bernoulli distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -98,8 +98,8 @@ NumericalScalar Bernoulli::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (fabs(k) < ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 1.0 - p_;
-  if (fabs(k - 1.0) < ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return p_;
+  if (fabs(k) < supportEpsilon_) return 1.0 - p_;
+  if (fabs(k - 1.0) < supportEpsilon_) return p_;
   return 0.0;
 }
 
@@ -111,9 +111,9 @@ NumericalScalar Bernoulli::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   // k < 0.0
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
+  if (k < -supportEpsilon_) return 0.0;
   // k >= 1.0
-  if (k > 1.0 - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 1.0;
+  if (k > 1.0 - supportEpsilon_) return 1.0;
   // k > 0.0 && k < 1.0
   return 1.0 - p_;
 }
@@ -125,7 +125,7 @@ NumericalPoint Bernoulli::computePDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   NumericalPoint pdfGradient(1, 0.0);
-  if ((k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (fabs(k - round(k)) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) return pdfGradient;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return pdfGradient;
   throw NotYetImplementedException(HERE);
 }
 
@@ -136,14 +136,13 @@ NumericalPoint Bernoulli::computeCDFGradient(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return NumericalPoint(1, 0.0);
+  if (k < -supportEpsilon_) return NumericalPoint(1, 0.0);
   throw NotYetImplementedException(HERE);
 }
 
 /* Get the quantile of the distribution */
 NumericalScalar Bernoulli::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (prob < 1.0 - p_) return (tail ? 1.0 : 0.0);
   return (tail ? 0.0 : 1.0);
