@@ -3,7 +3,7 @@
  *  @file  BernoulliFactory.cxx
  *  @brief Factory for Bernoulli distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -67,14 +67,17 @@ Bernoulli BernoulliFactory::buildAsBernoulli(const NumericalSample & sample) con
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Bernoulli distribution from an empty sample";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a Bernoulli distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
   NumericalScalar sum(0.0);
+  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
   for (UnsignedLong i = 0; i < size; ++i)
   {
     const NumericalScalar x(sample[i][0]);
     const int iX(static_cast<int>(round(x)));
-    if ((fabs(x - iX) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || ((iX != 0) && (iX != 1))) throw InvalidArgumentException(HERE) << "Error: can build a Bernoulli distribution only from a sample made of 0 and 1.";
+    if ((fabs(x - iX) > supportEpsilon) || ((iX != 0) && (iX != 1))) throw InvalidArgumentException(HERE) << "Error: can build a Bernoulli distribution only from a sample made of 0 and 1.";
     sum += x;
   }
-  return Bernoulli(sum / size);
+  Bernoulli result(sum / size);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Bernoulli BernoulliFactory::buildAsBernoulli(const NumericalPointWithDescriptionCollection & parameters) const
