@@ -3,7 +3,7 @@
  *  @file  Beta.cxx
  *  @brief The Beta distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ static Factory<Beta> RegisteredFactory("Beta");
 
 /* Default constructor */
 Beta::Beta()
-  : NonEllipticalDistribution("Beta")
+  : ContinuousDistribution("Beta")
   , r_(2.0)
   , t_(4.0)
   , a_(-1.0)
@@ -54,7 +54,7 @@ Beta::Beta(const NumericalScalar arg1,
            const NumericalScalar a,
            const NumericalScalar b,
            const ParameterSet set)
-  : NonEllipticalDistribution("Beta")
+  : ContinuousDistribution("Beta")
   , r_(0.0)
   , t_(0.0)
   , a_(a)
@@ -92,7 +92,7 @@ Bool Beta::operator ==(const Beta & other) const
 /* String converter */
 String Beta::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Beta::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -105,7 +105,7 @@ String Beta::__repr__() const
 
 String Beta::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(r = " << r_ << ", t = " << t_ << ", a = " << a_ << ", b = " << b_ << ")";
   return oss;
 }
@@ -177,7 +177,7 @@ NumericalScalar Beta::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= a_) return 0.0;
-  if (x > b_) return 1.0;
+  if (x >= b_) return 1.0;
   return DistFunc::pBeta(r_, t_ - r_, (x - a_) / (b_ - a_));
 }
 
@@ -216,7 +216,7 @@ NumericalPoint Beta::computeCDFGradient(const NumericalPoint & point) const
   const NumericalScalar cdfShift(DistFunc::pBeta(r_ + 1.0, t_ - r_ - 1.0, (x - a_) * iBA));
   const NumericalScalar cdfDiff(cdfShift - cdf);
   const NumericalScalar factor(r_ * iBA);
-  static const NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  static const NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
   static const NumericalScalar i2Eps(0.5 / eps);
   cdfGradient[0] = i2Eps * (DistFunc::pBeta(r_ + eps, t_ - r_ - eps, (x - a_) / (b_ - a_)) - DistFunc::pBeta(r_ - eps, t_ - r_ + eps, (x - a_) / (b_ - a_)));
   cdfGradient[1] = i2Eps * (DistFunc::pBeta(r_, t_ - r_ + eps, (x - a_) / (b_ - a_)) - DistFunc::pBeta(r_, t_ - r_ - eps, (x - a_) / (b_ - a_)));
@@ -227,8 +227,7 @@ NumericalPoint Beta::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Beta::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return a_ + (b_ - a_) * DistFunc::qBeta(r_, t_ - r_, prob, tail);
 }
@@ -236,8 +235,7 @@ NumericalScalar Beta::computeScalarQuantile(const NumericalScalar prob,
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Beta::computeCharacteristicFunction(const NumericalScalar x) const
 {
-  const NumericalComplex result(SpecFunc::HyperGeom_1_1(r_, t_, NumericalComplex(0.0, (b_ - a_) * x)) * exp(NumericalComplex(0.0, a_)));
-  return result;
+  return exp(NumericalComplex(0.0, a_)) * SpecFunc::HyperGeom_1_1(r_, t_, NumericalComplex(0.0, (b_ - a_) * x));
 }
 
 /* Get the roughness, i.e. the L2-norm of the PDF */
@@ -437,7 +435,7 @@ NumericalScalar Beta::getB() const
 /* Method save() stores the object through the StorageManager */
 void Beta::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "r_", r_ );
   adv.saveAttribute( "t_", t_ );
   adv.saveAttribute( "a_", a_ );
@@ -448,7 +446,7 @@ void Beta::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Beta::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "r_", r_ );
   adv.loadAttribute( "t_", t_ );
   adv.loadAttribute( "a_", a_ );
