@@ -3,7 +3,7 @@
  *  @file  BetaFactory.cxx
  *  @brief Factory for Beta distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -73,7 +73,9 @@ Beta BetaFactory::buildAsBeta(const NumericalSample & sample) const
   const NumericalScalar sigma(sample.computeStandardDeviationPerComponent()[0]);
   const NumericalScalar t((b - mean) * (mean - a) / (sigma * sigma) - 1.0);
   const NumericalScalar r(t * (mean - a) / (b - a));
-  return Beta(r, t, a, b);
+  Beta result(r, t, a, b);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Beta BetaFactory::buildAsBeta(const NumericalPointWithDescriptionCollection & parameters) const
