@@ -3,7 +3,7 @@
  *  @file  Binomial.cxx
  *  @brief The Binomial distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -104,8 +104,7 @@ NumericalScalar Binomial::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if ((k < -supportEpsilon) || (fabs(k - round(k)) > supportEpsilon) || (k > n_ + supportEpsilon)) return 0.0;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_) || (k > n_ + supportEpsilon_)) return 0.0;
   return exp(SpecFunc::LnGamma(n_ + 1.0) - SpecFunc::LnGamma(n_ - k + 1.0) - SpecFunc::LnGamma(k + 1.0) + k * log(p_) + (n_ - k) * log1p(-p_));
 }
 
@@ -116,12 +115,10 @@ NumericalScalar Binomial::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if (k < -supportEpsilon) return 0.0;
-  if (k > n_ + supportEpsilon) return 1.0;
+  if (k < -supportEpsilon_) return 0.0;
+  if (k > n_ - supportEpsilon_) return 1.0;
   // Complementary relation for incomplete regularized Beta function: I(a, b, x) = 1 - I(b, a, 1-x)
-  NumericalScalar value = SpecFunc::BetaRatioInc(n_ - floor(k), floor(k) + 1, 1.0 - p_);
-  return value;
+  return DistFunc::pBeta(n_ - floor(k), floor(k) + 1, 1.0 - p_);
 }
 
 NumericalScalar Binomial::computeComplementaryCDF(const NumericalPoint & point) const
@@ -129,11 +126,10 @@ NumericalScalar Binomial::computeComplementaryCDF(const NumericalPoint & point)
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if (k < -supportEpsilon) return 1.0;
-  if (k > n_ + supportEpsilon) return 0.0;
+  if (k < -supportEpsilon_) return 1.0;
+  if (k > n_ + supportEpsilon_) return 0.0;
   // Complementary relation for incomplete regularized Beta function: I(a, b, x) = 1 - I(b, a, 1-x)
-  NumericalScalar value = SpecFunc::BetaRatioInc(floor(k) + 1, n_ - floor(k), p_);
+  NumericalScalar value = DistFunc::pBeta(floor(k) + 1, n_ - floor(k), p_);
   return value;
 }
 
@@ -144,8 +140,7 @@ NumericalPoint Binomial::computePDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   NumericalPoint pdfGradient(1, 0.0);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if ((k < -supportEpsilon) || (fabs(k - round(k)) > supportEpsilon)) return pdfGradient;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return pdfGradient;
   throw NotYetImplementedException(HERE);
 }
 
@@ -156,8 +151,7 @@ NumericalPoint Binomial::computeCDFGradient(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if (k < -supportEpsilon) return NumericalPoint(1, 0.0);
+  if (k < -supportEpsilon_) return NumericalPoint(1, 0.0);
   throw NotYetImplementedException(HERE);
 }
 
@@ -277,8 +271,7 @@ void Binomial::computeRange()
 
 /* Get the quantile of the distribution */
 NumericalScalar Binomial::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   LOGDEBUG(OSS() << "in Binomial::computeScalarQuantile, prob=" << prob << ", tail=" << (tail ? "true" : "false"));
   if (prob <= 0.0) return (tail ? n_ : 0.0);
@@ -290,10 +283,12 @@ NumericalScalar Binomial::computeScalarQuantile(const NumericalScalar prob,
   NumericalScalar quantile(round(getMean()[0] + getStandardDeviation()[0] * (qNorm + (qNorm * qNorm - 1.0) * gamma1 / 6.0 + qNorm * (qNorm * qNorm - 3.0) * gamma2 / 24.0 - qNorm * (2.0 * qNorm * qNorm - 5.0) * gamma1 * gamma1 / 36.0)));
   if (quantile < 0.0) quantile = 0.0;
   if (quantile > n_) quantile = n_;
+  // CDF of the guess
   NumericalScalar cdf(tail ? computeComplementaryCDF(quantile) : computeCDF(quantile));
   LOGDEBUG(OSS() << "in Binomial::computeScalarQuantile, Cornish-Fisher estimate=" << quantile << ", cdf=" << cdf);
   NumericalScalar oldCDF(cdf);
   const NumericalScalar step(tail ? -1.0 : 1.0);
+  // Do we have to
   while (cdf >= prob)
   {
     quantile -= step;
@@ -301,6 +296,7 @@ NumericalScalar Binomial::computeScalarQuantile(const NumericalScalar prob,
     cdf = tail ? computeComplementaryCDF(quantile) : computeCDF(quantile);
     LOGDEBUG(OSS() << "in Binomial::computeScalarQuantile, backward search, quantile=" << quantile << ", cdf=" << cdf);
   }
+  // If
   if (cdf < oldCDF)
   {
     quantile += step;
@@ -310,7 +306,6 @@ NumericalScalar Binomial::computeScalarQuantile(const NumericalScalar prob,
   while (cdf < prob)
   {
     quantile += step;
-    oldCDF = cdf;
     cdf = tail ? computeComplementaryCDF(quantile) : computeCDF(quantile);
     LOGDEBUG(OSS() << "in Binomial::computeScalarQuantile, forward search, quantile=" << quantile << ", cdf=" << cdf);
   }
