@@ -3,7 +3,7 @@
  *  @file  BinomialFactory.cxx
  *  @brief Factory for Binomial distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -132,7 +132,9 @@ Binomial BinomialFactory::buildAsBinomial(const NumericalSample & sample) const
     // Check that we don't go too far when in the backward direction
     if (step < 0) loop = loop && (n > upperBound);
   }
-  return Binomial(maxN, mean / maxN);
+  Binomial result(maxN, mean / maxN);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 NumericalScalar BinomialFactory::ComputeLogLikelihood(const UnsignedLong n,
