@@ -3,7 +3,7 @@
  *  @file  Burr.cxx
  *  @brief The Burr distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published bydistributiolib
@@ -35,7 +35,7 @@ static Factory<Burr> RegisteredFactory("Burr");
 
 /* Default constructor */
 Burr::Burr()
-  : NonEllipticalDistribution("Burr")
+  : ContinuousDistribution("Burr")
   , c_(1.0)
   , k_(1.0)
 {
@@ -46,7 +46,7 @@ Burr::Burr()
 /* Parameters constructor */
 Burr::Burr(const NumericalScalar c,
            const NumericalScalar k)
-  : NonEllipticalDistribution("Burr")
+  : ContinuousDistribution("Burr")
   , c_(c)
   , k_(0.)
 {
@@ -144,7 +144,7 @@ NumericalScalar Burr::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar x(point[0]);
-  if (x < 0.0) return 0.0;
+  if (x <= 0.0) return 0.0;
   return -expm1(-k_ * log1p(exp(c_ * log(x))));
 }
 
@@ -180,8 +180,7 @@ NumericalPoint Burr::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Burr::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return exp(log(expm1(-log(prob) / k_)) / c_);
   return exp(log(expm1(-log1p(-prob) / k_)) / c_);
@@ -293,7 +292,7 @@ NumericalScalar Burr::getK() const
 /* Method save() stores the object through the StorageManager */
 void Burr::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "c_", c_ );
   adv.saveAttribute( "k_", k_ );
 }
@@ -301,7 +300,7 @@ void Burr::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Burr::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "c_", c_ );
   adv.loadAttribute( "k_", k_ );
   computeRange();
