@@ -3,7 +3,7 @@
  *  @file  BurrFactory.cxx
  *  @brief Factory for Burr distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -133,7 +133,9 @@ Burr BurrFactory::buildAsBurr(const NumericalSample & sample) const
   NumericalScalar sumLogXC(0.0);
   for (UnsignedLong i = 0; i < size; ++i) sumLogXC += log1p(pow(sample[i][0], c));
   const NumericalScalar k(size / sumLogXC);
-  return Burr(c, k);
+  Burr result(c, k);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Burr BurrFactory::buildAsBurr(const NumericalPointWithDescriptionCollection & parameters) const
