@@ -3,7 +3,7 @@
  *  @file  Chi.cxx
  *  @brief The Chi distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ static Factory<Chi> RegisteredFactory("Chi");
 
 /* Default constructor */
 Chi::Chi()
-  : NonEllipticalDistribution("Chi")
+  : ContinuousDistribution("Chi")
   , nu_(0.0)
   , normalizationFactor_(0.0)
 {
@@ -48,7 +48,7 @@ Chi::Chi()
 
 /* Parameters constructor */
 Chi::Chi(const NumericalScalar nu)
-  : NonEllipticalDistribution("Chi")
+  : ContinuousDistribution("Chi")
   , nu_(0.0)
   , normalizationFactor_(0.0)
 {
@@ -219,15 +219,14 @@ NumericalPoint Chi::computeCDFGradient(const NumericalPoint & point) const
   NumericalPoint cdfGradient(1, 0.0);
   const NumericalScalar x(point[0]);
   if (x <= 0.0) return cdfGradient;
-  NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
   cdfGradient[0] = (DistFunc::pGamma(0.5 * (nu_ + eps), 0.5 * x * x) - DistFunc::pGamma(0.5 * (nu_ - eps), 0.5 * x * x)) / (2.0 * eps);
   return cdfGradient;
 }
 
 /* Get the quantile of the distribution */
 NumericalScalar Chi::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return M_SQRT2 * sqrt(DistFunc::qGamma(0.5 * nu_, prob, tail));
 }
@@ -297,7 +296,7 @@ void Chi::setParametersCollection(const NumericalPointCollection & parametersCol
 /* Method save() stores the object through the StorageManager */
 void Chi::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "nu_", nu_ );
   adv.saveAttribute( "normalizationFactor_", normalizationFactor_ );
 }
@@ -305,7 +304,7 @@ void Chi::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Chi::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "nu_", nu_ );
   adv.loadAttribute( "normalizationFactor_", normalizationFactor_ );
   update();
