@@ -3,7 +3,7 @@
  *  @file  ChiFactory.cxx
  *  @brief Factory for Chi distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -70,7 +70,9 @@ Chi ChiFactory::buildAsChi(const NumericalSample & sample) const
   }
   try
   {
-    return Chi( sumSquares / size );
+    Chi result(sumSquares / size);
+    result.setDescription(sample.getDescription());
+    return result;
   }
   catch (InvalidArgumentException & ex)
   {
