@@ -3,7 +3,7 @@
  *  @file  ChiSquare.cxx
  *  @brief The ChiSquare distribution, ie the Gamma(nu/2,1/2) distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ static Factory<ChiSquare> RegisteredFactory("ChiSquare");
 
 /* Default constructor */
 ChiSquare::ChiSquare()
-  : NonEllipticalDistribution("ChiSquare")
+  : ContinuousDistribution("ChiSquare")
   , nu_(0.0)
   , normalizationFactor_(0.0)
 {
@@ -49,7 +49,7 @@ ChiSquare::ChiSquare()
 
 /* Parameters constructor */
 ChiSquare::ChiSquare(const NumericalScalar nu)
-  : NonEllipticalDistribution("ChiSquare")
+  : ContinuousDistribution("ChiSquare")
   , nu_(0.0)
   , normalizationFactor_(0.0)
 {
@@ -68,7 +68,7 @@ Bool ChiSquare::operator ==(const ChiSquare & other) const
 /* String converter */
 String ChiSquare::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ChiSquare::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -78,7 +78,7 @@ String ChiSquare::__repr__() const
 
 String ChiSquare::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(nu = " << nu_ << ")";
   return oss;
 }
@@ -212,15 +212,14 @@ NumericalPoint ChiSquare::computeCDFGradient(const NumericalPoint & point) const
   NumericalPoint cdfGradient(1, 0.0);
   const NumericalScalar x(point[0]);
   if (x <= 0.0) return cdfGradient;
-  NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
   cdfGradient[0] = (DistFunc::pGamma(0.5 * (nu_ + eps), 0.5 * x) - DistFunc::pGamma(0.5 * (nu_ - eps), 0.5 * x)) / (2.0 * eps);
   return cdfGradient;
 }
 
 /* Get the quantile of the distribution */
 NumericalScalar ChiSquare::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return 2.0 * DistFunc::qGamma(0.5 * nu_, prob, tail);
 }
@@ -286,7 +285,7 @@ void ChiSquare::setParametersCollection(const NumericalPointCollection & paramet
 /* Method save() stores the object through the StorageManager */
 void ChiSquare::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "nu_", nu_ );
   adv.saveAttribute( "normalizationFactor_", normalizationFactor_ );
 }
@@ -294,7 +293,7 @@ void ChiSquare::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void ChiSquare::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "nu_", nu_ );
   adv.loadAttribute( "normalizationFactor_", normalizationFactor_ );
   computeRange();
