@@ -3,7 +3,7 @@
  *  @file  ChiSquareFactory.cxx
  *  @brief Factory for ChiSquare distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,7 +63,9 @@ ChiSquare ChiSquareFactory::buildAsChiSquare(const NumericalSample & sample) con
   if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a ChiSquare distribution from an empty sample";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a ChiSquare distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
   const NumericalScalar mean(sample.computeMean()[0]);
-  return ChiSquare(mean);
+  ChiSquare result(mean);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 ChiSquare ChiSquareFactory::buildAsChiSquare(const NumericalPointWithDescriptionCollection & parameters) const
