@@ -3,7 +3,7 @@
  *  @file  ClaytonCopula.cxx
  *  @brief The ClaytonCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -48,6 +48,7 @@ ClaytonCopula::ClaytonCopula(const NumericalScalar theta)
 {
   // We set the dimension of the ClaytonCopula distribution
   setDimension( 2 );
+  computeRange();
 }
 
 /* Comparison operator */
@@ -60,7 +61,7 @@ Bool ClaytonCopula::operator ==(const ClaytonCopula & other) const
 /* String converter */
 String ClaytonCopula::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ClaytonCopula::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -70,7 +71,7 @@ String ClaytonCopula::__repr__() const
 
 String ClaytonCopula::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(theta = " << theta_ << ")";
   return oss;
 }
@@ -164,6 +165,22 @@ NumericalScalar ClaytonCopula::computeCDF(const NumericalPoint & point) const
   return pow(pow(u, -theta_) + pow(v, -theta_) - 1.0, -1.0 / theta_);
 }
 
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix ClaytonCopula::getSpearmanCorrelation() const
+{
+  return CopulaImplementation::getSpearmanCorrelation();
+  CorrelationMatrix rho(2);
+  return rho;
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix ClaytonCopula::getKendallTau() const
+{
+  CorrelationMatrix tau(2);
+  tau(0, 1) = theta_ / (theta_ + 2.0);
+  return tau;
+}
+
 /* Get the PDFGradient of the distribution */
 NumericalPoint ClaytonCopula::computePDFGradient(const NumericalPoint & point) const
 {
@@ -345,6 +362,7 @@ void ClaytonCopula::load(Advocate & adv)
 {
   ArchimedeanCopula::load(adv);
   adv.loadAttribute( "theta_", theta_ );
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
