@@ -3,7 +3,7 @@
  *  @file  ClaytonCopulaFactory.cxx
  *  @brief Factory for ClaytonCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,9 @@ ClaytonCopula ClaytonCopulaFactory::buildAsClaytonCopula(const NumericalSample &
   if (sample.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: cannot build a ClaytonCopula distribution from a sample of dimension not equal to 2";
   NumericalScalar tau(sample.computeKendallTau().operator()(0, 1));
   if (tau == 1) throw InvalidArgumentException(HERE) << "Error: cannot build a ClaytonCopula distribution from a sample with Kendall tau equals to 1";
-  return ClaytonCopula(2.0 * tau / (1.0 - tau));
+  ClaytonCopula result(2.0 * tau / (1.0 - tau));
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 ClaytonCopula ClaytonCopulaFactory::buildAsClaytonCopula(const NumericalPointWithDescriptionCollection & parameters) const
