@@ -3,7 +3,7 @@
  *  @file  ComposedCopula.cxx
  *  @brief Abstract top-level class for all ComposedCopulas
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,6 +42,8 @@ static Factory<ComposedCopula> RegisteredFactory("ComposedCopula");
 /* Default constructor */
 ComposedCopula::ComposedCopula()
   : CopulaImplementation("ComposedCopula")
+  , copulaCollection_(0)
+  , isIndependent_(false)
 {
   setDimension(1);
   CopulaCollection coll(1);
@@ -53,6 +55,7 @@ ComposedCopula::ComposedCopula()
 ComposedCopula::ComposedCopula(const CopulaCollection & coll)
   : CopulaImplementation("ComposedCopula")
   , copulaCollection_()
+  , isIndependent_(false)
 {
   // We assign the copula collection through the accessor in order to compute the composed copula dimension
   setCopulaCollection(coll);
@@ -68,7 +71,7 @@ Bool ComposedCopula::operator ==(const ComposedCopula & other) const
 /* String converter */
 String ComposedCopula::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ComposedCopula::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension();
@@ -79,20 +82,18 @@ String ComposedCopula::__repr__() const
 
 String ComposedCopula::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(";
   String separator("");
   for (UnsignedLong i = 0; i < copulaCollection_.getSize(); ++i)
   {
-    oss << separator << copulaCollection_[i].__str__();
+    oss << separator << copulaCollection_[i];
     separator = ", ";
   }
   oss << ")";
   return oss;
 }
 
-
-
 /* Distribution collection accessor */
 void ComposedCopula::setCopulaCollection(const CopulaCollection & coll)
 {
@@ -102,21 +103,21 @@ void ComposedCopula::setCopulaCollection(const CopulaCollection & coll)
   copulaCollection_ = coll;
   Description description(0);
   UnsignedLong dimension(0);
-  // Compute the dimension and build the description
+  // Compute the dimension, build the description and check the independence
+  isIndependent_ = true;
   for (UnsignedLong i = 0; i < size; ++i)
   {
     const UnsignedLong copulaDimension(coll[i].getDimension());
     dimension += copulaDimension;
     const Description copulaDescription(coll[i].getDescription());
-    for (UnsignedLong j = 0; j < copulaDimension; ++j)
-    {
-      description.add(copulaDescription[j]);
-    }
+    for (UnsignedLong j = 0; j < copulaDimension; ++j) description.add(copulaDescription[j]);
+    isIndependent_ = isIndependent_ && copulaCollection_[i].hasIndependentCopula();
   }
   isAlreadyComputedCovariance_ = false;
   // One MUST set the dimension BEFORE the description, else an error occurs
   setDimension(dimension);
   setDescription(description);
+  computeRange();
 }
 
 
@@ -283,6 +284,44 @@ NumericalScalar ComposedCopula::computeProbability(const Interval & interval) co
   return value;
 }
 
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix ComposedCopula::getSpearmanCorrelation() const
+{
+  const UnsignedLong dimension(getDimension());
+  CorrelationMatrix rho(dimension);
+  const UnsignedLong size(copulaCollection_.getSize());
+  UnsignedLong globalIndex(0);
+  for (UnsignedLong n = 0; n < size; ++n)
+  {
+    const CorrelationMatrix localRho(copulaCollection_[n].getSpearmanCorrelation());
+    const UnsignedLong localSize(localRho.getDimension());
+    for (UnsignedLong i = 0; i < localSize; ++i)
+      for (UnsignedLong j = 0; j < i; ++j)
+        rho(globalIndex + i, globalIndex + j) = localRho(i, j);
+    globalIndex += localSize;
+  }
+  return rho;
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix ComposedCopula::getKendallTau() const
+{
+  const UnsignedLong dimension(getDimension());
+  CorrelationMatrix tau(dimension);
+  const UnsignedLong size(copulaCollection_.getSize());
+  UnsignedLong globalIndex(0);
+  for (UnsignedLong n = 0; n < size; ++n)
+  {
+    const CorrelationMatrix localTau(copulaCollection_[n].getKendallTau());
+    const UnsignedLong localSize(localTau.getDimension());
+    for (UnsignedLong i = 0; i < localSize; ++i)
+      for (UnsignedLong j = 0; j < i; ++j)
+        tau(globalIndex + i, globalIndex + j) = localTau(i, j);
+    globalIndex += localSize;
+  }
+  return tau;
+}
+
 /* Get the PDF gradient of the distribution */
 NumericalPoint ComposedCopula::computePDFGradient(const NumericalPoint & point) const
 {
@@ -307,7 +346,7 @@ NumericalScalar ComposedCopula::computeConditionalPDF(const NumericalScalar x, c
   const UnsignedLong conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
-  if ((conditioningDimension == 0) || (hasIndependentCopula())) return Distribution(getMarginal(conditioningDimension)).computePDF(x);
+  if ((conditioningDimension == 0) || (hasIndependentCopula())) return (x < 0.0 ? 0.0 : x > 1.0 ? 0.0 : 1);
   // General case
   UnsignedLong copulaIndex(0);
   UnsignedLong partialDimension(copulaCollection_[copulaIndex].getDimension());
@@ -319,10 +358,7 @@ NumericalScalar ComposedCopula::computeConditionalPDF(const NumericalScalar x, c
   // Extract the relevant part of the conditioning
   const UnsignedLong conditioningSize(partialDimension - conditioningDimension);
   NumericalPoint conditioningVector(conditioningSize);
-  for (UnsignedLong i = 0; i < conditioningSize; ++i)
-  {
-    conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
-  }
+  for (UnsignedLong i = 0; i < conditioningSize; ++i) conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
   return copulaCollection_[copulaIndex].computeConditionalPDF(x, conditioningVector);
 }
 
@@ -332,7 +368,7 @@ NumericalScalar ComposedCopula::computeConditionalCDF(const NumericalScalar x, c
   const UnsignedLong conditioningDimension(y.getDimension());
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional PDF with a conditioning point of dimension greater or equal to the distribution dimension.";
   // Special case for no conditioning or independent copula
-  if ((conditioningDimension == 0) || (hasIndependentCopula())) return Distribution(getMarginal(conditioningDimension)).computeCDF(x);
+  if ((conditioningDimension == 0) || (hasIndependentCopula())) return std::min(1.0, std::max(0.0, x));
   // General case
   UnsignedLong copulaIndex(0);
   UnsignedLong partialDimension(copulaCollection_[copulaIndex].getDimension());
@@ -344,10 +380,7 @@ NumericalScalar ComposedCopula::computeConditionalCDF(const NumericalScalar x, c
   // Extract the relevant part of the conditioning
   const UnsignedLong conditioningSize(partialDimension - conditioningDimension);
   NumericalPoint conditioningVector(conditioningSize);
-  for (UnsignedLong i = 0; i < conditioningSize; ++i)
-  {
-    conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
-  }
+  for (UnsignedLong i = 0; i < conditioningSize; ++i) conditioningVector[i] = y[conditioningDimension - conditioningSize + i];
   return copulaCollection_[copulaIndex].computeConditionalCDF(x, conditioningVector);
 }
 
@@ -488,20 +521,13 @@ void ComposedCopula::setParametersCollection(const NumericalPointCollection & pa
 /* Tell if the distribution has elliptical copula */
 Bool ComposedCopula::hasEllipticalCopula() const
 {
-  return hasIndependentCopula();
+  return isIndependent_;
 }
 
 /* Tell if the distribution has independent copula */
 Bool ComposedCopula::hasIndependentCopula() const
 {
-  const UnsignedLong size(copulaCollection_.getSize());
-  for (UnsignedLong i = 0; i < size; ++i)
-  {
-    // As soon as one of the elementary copula is not the independent one, the composed copula
-    // is not the independent one
-    if (!copulaCollection_[i].getImplementation()->hasIndependentCopula()) return false;
-  }
-  return true;
+  return isIndependent_;
 }
 
 /* Method save() stores the object through the StorageManager */
@@ -516,6 +542,7 @@ void ComposedCopula::load(Advocate & adv)
 {
   CopulaImplementation::load(adv);
   adv.loadAttribute( "copulaCollection_", copulaCollection_ );
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
