@@ -3,7 +3,7 @@
  *  @file  ComposedDistribution.cxx
  *  @brief Abstract top-level class for all ComposedDistributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,12 @@
 #include "MarginalTransformationEvaluation.hxx"
 #include "MarginalTransformationGradient.hxx"
 #include "MarginalTransformationHessian.hxx"
+#include "NatafEllipticalDistributionEvaluation.hxx"
+#include "NatafEllipticalDistributionGradient.hxx"
+#include "NatafEllipticalDistributionHessian.hxx"
+#include "InverseNatafEllipticalDistributionEvaluation.hxx"
+#include "InverseNatafEllipticalDistributionGradient.hxx"
+#include "InverseNatafEllipticalDistributionHessian.hxx"
 #include "LinearNumericalMathFunction.hxx"
 #include "Indices.hxx"
 #include "PersistentObjectFactory.hxx"
@@ -35,6 +41,7 @@
 #include "IndependentCopula.hxx"
 #include "NormalCopula.hxx"
 #include "Log.hxx"
+#include "TBB.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -72,11 +79,12 @@ ComposedDistribution::ComposedDistribution(const DistributionCollection & coll)
 
 /* Default constructor */
 ComposedDistribution::ComposedDistribution(const DistributionCollection & coll,
-    const Copula & copula)
+    const Distribution & copula)
   : DistributionImplementation("ComposedDistribution")
   , distributionCollection_()
   , copula_(copula)
 {
+  if (!copula.isCopula()) throw InvalidArgumentException(HERE) << "Error: the given distribution=" << copula << " is not a copula.";
   setDimension(copula.getDimension());
   // We can NOT set distributionCollection_ in the member area of the constructor
   // because we must check before if the collection is valid (ie, if all the
@@ -170,7 +178,7 @@ const ComposedDistribution::DistributionCollection & ComposedDistribution::getDi
 
 
 /* Copula accessor */
-void ComposedDistribution::setCopula(const Copula & copula)
+void ComposedDistribution::setCopula(const Distribution & copula)
 {
   // We check if the copula has a dimension compatible with the one of the object,
   // especially if the object has already been created and has a collection of distribution
@@ -214,11 +222,48 @@ NumericalPoint ComposedDistribution::getRealization() const
     return result;
   }
   // General case
-  NumericalPoint realization(copula_.getRealization());
+  const NumericalPoint realization(copula_.getRealization());
   for (UnsignedLong i = 0; i < dimension; ++i) result[i] = distributionCollection_[i].computeQuantile(realization[i])[0];
   return result;
 }
 
+/* Get a sample of the distribution */
+NumericalSample ComposedDistribution::getSampleParallel(const UnsignedLong size) const
+{
+  const UnsignedLong dimension(getDimension());
+  // For 1D or independent components, we can only rely on possible parallel
+  // implementation of getSample() methods of the marginal distributions
+  if (dimension == 1) return distributionCollection_[0].getSample(size);
+  // Special case for independent copula
+  if (hasIndependentCopula())
+  {
+    NumericalSample result(size, dimension);
+    for (UnsignedLong i = 0; i < dimension; ++i)
+    {
+      const NumericalSample marginalSample(distributionCollection_[i].getSample(size));
+      for (UnsignedLong j = 0; j < size; ++j) result[j][i] = marginalSample[j][0];
+    }
+    result.setName(getName());
+    result.setDescription(getDescription());
+    return result;
+  }
+  // For dependent components, we can use some parallelism on top
+  // of possible parallelism of the getSample() method of the copula
+  const NumericalSample copulaSample(copula_.getSample(size));
+  NumericalSample result(size, dimension);
+  const ComposedDistribution::ComputeSamplePolicy policy( copulaSample, result, distributionCollection_ );
+  TBB::ParallelFor( 0, size, policy );
+  result.setName(getName());
+  result.setDescription(getDescription());
+  return result;
+}
+
+NumericalSample ComposedDistribution::getSample(const UnsignedLong size) const
+{
+  if (isParallel_) return getSampleParallel(size);
+  return DistributionImplementation::getSample(size);
+}
+
 /* Get the DDF of the ComposedDistribution */
 NumericalPoint ComposedDistribution::computeDDF(const NumericalPoint & point) const
 {
@@ -301,6 +346,26 @@ NumericalScalar ComposedDistribution::computeCDF(const NumericalPoint & point) c
   return copula_.computeCDF(uPoint);
 }
 
+NumericalScalar ComposedDistribution::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  /* Survival = copula_survival(dist1_survival(p1), ..., distn_survival(pn)) */
+  const UnsignedLong dimension(getDimension());
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
+
+  if (dimension == 1) return distributionCollection_[0].computeSurvivalFunction(point);
+  // Special case for the independent case, to boost performances
+  if (hasIndependentCopula())
+  {
+    NumericalScalar productSurvival(1.0);
+    for (UnsignedLong i = 0; i < dimension; ++i) productSurvival *= distributionCollection_[i].computeSurvivalFunction(point[i]);
+    return productSurvival;
+  }
+  // General case
+  NumericalPoint uPoint(dimension);
+  for (UnsignedLong i = 0; i < dimension; ++i) uPoint[i] = distributionCollection_[i].computeSurvivalFunction(point[i]);
+  return copula_.computeSurvivalFunction(uPoint);
+}
+
 /* Compute the probability content of an interval */
 NumericalScalar ComposedDistribution::computeProbability(const Interval & interval) const
 {
@@ -461,6 +526,15 @@ void ComposedDistribution::computeCovariance() const
   // Off-diagonal terms if the copula is not the independent copula
   if (!hasIndependentCopula())
   {
+    // Special case: elliptical distribution. The covariance is the shape matrix of the associated copula, scaled by the marginal standard deviations
+    if (isElliptical())
+    {
+      const CovarianceMatrix shape(copula_.getShapeMatrix());
+      for (UnsignedLong rowIndex = 0; rowIndex < dimension; ++rowIndex)
+        for (UnsignedLong columnIndex = rowIndex + 1; columnIndex < dimension; ++columnIndex)
+          covariance_(rowIndex, columnIndex) = shape(rowIndex, columnIndex) * sigma[rowIndex] * sigma[columnIndex];
+      return;
+    }
     // To ensure that the mean is up to date
     mean_ = getMean();
     // Compute the weights and nodes of the 1D gauss quadrature over [-1, 1]
@@ -547,7 +621,9 @@ NumericalPoint ComposedDistribution::getKurtosis() const
 ComposedDistribution::Implementation ComposedDistribution::getMarginal(const UnsignedLong i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
-  return distributionCollection_[i].getImplementation()->clone();
+  Distribution marginal(distributionCollection_[i]);
+  marginal.setDescription(Description(1, getDescription()[i]));
+  return marginal.getImplementation()->clone();
 }
 
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
@@ -557,11 +633,20 @@ ComposedDistribution::Implementation ComposedDistribution::getMarginal(const Ind
   const Copula marginalCopula(copula_.getMarginal(indices));
   DistributionCollection marginalDistributions(0);
   const UnsignedLong size(indices.getSize());
-  for (UnsignedLong i = 0; i < size; ++i) marginalDistributions.add(distributionCollection_[indices[i]]);
-  return new ComposedDistribution(marginalDistributions, marginalCopula);
+  const Description description(getDescription());
+  Description marginalDescription(size);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    const UnsignedLong j(indices[i]);
+    marginalDistributions.add(distributionCollection_[j]);
+    marginalDescription[i] = description[j];
+  }
+  ComposedDistribution marginal(marginalDistributions, marginalCopula);
+  marginal.setDescription(marginalDescription);
+  return marginal.clone();
 }
 
-/* Get the isoprobabilist transformation */
+/* Get the isoprobabilistic transformation */
 ComposedDistribution::IsoProbabilisticTransformation ComposedDistribution::getIsoProbabilisticTransformation() const
 {
   const UnsignedLong dimension(getDimension());
@@ -595,21 +680,35 @@ ComposedDistribution::IsoProbabilisticTransformation ComposedDistribution::getIs
     marginalTransformation.setParameters(parameters);
     return marginalTransformation;
   }
-  // // Special case for the elliptical copula case: generalized Nataf transformation (marginal transformations plus linear transformation)
-  // if (XXX)
-  //   {
-  //     // Standard distribution
-  //     Distribution standardDistribution(getStandardDistribution());
-  //     // Get the evaluation implementations
-  //     MarginalTransformationEvaluation evaluation(distributionCollection_, DistributionCollection(dimension, standardDistribution.getMarginal(0)));
-  //     // We have to correct the direction because the output collection corresponds to the standard space, so there is no parameter to take into account for these distributions
-  //     evaluation.setDirection(MarginalTransformationEvaluation::FROM);
-  //     IsoProbabilisticTransformation marginalTransformation(evaluation.clone(), new MarginalTransformationGradient(evaluation), new MarginalTransformationHessian(evaluation));
-  //     marginalTransformation.setParameters(parameters);
-  //     // Suppress the correlation between the components.
-  //     LinearNumericalMathFunction linear(NumericalPoint(dimension, 0.0), NumericalPoint(dimension, 0.0), standardDistribution.getInverseCholesky());
-  //     return IsoProbabilisticTransformation(linear, marginalTransformation);
-  //   }
+  // Special case for the elliptical distribution case: linear transformation
+  if (isElliptical())
+  {
+    const SquareMatrix inverseCholesky(getInverseCholesky());
+    const NumericalPoint mean(getMean());
+    IsoProbabilisticTransformation transform;
+    transform.setEvaluationImplementation(new NatafEllipticalDistributionEvaluation(mean, inverseCholesky));
+    transform.setGradientImplementation(new NatafEllipticalDistributionGradient(inverseCholesky));
+    transform.setHessianImplementation(new NatafEllipticalDistributionHessian(dimension));
+    transform.setParameters(parameters);
+    return transform;
+  }
+  // Special case for the elliptical copula case: generalized Nataf transformation (marginal transformations plus linear transformation)
+  if (hasEllipticalCopula())
+  {
+    // Standard distribution
+    const Distribution standardDistribution(getStandardDistribution());
+    // Get the evaluation implementations
+    const Distribution standardMarginal(standardDistribution.getMarginal(0));
+    MarginalTransformationEvaluation evaluation(distributionCollection_, DistributionCollection(dimension, standardMarginal));
+    // We have to correct the direction because the output collection corresponds to the standard space, so there is no parameter to take into account for these distributions
+    evaluation.setDirection(MarginalTransformationEvaluation::FROM);
+    IsoProbabilisticTransformation marginalTransformation(evaluation.clone(), MarginalTransformationGradient(evaluation).clone(), MarginalTransformationHessian(evaluation).clone());
+    marginalTransformation.setParameters(parameters);
+    // Suppress the correlation between the components.
+    const SquareMatrix inverseCholesky(copula_.getShapeMatrix().computeCholesky().solveLinearSystem(IdentityMatrix(dimension)).getImplementation());
+    LinearNumericalMathFunction linear(NumericalPoint(dimension, 0.0), NumericalPoint(dimension, 0.0), inverseCholesky);
+    return IsoProbabilisticTransformation(linear, marginalTransformation);
+  }
   // General case: go to uniform marginal distributions using marginal transformations, then use the isoprobabilistic ransformation of the copula
   // Get the IsoProbabilisticTransformation from the copula
   const IsoProbabilisticTransformation copulaIsoprobabilisticTransformation(copula_.getIsoProbabilisticTransformation());
@@ -654,21 +753,36 @@ ComposedDistribution::InverseIsoProbabilisticTransformation ComposedDistribution
     marginalTransformation.setParameters(parameters);
     return marginalTransformation;
   }
-  // // Special case for the elliptical copula case: generalized Nataf inverse transformation (linear transformation to induce correlation then marginal transformations)
-  // if (hasEllipticalCopula())
-  //   {
-  //     // Standard distribution
-  //     Distribution standardDistribution(getStandardDistribution());
-  //     // Create the correlation between the components.
-  //     LinearNumericalMathFunction linear(NumericalPoint(dimension, 0.0), NumericalPoint(dimension, 0.0), standardDistribution.getCholesky());
-  //     // Get the evaluation implementations
-  //     MarginalTransformationEvaluation evaluation(DistributionCollection(dimension, standardDistribution.getMarginal(0)), distributionCollection_);
-  //     // We have to correct the direction because the output collection corresponds to the standard space, so there is no parameter to take into account for these distributions
-  //     evaluation.setDirection(MarginalTransformationEvaluation::TO);
-  //     InverseIsoProbabilisticTransformation marginalTransformation(evaluation.clone(), new MarginalTransformationGradient(evaluation), new MarginalTransformationHessian(evaluation));
-  //     marginalTransformation.setParameters(parameters);
-  //     return InverseIsoProbabilisticTransformation(marginalTransformation, linear);
-  //   }
+  // Special case for the elliptical distribution case: linear transformation
+  if (isElliptical())
+  {
+    const SquareMatrix inverseCholesky(getInverseCholesky());
+    const NumericalPoint mean(getMean());
+    InverseIsoProbabilisticTransformation inverseTransform;
+    inverseTransform.setEvaluationImplementation(new InverseNatafEllipticalDistributionEvaluation(mean, inverseCholesky));
+    inverseTransform.setGradientImplementation(new InverseNatafEllipticalDistributionGradient(inverseCholesky));
+    inverseTransform.setHessianImplementation(new InverseNatafEllipticalDistributionHessian(dimension));
+    inverseTransform.setParameters(parameters);
+    return inverseTransform;
+  }
+  // Special case for the elliptical copula case: generalized Nataf transformation (marginal transformations plus linear transformation)
+  if (hasEllipticalCopula())
+  {
+    // Standard distribution
+    const Distribution standardDistribution(getStandardDistribution());
+    // Get the evaluation implementations
+    const Distribution standardMarginal(standardDistribution.getMarginal(0));
+    MarginalTransformationEvaluation evaluation(DistributionCollection(dimension, standardMarginal), distributionCollection_);
+    // We have to correct the direction because the output collection corresponds to the standard space, so there is no parameter to take into account for these distributions
+    evaluation.setDirection(MarginalTransformationEvaluation::TO);
+    InverseIsoProbabilisticTransformation marginalTransformation(evaluation.clone(), new MarginalTransformationGradient(evaluation), new MarginalTransformationHessian(evaluation));
+    marginalTransformation.setParameters(parameters);
+    // Suppress the correlation between the components.
+    const SquareMatrix cholesky(copula_.getShapeMatrix().computeCholesky());
+    // const SquareMatrix cholesky(ComposedDistribution(DistributionCollection(dimension, standardMarginal), getCopula()).getCholesky());
+    LinearNumericalMathFunction linear(NumericalPoint(dimension, 0.0), NumericalPoint(dimension, 0.0), cholesky);
+    return InverseIsoProbabilisticTransformation(marginalTransformation, linear);
+  }
   // General case: go to the copula using its inverse isoprobabilistic transformation, then add the correct marginal distributions using marginal transformations
   // Get the InverseIsoProbabilisticTransformation from the copula
   const InverseIsoProbabilisticTransformation copulaInverseIsoprobabilisticTransformation(copula_.getInverseIsoProbabilisticTransformation());
@@ -697,6 +811,10 @@ ComposedDistribution::NumericalPointWithDescriptionCollection ComposedDistributi
     // Each marginal distribution must output a collection of parameters of size 1, even if it contains an empty NumericalPoint
     const NumericalPointWithDescriptionCollection marginalParameters(distributionCollection_[marginalIndex].getParametersCollection());
     NumericalPointWithDescription point(marginalParameters[0]);
+    Description marginalParametersDescription(point.getDescription());
+    // Here we must add a unique prefix to the marginal parameters description in order to deambiguate the parameters of different marginals sharing the same description
+    for (UnsignedLong i = 0; i < point.getDimension(); ++i) marginalParametersDescription[i] = (OSS() << marginalParametersDescription[i] << "_marginal_" << marginalIndex);
+    point.setDescription(marginalParametersDescription);
     point.setName(description[marginalIndex]);
     parameters[marginalIndex] = point;
   } // marginalIndex
@@ -704,6 +822,10 @@ ComposedDistribution::NumericalPointWithDescriptionCollection ComposedDistributi
   {
     // Second put the dependence parameters
     NumericalPointWithDescription point(copula_.getParametersCollection()[0]);
+    Description copulaParametersDescription(point.getDescription());
+    // Here we must add a unique prefix to the copula parameters description in order to deambiguate the parameters of marginals sharing the same description
+    for (UnsignedLong i = 0; i < point.getDimension(); ++i) copulaParametersDescription[i] = (OSS() << copulaParametersDescription[i] << "_copula");
+    point.setDescription(copulaParametersDescription);
     point.setName(copula_.getName());
     parameters[dimension] = point;
   } // dimension > 1
@@ -730,6 +852,12 @@ Bool ComposedDistribution::hasIndependentCopula() const
   return copula_.hasIndependentCopula();
 }
 
+/* Tell if the distribution has elliptical copula */
+Bool ComposedDistribution::hasEllipticalCopula() const
+{
+  return copula_.hasEllipticalCopula();
+}
+
 /* Check if the distribution is elliptical */
 Bool ComposedDistribution::isElliptical() const
 {
@@ -744,9 +872,35 @@ Bool ComposedDistribution::isElliptical() const
     const String currentMarginalKind(distributionCollection_[i].getImplementation()->getClassName());
     hasNormalMarginals = hasNormalMarginals && (currentMarginalKind == Normal::GetClassName());
   }
+  // For now, we are not smart enough to detect a fully general elliptical copula. The general
+  // way to do it is to compare the density generator of the marginals and the copula.
   return hasNormalCopula && hasNormalMarginals;
 }
 
+/* Check if the distribution is continuous */
+Bool ComposedDistribution::isContinuous() const
+{
+  const UnsignedLong dimension(getDimension());
+  for (UnsignedLong i = 0; i < dimension; ++i) if (!distributionCollection_[i].isContinuous()) return false;
+  return true;
+}
+
+/* Check if the distribution is discrete */
+Bool ComposedDistribution::isDiscrete() const
+{
+  const UnsignedLong dimension(getDimension());
+  for (UnsignedLong i = 0; i < dimension; ++i) if (!distributionCollection_[i].isDiscrete()) return false;
+  return true;
+}
+
+/* Tell if the distribution is integer valued */
+Bool ComposedDistribution::isIntegral() const
+{
+  const UnsignedLong dimension(getDimension());
+  for (UnsignedLong i = 0; i < dimension; ++i) if (!distributionCollection_[i].isIntegral()) return false;
+  return true;
+}
+
 /* Method save() stores the object through the StorageManager */
 void ComposedDistribution::save(Advocate & adv) const
 {
