@@ -3,7 +3,7 @@
  *  @file  ConditionalDistribution.cxx
  *  @brief The ConditionalDistribution distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -95,7 +95,7 @@ Bool ConditionalDistribution::operator ==(const ConditionalDistribution & other)
 /* String converter */
 String ConditionalDistribution::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ConditionalDistribution::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -106,7 +106,7 @@ String ConditionalDistribution::__repr__() const
 
 String ConditionalDistribution::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(X|Theta = " << conditionedDistribution_.getImplementation()->getClassName() << ", Theta = " << conditioningDistribution_.__str__() << ")";
   return oss;
 }
@@ -361,13 +361,11 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
     const NumericalPoint & thetaStar) const
 {
   const NumericalScalar epsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  // std::cerr << "in ConditionalDistribution::computeExpectation, thetaStar=" << thetaStar << std::endl;
   const UnsignedLong conditioningDimension(conditioningDistribution_.getDimension());
   if (f.getInputDimension() != conditioningDimension) throw InvalidArgumentException(HERE) << "Error: the given function must have an input dimension=" << f.getInputDimension() << " equal to the conditioning dimension=" << conditioningDimension;
   if (thetaStar.getDimension() != conditioningDimension) throw InvalidArgumentException(HERE) << "Error: the given upper bound must have a dimension=" << thetaStar.getDimension() << " equal to the conditioning dimension=" << conditioningDimension;
   const UnsignedLong outputDimension(f.getOutputDimension());
   NumericalPoint result(outputDimension);
-  // std::cerr << "result=" << result << std::endl;
   // Here, we reuse the analysis made in the underlying conditional distribution
   const UnsignedLong continuousDimension(continuousMarginalsIndices_.getSize());
   const UnsignedLong continuousAtomsNumber(continuousNodes_.getSize());
@@ -378,28 +376,23 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
   // Zeroth case: all Dirac
   if (diracDimension == conditioningDimension)
   {
-    // std::cerr << "all Dirac, values=" << diracValues_ << std::endl;
     for (UnsignedLong i = 0; i < diracDimension; ++i)
       if (diracValues_[i] > thetaStar[i] + epsilon) return result;
     result = f(diracValues_);
-    // std::cerr << "result=" << result << std::endl;
     return result;
   }
   // First case: no continuous marginal
   if (continuousDimension == 0)
   {
-    // std::cerr << "no continuous marginal" << std::endl;
     NumericalPoint theta(conditioningDimension);
     // First, the Dirac components. It can be either a Dirac distribution or a userDefined distribution, so we check the support directly
     for (UnsignedLong i = 0; i < diracDimension; ++i)
     {
       const NumericalScalar value(diracValues_[i]);
       // If the hyper rectangle does not intersect the manifold that supports the total mass, then value = 0
-      // std::cerr << "no continuous marginal" << std::endl;
       if (value > thetaStar[i] + epsilon) return result;
       theta[diracMarginalsIndices_[i]] = value;
     }
-    // std::cerr << "after Dirac, theta=" << theta << std::endl;
     // Second, the discrete components
     // For each combination of the discrete components
     for (UnsignedLong i = 0; i < discreteAtomsNumber; ++i)
@@ -412,16 +405,13 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
       {
         const NumericalScalar value(discreteNode[j]);
         currentTheta[discreteMarginalsIndices_[j]] = value;
-        // std::cerr << "currentTheta=" << currentTheta << std::endl;
         rejectNode = (value > thetaStar[i] + epsilon);
         if (rejectNode) break;
       }
       // Skip the current integration point if the current sub-manifold is outside of the integration region
       if (rejectNode) continue;
-      // std::cerr << "currentTheta=" << currentTheta << std::endl;
       const NumericalScalar w(conditioningDistribution_.computePDF(currentTheta));
       result += w * f(currentTheta);
-      // std::cerr << "w=" << w << ", result=" << result << std::endl;
     } // Discrete measure
     return result;
   } // No continuous marginal
@@ -429,12 +419,10 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
   // Second case: no discrete marginal
   if (discreteDimension == 0)
   {
-    // std::cerr << "no discrete marginal" << std::endl;
     // The current value of theta in the discretization
     NumericalPoint theta(conditioningDimension);
     // The sub point associated with the continuous components
     NumericalPoint subPoint(continuousDimension);
-    // std::cerr << "subPoint=" << subPoint << ", continuousUpperBounds_=" << continuousUpperBounds_ << ", thetaStar=" << thetaStar << ", continuousMarginalsIndices_=" << continuousMarginalsIndices_ << std::endl;
     for (UnsignedLong i = 0; i < continuousDimension; ++i)
       subPoint[i] = std::min(continuousUpperBounds_[i], thetaStar[continuousMarginalsIndices_[i]]);
     // First, the Dirac components
@@ -451,15 +439,11 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
       NumericalPoint currentTheta(theta);
       // Complete the filling of theta using the Gauss integration node
       const NumericalPoint continuousNode(continuousNodes_[i]);
-      // std::cerr << "continuousNode=" << continuousNode << std::endl;
       for (UnsignedLong j = 0; j < continuousDimension; ++j)
         currentTheta[continuousMarginalsIndices_[j]] = continuousLowerBounds_[j] + 0.5 * (1.0 + continuousNode[j]) * (subPoint[j] - continuousLowerBounds_[j]);
-      // std::cerr << "currentTheta=" << currentTheta << std::endl;
       // Current contribution to the CDF
       const NumericalScalar w(conditioningDistribution_.computePDF(currentTheta) * continuousWeights_[i]);
-      // std::cerr << "w=" << w << std::endl;
       const NumericalPoint fTheta(f(currentTheta));
-      // std::cerr << "fTheta=" << fTheta << std::endl;
       result += w * f(currentTheta);
     } // Continuous measure
     result *= Interval(continuousLowerBounds_, subPoint).getNumericalVolume();
@@ -467,7 +451,6 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
   } // No discrete marginal
 
   // Third case: continuous and discrete marginals
-  // std::cerr << "both continuous and discrete marginals" << std::endl;
   NumericalPoint theta(conditioningDimension);
   // The sub point associated with the continuous components
   NumericalPoint subPoint(continuousDimension);
@@ -503,16 +486,11 @@ NumericalPoint ConditionalDistribution::computeExpectation(const NumericalMathFu
     {
       // Complete the filling of theta using the Gauss integration node
       const NumericalPoint continuousNode(continuousNodes_[j]);
-      // std::cerr << "continuousNode=" << continuousNode << std::endl;
       for (UnsignedLong k = 0; k < continuousDimension; ++k)
         currentTheta[continuousMarginalsIndices_[k]] = continuousLowerBounds_[k] + 0.5 * (1.0 + continuousNode[k]) * (subPoint[k] - continuousLowerBounds_[k]);
-      // std::cerr << "currentTheta=" << currentTheta << std::endl;
       const NumericalScalar w(conditioningDistribution_.computePDF(currentTheta) * continuousWeights_[j]);
-      // std::cerr << "w=" << w << std::endl;
       const NumericalPoint fTheta(f(currentTheta));
-      // std::cerr << "fTheta=" << fTheta << std::endl;
       result += w * f(currentTheta);
-      // std::cerr << "result=" << result << std::endl;
     } // Continuous atoms
   } // Overall discretization
   result *= Interval(continuousLowerBounds_, subPoint).getNumericalVolume();
