@@ -3,7 +3,7 @@
  *  @file  Dirichlet.cxx
  *  @brief The Dirichlet distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,7 +40,7 @@ static Factory<Dirichlet> RegisteredFactory("Dirichlet");
 
 /* Default constructor */
 Dirichlet::Dirichlet()
-  : NonEllipticalDistribution("Dirichlet"),
+  : ContinuousDistribution("Dirichlet"),
     theta_(0),
     sumTheta_(0.0),
     normalizationFactor_(0.0),
@@ -53,7 +53,7 @@ Dirichlet::Dirichlet()
 
 /* Parameters constructor */
 Dirichlet::Dirichlet(const NumericalPoint & theta)
-  : NonEllipticalDistribution("Dirichlet"),
+  : ContinuousDistribution("Dirichlet"),
     theta_(0),
     sumTheta_(0.0),
     normalizationFactor_(0.0),
@@ -74,7 +74,7 @@ Bool Dirichlet::operator ==(const Dirichlet & other) const
 /* String converter */
 String Dirichlet::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Dirichlet::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -84,7 +84,7 @@ String Dirichlet::__repr__() const
 
 String Dirichlet::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(theta = " << theta_.__str__() << ")";
   return oss;
 }
@@ -161,7 +161,12 @@ NumericalScalar Dirichlet::computeCDF(const NumericalPoint & point) const
   const UnsignedLong dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
-  if (dimension == 1) return DistFunc::pBeta(theta_[0], theta_[1], point[0]);
+  if (dimension == 1)
+  {
+    if (point[0] <= 0.0) return 0.0;
+    if (point[0] >= 1.0) return 1.0;
+    return DistFunc::pBeta(theta_[0], theta_[1], point[0]);
+  }
   // First, the trivial cases
   Bool oneNegative(false);
   Bool allPositive(true);
@@ -280,20 +285,9 @@ NumericalScalar Dirichlet::computeCDF(const NumericalPoint & point) const
   return NumericalScalar(successNumber) / samplingSize;
 }
 
-NumericalScalar Dirichlet::computeComplementaryCDF(const NumericalPoint & point) const
-{
-  const UnsignedLong dimension(getDimension());
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-
-  if (dimension == 1) return DistFunc::pBeta(theta_[0], theta_[1], point[0], true);
-  // other cases do not depend on tail flag
-  return computeCDF(point);
-}
-
 /* Get the quantile of the distribution */
 NumericalScalar Dirichlet::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return DistFunc::qBeta(theta_[0], theta_[1], prob, tail);
 }
@@ -515,7 +509,7 @@ void Dirichlet::setParametersCollection(const NumericalPointCollection & paramet
 /* Method save() stores the object through the StorageManager */
 void Dirichlet::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "theta_", theta_ );
   adv.saveAttribute( "sumTheta_", sumTheta_ );
   adv.saveAttribute( "normalizationFactor_", normalizationFactor_ );
@@ -524,7 +518,7 @@ void Dirichlet::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Dirichlet::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "theta_", theta_ );
   adv.loadAttribute( "sumTheta_", sumTheta_ );
   adv.loadAttribute( "normalizationFactor_", normalizationFactor_ );
