@@ -3,7 +3,7 @@
  *  @file  DirichletFactory.cxx
  *  @brief Factory for Dirichlet distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -154,7 +154,9 @@ Dirichlet DirichletFactory::buildAsDirichlet(const NumericalSample & sample) con
     }
     convergence = (delta < dimension * ResourceMap::GetAsNumericalScalar( "DirichletFactory-ParametersEpsilon" ));
   }
-  return Dirichlet(theta);
+  Dirichlet result(theta);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Dirichlet DirichletFactory::buildAsDirichlet(const NumericalPointWithDescriptionCollection & parameters) const
