@@ -3,7 +3,7 @@
  *  @file  Epanechnikov.cxx
  *  @brief The Epanechnikov distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ static Factory<Epanechnikov> RegisteredFactory("Epanechnikov");
 
 /* Default constructor */
 Epanechnikov::Epanechnikov()
-  : NonEllipticalDistribution("Epanechnikov")
+  : ContinuousDistribution("Epanechnikov")
 {
   setDimension(1);
   setRange(Interval(-1.0, 1.0));
@@ -52,7 +52,7 @@ Bool Epanechnikov::operator ==(const Epanechnikov & other) const
 /* String converter */
 String Epanechnikov::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Epanechnikov::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension();
@@ -61,7 +61,7 @@ String Epanechnikov::__repr__() const
 
 String Epanechnikov::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "()";
   return oss;
 }
@@ -101,7 +101,7 @@ NumericalScalar Epanechnikov::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= -1.0) return 0.0;
-  if (x > 1.0) return 1.0;
+  if (x >= 1.0) return 1.0;
   return 0.5 + x * (0.75 - 0.25 * x * x);
 }
 
@@ -133,8 +133,7 @@ NumericalPoint Epanechnikov::computeCDFGradient(const NumericalPoint & point) co
 
 /* Get the quantile of the distribution */
 NumericalScalar Epanechnikov::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   // 2.094395102393195492308429 = 2 * Pi / 3
   if (tail) return 2.0 * cos(0.3333333333333333333333333 * acos(2.0 * prob - 1.0) - 2.094395102393195492308429);
@@ -199,13 +198,13 @@ Epanechnikov::NumericalPointWithDescriptionCollection Epanechnikov::getParameter
 /* Method save() stores the object through the StorageManager */
 void Epanechnikov::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
 }
 
 /* Method load() reloads the object from the StorageManager */
 void Epanechnikov::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
 }
 
 END_NAMESPACE_OPENTURNS
