@@ -3,7 +3,7 @@
  *  @file  Exponential.cxx
  *  @brief The Exponential distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,7 +35,7 @@ static Factory<Exponential> RegisteredFactory("Exponential");
 
 /* Default constructor */
 Exponential::Exponential()
-  : NonEllipticalDistribution("Exponential"),
+  : ContinuousDistribution("Exponential"),
     lambda_(1.0),
     gamma_(0.0)
 {
@@ -46,7 +46,7 @@ Exponential::Exponential()
 /* Parameters constructor */
 Exponential::Exponential(const NumericalScalar lambda,
                          const NumericalScalar gamma)
-  : NonEllipticalDistribution("Exponential"),
+  : ContinuousDistribution("Exponential"),
     lambda_(0.0),
     gamma_(gamma)
 {
@@ -66,7 +66,7 @@ Bool Exponential::operator ==(const Exponential & other) const
 /* String converter */
 String Exponential::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Exponential::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -77,7 +77,7 @@ String Exponential::__repr__() const
 
 String Exponential::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(lambda = " << lambda_ << ", gamma = " << gamma_ << ")";
   return oss;
 }
@@ -130,8 +130,18 @@ NumericalScalar Exponential::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar x(point[0] - gamma_);
-  if (x < 0.0) return 0.0;
-  return 1.0 - exp(-lambda_ * x);
+  if (x <= 0.0) return 0.0;
+  return -expm1(-lambda_ * x);
+}
+
+/* Get the complementary CDF of the distribution */
+NumericalScalar Exponential::computeComplementaryCDF(const NumericalPoint & point) const
+{
+  if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
+
+  const NumericalScalar x(point[0] - gamma_);
+  if (x < 0.0) return 1.0;
+  return exp(-lambda_ * x);
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
@@ -175,8 +185,7 @@ NumericalPoint Exponential::computeCDFGradient(const NumericalPoint & point) con
 
 /* Get the quantile of the distribution */
 NumericalScalar Exponential::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return gamma_ - log(prob) / lambda_;
   return gamma_ - log1p(-prob) / lambda_;
@@ -295,7 +304,7 @@ void Exponential::computeRange()
 /* Method save() stores the object through the StorageManager */
 void Exponential::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "lambda_", lambda_ );
   adv.saveAttribute( "gamma_", gamma_ );
 }
@@ -303,7 +312,7 @@ void Exponential::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Exponential::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "lambda_", lambda_ );
   adv.loadAttribute( "gamma_", gamma_ );
   computeRange();
