@@ -3,7 +3,7 @@
  *  @file  ExponentialFactory.cxx
  *  @brief Factory for Exponential distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -67,7 +67,9 @@ Exponential ExponentialFactory::buildAsExponential(const NumericalSample & sampl
   const NumericalScalar mean(sample.computeMean()[0]);
   if (mean == gamma) throw InvalidArgumentException(HERE) << "Error: can build an Exponential distribution only from a sample with mean > min, here mean=" << mean << " and min=" << gamma;
   const NumericalScalar lambda(1.0 / (mean - gamma));
-  return Exponential(lambda, gamma);
+  Exponential result(lambda, gamma);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Exponential ExponentialFactory::buildAsExponential(const NumericalPointWithDescriptionCollection & parameters) const
