@@ -3,7 +3,7 @@
  *  @file  FisherSnedecor.cxx
  *  @brief The Fisher-Snedecor distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ static Factory<FisherSnedecor> RegisteredFactory("FisherSnedecor");
 
 /* Default constructor */
 FisherSnedecor::FisherSnedecor()
-  : NonEllipticalDistribution("FisherSnedecor")
+  : ContinuousDistribution("FisherSnedecor")
   , d1_(1.0)
   , d2_(1.0)
   , normalizationFactor_(0.0)
@@ -50,7 +50,7 @@ FisherSnedecor::FisherSnedecor()
 /* Parameters constructor */
 FisherSnedecor::FisherSnedecor(const NumericalScalar d1,
                                const NumericalScalar d2)
-  : NonEllipticalDistribution("FisherSnedecor")
+  : ContinuousDistribution("FisherSnedecor")
   , d1_(d1)
   , d2_(0.0)
   , normalizationFactor_(0.0)
@@ -71,7 +71,7 @@ Bool FisherSnedecor::operator ==(const FisherSnedecor & other) const
 /* String converter */
 String FisherSnedecor::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << FisherSnedecor::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -82,7 +82,7 @@ String FisherSnedecor::__repr__() const
 
 String FisherSnedecor::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(d1 = " << d1_ << ", d2 = " << d2_ << ")";
   return oss;
 }
@@ -96,7 +96,12 @@ FisherSnedecor * FisherSnedecor::clone() const
 /* Compute the numerical range of the distribution given the parameters values */
 void FisherSnedecor::computeRange()
 {
-  setRange(Interval(NumericalPoint(1, 0.0), NumericalPoint(1, computeScalarQuantile(cdfEpsilon_, true)), Interval::BoolCollection(1, true), Interval::BoolCollection(1, false)));
+  // Initialize the range with inverted bounds in order to use the generic
+  // implementation of the computeScalarQuantile method to find the upper bound
+  setRange(Interval(NumericalPoint(1, 0.0), NumericalPoint(1, -1.0), Interval::BoolCollection(1, true), Interval::BoolCollection(1, false)));
+  // Now, compute the upper bound
+  const NumericalPoint upperBound(computeUpperBound());
+  setRange(Interval(NumericalPoint(1, 0.0), upperBound, Interval::BoolCollection(1, true), Interval::BoolCollection(1, false)));
 }
 
 /* Update the derivative attributes */
@@ -144,13 +149,13 @@ NumericalScalar FisherSnedecor::computeCDF(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar FisherSnedecor::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
+  if (getRange().getUpperBound()[0] < 0.0) return DistributionImplementation::computeScalarQuantile(prob, tail);
   const NumericalScalar p(tail ? 1.0 - prob : prob);
   const NumericalScalar q(DistFunc::qBeta(0.5 * d1_, 0.5 * d2_, p));
-  const NumericalScalar value(d2_ * q / (d1_ * (1.0 - q)));
-  return value;
+  if (q >= 1.0) return getRange().getUpperBound()[0];
+  return d2_ * q / (d1_ * (1.0 - q));
 }
 
 /* Compute the mean of the distribution */
@@ -256,7 +261,7 @@ NumericalScalar FisherSnedecor::getD2() const
 /* Method save() stores the object through the StorageManager */
 void FisherSnedecor::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "d1_", d1_ );
   adv.saveAttribute( "d2_", d2_ );
   adv.saveAttribute( "normalizationFactor_", normalizationFactor_ );
@@ -265,7 +270,7 @@ void FisherSnedecor::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void FisherSnedecor::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "d1_", d1_ );
   adv.loadAttribute( "d2_", d2_ );
   adv.loadAttribute( "normalizationFactor_", normalizationFactor_ );
