@@ -3,7 +3,7 @@
  *  @file  FrankCopula.cxx
  *  @brief The FrankCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,32 +26,32 @@
 #include "RandomGenerator.hxx"
 #include "PersistentObjectFactory.hxx"
 #include "Exception.hxx"
+#include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(FrankCopula);
 
 static Factory<FrankCopula> RegisteredFactory("FrankCopula");
 
 /* Default constructor */
 FrankCopula::FrankCopula()
-  : ArchimedeanCopula("FrankCopula"),
-    theta_(2.0)
+  : ArchimedeanCopula("FrankCopula")
+  , theta_(2.0)
 {
   // We set the dimension of the FrankCopula distribution
   setDimension( 2 );
+  computeRange();
 }
 
 /* Parameters constructor */
 FrankCopula::FrankCopula(const NumericalScalar theta)
-  : ArchimedeanCopula("FrankCopula"),
-    theta_(theta)
+  : ArchimedeanCopula("FrankCopula")
+  , theta_(theta)
 {
   // We set the dimension of the FrankCopula distribution
   setDimension( 2 );
+  computeRange();
 }
 
 /* Comparison operator */
@@ -64,7 +64,7 @@ Bool FrankCopula::operator ==(const FrankCopula & other) const
 /* String converter */
 String FrankCopula::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << FrankCopula::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -74,7 +74,7 @@ String FrankCopula::__repr__() const
 
 String FrankCopula::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(theta = " << theta_ << ")";
   return oss;
 }
@@ -194,7 +194,23 @@ NumericalScalar FrankCopula::computeCDF(const NumericalPoint & point) const
   return -log1p(expm1MinusThetaU * expm1MinusThetaV / expm1MinusTheta) / theta_;
 }
 
-/** Get the PDFGradient of the distribution */
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix FrankCopula::getSpearmanCorrelation() const
+{
+  CorrelationMatrix rho(2);
+  rho(0, 1) = 1.0 - 12.0 * (SpecFunc::Debye(-theta_, 2) - SpecFunc::Debye(-theta_, 1)) / theta_;
+  return rho;
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix FrankCopula::getKendallTau() const
+{
+  CorrelationMatrix tau(2);
+  tau(0, 1) = 1.0 + 4.0 * (SpecFunc::Debye(theta_, 1) - 1.0) / theta_;
+  return tau;
+}
+
+/* Get the PDFGradient of the distribution */
 NumericalPoint FrankCopula::computePDFGradient(const NumericalPoint & point) const
 {
   const UnsignedLong dimension(getDimension());
@@ -203,7 +219,7 @@ NumericalPoint FrankCopula::computePDFGradient(const NumericalPoint & point) con
   throw NotYetImplementedException(HERE);
 }
 
-/** Get the CDFGradient of the distribution */
+/* Get the CDFGradient of the distribution */
 NumericalPoint FrankCopula::computeCDFGradient(const NumericalPoint & point) const
 {
   const UnsignedLong dimension(getDimension());
@@ -288,7 +304,7 @@ NumericalScalar FrankCopula::computeArchimedeanGeneratorDerivative(const Numeric
   // Independent case
   if (theta_ == 0.0) return -1.0 / t;
   // General case
-  return theta_ / (1.0 - exp(-theta_ * t));
+  return -theta_ / expm1(-theta_ * t);
 }
 
 /* Compute the seconde derivative of the density generator */
@@ -302,7 +318,7 @@ NumericalScalar FrankCopula::computeArchimedeanGeneratorSecondDerivative(const N
   return ratio * ratio * exp(thetaT);
 }
 
-/** Parameters value and description accessor */
+/* Parameters value and description accessor */
 FrankCopula::NumericalPointWithDescriptionCollection FrankCopula::getParametersCollection() const
 {
   NumericalPointWithDescriptionCollection parameters(1);
@@ -330,6 +346,7 @@ Bool FrankCopula::hasIndependentCopula() const
 /* Theta accessor */
 void FrankCopula::setTheta(const NumericalScalar theta)
 {
+  if (theta < 0.0) throw InvalidArgumentException(HERE) << "Theta MUST be nonnegative";
   theta_ = theta;
 }
 
@@ -351,6 +368,7 @@ void FrankCopula::load(Advocate & adv)
 {
   ArchimedeanCopula::load(adv);
   adv.loadAttribute( "theta_", theta_ );
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
