@@ -3,7 +3,7 @@
  *  @file  FrankCopulaFactory.cxx
  *  @brief Factory for FrankCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -107,7 +107,9 @@ FrankCopula FrankCopulaFactory::buildAsFrankCopula(const NumericalSample & sampl
     if (tauTheta <= tau) minTheta = theta;
     else maxTheta = theta;
   }
-  return FrankCopula(theta);
+  FrankCopula result(theta);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 FrankCopula FrankCopulaFactory::buildAsFrankCopula(const NumericalPointWithDescriptionCollection & parameters) const
