@@ -3,7 +3,7 @@
  *  @file  Gamma.cxx
  *  @brief The Gamma distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ static Factory<Gamma> RegisteredFactory("Gamma");
 
 /* Default constructor */
 Gamma::Gamma()
-  : NonEllipticalDistribution("Gamma")
+  : ContinuousDistribution("Gamma")
   , k_(1.0)
   , lambda_(1.0)
   , gamma_(0.0)
@@ -51,7 +51,7 @@ Gamma::Gamma(const NumericalScalar arg1,
              const NumericalScalar arg2,
              const NumericalScalar gamma,
              const ParameterSet set)
-  : NonEllipticalDistribution("Gamma")
+  : ContinuousDistribution("Gamma")
   , k_(0.0)
   , lambda_(0.0)
   , gamma_(gamma)
@@ -209,7 +209,15 @@ void Gamma::computeRange()
 /** Update the derivative attributes */
 void Gamma::update()
 {
-  normalizationFactor_ = k_ * log(lambda_) - SpecFunc::LnGamma(k_);
+  // For large k define an alternative normalization factor and use an asymptotic expansion to avoid cancellation
+  if (k_ >= 6.9707081224932495879)
+  {
+    static const NumericalScalar alpha[10] = {0.91893853320467274177, 0.83333333333333333333e-1, -0.27777777777777777778e-2, 0.79365079365079365079e-3, -0.59523809523809523810e-3, 0.84175084175084175084e-3, -0.19175269175269175269e-2, 0.64102564102564102564e-2, -0.29550653594771241830e-1, 0.17964437236883057316};
+    const NumericalScalar ik(1.0 / k_);
+    const NumericalScalar ik2(ik * ik);
+    normalizationFactor_ = log(lambda_) + k_ - 0.5 * log(k_) - (alpha[0] + ik * (alpha[1] + ik2 * (alpha[2] + ik2 * (alpha[3] + ik2 * (alpha[4] + ik2 * (alpha[5] + ik2 * (alpha[6] + ik2 * (alpha[7] + ik2 * (alpha[8] + ik2 * alpha[9])))))))));
+  }
+  else normalizationFactor_ = log(lambda_) - SpecFunc::LnGamma(k_);
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
 }
@@ -247,9 +255,11 @@ NumericalScalar Gamma::computeLogPDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalScalar x(point[0] - gamma_);
-  if (x <= 0.0) return -SpecFunc::MaxNumericalScalar;
-  return normalizationFactor_ + (k_ - 1) * log(x) - lambda_ * x;
+  const NumericalScalar u(lambda_ * (point[0] - gamma_));
+  if (u <= 0.0) return -SpecFunc::MaxNumericalScalar;
+  // Use asymptotic expansion for large k
+  if (k_ >= 6.9707081224932495879) return normalizationFactor_ - u + (k_ - 1.0) * log(u / k_);
+  return normalizationFactor_ + (k_ - 1) * log(u) - u;
 }
 
 /* Get the CDF of the distribution */
@@ -309,7 +319,7 @@ NumericalPoint Gamma::computeCDFGradient(const NumericalPoint & point) const
   if (x <= 0.0) return cdfGradient;
   const NumericalScalar lambdaX(lambda_ * x);
   const NumericalScalar factor(exp(k_ * log(lambdaX) - SpecFunc::LnGamma(k_) - lambdaX));
-  const NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  const NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
   cdfGradient[0] = (DistFunc::pGamma(k_ + eps, lambda_ * x) - DistFunc::pGamma(k_ - eps, lambda_ * x)) / (2.0 * eps);
   cdfGradient[1] = factor / lambda_;
   cdfGradient[2] = -factor / x;
@@ -318,8 +328,7 @@ NumericalPoint Gamma::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Gamma::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return gamma_ + DistFunc::qGamma(k_, prob, tail) / lambda_;
 }
@@ -395,7 +404,7 @@ void Gamma::setParametersCollection(const NumericalPointCollection & parametersC
 /* Method save() stores the object through the StorageManager */
 void Gamma::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "k_", k_ );
   adv.saveAttribute( "lambda_", lambda_ );
   adv.saveAttribute( "gamma_", gamma_ );
@@ -405,7 +414,7 @@ void Gamma::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Gamma::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "k_", k_ );
   adv.loadAttribute( "lambda_", lambda_ );
   adv.loadAttribute( "gamma_", gamma_ );
