@@ -3,7 +3,7 @@
  *  @file  GammaFactory.cxx
  *  @brief Factory for Gamma distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,7 +71,9 @@ Gamma GammaFactory::buildAsGamma(const NumericalSample & sample) const
   NumericalScalar lambda((mu - gamma) / sigma);
   const NumericalScalar k(lambda * lambda);
   lambda /= sigma;
-  return Gamma(k, lambda, gamma);
+  Gamma result(k, lambda, gamma);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Gamma GammaFactory::buildAsGamma(const NumericalPointWithDescriptionCollection & parameters) const
