@@ -3,7 +3,7 @@
  *  @file  Geometric.cxx
  *  @brief The Geometric distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,7 +63,7 @@ Bool Geometric::operator ==(const Geometric & other) const
 /* String converter */
 String Geometric::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Geometric::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -73,7 +73,7 @@ String Geometric::__repr__() const
 
 String Geometric::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(p = " << p_ << ")";
   return oss;
 }
@@ -107,8 +107,7 @@ NumericalScalar Geometric::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if ((k < 1.0 - supportEpsilon) || (fabs(k - round(k)) > supportEpsilon)) return 0.0;
+  if ((k < 1.0 - supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return 0.0;
   return p_ * pow(1.0 - p_, k - 1.0);
 }
 
@@ -138,8 +137,7 @@ NumericalPoint Geometric::computePDFGradient(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
-  if ((k < 1.0 - supportEpsilon) || (fabs(k - round(k)) > supportEpsilon)) return NumericalPoint(1, 0.0);
+  if ((k < 1.0 - supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return NumericalPoint(1, 0.0);
   return NumericalPoint(1, (1.0 - k * p_) * pow(1.0 - p_, k - 2.0));
 }
 
@@ -155,8 +153,7 @@ NumericalPoint Geometric::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Geometric::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return ceil(log(prob) / log1p(-p_));
   return ceil(log1p(-prob) / log1p(-p_));
