@@ -3,7 +3,7 @@
  *  @file  GeometricFactory.cxx
  *  @brief Factory for Geometric distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,7 +72,9 @@ Geometric GeometricFactory::buildAsGeometric(const NumericalSample & sample) con
     if ((x != trunc(x)) || (x < 1.0)) throw InvalidArgumentException(HERE) << "Error: can build a Geometric distribution only from a sample with integer components >= 1, here sample[" << i << "][0]=" << x;
     sum += x;
   }
-  return Geometric(size / sum);
+  Geometric result(size / sum);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Geometric GeometricFactory::buildAsGeometric(const NumericalPointWithDescriptionCollection & parameters) const
