@@ -3,7 +3,7 @@
  *  @file  Gumbel.cxx
  *  @brief The Gumbel distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,7 +35,7 @@ static Factory<Gumbel> RegisteredFactory("Gumbel");
 
 /* Default constructor */
 Gumbel::Gumbel()
-  : NonEllipticalDistribution("Gumbel"),
+  : ContinuousDistribution("Gumbel"),
     alpha_(1.0), beta_(0.0)
 {
   setDimension( 1 );
@@ -46,7 +46,7 @@ Gumbel::Gumbel()
 Gumbel::Gumbel(const NumericalScalar arg1,
                const NumericalScalar arg2,
                const ParameterSet set)
-  : NonEllipticalDistribution("Gumbel"),
+  : ContinuousDistribution("Gumbel"),
     alpha_(0.0),
     beta_(arg2)
 {
@@ -82,7 +82,7 @@ Bool Gumbel::operator ==(const Gumbel & other) const
 /* String converter */
 String Gumbel::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Gumbel::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -93,7 +93,7 @@ String Gumbel::__repr__() const
 
 String Gumbel::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(alpha = " << alpha_ << ", beta = " << beta_ << ")";
   return oss;
 }
@@ -212,8 +212,7 @@ NumericalPoint Gumbel::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Gumbel::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return beta_ - log(-log1p(-prob)) / alpha_;
   return beta_ - log(-log(prob)) / alpha_;
@@ -361,7 +360,7 @@ NumericalScalar Gumbel::getB() const
 /* Method save() stores the object through the StorageManager */
 void Gumbel::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "alpha_", alpha_ );
   adv.saveAttribute( "beta_", beta_ );
 }
@@ -369,7 +368,7 @@ void Gumbel::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Gumbel::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "alpha_", alpha_ );
   adv.loadAttribute( "beta_", beta_ );
   computeRange();
