@@ -3,7 +3,7 @@
  *  @file  GumbelCopula.cxx
  *  @brief The GumbelCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -41,6 +41,7 @@ GumbelCopula::GumbelCopula()
 {
   // We set the dimension of the GumbelCopula distribution
   setDimension( 2 );
+  computeRange();
 }
 
 /* Parameters constructor */
@@ -52,6 +53,7 @@ GumbelCopula::GumbelCopula(const NumericalScalar theta)
   setDimension( 2 );
   // Check the value of theta
   setTheta(theta);
+  computeRange();
 }
 
 /* Comparison operator */
@@ -64,7 +66,7 @@ Bool GumbelCopula::operator ==(const GumbelCopula & other) const
 /* String converter */
 String GumbelCopula::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << GumbelCopula::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -74,7 +76,7 @@ String GumbelCopula::__repr__() const
 
 String GumbelCopula::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(theta = " << theta_ << ")";
   return oss;
 }
@@ -284,6 +286,22 @@ NumericalScalar GumbelCopula::computeConditionalQuantile(const NumericalScalar q
   return exp(-pow(exp(theta_ * (log(factor) / (theta_ - 1.0) - SpecFunc::LambertW(pow(factor, inverseThetaMinusOne) * inverseThetaMinusOne))) - minusLogUPowTheta, 1.0 / theta_));
 }
 
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix GumbelCopula::getSpearmanCorrelation() const
+{
+  return CopulaImplementation::getSpearmanCorrelation();
+  CorrelationMatrix rho(2);
+  return rho;
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix GumbelCopula::getKendallTau() const
+{
+  CorrelationMatrix tau(2);
+  tau(0, 1) = 1.0 - 1.0 / theta_;
+  return tau;
+}
+
 /* Parameters value and description accessor */
 GumbelCopula::NumericalPointWithDescriptionCollection GumbelCopula::getParametersCollection() const
 {
@@ -340,7 +358,7 @@ Bool GumbelCopula::hasIndependentCopula() const
 /* Theta accessor */
 void GumbelCopula::setTheta(const NumericalScalar theta)
 {
-  if (theta <= 1.0) throw InvalidArgumentException(HERE) << "Theta MUST be strictly greater than 1";
+  if (theta < 1.0) throw InvalidArgumentException(HERE) << "Theta MUST be greater or equal to 1";
   theta_ = theta;
 }
 
@@ -362,9 +380,7 @@ void GumbelCopula::load(Advocate & adv)
 {
   ArchimedeanCopula::load(adv);
   adv.loadAttribute( "theta_", theta_ );
+  computeRange();
 }
 
-
-
-
 END_NAMESPACE_OPENTURNS
