@@ -3,7 +3,7 @@
  *  @file  GumbelCopulaFactory.cxx
  *  @brief Factory for GumbelCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,9 @@ GumbelCopula GumbelCopulaFactory::buildAsGumbelCopula(const NumericalSample & sa
   if (sample.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: cannot build a GumbelCopula distribution from a sample of dimension not equal to 2";
   NumericalScalar tau(sample.computeKendallTau().operator()(0, 1));
   if (tau == 1) throw InvalidArgumentException(HERE) << "Error: cannot build a GumbelCopula distribution from a sample with Kendall tau equals to 1";
-  return GumbelCopula(1.0 / (1.0 - tau));
+  GumbelCopula result(1.0 / (1.0 - tau));
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 GumbelCopula GumbelCopulaFactory::buildAsGumbelCopula(const NumericalPointWithDescriptionCollection & parameters) const
