@@ -3,7 +3,7 @@
  *  @file  GumbelFactory.cxx
  *  @brief Factory for Gumbel distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -65,7 +65,9 @@ Gumbel GumbelFactory::buildAsGumbel(const NumericalSample & sample) const
   NumericalScalar mu(sample.computeMean()[0]);
   NumericalScalar sigma(sample.computeStandardDeviationPerComponent()[0]);
   if (sigma <= 0.0) throw InvalidArgumentException(HERE) << "Error: can build a Gumbel distribution only if sigma >= 0, here sigma=" << sigma;
-  return Gumbel(mu, sigma, Gumbel::MUSIGMA);
+  Gumbel result(mu, sigma, Gumbel::MUSIGMA);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Gumbel GumbelFactory::buildAsGumbel(const NumericalPointWithDescriptionCollection & parameters) const
