@@ -3,7 +3,7 @@
  *  @file  Histogram.cxx
  *  @brief The Histogram distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,21 +30,16 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<HistogramPair>);
 static Factory<PersistentCollection<HistogramPair> > RegisteredFactory("PersistentCollection<HistogramPair>");
 
-
-
-
 CLASSNAMEINIT(Histogram);
 
 static Factory<Histogram> RegisteredFactory_alt("Histogram");
 
 /* Default constructor */
 Histogram::Histogram()
-  : NonEllipticalDistribution("Histogram")
+  : ContinuousDistribution("Histogram")
   , first_(0.0)
   , collection_(0)
   , cumulatedWidth_(0)
@@ -57,7 +52,7 @@ Histogram::Histogram()
 /* Parameters constructor */
 Histogram::Histogram(const NumericalScalar first,
                      const HistogramPairCollection & collection)
-  : NonEllipticalDistribution("Histogram")
+  : ContinuousDistribution("Histogram")
   , first_(first)
   , collection_(0)
   , cumulatedWidth_(0)
@@ -67,6 +62,25 @@ Histogram::Histogram(const NumericalScalar first,
   setDimension( 1 );
 }
 
+Histogram::Histogram(const NumericalScalar first,
+                     const NumericalPoint & width,
+                     const NumericalPoint & height)
+  : ContinuousDistribution("Histogram")
+  , first_(first)
+  , collection_(0)
+  , cumulatedWidth_(0)
+{
+  // Convert the width and height into an Histogram pairs collection
+  const UnsignedLong size(width.getSize());
+  if (size == 0) throw InvalidArgumentException(HERE) << "Error: the given width has a size of 0.";
+  if (size != height.getSize()) throw InvalidArgumentException(HERE) << "Error: the width and the height must have the same size.";
+  HistogramPairCollection collection(size);
+  for (UnsignedLong i = 0; i < size; ++i) collection[i] = HistogramPair(width[i], height[i]);
+  // This call set also the range.
+  setPairCollection(collection);
+  setDimension( 1 );
+}
+
 /* Comparison operator */
 Bool Histogram::operator ==(const Histogram & other) const
 {
@@ -77,7 +91,7 @@ Bool Histogram::operator ==(const Histogram & other) const
 /* String converter */
 String Histogram::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Histogram::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -88,7 +102,7 @@ String Histogram::__repr__() const
 
 String Histogram::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(origin = " << first_;
   for (UnsignedLong i = 0; i < collection_.getSize(); ++i) oss << ", {w" << i << " = " << collection_[i].getWidth() << ", h" << i << " = " << collection_[i].getHeight() << "}";
   oss << ")";
@@ -191,8 +205,7 @@ NumericalPoint Histogram::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Histogram::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   const NumericalScalar p(tail ? 1.0 - prob : prob);
   const UnsignedLong size(collection_.getSize());
@@ -261,6 +274,35 @@ void Histogram::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
+/* Get the moments of the standardized distribution */
+NumericalPoint Histogram::getStandardMoment(const UnsignedLong n) const
+{
+  if (n == 0) return NumericalPoint(1, 1.0);
+  NumericalScalar value(0.0);
+  const UnsignedLong size(collection_.getSize());
+  NumericalScalar xPrec(-1.0);
+  const NumericalScalar factor(2.0 / cumulatedWidth_[size - 1]);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    const NumericalScalar x(xPrec + collection_[i].getWidth() * factor);
+    value += (pow(x, n + 1) - pow(xPrec, n + 1)) * collection_[i].getHeight();
+    xPrec = x;
+  }
+  value /= (n + 1) * factor;
+  return NumericalPoint(1, value);
+}
+
+/* Get the standard representative in the parametric family, associated with the standard moments */
+Histogram::Implementation Histogram::getStandardRepresentative() const
+{
+  const UnsignedLong size(collection_.getSize());
+  HistogramPairCollection collection(size);
+  const NumericalScalar first(-1.0);
+  const NumericalScalar factor(2.0 / cumulatedWidth_[size - 1]);
+  for (UnsignedLong i = 0; i < size; ++i) collection[i] = HistogramPair(factor * collection_[i].getWidth(), collection_[i].getHeight() / factor);
+  return Histogram(first, collection).clone();
+}
+
 /* Parameters value and description accessor */
 Histogram::NumericalPointWithDescriptionCollection Histogram::getParametersCollection() const
 {
@@ -317,7 +359,7 @@ NumericalScalar Histogram::getFirst() const
 /* Collection accessor */
 void Histogram::setPairCollection(const HistogramPairCollection & collection)
 {
-  NumericalScalar surface = 0.0;
+  NumericalScalar surface(0.0);
   const UnsignedLong size(collection.getSize());
   cumulatedWidth_ = NumericalPoint(size);
   cumulatedSurface_ = NumericalPoint(size);
@@ -366,7 +408,7 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
                          const UnsignedLong pointNumber) const
 {
   if (xMax <= xMin) throw InvalidArgumentException(HERE) << "Error: cannot draw a PDF with xMax >= xMin, here xmin=" << xMin << " and xmax=" << xMax;
-  const String title(OSS() << getName() << " PDF");
+  const String title(OSS() << getDescription()[0] << " PDF");
   const String xName(getDescription()[0]);
   Graph graphPDF(title, xName, "PDF", true, "topright");
   const UnsignedLong size(collection_.getSize());
@@ -400,6 +442,7 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
   // Find the index of the right bar to draw
   UnsignedLong indexRight(indexLeft);
   UnsignedLong shiftFull(0);
+  NumericalSample dataFull(0, 2);
   while ((indexRight < size) && (first_ + cumulatedWidth_[indexRight] < xMax)) ++indexRight;
   // The graph is made of full bars for the class indices between indexLeft and indexRight
   // The graph can include completely the first class or not. It is checked using first_.
@@ -413,7 +456,7 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     data[0][1] = 0.0;
     data[1][0] = first_;
     data[1][1] = 0.0;
-    graphPDF.add(Curve(data, "red", "solid", 2, title));
+    dataFull.add(data);
   }
   // The first class that appears in the graph is only partially included
   else
@@ -425,23 +468,9 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     data[1][1] = data[0][1];
     data[2][0] = data[1][0];
     data[2][1] = 0.0;
-    graphPDF.add(Curve(data, "red", "solid", 2, title));
+    dataFull.add(data);
     shiftFull = 1;
   }
-#ifdef USEBARPLOT
-  // Central part of the graph
-  NumericalSample data(0, 2);
-  for (UnsignedLong i = indexLeft + shiftFull; i < indexRight; ++i)
-  {
-    NumericalPoint point(2);
-    point[0] = collection_[i].getWidth();
-    point[1] = collection_[i].getHeight();
-    data.add(point);
-  }
-  // If there is at least one full bar to draw, do it using the BarPlot object
-  if (data.getSize() > 0)
-    graphPDF.add(BarPlot(data, first_, "red", "solid", "solid", ""));
-#else
   // Central part of the graph
   NumericalScalar startX(first_);
   if (indexLeft + shiftFull > 0) startX += cumulatedWidth_[indexLeft + shiftFull];
@@ -457,9 +486,8 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     data[2][1] = collection_[i].getHeight();
     data[3][0] = startX;
     data[3][1] = 0.0;
-    graphPDF.add(Curve(data, "red", "solid", 2, ""));
+    dataFull.add(data);
   }
-#endif
   // The last class is completely included
   if (indexRight == size)
   {
@@ -468,7 +496,7 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     data[0][1] = 0.0;
     data[1][0] = xMax;
     data[1][1] = 0.0;
-    graphPDF.add(Curve(data, "red", "solid", 2, ""));
+    dataFull.add(data);
   }
   // The last class that appears in the graph is only partially included
   else
@@ -480,15 +508,21 @@ Graph Histogram::drawPDF(const NumericalScalar xMin,
     data[1][1] = collection_[indexRight].getHeight();
     data[2][0] = xMax;
     data[2][1] = collection_[indexRight].getHeight();
-    graphPDF.add(Curve(data, "red", "solid", 2, ""));
+    dataFull.add(data);
   }
+  Curve curve(dataFull, "red", "solid", 2, "");
+  curve.setLegend(title);
+  graphPDF.add(curve);
+  NumericalPoint bb(graphPDF.getBoundingBox());
+  bb[3] *= 1.1;
+  graphPDF.setBoundingBox(bb);
   return graphPDF;
 }
 
 /* Method save() stores the object through the StorageManager */
 void Histogram::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "first_", first_);
   adv.saveAttribute( "collection_", collection_);
   adv.saveAttribute( "cumulatedWidth_", cumulatedWidth_);
@@ -498,7 +532,7 @@ void Histogram::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Histogram::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "first_", first_);
   adv.loadAttribute( "collection_", collection_);
   adv.loadAttribute( "cumulatedWidth_", cumulatedWidth_);
