@@ -3,7 +3,7 @@
  *  @file  HistogramFactory.cxx
  *  @brief Factory for Histogram distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -81,7 +81,9 @@ Histogram HistogramFactory::buildAsHistogram(const NumericalSample & sample) con
   const NumericalScalar inverseArea(1.0 / (hOpt * size));
   Histogram::HistogramPairCollection collection(barNumber);
   for(UnsignedLong i = 0; i < barNumber; ++i) collection[i] = HistogramPair(hOpt, heights[i] * inverseArea);
-  return Histogram(min, collection);
+  Histogram result(min, collection);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Histogram HistogramFactory::buildAsHistogram() const
