@@ -3,7 +3,7 @@
  *  @file  IndependentCopula.cxx
  *  @brief A class that implements an independent copula
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,9 +36,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(IndependentCopula);
 
 static Factory<IndependentCopula> RegisteredFactory("IndependentCopula");
@@ -48,6 +45,7 @@ IndependentCopula::IndependentCopula(const UnsignedLong dimension)
   : CopulaImplementation("IndependentCopula")
 {
   setDimension(dimension);
+  computeRange();
 }
 
 /* Comparison operator */
@@ -60,7 +58,7 @@ Bool IndependentCopula::operator ==(const IndependentCopula & other) const
 /* String converter */
 String IndependentCopula::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << IndependentCopula::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension();
@@ -70,7 +68,7 @@ String IndependentCopula::__repr__() const
 /* String converter */
 String IndependentCopula::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(dimension = " << getDimension() << ")";
   return oss;
 }
@@ -151,6 +149,24 @@ NumericalScalar IndependentCopula::computeCDF(const NumericalPoint & point) cons
   return value;
 }
 
+/* Get the survival function of the distribution */
+NumericalScalar IndependentCopula::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  return computeCDF(NumericalPoint(getDimension(), 1.0) - point);
+}
+
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix IndependentCopula::getSpearmanCorrelation() const
+{
+  return IdentityMatrix(getDimension());
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix IndependentCopula::getKendallTau() const
+{
+  return IdentityMatrix(getDimension());
+}
+
 /* Get the PDF gradient of the distribution */
 NumericalPoint IndependentCopula::computePDFGradient(const NumericalPoint & point) const
 {
@@ -280,6 +296,7 @@ void IndependentCopula::save(Advocate & adv) const
 void IndependentCopula::load(Advocate & adv)
 {
   CopulaImplementation::load(adv);
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
