@@ -3,7 +3,7 @@
  *  @file  InverseNormal.cxx
  *  @brief The InverseNormal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 #include "DistFunc.hxx"
 #include "RandomGenerator.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "AnalyticalNumericalMathEvaluationImplementation.hxx"
-#include "AnalyticalNumericalMathGradientImplementation.hxx"
 #include "SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -38,7 +36,7 @@ static Factory<InverseNormal> RegisteredFactory("InverseNormal");
 
 /* Default constructor */
 InverseNormal::InverseNormal()
-  : NonEllipticalDistribution("InverseNormal"),
+  : ContinuousDistribution("InverseNormal"),
     lambda_(1.0),
     mu_(1.0)
 {
@@ -49,7 +47,7 @@ InverseNormal::InverseNormal()
 /* Parameters constructor */
 InverseNormal::InverseNormal(const NumericalScalar lambda,
                              const NumericalScalar mu)
-  : NonEllipticalDistribution("InverseNormal"),
+  : ContinuousDistribution("InverseNormal"),
     lambda_(0.0),
     mu_(0.0)
 {
@@ -68,7 +66,7 @@ Bool InverseNormal::operator ==(const InverseNormal & other) const
 /* String converter */
 String InverseNormal::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << InverseNormal::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -79,7 +77,7 @@ String InverseNormal::__repr__() const
 
 String InverseNormal::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(lambda = " << lambda_ << ", mu = " << mu_ << ")";
   return oss;
 }
@@ -95,7 +93,9 @@ NumericalPoint InverseNormal::getRealization() const
 {
   const NumericalScalar nu(DistFunc::rNormal());
   const NumericalScalar y(nu * nu);
-  const NumericalScalar x(mu_ * (1.0 + (1.0 / (2.0 * lambda_)) * (mu_ * y - sqrt(4.0 * mu_ * lambda_ * y + mu_ * mu_ * y * y))));
+  const NumericalScalar w(mu_ * y / lambda_);
+  // Lower bound computed by Maple to insure double precision
+  const NumericalScalar x(w < 5.015e5 ? mu_ * (1.0 + 0.5 * w * (1.0 - sqrt(1.0 + 4.0 / w))) : mu_ * ((5.0 / w - 2.0) / w + 1.0) / w);
   const NumericalScalar z(RandomGenerator::Generate());
   if (z * (mu_ + x) <= mu_) return NumericalPoint(1, x);
   return NumericalPoint(1, mu_ * mu_ / x);
@@ -130,9 +130,12 @@ NumericalScalar InverseNormal::computeCDF(const NumericalPoint & point) const
   if (x <= 0.0) return 0.0;
   const NumericalScalar lx(sqrt(lambda_ / x));
   const NumericalScalar phiArg1( lx * ( x / mu_ - 1.0));
+  // Quick return if in the far right tail. The pNormal() function is constant
+  // equal to 1 in double precision for argument greater than 8.24, and the
+  // InverseNormal CDF is greater than pNormal()
+  if (phiArg1 > 8.24) return 1.0;
   const NumericalScalar phiArg2(-lx * ( x / mu_ + 1.0));
-  const NumericalScalar result(DistFunc::pNormal(phiArg1) + exp(2.0 * lambda_ / mu_) * DistFunc::pNormal(phiArg2));
-  return result;
+  return DistFunc::pNormal(phiArg1) + exp(2.0 * lambda_ / mu_ + log(DistFunc::pNormal(phiArg2)));
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
@@ -193,18 +196,19 @@ NumericalPoint InverseNormal::getKurtosis() const
   return NumericalPoint(1, 3.0 + 15.0 * mu_ / lambda_);
 }
 
-
 /* Get the moments of the standardized distribution */
 NumericalPoint InverseNormal::getStandardMoment(const UnsignedLong n) const
 {
   if (n == 0) return NumericalPoint(1, 1.0);
-  String formula(OSS() << "exp((" << lambda_ / mu_ << ") * (1 - sqrt(1 - 2 * (" << mu_ * mu_ / lambda_ << ") * t)))");
-  for (UnsignedLong i = 0; i < n; ++i)
+  NumericalScalar moment(1.0);
+  NumericalScalar rho(0.5 * mu_ / lambda_);
+  NumericalScalar product(1.0);
+  for (UnsignedLong k = 1; k < n; ++k)
   {
-    const AnalyticalNumericalMathGradientImplementation gradient(AnalyticalNumericalMathEvaluationImplementation(Description(1, "t"), Description(1, "y"), Description(1, formula)));
-    formula = gradient.getFormula(0, 0);
+    product *= (n - k) * (n + k - 1) * rho / k;
+    moment += product;
   }
-  return AnalyticalNumericalMathEvaluationImplementation(Description(1, "t"), Description(1, "y"), Description(1, formula))(NumericalPoint(1, 0.0));
+  return NumericalPoint(1, pow(mu_, n) * moment);
 }
 
 /* Interface specific to InverseNormal */
@@ -260,7 +264,7 @@ void InverseNormal::setParametersCollection(const NumericalPointCollection & par
 /* Method save() stores the object through the StorageManager */
 void InverseNormal::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "lambda_", lambda_ );
   adv.saveAttribute( "mu_", mu_ );
 }
@@ -268,7 +272,7 @@ void InverseNormal::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void InverseNormal::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "lambda_", lambda_ );
   adv.loadAttribute( "mu_", mu_ );
   computeRange();
