@@ -3,7 +3,7 @@
  *  @file  InverseNormalFactory.cxx
  *  @brief Factory for InverseNormal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include <cmath>
 #include "InverseNormalFactory.hxx"
+#include "ResourceMap.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -64,15 +65,24 @@ InverseNormal InverseNormalFactory::buildAsInverseNormal(const NumericalSample &
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build an InverseNormal distribution from an empty sample";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot build an InverseNormal distribution from a sample of dimension different from 1";
   const NumericalScalar mu(sample.computeMean()[0]);
-  NumericalScalar sum(0.0);
-  for (UnsignedLong i = 0; i < size; ++i)
+  NumericalScalar lambda(-1.0);
+  if (ResourceMap::Get("InverseNormalFactory-Method") == "MLE")
+    // Maximum likelihood estimation
   {
-    const NumericalScalar xI(sample[i][0]);
-    if (xI <= 0.0) throw InvalidArgumentException(HERE) << "Error: cannot build an InverseNormal distribution from a sample with non positive values";
-    sum += 1.0 / sample[i][0];
+    NumericalScalar sum(0.0);
+    for (UnsignedLong i = 0; i < size; ++i)
+    {
+      const NumericalScalar xI(sample[i][0]);
+      if (xI <= 0.0) throw InvalidArgumentException(HERE) << "Error: cannot build an InverseNormal distribution from a sample with non positive values";
+      sum += 1.0 / sample[i][0];
+    }
+    lambda = 1.0 / (sum / size - 1.0 / mu);
   }
-  const NumericalScalar lambda(1.0 / (sum / size - 1.0 / mu));
-  return InverseNormal(lambda, mu);
+  // Moments estimation
+  else lambda = pow(mu, 3) / sample.computeCovariance()(0, 0);
+  InverseNormal result(lambda, mu);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 InverseNormal InverseNormalFactory::buildAsInverseNormal(const NumericalPointWithDescriptionCollection & parameters) const
