@@ -2,14 +2,14 @@
 /**
  *  @file  KernelMixture.cxx
  *  @brief Class for a product-kernel multidimensional mixture. If K is the
- *         underlying 1D kernel, h=(h_1,\\dot,h_n) is the vector of bandwidth
- *         and X=(X^1,\\dots,X^N) is the nD sample, the PDF of the kernel mixture
+ *         underlying 1D kernel, h=(h_1,\dot,h_n) is the vector of bandwidth
+ *         and X=(X^1,\dots,X^N) is the nD sample, the PDF of the kernel mixture
  *         is:
- *         PDF(x) = C\\sum_{i=1}^N\\prod_{j=1}^n K((x_j - X^i_j)/h_j),
+ *         PDF(x) = C\sum_{i=1}^N\prod_{j=1}^n K((x_j - X^i_j)/h_j),
  *         where:
- *         C = \\frac{1}{N\\prod_{k=1}^n h_k}
+ *         C = \frac{1}{N\prod_{k=1}^n h_k}
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,6 +32,7 @@
 #include "RandomGenerator.hxx"
 #include "Exception.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "Brent.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -40,15 +41,37 @@ CLASSNAMEINIT(KernelMixture);
 static Factory<KernelMixture> RegisteredFactory("KernelMixture");
 
 /* Default constructor */
+KernelMixture::KernelMixture()
+  : ContinuousDistribution("KernelMixture")
+  , kernel_()
+  , bandwidth_(0)
+  , bandwidthInverse_(0)
+  , normalizationFactor_(0.0)
+  , sample_(0, 1)
+  , pdfApproximationCDF_()
+  , cdfApproximation_()
+  , pdfApproximationCCDF_()
+  , ccdfApproximation_()
+  , useApproximatePDFCDF_(false)
+{
+  // Nothing to do
+}
+
+/* Parameters constructor */
 KernelMixture::KernelMixture(const Distribution & kernel,
                              const NumericalPoint & bandwidth,
                              const NumericalSample & sample)
-  : NonEllipticalDistribution("KernelMixture"),
-    kernel_(kernel),
-    bandwidth_(0),
-    bandwidthInverse_(0),
-    normalizationFactor_(0.0),
-    sample_(sample)
+  : ContinuousDistribution("KernelMixture")
+  , kernel_(kernel)
+  , bandwidth_(0)
+  , bandwidthInverse_(0)
+  , normalizationFactor_(0.0)
+  , sample_(sample)
+  , pdfApproximationCDF_()
+  , cdfApproximation_()
+  , pdfApproximationCCDF_()
+  , ccdfApproximation_()
+  , useApproximatePDFCDF_(false)
 {
   // We check if the given kernel is 1-D (product kernel)
   if (kernel.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: only 1D kernel is allowed for multidimensional product kernels";
@@ -56,12 +79,23 @@ KernelMixture::KernelMixture(const Distribution & kernel,
   setDimension(sample.getDimension());
   // This call set also the range.
   setBandwidth(bandwidth);
+  if ((getDimension() == 1) && (sample.getSize() >= ResourceMap::GetAsUnsignedLong("KernelMixture-SmallSize")) && (sample.getSize() < ResourceMap::GetAsUnsignedLong("KernelMixture-LargeSize")))
+  {
+    // Here we use the implementation provided by the DistributionImplementation class instead of the ContinuousDistribution class in order to use both the PDF and the CDF
+    Collection<PiecewiseHermiteEvaluationImplementation> coll(DistributionImplementation::interpolatePDFCDF(ResourceMap::GetAsUnsignedLong("KernelMixture-PDFCDFDiscretization")));
+    pdfApproximationCDF_ = coll[0];
+    cdfApproximation_ = coll[1];
+    pdfApproximationCCDF_ = coll[2];
+    ccdfApproximation_ = coll[3];
+    useApproximatePDFCDF_ = true;
+  }
 }
 
 /* Comparison operator */
 Bool KernelMixture::operator ==(const KernelMixture & other) const
 {
   if (this == &other) return true;
+  if (useApproximatePDFCDF_) return (bandwidth_ == other.bandwidth_) && (kernel_ == other.kernel_) && (pdfApproximationCDF_ == other.pdfApproximationCDF_) && (cdfApproximation_ == other.cdfApproximation_) && (pdfApproximationCCDF_ == other.pdfApproximationCCDF_) && (ccdfApproximation_ == other.ccdfApproximation_);
   return (bandwidth_ == other.bandwidth_) && (kernel_ == other.kernel_) && (sample_ == other.sample_);
 }
 
@@ -117,10 +151,21 @@ Distribution KernelMixture::getKernel() const
 void KernelMixture::setInternalSample(const NumericalSample & sample)
 {
   if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a KernelMixture based on an empty sample.";
+  if (sample.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given sample has dimension=" << sample.getDimension() << ", expected dimension=" << getDimension() << ".";
   sample_ = sample;
+  computeRange();
+  if ((getDimension() == 1) && (sample.getSize() >= ResourceMap::GetAsUnsignedLong("KernelMixture-SmallSize")) && (sample.getSize() < ResourceMap::GetAsUnsignedLong("KernelMixture-LargeSize")))
+  {
+    // Here we use the implementation provided by the DistributionImplementation class instead of the ContinuousDistribution class in order to use both the PDF and the CDF
+    Collection<PiecewiseHermiteEvaluationImplementation> coll(DistributionImplementation::interpolatePDFCDF(ResourceMap::GetAsUnsignedLong("KernelMixture-PDFCDFDiscretization")));
+    pdfApproximationCDF_ = coll[0];
+    cdfApproximation_ = coll[1];
+    pdfApproximationCCDF_ = coll[2];
+    ccdfApproximation_ = coll[3];
+    useApproximatePDFCDF_ = true;
+  }
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
-  computeRange();
 }
 
 NumericalSample KernelMixture::getInternalSample() const
@@ -169,10 +214,8 @@ NumericalPoint KernelMixture::getRealization() const
   NumericalPoint result(sample_[RandomGenerator::IntegerGenerate(sample_.getSize())]);
   // Then add a random noise according to the product kernel
   const UnsignedLong dimension(getDimension());
-  for (UnsignedLong i = 0; i < dimension; ++i)
-  {
-    result[i] += bandwidth_[i] * kernel_.getRealization()[0];
-  }
+  const NumericalSample kernelSample(kernel_.getSample(dimension));
+  for (UnsignedLong i = 0; i < dimension; ++i) result[i] += bandwidth_[i] * kernelSample[i][0];
   return result;
 }
 
@@ -212,19 +255,30 @@ NumericalScalar KernelMixture::computePDF(const NumericalPoint & point) const
 {
   const UnsignedLong dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-
+  if (useApproximatePDFCDF_)
+  {
+    if (point[0] < getMean()[0]) return pdfApproximationCDF_(point)[0];
+    else return pdfApproximationCCDF_(point)[0];
+  }
   NumericalScalar pdfValue(0.0);
+  const UnsignedLong size(sample_.getSize());
+  if (dimension == 1)
+  {
+    const NumericalScalar x(point[0]);
+    const NumericalScalar h(bandwidth_[0]);
+    for(UnsignedLong i = 0; i < size; ++i) pdfValue += kernel_.computePDF((x - sample_[i][0]) / h);
+    return pdfValue / (h * size);
+  }
   // Quick rejection test
   if (!getRange().numericallyContains(point)) return pdfValue;
-  const UnsignedLong size(sample_.getSize());
-  const NumericalScalar pdfEpsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultPDFEpsilon"));
+  const NumericalScalar pdfEpsilon(kernel_.getPDFEpsilon());
   for(UnsignedLong i = 0; i < size; ++i)
   {
-    NumericalScalar pdfAtom(1.0);
-    for (UnsignedLong j = 0; j < dimension; ++j)
+    NumericalScalar pdfAtom(kernel_.computePDF(NumericalPoint(1, (point[0] - sample_[i][0]) * bandwidthInverse_[0])));
+    for (UnsignedLong j = 1; j < dimension; ++j)
     {
-      pdfAtom *= kernel_.computePDF(NumericalPoint(1, (point[j] - sample_[i][j]) * bandwidthInverse_[j]));
       if (pdfAtom < pdfEpsilon) break;
+      pdfAtom *= kernel_.computePDF(NumericalPoint(1, (point[j] - sample_[i][j]) * bandwidthInverse_[j]));
     }
     pdfValue += pdfAtom;
   } /* end for */
@@ -236,18 +290,127 @@ NumericalScalar KernelMixture::computeCDF(const NumericalPoint & point) const
 {
   const UnsignedLong dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-
+  if (useApproximatePDFCDF_)
+  {
+    if (point[0] < getMean()[0]) return cdfApproximation_(point)[0];
+    else return 1.0 - ccdfApproximation_(point)[0];
+  }
   NumericalScalar cdfValue(0.0);
   const UnsignedLong size(sample_.getSize());
+  if (dimension == 1)
+  {
+    const NumericalScalar x(point[0]);
+    const NumericalScalar h(bandwidth_[0]);
+    for(UnsignedLong i = 0; i < size; ++i)
+      cdfValue += kernel_.computeCDF((x - sample_[i][0]) / h);
+    return cdfValue / size;
+  }
+  // Check against the range of the distribution
+  Bool allTooLarge(true);
+  Bool oneTooSmall(false);
+  const NumericalPoint lower(getRange().getLowerBound());
+  const NumericalPoint upper(getRange().getUpperBound());
+  for (UnsignedLong i = 0; i < dimension; ++i)
+  {
+    allTooLarge = allTooLarge && (point[i] >= upper[i]);
+    oneTooSmall = oneTooSmall || (point[i] <= lower[i]);
+  }
+  if (allTooLarge) return 1.0;
+  if (oneTooSmall) return 0.0;
+  const NumericalScalar cdfEpsilon(kernel_.getCDFEpsilon());
+  for(UnsignedLong i = 0; i < size; ++i)
+  {
+    NumericalScalar cdfAtom(kernel_.computeCDF((point[0] - sample_[i][0]) * bandwidthInverse_[0]));
+    for (UnsignedLong j = 1; j < dimension; ++j)
+    {
+      if (cdfAtom < cdfEpsilon) break;
+      cdfAtom *= kernel_.computeCDF((point[j] - sample_[i][j]) * bandwidthInverse_[j]);
+    }
+    cdfValue += cdfAtom;
+  } /* end for */
+  return cdfValue / size;
+}
+
+/* Get the complementary CDF of the distribution */
+NumericalScalar KernelMixture::computeComplementaryCDF(const NumericalPoint & point) const
+{
+  const UnsignedLong dimension(getDimension());
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
+  if (useApproximatePDFCDF_)
+  {
+    if (point[0] < getMean()[0]) return 1.0 - cdfApproximation_(point)[0];
+    else return ccdfApproximation_(point)[0];
+  }
+  // More accurate computation for 1D case...
+  if (dimension == 1) return computeSurvivalFunction(point);
+  // ... than in the general case
+  return DistributionImplementation::computeComplementaryCDF(point);
+}
+
+/* Get the survival function of the KernelMixture */
+NumericalScalar KernelMixture::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  const UnsignedLong dimension(getDimension());
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
+  if (useApproximatePDFCDF_)
+  {
+    if (point[0] < getMean()[0]) return 1.0 - cdfApproximation_(point)[0];
+    else return ccdfApproximation_(point)[0];
+  }
+  // Check against the range of the distribution
+  Bool oneTooLarge(true);
+  Bool allTooSmall(false);
+  const NumericalPoint lower(getRange().getLowerBound());
+  const NumericalPoint upper(getRange().getUpperBound());
+  for (UnsignedLong i = 0; i < dimension; ++i)
+  {
+    oneTooLarge = oneTooLarge && (point[i] >= upper[i]);
+    allTooSmall = allTooSmall || (point[i] <= lower[i]);
+  }
+  if (oneTooLarge) return 0.0;
+  if (allTooSmall) return 1.0;
+  const NumericalScalar cdfEpsilon(kernel_.getCDFEpsilon());
+  NumericalScalar survivalValue(0.0);
+  const UnsignedLong size(sample_.getSize());
   for(UnsignedLong i = 0; i < size; ++i)
   {
-    NumericalScalar cdfAtom(1.0);
-    for (UnsignedLong j = 0; j < dimension; ++j)
-      cdfAtom *= kernel_.computeCDF((point[j] - sample_[i][j]) * bandwidthInverse_[j]);
-    cdfValue += cdfAtom;
+    NumericalScalar cdfAtom(kernel_.computeSurvivalFunction((point[0] - sample_[i][0]) * bandwidthInverse_[0]));
+    for (UnsignedLong j = 1; j < dimension; ++j)
+    {
+      if (cdfAtom < cdfEpsilon) break;
+      cdfAtom *= kernel_.computeSurvivalFunction((point[j] - sample_[i][j]) * bandwidthInverse_[j]);
+    }
+    survivalValue += cdfAtom;
   } /* end for */
   cdfEpsilon_ = kernel_.getCDFEpsilon() * size;
-  return cdfValue / size;
+  return survivalValue / size;
+}
+
+/* Compute the quantile function of the distribution */
+NumericalScalar KernelMixture::computeScalarQuantile(const NumericalScalar prob,
+    const Bool tail) const
+{
+  if (!useApproximatePDFCDF_) return DistributionImplementation::computeScalarQuantile(prob, tail);
+  const NumericalScalar a(getRange().getLowerBound()[0]);
+  const NumericalScalar b(getRange().getUpperBound()[0]);
+  if (prob <= 0.0) return (tail ? b : a);
+  if (prob >= 1.0) return (tail ? a : b);
+  const UnsignedLong n(cdfApproximation_.getLocations().getSize());
+  if (tail)
+  {
+    // Here we have to solve ComplementaryCDF(x) = prob which is mathematically
+    // equivalent to CDF(x) = 1 - prob, but numerically different with an
+    // accuracy that depends on prob.
+    // The cut-off is around the mean value
+    if (prob <= ccdfApproximation_.getValues()[0][0]) return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(ccdfApproximation_, prob, ccdfApproximation_.getLocations()[0], ccdfApproximation_.getLocations()[n - 1], ccdfApproximation_.getValues()[0][0], ccdfApproximation_.getValues()[n - 1][0]);
+    return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(cdfApproximation_, 1.0 - prob, cdfApproximation_.getLocations()[0], cdfApproximation_.getLocations()[n - 1], cdfApproximation_.getValues()[0][0], cdfApproximation_.getValues()[n - 1][0]);
+  }
+  // Here we have to solve CDF(x) = prob which is mathematically
+  // equivalent to ComplementaryCDF(x) = 1 - prob, but numerically
+  // different with an accuracy that depends on prob.
+  // The cut-off is around the mean value
+  if (prob <= cdfApproximation_.getValues()[n - 1][0]) return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(cdfApproximation_, prob, cdfApproximation_.getLocations()[0], cdfApproximation_.getLocations()[n - 1], cdfApproximation_.getValues()[0][0], cdfApproximation_.getValues()[n - 1][0]);
+  return Brent(quantileEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_).solve(ccdfApproximation_, 1.0 - prob, ccdfApproximation_.getLocations()[0], ccdfApproximation_.getLocations()[n - 1], ccdfApproximation_.getValues()[0][0], ccdfApproximation_.getValues()[n - 1][0]);
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
@@ -302,10 +465,7 @@ KernelMixture::Implementation KernelMixture::getMarginal(const Indices & indices
   // General case
   const UnsignedLong marginalDimension(indices.getSize());
   NumericalPoint marginalBandwidth(marginalDimension);
-  for (UnsignedLong i = 0; i < marginalDimension; ++i)
-  {
-    marginalBandwidth[i] = bandwidth_[indices[i]];
-  }
+  for (UnsignedLong i = 0; i < marginalDimension; ++i) marginalBandwidth[i] = bandwidth_[indices[i]];
   return new KernelMixture(kernel_, marginalBandwidth, sample_.getMarginal(indices));
 }
 
@@ -323,11 +483,11 @@ void KernelMixture::computeMean() const
   // We know that the kernel is 1D, so its mean value is actually a scalar
   const NumericalScalar meanKernel(kernel_.getMean()[0]);
   mean_ = sample_.computeMean();
+  isAlreadyComputedMean_ = true;
   // Special case for symmetric kernel
   if (meanKernel == 0.0) return;
   // General case
   mean_ += meanKernel * bandwidth_;
-  isAlreadyComputedMean_ = true;
 }
 
 /* Compute the covariance of the KernelMixture
@@ -403,17 +563,46 @@ KernelMixture::NumericalPointWithDescriptionCollection KernelMixture::getParamet
 {
   const UnsignedLong dimension(getDimension());
   const UnsignedLong size(sample_.getSize());
-  NumericalPointWithDescriptionCollection parameters(dimension + 1);
+  NumericalPointWithDescriptionCollection parameters(dimension + (dimension > 1 ? 1 : 0));
   // The marginal parameters : the sample and the bandwidth
   for (UnsignedLong i = 0; i < dimension; ++i)
   {
     NumericalPointWithDescription marginalParameters(size + 1);
+    Description description(marginalParameters.getDimension());
     for (UnsignedLong j = 0; j < size; ++j)
+    {
       marginalParameters[j] = sample_[j][i];
+      if (dimension > 1) description[j] = (OSS() << "x_" << j << "^" << i);
+      else description[j] = (OSS() << "x_" << j);
+    }
     marginalParameters[size] = bandwidth_[i];
+    if (dimension > 1) description[size] = (OSS() << "h_" << i);
+    else description[size] = (OSS() << "h");
+    marginalParameters.setDescription(description);
     parameters[i] = marginalParameters;
   }
-  parameters[dimension] = kernel_.getParametersCollection()[0];
+  // The dependence parameters is the union of all the parameters as they all contribute to the copula, presented in a different way
+  if (dimension > 1)
+  {
+    NumericalPointWithDescription dependence(dimension * (size + 1));
+    Description description(dependence.getDimension());
+    UnsignedLong index(0);
+    for (UnsignedLong i = 0; i < size; ++i)
+      for (UnsignedLong j = 0; j < dimension; ++j)
+      {
+        dependence[index] = sample_[i][j];
+        description[index] = (OSS() << "x_" << i << "^" << j);
+        ++index;
+      }
+    for (UnsignedLong i = 0; i < dimension; ++i)
+    {
+      dependence[index] = bandwidth_[i];
+      description[index] = (OSS() << "h_" << i);
+      ++index;
+    }
+    dependence.setDescription(description);
+    parameters[dimension] = dependence;
+  }
   return parameters;
 } // getParametersCollection
 
@@ -448,23 +637,33 @@ Bool KernelMixture::hasIndependentCopula() const
 /* Method save() stores the object through the StorageManager */
 void KernelMixture::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "kernel_", kernel_ );
   adv.saveAttribute( "bandwidth_", bandwidth_ );
   adv.saveAttribute( "bandwidthInverse_", bandwidthInverse_ );
   adv.saveAttribute( "normalizationFactor_", normalizationFactor_ );
   adv.saveAttribute( "sample_", sample_ );
+  adv.saveAttribute( "pdfApproximationCDF_", pdfApproximationCDF_ );
+  adv.saveAttribute( "cdfApproximation_", cdfApproximation_ );
+  adv.saveAttribute( "pdfApproximationCCDF_", pdfApproximationCCDF_ );
+  adv.saveAttribute( "ccdfApproximation_", ccdfApproximation_ );
+  adv.saveAttribute( "useApproximatePDFCDF_", useApproximatePDFCDF_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
 void KernelMixture::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "kernel_", kernel_ );
   adv.loadAttribute( "bandwidth_", bandwidth_ );
   adv.loadAttribute( "bandwidthInverse_", bandwidthInverse_ );
   adv.loadAttribute( "normalizationFactor_", normalizationFactor_ );
   adv.loadAttribute( "sample_", sample_ );
+  adv.loadAttribute( "pdfApproximationCDF_", pdfApproximationCDF_ );
+  adv.loadAttribute( "cdfApproximation_", cdfApproximation_ );
+  adv.loadAttribute( "pdfApproximationCCDF_", pdfApproximationCCDF_ );
+  adv.loadAttribute( "ccdfApproximation_", ccdfApproximation_ );
+  adv.loadAttribute( "useApproximatePDFCDF_", useApproximatePDFCDF_ );
   computeRange();
 }
 
