@@ -3,7 +3,7 @@
  *  @file  KernelSmoothing.cxx
  *  @brief This class acts like a KernelMixture factory, implementing a
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -57,7 +57,7 @@ KernelSmoothing::KernelSmoothing(const String & name)
   , bined_(true)
   , binNumber_(ResourceMap::GetAsUnsignedLong( "KernelSmoothing-BinNumber" ))
 {
-  if (binNumber_ < 2) throw InvalidArgumentException(HERE) << "Error: The default number of bins=" << binNumber_ << " is less than 2. Chek the ResourceMap or the openturns.conf file.";
+  if (binNumber_ < 2) throw InvalidArgumentException(HERE) << "Error: The default number of bins=" << binNumber_ << " is less than 2. Check the ResourceMap or the openturns.conf file.";
 }
 
 /* Default constructor */
@@ -234,10 +234,20 @@ Distribution KernelSmoothing::build(const NumericalSample & sample,
   // The usual case: no boundary correction, no binning
   const Bool mustBin(bined_ && (dimension * log(binNumber_) < log(size)));
   if (bined_ != mustBin) LOGINFO("Will not bin the data because the bin number is greater than the sample size");
-  if ((dimension > 2) || ((!mustBin) && (!boundaryCorrection))) return KernelMixture(kernel_, bandwidth, sample);
+  if ((dimension > 2) || ((!mustBin) && (!boundaryCorrection)))
+  {
+    KernelMixture result(kernel_, bandwidth, sample);
+    result.setDescription(sample.getDescription());
+    return result;
+  }
   const NumericalPoint xmin(sample.getMin());
   const NumericalPoint xmax(sample.getMax());
-  if (xmin == xmax) return Dirac(xmin);
+  if (xmin == xmax)
+  {
+    Dirac result(xmin);
+    result.setDescription(sample.getDescription());
+    return result;
+  }
   // 2D binning?
   if ((dimension == 2) && mustBin)
   {
@@ -277,8 +287,10 @@ Distribution KernelSmoothing::build(const NumericalSample & sample,
         atoms[i + j * binNumber_] = atom;
       }
     }
-    return Mixture(atoms, reducedData);
-  }
+    Mixture result(atoms, reducedData);
+    result.setDescription(sample.getDescription());
+    return result;
+  } // 2D binning
 
   // Here we are in the 1D case, with at least binning or boundary boundary correction
   NumericalSample newSample(sample);
@@ -297,7 +309,12 @@ Distribution KernelSmoothing::build(const NumericalSample & sample,
     }
   }
   // Now, work on the extended sample
-  if (!mustBin) return TruncatedDistribution(KernelMixture(kernel_, bandwidth, newSample), xmin[0], xmax[0]);
+  if (!mustBin)
+  {
+    TruncatedDistribution result(KernelMixture(kernel_, bandwidth, newSample), xmin[0], xmax[0]);
+    result.setDescription(sample.getDescription());
+    return result;
+  }
   if (boundaryCorrection)
   {
     xminNew = newSample.getMin()[0];
@@ -324,8 +341,15 @@ Distribution KernelSmoothing::build(const NumericalSample & sample,
     KernelMixture atom(kernel_, bandwidth, NumericalSample(1, NumericalPoint(1, x[i])));
     atoms[i] = atom;
   }
-  if (boundaryCorrection) return TruncatedDistribution(Mixture(atoms, reducedData), xmin[0], xmax[0]);
-  return Mixture(atoms, reducedData);
+  if (boundaryCorrection)
+  {
+    TruncatedDistribution result(Mixture(atoms, reducedData), xmin[0], xmax[0]);
+    result.setDescription(sample.getDescription());
+    return result;
+  }
+  Mixture result(atoms, reducedData);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 /* Bandwidth accessor */
