@@ -3,7 +3,7 @@
  *  @file  Laplace.cxx
  *  @brief The Laplace distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,7 +35,7 @@ static Factory<Laplace> RegisteredFactory("Laplace");
 
 /* Default constructor */
 Laplace::Laplace()
-  : NonEllipticalDistribution("Laplace"),
+  : ContinuousDistribution("Laplace"),
     lambda_(1.0),
     mu_(0.0)
 {
@@ -46,7 +46,7 @@ Laplace::Laplace()
 /* Parameters constructor */
 Laplace::Laplace(const NumericalScalar lambda,
                  const NumericalScalar mu)
-  : NonEllipticalDistribution("Laplace"),
+  : ContinuousDistribution("Laplace"),
     lambda_(lambda),
     mu_(mu)
 {
@@ -132,6 +132,16 @@ NumericalScalar Laplace::computeCDF(const NumericalPoint & point) const
   return 1.0 - 0.5 * exp(-u);
 }
 
+/* Get the complementary CDF of the distribution */
+NumericalScalar Laplace::computeComplementaryCDF(const NumericalPoint & point) const
+{
+  if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
+
+  const NumericalScalar u(lambda_ * (point[0] - mu_));
+  if (u < 0.0) return 1.0 - 0.5 * exp(u);
+  return 0.5 * exp(-u);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Laplace::computeCharacteristicFunction(const NumericalScalar x) const
 {
@@ -173,8 +183,7 @@ NumericalPoint Laplace::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Laplace::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   const NumericalScalar d(tail ? 0.5 - prob : prob - 0.5);
   if (d < 0.0) return mu_ + log1p(2.0 * d) / lambda_;
@@ -289,7 +298,7 @@ NumericalScalar Laplace::getLambda() const
 /* Method save() stores the object through the StorageManager */
 void Laplace::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "lambda_", lambda_ );
   adv.saveAttribute( "mu_", mu_ );
 }
@@ -297,7 +306,7 @@ void Laplace::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Laplace::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "lambda_", lambda_ );
   adv.loadAttribute( "mu_", mu_ );
   computeRange();
