@@ -3,7 +3,7 @@
  *  @file  LaplaceFactory.cxx
  *  @brief Factory for Laplace distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,7 +66,9 @@ Laplace LaplaceFactory::buildAsLaplace(const NumericalSample & sample) const
   NumericalScalar tau(0.0);
   for (UnsignedLong i = 0; i < size; ++i) tau += fabs(sample[i][0] - mu);
   if (tau == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Laplace distribution with infinite lambda.";
-  return Laplace(size / tau, mu);
+  Laplace result(size / tau, mu);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Laplace LaplaceFactory::buildAsLaplace(const NumericalPointWithDescriptionCollection & parameters) const
