@@ -3,7 +3,7 @@
  *  @file  LogNormal.cxx
  *  @brief The LogNormal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,7 @@ static Factory<LogNormal> RegisteredFactory("LogNormal");
 
 /* Default constructor */
 LogNormal::LogNormal()
-  : NonEllipticalDistribution("LogNormal")
+  : ContinuousDistribution("LogNormal")
   , muLog_(0.0)
   , sigmaLog_(0.0)
   , gamma_(0.0)
@@ -59,7 +59,7 @@ LogNormal::LogNormal(const NumericalScalar arg1,
                      const NumericalScalar arg2,
                      const NumericalScalar gamma,
                      const ParameterSet set)
-  : NonEllipticalDistribution("LogNormal"),
+  : ContinuousDistribution("LogNormal"),
     muLog_(0.0),
     sigmaLog_(0.0),
     gamma_(gamma),
@@ -106,7 +106,7 @@ Bool LogNormal::operator ==(const LogNormal & other) const
 /* String converter */
 String LogNormal::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << LogNormal::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -118,7 +118,7 @@ String LogNormal::__repr__() const
 
 String LogNormal::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(muLog = " << muLog_ << ", sigmaLog = " << sigmaLog_ << ", gamma = " << gamma_ << ")";
   return oss;
 }
@@ -313,8 +313,7 @@ NumericalPoint LogNormal::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar LogNormal::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return gamma_ + exp(muLog_ + sigmaLog_ * DistFunc::qNormal(prob, tail));
 }
@@ -517,7 +516,7 @@ NumericalScalar LogNormal::getSigmaOverMu() const
 /* Method save() stores the object through the StorageManager */
 void LogNormal::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "muLog_", muLog_ );
   adv.saveAttribute( "sigmaLog_", sigmaLog_ );
   adv.saveAttribute( "gamma_", gamma_ );
@@ -528,7 +527,7 @@ void LogNormal::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void LogNormal::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "muLog_", muLog_ );
   adv.loadAttribute( "sigmaLog_", sigmaLog_ );
   adv.loadAttribute( "gamma_", gamma_ );
