@@ -3,7 +3,7 @@
  *  @file  LogNormalFactory.cxx
  *  @brief Factory for LogNormal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include "Brent.hxx"
 #include "DistFunc.hxx"
 #include "SpecFunc.hxx"
+#include "ResourceMap.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -63,7 +64,9 @@ LogNormal LogNormalFactory::buildMethodOfMoments(const NumericalSample & sample)
   const NumericalScalar mu(log(beta));
   const NumericalScalar mean(sample.computeMean()[0]);
   const NumericalScalar gamma(mean - beta * sqrt(omega));
-  return LogNormal(mu, sigma, gamma);
+  LogNormal result(mu, sigma, gamma);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 struct LogNormalFactoryLMLEParameterConstraint
@@ -121,7 +124,7 @@ LogNormal LogNormalFactory::buildMethodOfLocalLikelihoodMaximization(const Numer
   const NumericalMathFunction f(bindMethod<LogNormalFactoryLMLEParameterConstraint, NumericalPoint, NumericalPoint>(constraint, &LogNormalFactoryLMLEParameterConstraint::computeConstraint, 1, 1));
   NumericalScalar constraintRight(f(NumericalPoint(1, right))[0]);
   NumericalScalar left(right - step);
-  NumericalScalar constraintLeft(f(NumericalPoint(1, right))[0]);
+  NumericalScalar constraintLeft(f(NumericalPoint(1, left))[0]);
   // First, the bracketing interval. We should find a change of sign within [Xmin-sigma, Xmin], else use another estimator
   while ((constraintLeft < 0.0) == (constraintRight < 0.0) && (step < sqrt(SpecFunc::MaxNumericalScalar)))
   {
@@ -149,7 +152,7 @@ LogNormal LogNormalFactory::buildMethodOfLocalLikelihoodMaximization(const Numer
 
 struct LogNormalFactoryMMEParameterConstraint
 {
-  /** Constructor from a sample and a derivative factor estimate */
+  /* Constructor from a sample and a derivative factor estimate */
   LogNormalFactoryMMEParameterConstraint(const UnsignedLong n,
                                          const NumericalScalar xMin,
                                          const NumericalScalar mean,
@@ -223,6 +226,11 @@ LogNormal LogNormalFactory::buildMethodOfModifiedMoments(const NumericalSample &
   return LogNormal(mu, sigma, gamma);
 }
 
+LogNormalFactory::Implementation LogNormalFactory::build(const NumericalSample & sample) const
+{
+  return build(sample, ResourceMap::GetAsUnsignedLong("LogNormalFactory-EstimationMethod"));
+}
+
 LogNormalFactory::Implementation LogNormalFactory::build(const NumericalSample & sample,
     const UnsignedLong method) const
 {
@@ -239,6 +247,11 @@ LogNormalFactory::Implementation LogNormalFactory::build(const NumericalPointCol
   return buildAsLogNormal(parameters).clone();
 }
 
+LogNormal LogNormalFactory::buildAsLogNormal(const NumericalSample & sample) const
+{
+  return buildAsLogNormal(sample, ResourceMap::GetAsUnsignedLong("LogNormalFactory-EstimationMethod"));
+};
+
 LogNormal LogNormalFactory::buildAsLogNormal(const NumericalSample & sample,
     const UnsignedLong method) const
 {
