@@ -3,7 +3,7 @@
  *  @file  LogUniform.cxx
  *  @brief The LogUniform distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,20 +29,17 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(LogUniform);
 
 static Factory<LogUniform> RegisteredFactory("LogUniform");
 
 /* Default constructor */
 LogUniform::LogUniform()
-  : NonEllipticalDistribution("LogUniform"),
-    aLog_(-1.0),
-    bLog_(1.0),
-    a_(exp(-1.0)),
-    b_(exp(1.0))
+  : ContinuousDistribution("LogUniform")
+  , aLog_(-1.0)
+  , bLog_(1.0)
+  , a_(exp(-1.0))
+  , b_(exp(1.0))
 {
   setDimension( 1 );
   computeRange();
@@ -51,11 +48,11 @@ LogUniform::LogUniform()
 /* Parameters constructor */
 LogUniform::LogUniform(const NumericalScalar aLog,
                        const NumericalScalar bLog)
-  : NonEllipticalDistribution("LogUniform"),
-    aLog_(aLog),
-    bLog_(bLog),
-    a_(exp(aLog_)),
-    b_(exp(bLog_))
+  : ContinuousDistribution("LogUniform")
+  , aLog_(aLog)
+  , bLog_(bLog)
+  , a_(exp(aLog_))
+  , b_(exp(bLog_))
 {
   if (bLog <= aLog) throw InvalidArgumentException(HERE) << "Error the lower bound aLog of a LogUniform distribution must be lesser than its upper bound bLog, here aLog=" << aLog << " bLog=" << bLog;
   setDimension( 1 );
@@ -72,7 +69,7 @@ Bool LogUniform::operator ==(const LogUniform & other) const
 /* String converter */
 String LogUniform::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << LogUniform::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -85,7 +82,7 @@ String LogUniform::__repr__() const
 
 String LogUniform::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(aLog = " << aLog_ << ", bLog = " << bLog_ << ")";
   return oss;
 }
@@ -139,7 +136,7 @@ NumericalScalar LogUniform::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= a_) return 0.0;
-  if (x > b_)  return 1.0;
+  if (x >= b_)  return 1.0;
   return (log(x) - aLog_) / (bLog_ - aLog_);
 }
 
@@ -184,8 +181,7 @@ NumericalPoint LogUniform::computeCDFGradient(const NumericalPoint & point) cons
 
 /* Get the quantile of the distribution */
 NumericalScalar LogUniform::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return exp(bLog_ - prob * (bLog_ - aLog_));
   return exp(aLog_ + prob * (bLog_ - aLog_));
@@ -322,7 +318,7 @@ NumericalScalar LogUniform::getBLog() const
 /* Method save() stores the object through the StorageManager */
 void LogUniform::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "aLog_", aLog_ );
   adv.saveAttribute( "bLog_", bLog_ );
   adv.saveAttribute( "a_", a_ );
@@ -332,7 +328,7 @@ void LogUniform::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void LogUniform::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "aLog_", aLog_ );
   adv.loadAttribute( "bLog_", bLog_ );
   adv.loadAttribute( "a_", a_ );
