@@ -3,7 +3,7 @@
  *  @file  LogUniformFactory.cxx
  *  @brief Factory for LogUniform distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,7 +71,9 @@ LogUniform LogUniformFactory::buildAsLogUniform(const NumericalSample & sample)
   const NumericalScalar b(xMax + fabs(xMax) / (2.0 + size));
   const NumericalScalar bLog(log(b));
   if (aLog >= bLog) throw InvalidArgumentException(HERE) << "Error: can build a LogUniform distribution only if aLog < bLog, here aLog=" << aLog << " and bLog=" << bLog;
-  return LogUniform(aLog, bLog);
+  LogUniform result(aLog, bLog);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 LogUniform LogUniformFactory::buildAsLogUniform(const NumericalPointWithDescriptionCollection & parameters) const
