@@ -3,7 +3,7 @@
  *  @file  Logistic.cxx
  *  @brief The Logistic distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,7 +35,7 @@ static Factory<Logistic> RegisteredFactory("Logistic");
 
 /* Default constructor */
 Logistic::Logistic()
-  : NonEllipticalDistribution("Logistic"),
+  : ContinuousDistribution("Logistic"),
     alpha_(0.0), beta_(1.0)
 {
   setDimension( 1 );
@@ -45,7 +45,7 @@ Logistic::Logistic()
 /* Parameters constructor */
 Logistic::Logistic(const NumericalScalar alpha,
                    const NumericalScalar beta)
-  : NonEllipticalDistribution("Logistic"),
+  : ContinuousDistribution("Logistic"),
     alpha_(alpha), beta_(0.0)
 {
   // This call set also the range.
@@ -108,21 +108,29 @@ NumericalPoint Logistic::computeDDF(const NumericalPoint & point) const
 NumericalScalar Logistic::computePDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
-
-  const NumericalScalar x((point[0] - alpha_) / beta_);
-  if ((x <= 0.5 * SpecFunc::LogMinNumericalScalar) || (x >= 0.5 * SpecFunc::LogMaxNumericalScalar)) return 0.0;
-  NumericalScalar expX(exp(x));
-  NumericalScalar betaExpX(beta_ * (1.0 + expX));
-  return beta_ * expX / (betaExpX * betaExpX);
+  const NumericalScalar z((point[0] - alpha_) / beta_);
+  if (z > 12.38075336)
+  {
+    const NumericalScalar expMZ(exp(-z));
+    return expMZ * (1.0 - 2.0 * expMZ) / beta_;
+  }
+  if (z < -12.38075336)
+  {
+    const NumericalScalar expZ(exp(z));
+    return expZ * (1.0 - 2.0 * expZ) / beta_;
+  }
+  const NumericalScalar expMZ(exp(-z));
+  return expMZ / (beta_ * pow(1.0 + expMZ, 2.0));
 }
 
 NumericalScalar Logistic::computeLogPDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalScalar x((point[0] - alpha_) / beta_);
-  if ((x <= 0.5 * SpecFunc::LogMinNumericalScalar) || (x >= 0.5 * SpecFunc::LogMaxNumericalScalar)) return -SpecFunc::MaxNumericalScalar;
-  return -log(beta_) + x - 2.0 * log1p(exp(x));
+  const NumericalScalar z((point[0] - alpha_) / beta_);
+  if (z > 12.38075336) return -z + log1p(-2.0 * exp(-z)) - log(beta_);
+  if (z < -12.38075336) return z + log1p(-2.0 * exp(z)) - log(beta_);
+  return -z - log(beta_) - 2.0 * log1p(exp(-z));
 }
 
 /* Get the CDF of the distribution */
@@ -130,16 +138,36 @@ NumericalScalar Logistic::computeCDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalScalar expX(exp((point[0] - alpha_) / beta_));
-  return expX / (1.0 + expX);
+  const NumericalScalar z((point[0] - alpha_) / beta_);
+  if (z > 12.01454911)
+  {
+    const NumericalScalar expMZ(exp(-z));
+    return 1.0 - expMZ * (1.0 - expMZ);
+  }
+  if (z < -12.01454911)
+  {
+    const NumericalScalar expZ(exp(z));
+    return expZ * (1.0 - expZ);
+  }
+  return 1.0 / (1.0 + exp(-z));
 }
 
 NumericalScalar Logistic::computeComplementaryCDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalScalar expX(exp((point[0] - alpha_) / beta_));
-  return 1.0 / (1.0 + expX);
+  const NumericalScalar z((point[0] - alpha_) / beta_);
+  if (z > 12.01454911)
+  {
+    const NumericalScalar expMZ(exp(-z));
+    return expMZ * (1.0 - expMZ);
+  }
+  if (z < -12.01454911)
+  {
+    const NumericalScalar expZ(exp(z));
+    return 1.0 - expZ * (1.0 - expZ);
+  }
+  return 1.0 / (1.0 + exp(z));
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
@@ -181,8 +209,7 @@ NumericalPoint Logistic::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Logistic::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return alpha_ + beta_ * log((1.0 - prob) / prob);
   return alpha_ + beta_ * log(prob / (1.0 - prob));
@@ -327,7 +354,7 @@ NumericalScalar Logistic::getBeta() const
 /* Method save() stores the object through the StorageManager */
 void Logistic::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "alpha_", alpha_ );
   adv.saveAttribute( "beta_", beta_ );
 }
@@ -335,7 +362,7 @@ void Logistic::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Logistic::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "alpha_", alpha_ );
   adv.loadAttribute( "beta_", beta_ );
   computeRange();
