@@ -3,7 +3,7 @@
  *  @file  LogisticFactory.cxx
  *  @brief Factory for Logistic distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -66,7 +66,9 @@ Logistic LogisticFactory::buildAsLogistic(const NumericalSample & sample) const
   NumericalScalar alpha(sample.computeMean()[0]);
   NumericalScalar beta(sample.computeStandardDeviationPerComponent()[0] * SpecFunc::SQRT3_PI);
   if (beta <= 0.0) throw InvalidArgumentException(HERE) << "Error: can build a Logistic distribution only if beta > 0.0, here beta=" << beta;
-  return Logistic(alpha, beta);
+  Logistic result(alpha, beta);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Logistic LogisticFactory::buildAsLogistic(const NumericalPointWithDescriptionCollection & parameters) const
