@@ -3,7 +3,7 @@
  *  @file  MinCopula.cxx
  *  @brief A class that implements an independent copula
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -41,6 +41,7 @@ MinCopula::MinCopula(const UnsignedLong dim)
 {
   // The range is generic for all the copulas
   setDimension(dim);
+  computeRange();
 }
 
 /* Comparison operator */
@@ -111,6 +112,12 @@ NumericalScalar MinCopula::computeCDF(const NumericalPoint & point) const
   return std::max(0.0, std::min(1.0, u));
 } // computeCDF
 
+/* Compute the survival function */
+NumericalScalar MinCopula::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  return computeCDF(NumericalPoint(getDimension(), 1.0) - point);
+}
+
 /* Get the quantile of the distribution */
 NumericalPoint MinCopula::computeQuantile(const NumericalScalar prob,
     const Bool tail) const
@@ -133,6 +140,20 @@ void MinCopula::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix MinCopula::getSpearmanCorrelation() const
+{
+  const UnsignedLong dimension(getDimension());
+  return CorrelationMatrix(dimension, Collection<NumericalScalar>(dimension * dimension, 1.0));
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix MinCopula::getKendallTau() const
+{
+  const UnsignedLong dimension(getDimension());
+  return CorrelationMatrix(dimension, Collection<NumericalScalar>(dimension * dimension, 1.0));
+}
+
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 MinCopula::Implementation MinCopula::getMarginal(const Indices & indices) const
 {
@@ -205,6 +226,7 @@ void MinCopula::load(Advocate & adv)
 {
   // The range is generic for all the copulas
   CopulaImplementation::load(adv);
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
