@@ -3,7 +3,7 @@
  *  @file  Mixture.cxx
  *  @brief Abstract top-level class for all Mixtures
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,6 +38,11 @@ Mixture::Mixture()
   : DistributionImplementation("Mixture")
   , distributionCollection_(1)
   , weightsDistribution_(UserDefined())
+  , pdfApproximationCDF_()
+  , cdfApproximation_()
+  , pdfApproximationCCDF_()
+  , ccdfApproximation_()
+  , useApproximatePDFCDF_(false)
 {
   // Set an empty range
   setRange(Interval(1.0, 0.0));
@@ -48,6 +53,11 @@ Mixture::Mixture(const DistributionCollection & coll)
   : DistributionImplementation("Mixture")
   , distributionCollection_()
   , weightsDistribution_()
+  , pdfApproximationCDF_()
+  , cdfApproximation_()
+  , pdfApproximationCCDF_()
+  , ccdfApproximation_()
+  , useApproximatePDFCDF_(false)
 {
   // We could NOT set distributionCollection_ in the member area of the constructor
   // because we must check before if the collection is valid (ie, if all the
@@ -55,6 +65,16 @@ Mixture::Mixture(const DistributionCollection & coll)
   // the setDistributionCollection() method that do it for us.
   // This call set also the range.
   setDistributionCollection( coll );
+  if ((getDimension() == 1) && (coll.getSize() >= ResourceMap::GetAsUnsignedLong("Mixture-SmallSize")) && (coll.getSize() < ResourceMap::GetAsUnsignedLong("Mixture-LargeSize")))
+  {
+    // Here we use the implementation provided by the DistributionImplementation class instead of the ContinuousDistribution class in order to use both the PDF and the CDF
+    Collection<PiecewiseHermiteEvaluationImplementation> coll(DistributionImplementation::interpolatePDFCDF(ResourceMap::GetAsUnsignedLong("Mixture-PDFCDFDiscretization")));
+    pdfApproximationCDF_ = coll[0];
+    cdfApproximation_ = coll[1];
+    pdfApproximationCCDF_ = coll[2];
+    ccdfApproximation_ = coll[3];
+    useApproximatePDFCDF_ = true;
+  }
 }
 
 /* Parameters constructor */
@@ -63,6 +83,11 @@ Mixture::Mixture(const DistributionCollection & coll,
   : DistributionImplementation("Mixture")
   , distributionCollection_()
   , weightsDistribution_()
+  , pdfApproximationCDF_()
+  , cdfApproximation_()
+  , pdfApproximationCCDF_()
+  , ccdfApproximation_()
+  , useApproximatePDFCDF_(false)
 {
   if (coll.getSize() != weights.getSize()) throw InvalidArgumentException(HERE) << "Error: the weight size " << weights.getSize() << " must be equal to the distribution collection size " << coll.getSize();
   // We could NOT set distributionCollection_ in the member area of the constructor
@@ -71,6 +96,16 @@ Mixture::Mixture(const DistributionCollection & coll,
   // the setDistributionCollection() method that do it for us.
   // This call set also the range.
   setDistributionCollectionWithWeights( coll, weights );
+  if ((getDimension() == 1) && (coll.getSize() >= ResourceMap::GetAsUnsignedLong("Mixture-SmallSize")) && (coll.getSize() < ResourceMap::GetAsUnsignedLong("Mixture-LargeSize")))
+  {
+    // Here we use the implementation provided by the DistributionImplementation class instead of the ContinuousDistribution class in order to use both the PDF and the CDF
+    Collection<PiecewiseHermiteEvaluationImplementation> coll(DistributionImplementation::interpolatePDFCDF(ResourceMap::GetAsUnsignedLong("Mixture-PDFCDFDiscretization")));
+    pdfApproximationCDF_ = coll[0];
+    cdfApproximation_ = coll[1];
+    pdfApproximationCCDF_ = coll[2];
+    ccdfApproximation_ = coll[3];
+    useApproximatePDFCDF_ = true;
+  }
 }
 
 /* Comparison operator */
@@ -83,7 +118,7 @@ Bool Mixture::operator ==(const Mixture & other) const
 /* String converter */
 String Mixture::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Mixture::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -94,12 +129,12 @@ String Mixture::__repr__() const
 
 String Mixture::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(";
   String separator("");
   for (UnsignedLong i = 0; i < distributionCollection_.getSize(); ++i)
   {
-    oss << separator << "(w = " << distributionCollection_[i].getWeight() << ", d = " << distributionCollection_[i].__str__();
+    oss << separator << "(w = " << distributionCollection_[i].getWeight() << ", d = " << distributionCollection_[i];
     separator = ", ";
   }
   oss << ")";
@@ -235,7 +270,7 @@ Mixture * Mixture::clone() const
 NumericalPoint Mixture::getRealization() const
 {
   // Select the atom following the weightsDistribution
-  const UnsignedLong index((UnsignedLong)(round(weightsDistribution_.getRealization()[0])));
+  const UnsignedLong index(static_cast<UnsignedLong>(round(weightsDistribution_.getRealization()[0])));
   return distributionCollection_[index].getRealization();
 }
 
@@ -258,7 +293,11 @@ NumericalScalar Mixture::computePDF(const NumericalPoint & point) const
 {
   const UnsignedLong dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-
+  if (useApproximatePDFCDF_)
+  {
+    if (point[0] < getMean()[0]) return pdfApproximationCDF_.derivate(point)[0];
+    else return pdfApproximationCCDF_.derivate(point)[0];
+  }
   NumericalScalar pdfValue(0.0);
   const UnsignedLong size(distributionCollection_.getSize());
   if (!getRange().numericallyContains(point)) return pdfValue;
@@ -272,12 +311,29 @@ NumericalScalar Mixture::computeCDF(const NumericalPoint & point) const
   const UnsignedLong dimension(getDimension());
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
+  if (useApproximatePDFCDF_)
+  {
+    if (point[0] < getMean()[0]) return cdfApproximation_(point)[0];
+    else return 1.0 - ccdfApproximation_(point)[0];
+  }
   NumericalScalar cdfValue(0.0);
   const UnsignedLong size(distributionCollection_.getSize());
   for(UnsignedLong i = 0; i < size; ++i) cdfValue += distributionCollection_[i].getWeight() * distributionCollection_[i].computeCDF(point);
   return cdfValue;
 }
 
+/* Get the survival function of the Mixture */
+NumericalScalar Mixture::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  const UnsignedLong dimension(getDimension());
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
+
+  NumericalScalar survivalValue(0.0);
+  const UnsignedLong size(distributionCollection_.getSize());
+  for(UnsignedLong i = 0; i < size; ++i) survivalValue += distributionCollection_[i].getWeight() * distributionCollection_[i].computeSurvivalFunction(point);
+  return survivalValue;
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Mixture::computeCharacteristicFunction(const NumericalScalar x) const
 {
@@ -411,10 +467,10 @@ Mixture::NumericalPointWithDescriptionCollection Mixture::getParametersCollectio
     return parameters;
   }
   // General case
-  NumericalPointWithDescriptionCollection parameters(dimension + 1);
+  NumericalPointWithDescriptionCollection parameters(size + 1);
   Description description;
   // First put the marginal parameters
-  for (UnsignedLong marginalIndex = 0; marginalIndex < dimension; ++marginalIndex)
+  for (UnsignedLong marginalIndex = 0; marginalIndex < size; ++marginalIndex)
   {
     // Each marginal distribution must output a collection of parameters of size 1, even if it contains an empty NumericalPoint
     const NumericalPointWithDescriptionCollection marginalParameters(distributionCollection_[marginalIndex].getParametersCollection());
@@ -433,15 +489,23 @@ Mixture::NumericalPointWithDescriptionCollection Mixture::getParametersCollectio
     // Add the current atom dependence parameters
     for (UnsignedLong j = 0; j < atomParameterDimension; j++)
     {
-      parameters[dimension].add(atomDependenceParameters[j]);
+      parameters[size].add(atomDependenceParameters[j]);
       description.add(prefix + atomDescription[j]);
     }
   }
-  parameters[dimension].setDescription(description);
-  parameters[dimension].setName("dependence");
+  parameters[size].setDescription(description);
+  parameters[size].setName("dependence");
   return parameters;
 } // getParametersCollection
 
+/* Check if the distribution is elliptical */
+Bool Mixture::isCopula() const
+{
+  const UnsignedLong size(distributionCollection_.getSize());
+  for (UnsignedLong i = 0; i < size; ++i) if (!distributionCollection_[i].isCopula()) return false;
+  return true;
+}
+
 /* Check if the distribution is elliptical */
 Bool Mixture::isElliptical() const
 {
@@ -454,12 +518,15 @@ Bool Mixture::isElliptical() const
 Bool Mixture::isContinuous() const
 {
   const UnsignedLong size(distributionCollection_.getSize());
-  Bool flag(distributionCollection_[0].getImplementation()->isContinuous());
-  for (UnsignedLong i = 1; i < size; ++i)
-  {
-    flag = flag && distributionCollection_[i].getImplementation()->isContinuous();
-    if (!flag) return false;
-  }
+  for (UnsignedLong i = 0; i < size; ++i) if (!distributionCollection_[i].isContinuous()) return false;
+  return true;
+}
+
+/* Check if the distribution is discrete */
+Bool Mixture::isDiscrete() const
+{
+  const UnsignedLong size(distributionCollection_.getSize());
+  for (UnsignedLong i = 1; i < size; ++i) if (!distributionCollection_[i].isDiscrete()) return false;
   return true;
 }
 
@@ -467,12 +534,7 @@ Bool Mixture::isContinuous() const
 Bool Mixture::isIntegral() const
 {
   const UnsignedLong size(distributionCollection_.getSize());
-  Bool flag(distributionCollection_[0].getImplementation()->isIntegral());
-  for (UnsignedLong i = 1; i < size; ++i)
-  {
-    flag = flag && distributionCollection_[i].getImplementation()->isIntegral();
-    if (!flag) return false;
-  }
+  for (UnsignedLong i = 1; i < size; ++i) if (!distributionCollection_[i].isIntegral()) return false;
   return true;
 }
 
@@ -504,6 +566,11 @@ void Mixture::save(Advocate & adv) const
   DistributionImplementation::save(adv);
   adv.saveAttribute( "distributionCollection_", distributionCollection_ );
   adv.saveAttribute( "weightsDistribution_", weightsDistribution_ );
+  adv.saveAttribute( "pdfApproximationCDF_", pdfApproximationCDF_ );
+  adv.saveAttribute( "cdfApproximation_", cdfApproximation_ );
+  adv.saveAttribute( "pdfApproximationCCDF_", pdfApproximationCCDF_ );
+  adv.saveAttribute( "ccdfApproximation_", ccdfApproximation_ );
+  adv.saveAttribute( "useApproximatePDFCDF_", useApproximatePDFCDF_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -512,6 +579,11 @@ void Mixture::load(Advocate & adv)
   DistributionImplementation::load(adv);
   adv.loadAttribute( "distributionCollection_", distributionCollection_ );
   adv.loadAttribute( "weightsDistribution_", weightsDistribution_ );
+  adv.loadAttribute( "pdfApproximationCDF_", pdfApproximationCDF_ );
+  adv.loadAttribute( "cdfApproximation_", cdfApproximation_ );
+  adv.loadAttribute( "pdfApproximationCCDF_", pdfApproximationCCDF_ );
+  adv.loadAttribute( "ccdfApproximation_", ccdfApproximation_ );
+  adv.loadAttribute( "useApproximatePDFCDF_", useApproximatePDFCDF_ );
   // To compute the range
   setDistributionCollection(distributionCollection_);
 }
