@@ -3,7 +3,7 @@
  *  @file  Multinomial.cxx
  *  @brief The Multinomial distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -49,6 +49,8 @@ Multinomial::Multinomial()
   , n_(0)
   , p_(0)
   , sumP_(0.0)
+  , smallA_(ResourceMap::GetAsNumericalScalar("Multinomial-smallA"))
+  , eta_(ResourceMap::GetAsNumericalScalar("Multinomial-eta"))
 {
   // This method compute the range also
   setN(1);
@@ -62,6 +64,8 @@ Multinomial::Multinomial(const UnsignedLong n,
   , n_(0)
   , p_(0)
   , sumP_(0.0)
+  , smallA_(ResourceMap::GetAsNumericalScalar("Multinomial-smallA"))
+  , eta_(ResourceMap::GetAsNumericalScalar("Multinomial-eta"))
 {
   // This method compute the range also
   setN( n );
@@ -140,21 +144,20 @@ NumericalScalar Multinomial::computePDF(const NumericalPoint & point) const
 
   // First, check the validity of the input
   NumericalScalar sumX(0.0);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
   for (UnsignedLong i = 0; i < dimension; ++i)
   {
     const NumericalScalar k(point[i]);
     // Early exit if the given point is not in the support of the distribution
-    if ((fabs(k - round(k)) > supportEpsilon) || (k < -supportEpsilon) || (k > n_ + supportEpsilon)) return 0.0;
+    if ((fabs(k - round(k)) > supportEpsilon_) || (k < -supportEpsilon_) || (k > n_ + supportEpsilon_)) return 0.0;
     sumX += k;
   }
-  if (sumX > n_ + supportEpsilon) return 0.0;
-  NumericalScalar logPDF(SpecFunc::LnGamma(n_ + 1.0) - SpecFunc::LnGamma(n_ - sumX + 1.0) + (n_ - sumX) * log1p(-sumP_));
+  if (sumX > n_ + supportEpsilon_) return 0.0;
+  NumericalScalar logPDF(lgamma(n_ + 1.0) - lgamma(n_ - sumX + 1.0) + (n_ - sumX) * log1p(-sumP_));
   for (UnsignedLong i = 0; i < dimension; ++i)
   {
     const NumericalScalar k(point[i]);
     // For p_[i] > 0, it is possible to obtain any value of k between 0 and n
-    if (p_[i] > 0.0) logPDF += k * log(p_[i]) - SpecFunc::LnGamma(k + 1.0);
+    if (p_[i] > 0.0) logPDF += k * log(p_[i]) - lgamma(k + 1.0);
     // Else only k == 0 is allowed, with a zero contribution to the log PDF
     else if (k > 0) return 0.0;
   }
@@ -186,11 +189,10 @@ NumericalComplex Multinomial::computeLocalPhi(const NumericalComplex & z,
     const NumericalScalar a) const
 {
   if (z == 0.0) return 1.0;
-  const NumericalScalar smallA(ResourceMap::GetAsNumericalScalar("Multinomial-smallA"));
   const NumericalComplex u(lambda * z);
   const UnsignedLong iMax(static_cast< UnsignedLong > (floor(a)));
   // Small value of a, evaluate the generating function as a polynomial
-  if (a <= smallA)
+  if (a <= smallA_)
   {
     NumericalComplex value(exp(-lambda));
     NumericalComplex term(value);
@@ -200,12 +202,12 @@ NumericalComplex Multinomial::computeLocalPhi(const NumericalComplex & z,
       value += term;
     }
     return value;
-  } // smallA
+  } // smallA_
   // Large a
   NumericalComplex value(exp(-lambda + u));
   UnsignedLong i(iMax + 1);
-  NumericalComplex term(exp(-lambda + NumericalComplex(i) * log(u) - SpecFunc::LogGamma(i + 1.0)));
-  while (abs(term) > SpecFunc::NumericalScalarEpsilon * abs(value))
+  NumericalComplex term(exp(-lambda + NumericalComplex(i) * log(u) - lgamma(i + 1.0)));
+  while (abs(term) > SpecFunc::Precision * abs(value))
   {
     value -= term;
     ++i;
@@ -224,29 +226,34 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
 
   // Early exit for 1D case
-  if (dimension == 1) return Binomial(n_, p_[0]).computeCDF(point);
+  if (dimension == 1)
+  {
+    const NumericalScalar k(point[0]);
+    if (k < -supportEpsilon_) return 0.0;
+    if (k > n_ + supportEpsilon_) return 1.0;
+    return DistFunc::pBeta(n_ - floor(k), floor(k) + 1, 1.0 - p_[0]);
+  }
   // First, check the bording cases
   Indices indices(0);
   Bool allZero(true);
   NumericalScalar sumX(0.0);
   // Trivial cases
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
   for (UnsignedLong i = 0; i < dimension; ++i)
   {
     // If the given point does not cover any point of the support, return 0.0
-    if (point[i] < -supportEpsilon) return 0.0;
-    if (point[i] < n_ - supportEpsilon) indices.add(i);
-    allZero = allZero && (fabs(point[i]) < supportEpsilon);
+    if (point[i] < -supportEpsilon_) return 0.0;
+    if (point[i] < n_ - supportEpsilon_) indices.add(i);
+    allZero = allZero && (fabs(point[i]) < supportEpsilon_);
     sumX += point[i];
   }
   // If we are at the origin, CDF=PDF(0,...,0)
   if (allZero) return pow(1.0 - sumP_, n_);
   // If the atoms with non zero probability sum to N
-  if ((fabs(sumP_ - 1.0) < supportEpsilon) && (sumX == n_))
+  if ((fabs(sumP_ - 1.0) < supportEpsilon_) && (sumX == n_))
   {
-    NumericalScalar value(SpecFunc::LogGamma(n_ + 1));
+    NumericalScalar value(lgamma(n_ + 1));
     for (UnsignedLong j = 0; j < dimension; ++j)
-      value += point[j] * log(p_[j]) - SpecFunc::LogGamma(point[j] + 1.0);
+      value += point[j] * log(p_[j]) - lgamma(point[j] + 1.0);
     return exp(value);
   }
   // If the point covers the whole support of the distribution, return 1.0
@@ -287,7 +294,7 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
     delta = phiK - phiKp1;
     value += sign * delta.real();
     const NumericalScalar dv(abs(delta));
-    if (dv < SpecFunc::NumericalScalarEpsilon * dv0) break;
+    if (dv < SpecFunc::Precision * dv0) break;
     sign = -sign;
   }
   // Due to round-off errors, the computed CDF can be slightly below 0 or over 1.
@@ -296,8 +303,7 @@ NumericalScalar Multinomial::computeCDF(const NumericalPoint & point) const
 
 /* Compute the scalar quantile of the 1D multinomial distribution */
 NumericalScalar Multinomial::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return Binomial(n_, p_[0]).computeQuantile(prob, tail)[0];
 } // computeScalarQuantile
@@ -321,7 +327,7 @@ NumericalScalar Multinomial::computeConditionalPDF(const NumericalScalar x,
   {
     const NumericalScalar yI(y[i]);
     const UnsignedLong intYI(static_cast<UnsignedLong>(round(yI)));
-    if (fabs(yI - intYI) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
+    if (fabs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
     sumY += yI;
     intY[i] = intYI;
     sumP += p_[i];
@@ -343,12 +349,11 @@ NumericalScalar Multinomial::computeConditionalCDF(const NumericalScalar x,
   UnsignedLongCollection intY(conditioningDimension);
   NumericalScalar sumY(0.0);
   NumericalScalar sumP(0.0);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
   for (UnsignedLong i = 0; i < conditioningDimension; ++i)
   {
     const NumericalScalar yI(y[i]);
     const UnsignedLong intYI(static_cast<UnsignedLong>(round(yI)));
-    if (fabs(yI - intYI) > supportEpsilon) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
+    if (fabs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
     sumY += yI;
     intY[i] = intYI;
     sumP += p_[i];
@@ -371,12 +376,11 @@ NumericalScalar Multinomial::computeConditionalQuantile(const NumericalScalar q,
   UnsignedLongCollection intY(conditioningDimension);
   NumericalScalar sumY(0.0);
   NumericalScalar sumP(0.0);
-  const NumericalScalar supportEpsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
   for (UnsignedLong i = 0; i < conditioningDimension; ++i)
   {
     const NumericalScalar yI(y[i]);
     const UnsignedLong intYI(static_cast<UnsignedLong>(round(yI)));
-    if (fabs(yI - intYI) > supportEpsilon) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
+    if (fabs(yI - intYI) > supportEpsilon_) throw InvalidArgumentException(HERE) << "Error: the conditioning vector has non-integer values";
     sumY += yI;
     intY[i] = intYI;
     sumP += p_[i];
@@ -467,7 +471,7 @@ NumericalSample Multinomial::getSupport() const
   const UnsignedLong size(enumerate.getStrataCumulatedCardinal(n_));
   NumericalSample support(0, dimension);
   for (UnsignedLong i = 0; i < size; ++i)
-    support.add(enumerate(i));
+    support.add(NumericalPoint(enumerate(i)));
   return support;
 }
 
@@ -568,9 +572,8 @@ void Multinomial::setN(const UnsignedLong n)
   {
     n_ = n;
     // Best overall performance for Poisson's formula, see reference
-    const NumericalScalar eta(ResourceMap::GetAsNumericalScalar("Multinomial-eta"));
-    r_ = pow(eta, 1.0 / (2.0 * n));
-    normalizationCDF_ = exp(SpecFunc::LogGamma(n + 1.0) - n * log(n) + n - log(2.0 * n) - 0.5 * log(eta));
+    r_ = pow(eta_, 1.0 / (2.0 * n));
+    normalizationCDF_ = exp(lgamma(n + 1.0) - n * log(n) + n - log(2.0 * n) - 0.5 * log(eta_));
     isAlreadyComputedMean_ = false;
     isAlreadyComputedCovariance_ = false;
     isAlreadyCreatedGeneratingFunction_ = false;
@@ -583,6 +586,28 @@ UnsignedLong Multinomial::getN() const
   return n_;
 }
 
+/* SmallA accessor */
+void Multinomial::setSmallA(const NumericalScalar smallA)
+{
+  smallA_ = smallA;
+}
+
+NumericalScalar Multinomial::getSmallA() const
+{
+  return smallA_;
+}
+
+/* Eta accessor */
+void Multinomial::setEta(const NumericalScalar eta)
+{
+  eta_ = eta;
+}
+
+NumericalScalar Multinomial::getEta() const
+{
+  return eta_;
+}
+
 /* Method save() stores the object through the StorageManager */
 void Multinomial::save(Advocate & adv) const
 {
@@ -592,6 +617,8 @@ void Multinomial::save(Advocate & adv) const
   adv.saveAttribute( "sumP_", sumP_ );
   adv.saveAttribute( "normalizationCDF_", normalizationCDF_ );
   adv.saveAttribute( "r_", r_ );
+  adv.saveAttribute( "smallA_", smallA_ );
+  adv.saveAttribute( "eta_", eta_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -603,6 +630,8 @@ void Multinomial::load(Advocate & adv)
   adv.loadAttribute( "sumP_", sumP_ );
   adv.loadAttribute( "normalizationCDF_", normalizationCDF_ );
   adv.loadAttribute( "r_", r_ );
+  adv.loadAttribute( "smallA_", smallA_ );
+  adv.loadAttribute( "eta_", eta_ );
   computeRange();
 }
 
