@@ -3,7 +3,7 @@
  *  @file  MultinomialFactory.cxx
  *  @brief Factory for Multinomial distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,9 +72,11 @@ Multinomial MultinomialFactory::buildAsMultinomial(const NumericalSample & sampl
       p[j] += x;
     }
   }
-  UnsignedLong n((UnsignedLong)max);
+  const UnsignedLong n((UnsignedLong)max);
   p *= 1.0 / (max * size);
-  return Multinomial(n, p);
+  Multinomial result(n, p);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Multinomial MultinomialFactory::buildAsMultinomial() const
