@@ -3,7 +3,7 @@
  *  @file  NegativeBinomial.cxx
  *  @brief The NegativeBinomial distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -105,7 +105,7 @@ NumericalScalar NegativeBinomial::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if ((k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (fabs(k - round(k)) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) return 0.0;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return 0.0;
   return exp(SpecFunc::LnGamma(k + r_) - SpecFunc::LnGamma(r_) - SpecFunc::LnGamma(k + 1.0) + k * log(p_) + r_ * log1p(-p_));
 }
 
@@ -116,9 +116,9 @@ NumericalScalar NegativeBinomial::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
-  const NumericalScalar value(SpecFunc::BetaRatioInc(r_, floor(k) + 1, 1.0 - p_));
-  return value;
+  if (k < -supportEpsilon_) return 0.0;
+  if (p_ <= 0.5) return DistFunc::pBeta(r_, floor(k) + 1, 1.0 - p_, false);
+  return DistFunc::pBeta(floor(k) + 1, r_, p_, true);
 }
 
 NumericalScalar NegativeBinomial::computeComplementaryCDF(const NumericalPoint & point) const
@@ -126,10 +126,10 @@ NumericalScalar NegativeBinomial::computeComplementaryCDF(const NumericalPoint &
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 1.0;
+  if (k < -supportEpsilon_) return 1.0;
   // Complementary relation for incomplete regularized Beta function: I(a, b, x) = 1 - I(b, a, 1-x)
-  NumericalScalar value = SpecFunc::BetaRatioInc(floor(k) + 1, r_, p_);
-  return value;
+  if (p_ <= 0.5) return DistFunc::pBeta(r_, floor(k) + 1, 1.0 - p_, true);
+  return DistFunc::pBeta(floor(k) + 1, r_, p_, false);
 }
 
 /* Get the PDF gradient of the distribution */
@@ -139,7 +139,7 @@ NumericalPoint NegativeBinomial::computePDFGradient(const NumericalPoint & point
 
   const NumericalScalar k(point[0]);
   NumericalPoint pdfGradient(1, 0.0);
-  if ((k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (fabs(k - round(k)) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) return pdfGradient;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return pdfGradient;
   throw NotYetImplementedException(HERE);
 }
 
@@ -150,7 +150,7 @@ NumericalPoint NegativeBinomial::computeCDFGradient(const NumericalPoint & point
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return NumericalPoint(1, 0.0);
+  if (k < -supportEpsilon_) return NumericalPoint(1, 0.0);
   throw NotYetImplementedException(HERE);
 }
 
@@ -269,8 +269,7 @@ void NegativeBinomial::computeRange()
 
 /* Get the quantile of the distribution */
 NumericalScalar NegativeBinomial::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   LOGDEBUG(OSS() << "in NegativeBinomial::computeScalarQuantile, prob=" << prob << ", tail=" << (tail ? "true" : "false"));
   if (prob <= 0.0) return (tail ? getRange().getUpperBound()[0] : 0.0);
