@@ -3,7 +3,7 @@
  *  @file  NonCentralChiSquare.cxx
  *  @brief The NonCentralChiSquare distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,8 +30,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(NonCentralChiSquare);
 
 static Factory<NonCentralChiSquare> RegisteredFactory("NonCentralChiSquare");
@@ -40,9 +38,10 @@ static Factory<NonCentralChiSquare> RegisteredFactory("NonCentralChiSquare");
 /* Default constructor */
 NonCentralChiSquare::NonCentralChiSquare(const NumericalScalar nu,
     const NumericalScalar lambda)
-  : NonEllipticalDistribution("NonCentralChiSquare"),
-    nu_(0.0),
-    lambda_(0.0)
+  : ContinuousDistribution("NonCentralChiSquare")
+  , nu_(0.0)
+  , lambda_(0.0)
+  , maximumIteration_(ResourceMap::GetAsUnsignedLong("DistFunc-MaximumIteration"))
 {
   // This call set also the range.
   setNuLambda(nu, lambda);
@@ -59,7 +58,7 @@ Bool NonCentralChiSquare::operator ==(const NonCentralChiSquare & other) const
 /* String converter */
 String NonCentralChiSquare::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NonCentralChiSquare::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -70,7 +69,7 @@ String NonCentralChiSquare::__repr__() const
 
 String NonCentralChiSquare::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(nu = " << nu_ << ", lambda = " << lambda_ << ")";
   return oss;
 }
@@ -92,8 +91,7 @@ NumericalScalar NonCentralChiSquare::computePDF(const NumericalPoint & point) co
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  pdfEpsilon_ = ResourceMap::GetAsNumericalScalar("DistFunc-Precision");
-  return DistFunc::dNonCentralChiSquare(nu_, lambda_, point[0]);
+  return DistFunc::dNonCentralChiSquare(nu_, lambda_, point[0], pdfEpsilon_, maximumIteration_);
 }
 
 /* Get the CDF of the distribution */
@@ -101,8 +99,8 @@ NumericalScalar NonCentralChiSquare::computeCDF(const NumericalPoint & point) co
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  cdfEpsilon_ = ResourceMap::GetAsNumericalScalar("DistFunc-Precision");
-  return DistFunc::pNonCentralChiSquare(nu_, lambda_, point[0]);
+  if (point[0] <= 0.0) return 0.0;
+  return DistFunc::pNonCentralChiSquare(nu_, lambda_, point[0], false, cdfEpsilon_, maximumIteration_);
 }
 
 /** Get the PDFGradient of the distribution */
@@ -110,10 +108,10 @@ NumericalPoint NonCentralChiSquare::computePDFGradient(const NumericalPoint & po
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  NumericalScalar eps(pow(pdfEpsilon_, 1.0 / 3.0));
   NumericalPoint pdfGradient(2);
-  pdfGradient[0] = (DistFunc::dNonCentralChiSquare(nu_ + eps, lambda_, point[0]) - DistFunc::dNonCentralChiSquare(nu_ - eps, lambda_, point[0])) / (2.0 * eps);
-  pdfGradient[1] = (DistFunc::dNonCentralChiSquare(nu_, lambda_ + eps, point[0]) - DistFunc::dNonCentralChiSquare(nu_, lambda_ - eps, point[0])) / (2.0 * eps);
+  pdfGradient[0] = (DistFunc::dNonCentralChiSquare(nu_ + eps, lambda_, point[0], pdfEpsilon_, maximumIteration_) - DistFunc::dNonCentralChiSquare(nu_ - eps, lambda_, point[0], pdfEpsilon_, maximumIteration_)) / (2.0 * eps);
+  pdfGradient[1] = (DistFunc::dNonCentralChiSquare(nu_, lambda_ + eps, point[0], pdfEpsilon_, maximumIteration_) - DistFunc::dNonCentralChiSquare(nu_, lambda_ - eps, point[0], pdfEpsilon_, maximumIteration_)) / (2.0 * eps);
   return pdfGradient;
 }
 
@@ -122,10 +120,10 @@ NumericalPoint NonCentralChiSquare::computeCDFGradient(const NumericalPoint & po
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
   NumericalPoint cdfGradient(2);
-  cdfGradient[0] = (DistFunc::pNonCentralChiSquare(nu_ + eps, lambda_, point[0]) - DistFunc::pNonCentralChiSquare(nu_ - eps, lambda_, point[0])) / (2.0 * eps);
-  cdfGradient[1] = (DistFunc::pNonCentralChiSquare(nu_, lambda_ + eps, point[0]) - DistFunc::pNonCentralChiSquare(nu_, lambda_ - eps, point[0])) / (2.0 * eps);
+  cdfGradient[0] = (DistFunc::pNonCentralChiSquare(nu_ + eps, lambda_, point[0], false, cdfEpsilon_, maximumIteration_) - DistFunc::pNonCentralChiSquare(nu_ - eps, lambda_, point[0], false, cdfEpsilon_, maximumIteration_)) / (2.0 * eps);
+  cdfGradient[1] = (DistFunc::pNonCentralChiSquare(nu_, lambda_ + eps, point[0], false, cdfEpsilon_, maximumIteration_) - DistFunc::pNonCentralChiSquare(nu_, lambda_ - eps, point[0], false, cdfEpsilon_, maximumIteration_)) / (2.0 * eps);
   return cdfGradient;
 }
 
@@ -233,8 +231,8 @@ void NonCentralChiSquare::setNu(const NumericalScalar nu)
 void NonCentralChiSquare::setNuLambda(const NumericalScalar nu,
                                       const NumericalScalar lambda)
 {
-  if (nu < 0.0) throw InvalidArgumentException(HERE) << "Nu MUST be strictly positive";
-  if (lambda < 0.0) throw InvalidArgumentException(HERE) << "Lambda MUST be strictly positive";
+  if (nu <= 0.0) throw InvalidArgumentException(HERE) << "Nu MUST be positive";
+  if (lambda < 0.0) throw InvalidArgumentException(HERE) << "Lambda MUST be nonnegative";
   if ((nu != nu_) || (lambda != lambda_))
   {
     nu_ = nu;
@@ -255,7 +253,7 @@ NumericalScalar NonCentralChiSquare::getNu() const
 /* Lambda accessor */
 void NonCentralChiSquare::setLambda(const NumericalScalar lambda)
 {
-  if (lambda < 0.0) throw InvalidArgumentException(HERE) << "Lambda MUST be strictly positive";
+  if (lambda < 0.0) throw InvalidArgumentException(HERE) << "Lambda MUST be nonnegative";
   if (lambda != lambda_)
   {
     lambda_ = lambda;
@@ -271,20 +269,33 @@ NumericalScalar NonCentralChiSquare::getLambda() const
   return lambda_;
 }
 
+/* Maximum iterations accessor */
+void NonCentralChiSquare::setMaximumIteration(const UnsignedLong maximumIteration)
+{
+  maximumIteration_ = maximumIteration;
+}
+
+UnsignedLong NonCentralChiSquare::getMaximumIteration() const
+{
+  return maximumIteration_;
+}
+
 /* Method save() stores the object through the StorageManager */
 void NonCentralChiSquare::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "nu_", nu_ );
   adv.saveAttribute( "lambda_", lambda_ );
+  adv.saveAttribute( "maximumIteration_", maximumIteration_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
 void NonCentralChiSquare::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "nu_", nu_ );
   adv.loadAttribute( "lambda_", lambda_ );
+  adv.loadAttribute( "maximumIteration_", maximumIteration_ );
   computeRange();
 }
 
