@@ -3,7 +3,7 @@
  *  @file  NonCentralStudent.cxx
  *  @brief The NonCentralStudent distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -41,10 +41,10 @@ static Factory<NonCentralStudent> RegisteredFactory("NonCentralStudent");
 NonCentralStudent::NonCentralStudent(const NumericalScalar nu,
                                      const NumericalScalar delta,
                                      const NumericalScalar gamma)
-  : NonEllipticalDistribution("NonCentralStudent"),
-    nu_(0.0),
-    delta_(delta),
-    gamma_(gamma)
+  : ContinuousDistribution("NonCentralStudent")
+  , nu_(0.0)
+  , delta_(delta)
+  , gamma_(gamma)
 {
   // This call set also the range.
   setNu(nu);
@@ -61,7 +61,7 @@ Bool NonCentralStudent::operator ==(const NonCentralStudent & other) const
 /* String converter */
 String NonCentralStudent::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << NonCentralStudent::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -73,7 +73,7 @@ String NonCentralStudent::__repr__() const
 
 String NonCentralStudent::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(nu = " << nu_ << ", delta = " << delta_ << ", gamma = " << gamma_ << ")";
   return oss;
 }
@@ -95,7 +95,6 @@ NumericalScalar NonCentralStudent::computePDF(const NumericalPoint & point) cons
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  pdfEpsilon_ = ResourceMap::GetAsNumericalScalar("DistFunc-Precision");
   return DistFunc::dNonCentralStudent(nu_, delta_, point[0] - gamma_);
 }
 
@@ -103,90 +102,15 @@ NumericalScalar NonCentralStudent::computePDF(const NumericalPoint & point) cons
 NumericalScalar NonCentralStudent::computeCDF(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
-  if (ResourceMap::GetAsUnsignedLong("NonCentralStudent-CDFAlgo") == 0) return DistFunc::pNonCentralStudent(nu_, delta_, point[0] - gamma_);
-  else return DistFunc::pNonCentralStudentAlt(nu_, delta_, point[0] - gamma_);
+  return DistFunc::pNonCentralStudent(nu_, delta_, point[0] - gamma_, false);
 }
 
-/* Get the quantile of the distribution */
-NumericalScalar NonCentralStudent::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
-{
-  // Step is the approximate mode
-  NumericalScalar step(sqrt(nu_ / (1.0 + nu_)) * delta_);
-  // Initial guess is the normal approximation
-  NumericalScalar q(gamma_ + step);
-  // Use normal approximation for nu > 2
-  if (nu_ > 2.0) q = gamma_ + getMean()[0] + getStandardDeviation()[0] * DistFunc::qNormal(prob, tail);
-  // Separate the case tail==true from the case tail==false for the bracketing step
-  NumericalScalar qMin(q);
-  NumericalScalar qMax(q);
-  NumericalScalar cdf(tail ? computeComplementaryCDF(q) : computeCDF(q));
-//   NumericalScalar previousCDF(cdf);
-  NumericalScalar cdfMin(cdf);
-  NumericalScalar cdfMax(cdf);
-  const NumericalScalar p(std::min(1.0, std::max(0.0, (tail ? 1.0 - prob : prob))));
-  Bool progress(true);
-  if (tail)
-  {
-    while ((cdfMin < p) && progress)
-    {
-      qMax = qMin;
-      qMin -= step;
-      cdfMax = cdfMin;
-      cdfMin = computeComplementaryCDF(qMin);
-      progress = fabs(cdfMax - cdfMin) > cdfEpsilon_;
-    }
-    while ((cdfMax > p) && progress)
-    {
-      qMin = qMax;
-      qMax += step;
-      cdfMin = cdfMax;
-      cdfMax = computeComplementaryCDF(qMax);
-      progress = fabs(cdfMax - cdfMin) > cdfEpsilon_;
-    }
-  }
-  else
-  {
-    while ((cdfMin > p) && progress)
-    {
-      qMax = qMin;
-      qMin -= step;
-      cdfMax = cdfMin;
-      cdfMin = computeCDF(qMin);
-      progress = fabs(cdfMax - cdfMin) > cdfEpsilon_;
-    }
-    while ((cdfMax < p) && progress)
-    {
-      qMin = qMax;
-      qMax += step;
-      cdfMin = cdfMax;
-      cdfMax = computeCDF(qMax);
-      progress = fabs(cdfMax - cdfMin) > cdfEpsilon_;
-    }
-  }
-  // Now, q is in [qMin, qMax]
-  CDFWrapper wrapper(*this, tail);
-  const NumericalMathFunction f(bindMethod<CDFWrapper, NumericalPoint, NumericalPoint>(wrapper, &CDFWrapper::computeCDF, 1, 1));
-  Brent solver(cdfEpsilon_, cdfEpsilon_, cdfEpsilon_, ResourceMap::GetAsUnsignedLong( "DistributionImplementation-DefaultQuantileIteration" ));
-  try
-  {
-    const NumericalScalar q(solver.solve(f, p, qMin, qMax, cdfMin, cdfMax));
-    return q;
-  }
-  catch (...)
-  {
-    const NumericalScalar q(0.5 * (qMin + qMax));
-    return q;
-  }
-}
-
-/** Get the PDFGradient of the distribution */
+/* Get the PDFGradient of the distribution */
 NumericalPoint NonCentralStudent::computePDFGradient(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  const NumericalScalar eps(pow(pdfEpsilon_, 1.0 / 3.0));
   NumericalPoint pdfGradient(3);
   pdfGradient[0] = (DistFunc::dNonCentralStudent(nu_ + eps, delta_, point[0] - gamma_) - DistFunc::dNonCentralStudent(nu_ - eps, delta_, point[0] - gamma_)) / (2.0 * eps);
   pdfGradient[1] = (DistFunc::dNonCentralStudent(nu_, delta_ + eps, point[0] - gamma_) - DistFunc::dNonCentralStudent(nu_, delta_ - eps, point[0] - gamma_)) / (2.0 * eps);
@@ -194,16 +118,16 @@ NumericalPoint NonCentralStudent::computePDFGradient(const NumericalPoint & poin
   return pdfGradient;
 }
 
-/** Get the CDFGradient of the distribution */
+/* Get the CDFGradient of the distribution */
 NumericalPoint NonCentralStudent::computeCDFGradient(const NumericalPoint & point) const
 {
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalScalar eps(pow(ResourceMap::GetAsNumericalScalar("DistFunc-Precision"), 1.0 / 3.0));
+  const NumericalScalar eps(pow(cdfEpsilon_, 1.0 / 3.0));
   NumericalPoint cdfGradient(3);
-  cdfGradient[0] = (DistFunc::pNonCentralStudent(nu_ + eps, delta_, point[0] - gamma_) - DistFunc::pNonCentralStudent(nu_ - eps, delta_, point[0] - gamma_)) / (2.0 * eps);
-  cdfGradient[1] = (DistFunc::pNonCentralStudent(nu_, delta_ + eps, point[0] - gamma_) - DistFunc::pNonCentralStudent(nu_, delta_ - eps, point[0] - gamma_)) / (2.0 * eps);
-  cdfGradient[2] = (DistFunc::pNonCentralStudent(nu_, delta_, point[0] - gamma_ - eps) - DistFunc::pNonCentralStudent(nu_, delta_, point[0] - gamma_ + eps)) / (2.0 * eps);
+  cdfGradient[0] = (DistFunc::pNonCentralStudent(nu_ + eps, delta_, point[0] - gamma_, false) - DistFunc::pNonCentralStudent(nu_ - eps, delta_, point[0] - gamma_, false)) / (2.0 * eps);
+  cdfGradient[1] = (DistFunc::pNonCentralStudent(nu_, delta_ + eps, point[0] - gamma_, false) - DistFunc::pNonCentralStudent(nu_, delta_ - eps, point[0] - gamma_, false)) / (2.0 * eps);
+  cdfGradient[2] = (DistFunc::pNonCentralStudent(nu_, delta_, point[0] - gamma_ - eps, false) - DistFunc::pNonCentralStudent(nu_, delta_, point[0] - gamma_ + eps, false)) / (2.0 * eps);
   return cdfGradient;
 }
 
@@ -346,7 +270,7 @@ NumericalScalar NonCentralStudent::getGamma() const
 /* Method save() stores the object through the StorageManager */
 void NonCentralStudent::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "nu_", nu_ );
   adv.saveAttribute( "delta_", delta_ );
   adv.saveAttribute( "gamma_", gamma_ );
@@ -355,7 +279,7 @@ void NonCentralStudent::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void NonCentralStudent::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "nu_", nu_ );
   adv.loadAttribute( "delta_", delta_ );
   adv.loadAttribute( "gamma_", gamma_ );
