@@ -3,7 +3,7 @@
  *  @file  Normal.cxx
  *  @brief The Normal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -174,7 +174,7 @@ NumericalPoint Normal::getRealization() const
 NumericalSample Normal::getSample(const UnsignedLong size) const
 {
   const UnsignedLong dimension(getDimension());
-  NumericalSampleImplementation result(size, dimension);
+  NumericalSample result(size, dimension);
   for (UnsignedLong i = 0; i < size; ++i)
     for (UnsignedLong j = 0; j < dimension; ++j) result[i][j] = DistFunc::rNormal();
   if (hasIndependentCopula_) result *= sigma_;
@@ -315,26 +315,6 @@ NumericalScalar Normal::computeCDF(const NumericalPoint & point) const
   return value;
 } // computeCDF
 
-/* Get the CDF of the distribution */
-NumericalScalar Normal::computeComplementaryCDF(const NumericalPoint & point) const
-{
-  const UnsignedLong dimension(getDimension());
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
-  // Special case for dimension 1
-  if (dimension == 1) return DistFunc::pNormal((point[0] - mean_[0]) / sigma_[0], true);
-  // Normalize the point to use the standard form of the multivariate normal distribution
-  NumericalPoint u(normalize(point));
-  /* Special treatment for independent components */
-  if (hasIndependentCopula_)
-  {
-    NumericalScalar value(DistFunc::pNormal(u[0]));
-    for (UnsignedLong i = 1; i < dimension; ++i) value *= DistFunc::pNormal(u[i], true);
-    return value;
-  }
-  // other cases do not depend on tail
-  return computeCDF(point);
-}
-
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Normal::computeCharacteristicFunction(const NumericalScalar x) const
 {
@@ -495,8 +475,7 @@ NumericalPoint Normal::computeCDFGradient(const NumericalPoint & point) const
 
 /* Compute the scalar quantile of the 1D normal distribution */
 NumericalScalar Normal::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return mean_[0] + sigma_[0] * DistFunc::qNormal(prob, tail);
 } // computeScalarQuantile
