@@ -3,7 +3,7 @@
  *  @file  NormalCopula.cxx
  *  @brief A class that implements an independent copula
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,6 +37,7 @@
 #include "Description.hxx"
 #include "DistFunc.hxx"
 #include "PersistentObjectFactory.hxx"
+#include "TBB.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -52,6 +53,7 @@ NormalCopula::NormalCopula(const UnsignedLong dim)
 {
   // The range is generic for all the copulas
   setDimension(dim);
+  computeRange();
 }
 
 /* Default constructor */
@@ -62,6 +64,7 @@ NormalCopula::NormalCopula(const CorrelationMatrix & correlation)
 {
   // The range is generic for all the copulas
   setDimension(correlation.getNbRows());
+  computeRange();
 }
 
 /* Comparison operator */
@@ -108,6 +111,38 @@ NumericalPoint NormalCopula::getRealization() const
   }
 }
 
+/* Get a sample of the distribution */
+NumericalSample NormalCopula::getSampleParallel(const UnsignedLong size) const
+{
+  if (hasIndependentCopula())
+  {
+    const UnsignedLong dimension(getDimension());
+    NumericalSample result(size, dimension);
+    const NumericalPoint rawData(RandomGenerator::Generate(dimension * size));
+    result.getImplementation()->setData(rawData);
+    result.setName(getName());
+    result.setDescription(getDescription());
+    return result;
+  }
+  else
+  {
+    const UnsignedLong dimension(getDimension());
+    const NumericalSample normalSample(normal_.getSample(size));
+    NumericalSample result(size, dimension);
+    const ComputeSamplePolicy policy( normalSample, result );
+    TBB::ParallelFor( 0, size, policy );
+    result.setName(getName());
+    result.setDescription(getDescription());
+    return result;
+  } // Nonindependente copula
+}
+
+NumericalSample NormalCopula::getSample(const UnsignedLong size) const
+{
+  if (isParallel_) return getSampleParallel(size);
+  return DistributionImplementation::getSample(size);
+}
+
 /* Get the DDF of the distribution */
 NumericalPoint NormalCopula::computeDDF(const NumericalPoint & point) const
 {
@@ -165,8 +200,8 @@ NumericalScalar NormalCopula::computePDF(const NumericalPoint & point) const
     normalPoint[i] = yi;
     value += yi * yi;
   }
-  // .398942280401432677939946059934 = 1 / sqrt(2.pi)
-  value = pow(.398942280401432677939946059934, dimension) * exp(-0.5 * value);
+  // 0.398942280401432677939946059934 = 1 / sqrt(2.pi)
+  value = pow(0.398942280401432677939946059934, dimension) * exp(-0.5 * value);
   return normal_.computePDF(normalPoint) / value;
 }
 
@@ -201,8 +236,8 @@ NumericalScalar NormalCopula::computeCDF(const NumericalPoint & point) const
   else return normal_.getMarginal(indices)->computeCDF(normalPoint);
 } // computeCDF
 
-/* Get the CDF of the distribution */
-NumericalScalar NormalCopula::computeComplementaryCDF(const NumericalPoint & point) const
+/* Get the survival function of the distribution */
+NumericalScalar NormalCopula::computeSurvivalFunction(const NumericalPoint & point) const
 {
   const UnsignedLong dimension(getDimension());
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << getDimension() << ", here dimension=" << point.getDimension();
@@ -227,10 +262,10 @@ NumericalScalar NormalCopula::computeComplementaryCDF(const NumericalPoint & poi
   for (UnsignedLong i = 0; i < activeDimension; ++i) normalPoint[i] = DistFunc::qNormal(point[indices[i]], true);
   // In the usual case when the given point is in the interior of the support
   // use the associated normal distribution
-  if (dimension == activeDimension) return normal_.computeComplementaryCDF(normalPoint);
+  if (dimension == activeDimension) return normal_.computeSurvivalFunction(normalPoint);
   // In the other case, we must use the appropriate marginal distribution
-  else return Distribution(normal_.getMarginal(indices)).computeComplementaryCDF(normalPoint);
-} // computeCDF
+  else return Distribution(normal_.getMarginal(indices)).computeSurvivalFunction(normalPoint);
+} // computeSurvivalFunction
 
 /* Compute the probability content of an interval */
 NumericalScalar NormalCopula::computeProbability(const Interval & interval) const
@@ -274,6 +309,32 @@ NumericalScalar NormalCopula::computeProbability(const Interval & interval) cons
   return normal_.computeProbability(Interval(lowerBound, upperBound, finiteLowerBound, finiteUpperBound));
 }
 
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix NormalCopula::getSpearmanCorrelation() const
+{
+  const UnsignedLong dimension(getDimension());
+  CorrelationMatrix rho(dimension);
+  for (UnsignedLong i = 1; i < dimension; ++i)
+    for (UnsignedLong j = 0; j < i; ++j) rho(i, j) = asin(0.5 * correlation_(i, j)) * 6.0 / M_PI;
+  return rho;
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix NormalCopula::getKendallTau() const
+{
+  const UnsignedLong dimension(getDimension());
+  CorrelationMatrix tau(dimension);
+  for (UnsignedLong i = 1; i < dimension; ++i)
+    for (UnsignedLong j = 0; j < i; ++j) tau(i, j) = asin(correlation_(i, j)) * 2.0 / M_PI;
+  return tau;
+}
+
+/* Get the Shape matrix of the copula */
+CorrelationMatrix NormalCopula::getShapeMatrix() const
+{
+  return correlation_;
+}
+
 /* Get the PDF gradient of the distribution */
 NumericalPoint NormalCopula::computePDFGradient(const NumericalPoint & point) const
 {
@@ -481,6 +542,7 @@ void NormalCopula::load(Advocate & adv)
   adv.loadAttribute( "normal_", normal_ );
   adv.loadAttribute( "integrationNodesNumber_duplicate", integrationNodesNumber_ );
   adv.loadAttribute( "isAlreadyComputedCovariance_duplicate", isAlreadyComputedCovariance_ );
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
