@@ -3,7 +3,7 @@
  *  @file  NormalCopulaFactory.cxx
  *  @brief Factory for NormalCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,7 +63,9 @@ NormalCopula NormalCopulaFactory::buildAsNormalCopula(const NumericalSample & sa
   if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a NormalCopula distribution from an empty sample";
   try
   {
-    return NormalCopula(NormalCopula::GetCorrelationFromKendallCorrelation(sample.computeKendallTau()));
+    NormalCopula result(NormalCopula::GetCorrelationFromKendallCorrelation(sample.computeKendallTau()));
+    result.setDescription(sample.getDescription());
+    return result;
   }
   catch (...)
   {
