@@ -3,7 +3,7 @@
  *  @file  NormalFactory.cxx
  *  @brief Factory for Normal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,7 +63,9 @@ Normal NormalFactory::buildAsNormal(const NumericalSample & sample) const
   if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a Normal distribution from an empty sample";
   const NumericalPoint mean(sample.computeMean());
   const CovarianceMatrix covariance(sample.computeCovariance());
-  return Normal(mean, covariance);
+  Normal result(mean, covariance);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Normal NormalFactory::buildAsNormal(const NumericalPointWithDescriptionCollection & parameters) const
