@@ -3,7 +3,7 @@
  *  @file  Poisson.cxx
  *  @brief The Poisson distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,8 +36,8 @@ static Factory<Poisson> RegisteredFactory("Poisson");
 
 /* Default constructor */
 Poisson::Poisson()
-  : DiscreteDistribution("Poisson"),
-    lambda_(1.0)
+  : DiscreteDistribution("Poisson")
+  , lambda_(1.0)
 {
   // We set the dimension of the Poisson distribution
   setDimension( 1 );
@@ -46,8 +46,8 @@ Poisson::Poisson()
 
 /* Parameters constructor */
 Poisson::Poisson(const NumericalScalar lambda)
-  : DiscreteDistribution("Poisson"),
-    lambda_(0.0)
+  : DiscreteDistribution("Poisson")
+  , lambda_(0.0)
 {
   // We set the dimension of the Poisson distribution
   setDimension( 1 );
@@ -65,7 +65,7 @@ Bool Poisson::operator ==(const Poisson & other) const
 /* String converter */
 String Poisson::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Poisson::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -75,7 +75,7 @@ String Poisson::__repr__() const
 
 String Poisson::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(lambda = " << lambda_ << ")";
   return oss;
 }
@@ -99,7 +99,7 @@ NumericalScalar Poisson::computePDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if ((k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (fabs(k - round(k)) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) return 0.0;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return 0.0;
   return exp(k * log(lambda_) - lambda_ - SpecFunc::LnGamma(k + 1.0));
 }
 
@@ -110,7 +110,7 @@ NumericalScalar Poisson::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
+  if (k < -supportEpsilon_) return 0.0;
   return DistFunc::pGamma(floor(k) + 1.0, lambda_, true);
 }
 
@@ -119,7 +119,7 @@ NumericalScalar Poisson::computeComplementaryCDF(const NumericalPoint & point) c
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 1.0;
+  if (k < -supportEpsilon_) return 1.0;
   return DistFunc::pGamma(floor(k) + 1.0, lambda_);
 }
 
@@ -130,7 +130,7 @@ NumericalPoint Poisson::computePDFGradient(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
   NumericalPoint pdfGradient(1, 0.0);
-  if ((k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (fabs(k - round(k)) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) return pdfGradient;
+  if ((k < -supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_)) return pdfGradient;
   return NumericalPoint(1, (k - lambda_) * exp((k - 1.0) * log(lambda_) - lambda_ - SpecFunc::LnGamma(k + 1.0)));
 }
 
@@ -141,40 +141,15 @@ NumericalPoint Poisson::computeCDFGradient(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar k(point[0]);
-  if (k < -ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return NumericalPoint(1, 0.0);
+  if (k < -supportEpsilon_) return NumericalPoint(1, 0.0);
   return NumericalPoint(1, -exp(floor(k) * log(lambda_) - lambda_ - SpecFunc::LnGamma(floor(k) + 1.0)));
 }
 
 /* Get the quantile of the distribution */
 NumericalScalar Poisson::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
-  const NumericalScalar p(tail ? 1.0 - prob : prob);
-  UnsignedLong quantile((UnsignedLong)(round(DistFunc::qGamma(lambda_, p))));
-  NumericalScalar pdf(computePDF(quantile));
-  NumericalScalar cdf(computeCDF(quantile));
-  if (cdf < p)
-  {
-    while (cdf < p)
-    {
-      ++quantile;
-      pdf *= lambda_ / quantile;
-      cdf += pdf;
-    }
-    return quantile;
-  }
-  else
-  {
-    while ((cdf >= p) && (quantile > 0))
-    {
-      cdf -= pdf;
-      pdf *= quantile / lambda_;
-      --quantile;
-    }
-    if (cdf < p) return quantile + 1;
-    return quantile;
-  }
+  return DistFunc::qPoisson(lambda_, prob, tail);
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
