@@ -3,7 +3,7 @@
  *  @file  PoissonFactory.cxx
  *  @brief Factory for Poisson distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,7 +72,9 @@ Poisson PoissonFactory::buildAsPoisson(const NumericalSample & sample) const
     lambda += x;
   }
   if (lambda <= 0.0) throw InvalidArgumentException(HERE) << "Error: can build a poisson distribution only if lambda > 0, here lambda=" << lambda;
-  return Poisson(lambda / size);
+  Poisson result(lambda / size);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Poisson PoissonFactory::buildAsPoisson(const NumericalPointWithDescriptionCollection & parameters) const
