@@ -3,7 +3,7 @@
  *  @file  RandomMixture.cxx
  *  @brief Abstract top-level class for all RandomMixtures
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,6 +34,9 @@
 #include "Interval.hxx"
 #include "NumericalMathFunction.hxx"
 #include "Log.hxx"
+#include "Triangular.hxx"
+#include "Trapezoidal.hxx"
+#include "Uniform.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -127,7 +130,7 @@ Bool RandomMixture::operator ==(const RandomMixture & other) const
 /* String converter */
 String RandomMixture::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << RandomMixture::GetClassName()
       << " name=" << getName()
       << " distribution collection=" << distributionCollection_
@@ -138,7 +141,7 @@ String RandomMixture::__repr__() const
 /* String converter */
 String RandomMixture::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(";
   if (constant_ != 0.0) oss << constant_;
   const UnsignedLong size(distributionCollection_.getSize());
@@ -153,7 +156,7 @@ String RandomMixture::__str__(const String & offset) const
     if ((constant_ == 0.0) && (i == 0) && (w < 0.0)) oss << "-";
     const String coeff(OSS() << fabs(w));
     if (coeff != "1") oss << fabs(w) << " * ";
-    oss << distributionCollection_[i].__str__();
+    oss << distributionCollection_[i];
   }
   oss << ")";
   return oss;
@@ -191,12 +194,41 @@ void RandomMixture::setDistributionCollection(const DistributionCollection & col
   Bool hasNormalAtom(false);
   NumericalScalar aggregatedMean(0.0);
   NumericalScalar aggregatedVariance(0.0);
+  Bool hasPendingUniform(false);
+  Uniform pendingUniform;
   distributionCollection_ = DistributionCollection(0);
   for(UnsignedLong i = 0; i < size; ++i)
   {
     if (coll[i].getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: a RandomMixture cannot be built from a collection of distributions of dimension not equal to 1";
     // Knowledge-based optimization
-    if (coll[i].getImplementation()->getClassName() == "Normal")
+    if (coll[i].getImplementation()->getClassName() == "Uniform")
+    {
+      const NumericalScalar w(coll[i].getWeight());
+      const NumericalScalar low(coll[i].getRange().getLowerBound()[0]);
+      const NumericalScalar high(coll[i].getRange().getUpperBound()[0]);
+      NumericalScalar a0(w * low);
+      NumericalScalar b0(w * high);
+      if (a0 > b0) std::swap(a0, b0);
+      // If there is already a uniform, merge it into a symmetrical trapezoidal distribution
+      if (hasPendingUniform)
+      {
+        const NumericalScalar a1(pendingUniform.getA());
+        const NumericalScalar b1(pendingUniform.getB());
+        const NumericalScalar alpha(a1 + a0);
+        const NumericalScalar delta(b1 + b0);
+        const NumericalScalar halfWidth(0.5 * fabs((b1 - a1) - (b0 - a0)));
+        const NumericalScalar center(0.5 * (alpha + delta));
+        if (halfWidth > 0.0) distributionCollection_.add(Trapezoidal(alpha, center - halfWidth, center + halfWidth, delta));
+        else distributionCollection_.add(Triangular(alpha, center, delta));
+        hasPendingUniform = false;
+      }
+      else
+      {
+        pendingUniform = Uniform(a0, b0);
+        hasPendingUniform = true;
+      }
+    } // atom is a Uniform
+    else if (coll[i].getImplementation()->getClassName() == "Normal")
     {
       hasNormalAtom = true;
       const NumericalScalar w(coll[i].getWeight());
@@ -230,13 +262,41 @@ void RandomMixture::setDistributionCollection(const DistributionCollection & col
       {
         Distribution atom(mixture->distributionCollection_[j]);
         atom.setWeight(atom.getWeight() * w);
-        distributionCollection_.add(atom);
+        if (atom.getImplementation()->getClassName() == "Uniform")
+        {
+          const NumericalScalar w(atom.getWeight());
+          const NumericalScalar low(coll[i].getRange().getLowerBound()[0]);
+          const NumericalScalar high(coll[i].getRange().getUpperBound()[0]);
+          NumericalScalar a0(w * low);
+          NumericalScalar b0(w * high);
+          if (a0 > b0) std::swap(a0, b0);
+          // If there is already a uniform, merge it into a symmetrical trapezoidal distribution
+          if (hasPendingUniform)
+          {
+            const NumericalScalar a1(pendingUniform.getA());
+            const NumericalScalar b1(pendingUniform.getB());
+            const NumericalScalar alpha(a1 + a0);
+            const NumericalScalar delta(b1 + b0);
+            const NumericalScalar halfWidth(0.5 * fabs((b1 - a1) - (b0 - a0)));
+            const NumericalScalar center(0.5 * (alpha + delta));
+            if (halfWidth > 0.0) distributionCollection_.add(Trapezoidal(alpha, center - halfWidth, center + halfWidth, delta));
+            else distributionCollection_.add(Triangular(alpha, center, delta));
+            hasPendingUniform = false;
+          }
+          else
+          {
+            pendingUniform = Uniform(a0, b0);
+            hasPendingUniform = true;
+          }
+        } // atom is a Uniform
+        else distributionCollection_.add(atom);
       }
     } // atom is a RandomMixture
     else distributionCollection_.add(coll[i]);
   }
   // Set the aggregated normal as the last atom
   if (hasNormalAtom) distributionCollection_.add(Normal(aggregatedMean, sqrt(aggregatedVariance)));
+  if (hasPendingUniform) distributionCollection_.add(pendingUniform);
   setDimension(1);
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
@@ -367,13 +427,9 @@ NumericalScalar RandomMixture::computePDF(const NumericalPoint & point) const
 NumericalSample RandomMixture::computePDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
     const UnsignedLong pointNumber,
-    NumericalSample & grid,
-    const NumericalScalar precision) const
+    NumericalSample & grid) const
 {
-  const NumericalScalar oldPDFPrecision(pdfPrecision_);
-  pdfPrecision_ = std::max(precision / distributionCollection_.getSize(), pdfPrecision_);
-  const NumericalSample result(DistributionImplementation::computePDF(xMin, xMax, pointNumber, grid, precision));
-  pdfPrecision_ = oldPDFPrecision;
+  const NumericalSample result(DistributionImplementation::computePDF(xMin, xMax, pointNumber, grid));
   return result;
 }
 
@@ -445,28 +501,9 @@ NumericalScalar RandomMixture::computeComplementaryCDF(const NumericalPoint & po
 NumericalSample RandomMixture::computeCDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
     const UnsignedLong pointNumber,
-    NumericalSample & grid,
-    const NumericalScalar precision) const
+    NumericalSample & grid) const
 {
-  const NumericalScalar oldCDFPrecision(cdfPrecision_);
-  //        cdfPrecision_ = std::max(precision / distributionCollection_.getSize(), cdfPrecision_);
-  //         if (getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot compute the CDF over a regular 1D grid if the dimension is > 1";
-  //         NumericalSample result(pointNumber, 2);
-  //         NumericalScalar x(xMin);
-  //         NumericalScalar step((xMax - xMin) / NumericalScalar(pointNumber - 1.0));
-  //      result[0][0] = x;
-  //      result[0][1] = computeCDF(x, tail);
-  //         for (UnsignedLong i = 1; i < pointNumber; ++i)
-  //           {
-  //          x += step;
-  //             result[i][0] = x;
-  //          if (tail)
-  //            result[i][1] = result[i-1][1] - computeProbability(Interval(x - step, x));
-  //          else
-  //            result[i][1] = result[i-1][1] + computeProbability(Interval(x - step, x));
-  //           }
-  const NumericalSample result(DistributionImplementation::computeCDF(xMin, xMax, pointNumber, grid, precision));
-  cdfPrecision_ = oldCDFPrecision;
+  const NumericalSample result(DistributionImplementation::computeCDF(xMin, xMax, pointNumber, grid));
   return result;
 }
 
@@ -574,12 +611,9 @@ NumericalScalar RandomMixture::computeProbability(const Interval & interval) con
 NumericalSample RandomMixture::computeQuantile(const NumericalScalar qMin,
     const NumericalScalar qMax,
     const UnsignedLong pointNumber,
-    const NumericalScalar precision,
     const Bool tail) const
 {
   if (getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot compute the quantile over a regular 1D grid if the dimension is > 1";
-  const NumericalScalar oldCDFPrecision(cdfPrecision_);
-  const NumericalScalar oldPDFPrecision(pdfPrecision_);
   NumericalSample result(pointNumber, 2);
   NumericalScalar q(qMin);
   const NumericalScalar step((qMax - qMin) / NumericalScalar(pointNumber - 1.0));
@@ -589,15 +623,12 @@ NumericalSample RandomMixture::computeQuantile(const NumericalScalar qMin,
     result[i][1] = computeQuantile(q)[0];
     q += step;
   }
-  cdfPrecision_ = oldCDFPrecision;
-  pdfPrecision_ = oldPDFPrecision;
   return result;
 }
 
 /* Quantile computation for dimension=1 */
 NumericalScalar RandomMixture::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   // Special case for random mixture with only 1 atom: Y = alpha * X + beta
   // find Yq such that P(Y < Yq) = q
@@ -611,12 +642,9 @@ NumericalScalar RandomMixture::computeScalarQuantile(const NumericalScalar prob,
     return distributionCollection_[0].computeQuantile((alpha > 0.0) ? (prob) : (1.0 - prob))[0] * alpha + constant_;
   }
   // General case
-  return DistributionImplementation::computeScalarQuantile(prob, tail, precision);
+  return DistributionImplementation::computeScalarQuantile(prob, tail);
 }
 
-
-
-
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex RandomMixture::computeCharacteristicFunction(const NumericalScalar x) const
 {
