@@ -3,7 +3,7 @@
  *  @file  Rayleigh.cxx
  *  @brief The Rayleigh distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,7 @@ static Factory<Rayleigh> RegisteredFactory("Rayleigh");
 
 /* Default constructor */
 Rayleigh::Rayleigh()
-  : NonEllipticalDistribution("Rayleigh"),
+  : ContinuousDistribution("Rayleigh"),
     sigma_(1.0),
     gamma_(0.0)
 {
@@ -49,7 +49,7 @@ Rayleigh::Rayleigh()
 /* Parameters constructor */
 Rayleigh::Rayleigh(const NumericalScalar sigma,
                    const NumericalScalar gamma)
-  : NonEllipticalDistribution("Rayleigh"),
+  : ContinuousDistribution("Rayleigh"),
     sigma_(0.0), gamma_(gamma)
 {
   // This call set also the range
@@ -200,8 +200,7 @@ NumericalPoint Rayleigh::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Rayleigh::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return gamma_ + sigma_ * sqrt(-2.0 * log(prob));
   return gamma_ + sigma_ * sqrt(-2.0 * log1p(-prob));
@@ -317,7 +316,7 @@ NumericalScalar Rayleigh::getGamma() const
 /* Method save() stores the object through the StorageManager */
 void Rayleigh::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "sigma_", sigma_ );
   adv.saveAttribute( "gamma_", gamma_ );
 }
@@ -325,7 +324,7 @@ void Rayleigh::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Rayleigh::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "sigma_", sigma_ );
   adv.loadAttribute( "gamma_", gamma_ );
   computeRange();
