@@ -3,7 +3,7 @@
  *  @file  RayleighFactory.cxx
  *  @brief Factory for Rayleigh distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -73,7 +73,9 @@ Rayleigh RayleighFactory::buildAsRayleigh(const NumericalSample & sample) const
   }
   try
   {
-    return Rayleigh(sqrt(0.5 * sumSquares / size), gamma);
+    Rayleigh result(sqrt(0.5 * sumSquares / size), gamma);
+    result.setDescription(sample.getDescription());
+    return result;
   }
   catch (InvalidArgumentException & ex)
   {
