@@ -3,7 +3,7 @@
  *  @file  Rice.cxx
  *  @brief The Rice distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,9 +37,10 @@ static Factory<Rice> RegisteredFactory("Rice");
 
 /* Default constructor */
 Rice::Rice()
-  : NonEllipticalDistribution("Rice")
+  : ContinuousDistribution("Rice")
   , sigma_(1.0)
   , nu_(0.0)
+  , maximumIteration_(ResourceMap::GetAsUnsignedLong("DistFunc-MaximumIteration"))
 {
   setDimension(1);
   computeRange();
@@ -48,9 +49,10 @@ Rice::Rice()
 /* Parameters constructor */
 Rice::Rice(const NumericalScalar sigma,
            const NumericalScalar nu)
-  : NonEllipticalDistribution("Rice")
+  : ContinuousDistribution("Rice")
   , sigma_(0.0)
   , nu_(nu)
+  , maximumIteration_(ResourceMap::GetAsUnsignedLong("DistFunc-MaximumIteration"))
 {
   setNu(nu);
   // This call sets also the range
@@ -94,7 +96,7 @@ Rice * Rice::clone() const
 void Rice::computeRange()
 {
   const NumericalPoint lowerBound(1, 0.0 );
-  const NumericalPoint upperBound(computeUpperBound());
+  const NumericalPoint upperBound(1, computeScalarQuantile(cdfEpsilon_, true));
   const Interval::BoolCollection finiteLowerBound(1, true);
   const Interval::BoolCollection finiteUpperBound(1, false);
   setRange(Interval(lowerBound, upperBound, finiteLowerBound, finiteUpperBound));
@@ -118,7 +120,7 @@ NumericalScalar Rice::computePDF(const NumericalPoint & point) const
   if (x <= 0.0) return 0.0;
   const NumericalScalar lambda(pow(nu_ / sigma_, 2));
   const NumericalScalar z(x * pow(1.0 / sigma_, 2));
-  return 2.0 * z * DistFunc::dNonCentralChiSquare(2, lambda , x * z ) ;
+  return 2.0 * z * DistFunc::dNonCentralChiSquare(2, lambda , x * z, pdfEpsilon_, maximumIteration_) ;
 }
 
 
@@ -130,7 +132,7 @@ NumericalScalar Rice::computeCDF(const NumericalPoint & point) const
   if (point[0] <= 0.0) return 0.0;
   const NumericalScalar lambda(pow(nu_ / sigma_, 2));
   const NumericalScalar y(pow(point[0] / sigma_, 2));
-  return DistFunc::pNonCentralChiSquare(2, lambda , y );
+  return DistFunc::pNonCentralChiSquare(2, lambda , y, false, pdfEpsilon_, maximumIteration_);
 }
 
 NumericalScalar Rice::computeComplementaryCDF(const NumericalPoint & point) const
@@ -140,7 +142,7 @@ NumericalScalar Rice::computeComplementaryCDF(const NumericalPoint & point) cons
   if (point[0] <= 0.0) return 1.0;
   const NumericalScalar lambda(pow(nu_ / sigma_, 2));
   const NumericalScalar y(pow(point[0] / sigma_, 2));
-  return DistFunc::pNonCentralChiSquare(2, lambda , y, true );
+  return DistFunc::pNonCentralChiSquare(2, lambda , y, true, pdfEpsilon_, maximumIteration_);
 }
 
 /* Compute the mean of the distribution */
@@ -242,20 +244,33 @@ NumericalScalar Rice::getNu() const
   return nu_;
 }
 
+/* Maximum iterations accessor */
+void Rice::setMaximumIteration(const UnsignedLong maximumIteration)
+{
+  maximumIteration_ = maximumIteration;
+}
+
+UnsignedLong Rice::getMaximumIteration() const
+{
+  return maximumIteration_;
+}
+
 /* Method save() stores the object through the StorageManager */
 void Rice::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "sigma_", sigma_ );
   adv.saveAttribute( "nu_", nu_ );
+  adv.saveAttribute( "maximumIteration_", maximumIteration_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
 void Rice::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "sigma_", sigma_ );
   adv.loadAttribute( "nu_", nu_ );
+  adv.loadAttribute( "maximumIteration_", maximumIteration_ );
   computeRange();
 }
 
