@@ -3,7 +3,7 @@
  *  @file  Student.cxx
  *  @brief The Student distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -97,7 +97,7 @@ Bool Student::operator ==(const Student & other) const
 /* String converter */
 String Student::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Student::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -110,7 +110,7 @@ String Student::__repr__() const
 
 String Student::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName();
   if (getDimension() == 1) oss << "(nu = " << nu_ << ", mu = " << getMean()[0] << ", sigma = " << getSigma()[0] << ")";
   else oss << "(nu = " << nu_ << ", mu = " << getMean().__str__() << ", sigma = " << getSigma().__str__() << ", R = " << getCorrelation().__str__(offset) << ")";
@@ -277,18 +277,6 @@ NumericalScalar Student::computeCDF(const NumericalPoint & point) const
   return value;
 } // computeCDF
 
-/* Get the CDF of the distribution */
-NumericalScalar Student::computeComplementaryCDF(const NumericalPoint & point) const
-{
-  const UnsignedLong dimension(getDimension());
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << dimension << ", here dimension=" << point.getDimension();
-
-  // Special case for dimension 1
-  if (dimension == 1) return DistFunc::pStudent(nu_, (point[0] - mean_[0]) / sigma_[0], true);
-  // Other cases do not depend on tail flag
-  return computeCDF(point);
-}
-
 /* Compute the probability content of an interval */
 NumericalScalar Student::computeProbability(const Interval & interval) const
 {
@@ -533,7 +521,8 @@ Student::Implementation Student::getMarginal(const Indices & indices) const
 NumericalScalar Student::computeRadialDistributionCDF(const NumericalScalar radius,
     const Bool tail) const
 {
-  throw NotYetImplementedException(HERE);
+  const NumericalScalar r2(radius * radius);
+  return DistFunc::pBeta(0.5 * getDimension(), 0.5 * nu_, r2 / (nu_ + r2), tail);
 }
 
 /* Mu accessor */
@@ -591,6 +580,8 @@ NumericalPoint Student::getStandardMoment(const UnsignedLong n) const
   if (n % 2 == 1) return NumericalPoint(1, 0.0);
   NumericalScalar moment(1.0);
   for (UnsignedLong i = 0; i < n / 2; ++i) moment *= (nu_ * (2 * i + 1)) / (nu_ - 2 * (i + 1));
+  // Alternate expression, not very useful as the raw moments overflow the double precision for n approximately equal to 300 (if nu is large enough), and for these values the loop is equivalent to the analytic expression both in terms of speed and
+  // const NumericalScalar moment(exp(0.5 * n * log(nu_) + SpecFunc::LogGamma(0.5 * (n + 1.0)) + SpecFunc::LogGamma(0.5 * (nu_ - n)) - SpecFunc::LogGamma(0.5 * nu_)) / sqrt(M_PI));
   return NumericalPoint(1, moment);
 }
 
@@ -684,8 +675,7 @@ NumericalScalar Student::getNu() const
 
 /* Quantile computation for dimension=1 */
 NumericalScalar Student::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return mean_[0] + sigma_[0] * DistFunc::qStudent(nu_, prob, tail);
 }
