@@ -3,7 +3,7 @@
  *  @file  StudentFactory.cxx
  *  @brief Factory for Student distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -60,7 +60,9 @@ Student StudentFactory::buildAsStudent(const NumericalSample & sample) const
   const NumericalScalar sigma(sample.computeStandardDeviationPerComponent()[0]);
   const NumericalScalar nu(2.0 + 2.0 / (sigma * sigma - 1.0));
   if (nu <= 2.0) throw InvalidArgumentException(HERE) << "Error: can build a Student distribution only if nu > 2.0, here nu=" << nu;
-  return Student(nu, mu);
+  Student result(nu, mu);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Student StudentFactory::buildAsStudent() const
