@@ -3,7 +3,7 @@
  *  @file  TracyWidomGOE.cxx
  *  @brief The TracyWidomGOE distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ static Factory<TracyWidomGOE> RegisteredFactory("TracyWidomGOE");
 
 /* Default constructor */
 TracyWidomGOE::TracyWidomGOE()
-  : NonEllipticalDistribution("TracyWidomGOE")
+  : ContinuousDistribution("TracyWidomGOE")
 {
   throw NotYetImplementedException(HERE);
 }
@@ -107,8 +107,7 @@ NumericalPoint TracyWidomGOE::computeCDFGradient(const NumericalPoint & point) c
 
 /* Get the quantile of the distribution */
 NumericalScalar TracyWidomGOE::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   throw NotYetImplementedException(HERE);
 }
@@ -167,13 +166,13 @@ TracyWidomGOE::NumericalPointWithDescriptionCollection TracyWidomGOE::getParamet
 /* Method save() stores the object through the StorageManager */
 void TracyWidomGOE::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
 }
 
 /* Method load() reloads the object from the StorageManager */
 void TracyWidomGOE::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
 }
 
 END_NAMESPACE_OPENTURNS
