@@ -3,7 +3,7 @@
  *  @file  TracyWidomGSE.cxx
  *  @brief The TracyWidomGSE distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ static Factory<TracyWidomGSE> RegisteredFactory("TracyWidomGSE");
 
 /* Default constructor */
 TracyWidomGSE::TracyWidomGSE()
-  : NonEllipticalDistribution("TracyWidomGSE")
+  : ContinuousDistribution("TracyWidomGSE")
 {
   throw NotYetImplementedException(HERE);
   setDimension(1);
@@ -109,8 +109,7 @@ NumericalPoint TracyWidomGSE::computeCDFGradient(const NumericalPoint & point) c
 
 /* Get the quantile of the distribution */
 NumericalScalar TracyWidomGSE::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   throw NotYetImplementedException(HERE);
 }
@@ -169,13 +168,13 @@ TracyWidomGSE::NumericalPointWithDescriptionCollection TracyWidomGSE::getParamet
 /* Method save() stores the object through the StorageManager */
 void TracyWidomGSE::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
 }
 
 /* Method load() reloads the object from the StorageManager */
 void TracyWidomGSE::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
 }
 
 END_NAMESPACE_OPENTURNS
