@@ -3,7 +3,7 @@
  *  @file  TracyWidomGUE.cxx
  *  @brief The TracyWidomGUE distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,7 @@ static Factory<TracyWidomGUE> RegisteredFactory("TracyWidomGUE");
 
 /* Default constructor */
 TracyWidomGUE::TracyWidomGUE()
-  : NonEllipticalDistribution("TracyWidomGUE")
+  : ContinuousDistribution("TracyWidomGUE")
 {
   throw NotYetImplementedException(HERE);
   setDimension(1);
@@ -111,8 +111,7 @@ NumericalPoint TracyWidomGUE::computeCDFGradient(const NumericalPoint & point) c
 
 /* Get the quantile of the distribution */
 NumericalScalar TracyWidomGUE::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   throw NotYetImplementedException(HERE);
 }
@@ -171,13 +170,13 @@ TracyWidomGUE::NumericalPointWithDescriptionCollection TracyWidomGUE::getParamet
 /* Method save() stores the object through the StorageManager */
 void TracyWidomGUE::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
 }
 
 /* Method load() reloads the object from the StorageManager */
 void TracyWidomGUE::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
 }
 
 END_NAMESPACE_OPENTURNS
