@@ -3,7 +3,7 @@
  *  @file  Trapezoidal.cxx
  *  @brief The Trapezoidal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,20 +29,17 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(Trapezoidal);
 
 static Factory<Trapezoidal> RegisteredFactory("Trapezoidal");
 
 /* Default constructor */
 Trapezoidal::Trapezoidal()
-  : NonEllipticalDistribution("Trapezoidal"),
-    a_(-2.0),
-    b_(-1.0),
-    c_(1.0),
-    d_(2.0)
+  : ContinuousDistribution("Trapezoidal")
+  , a_(-2.0)
+  , b_(-1.0)
+  , c_(1.0)
+  , d_(2.0)
 {
   update();
 }
@@ -52,11 +49,11 @@ Trapezoidal::Trapezoidal(const NumericalScalar a,
                          const NumericalScalar b,
                          const NumericalScalar c,
                          const NumericalScalar d)
-  : NonEllipticalDistribution("Trapezoidal"),
-    a_(a),
-    b_(b),
-    c_(c),
-    d_(d)
+  : ContinuousDistribution("Trapezoidal")
+  , a_(a)
+  , b_(b)
+  , c_(c)
+  , d_(d)
 {
   update();
 }
@@ -129,9 +126,11 @@ NumericalScalar Trapezoidal::computePDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
 
-  if (x < a_) return 0.0;
+  if (x <= a_) return 0.0;
+  // Will never go there if a_ == b_
   if (x < b_) return h_ * (x - a_) / (b_ - a_);
   if (x < c_) return h_;
+  // Will never go there if c_ == d_
   if (x < d_) return h_ * (d_ - x) / (d_ - c_);
   return 0.0;
 }
@@ -142,25 +141,14 @@ NumericalScalar Trapezoidal::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar x(point[0]);
-  NumericalScalar cdf(1.0);
 
-  if (x < a_)
-  {
-    cdf = 0.0;
-  }
-  else if ( x < b_ )
-  {
-    cdf = 0.5 * h_ * ( (x - a_) * (x - a_) / (b_ - a_) );
-  }
-  else if ( x < c_ )
-  {
-    cdf = 0.5 * h_ * (2.0 * x - a_ - b_);
-  }
-  else if ( x < d_)
-  {
-    cdf = 0.5 * h_ * ( (2.0 * c_ - a_ - b_) + ( (c_ - x) * (c_ - 2.0 * d_ + x) / (d_ - c_) ) );
-  }
-  return cdf;
+  if (x <= a_) return 0.0;
+  // Will never go there if a_ == b_
+  if (x < b_) return 0.5 * h_ * ( (x - a_) * (x - a_) / (b_ - a_) );
+  if (x < c_) return 0.5 * h_ * (2.0 * x - a_ - b_);
+  // Will never go there if c_ == d_
+  if (x < d_) return 0.5 * h_ * ( (2.0 * c_ - a_ - b_) + ( (c_ - x) * (c_ - 2.0 * d_ + x) / (d_ - c_) ) );
+  return 1.0;
 }
 
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
@@ -175,10 +163,7 @@ NumericalComplex Trapezoidal::computeCharacteristicFunction(const NumericalScala
   NumericalScalar imag(0.0);
   NumericalComplex phi;
 
-  if (fabs(u) <= 1.0e-10)
-  {
-    phi = NumericalComplex((-a_ + 3.0 * b_ - 3.0 * c_ + d_) * h_ / 2.0, 1.0);
-  }
+  if (fabs(u) <= 1.0e-10) phi = NumericalComplex((-a_ + 3.0 * b_ - 3.0 * c_ + d_) * h_ / 2.0, 1.0);
   else
   {
     if (a_ < b_)
@@ -263,26 +248,17 @@ NumericalPoint Trapezoidal::computeCDFGradient(const NumericalPoint & point) con
 
 /* Get the quantile of the distribution */
 NumericalScalar Trapezoidal::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
-  NumericalScalar quantile;
   NumericalScalar c1(0.5 * (b_ - a_) * h_);
   NumericalScalar c2(c1 + (c_ - b_) * h_);
   NumericalScalar proba( tail ? 1.0 - prob : prob);
-  if (prob <= c1)  //p in (0.0; c1)
-  {
-    quantile = a_ + sqrt(2.0 * (b_ - a_) * proba / h_);
-  }
-  else if (prob <= c2)    //p in (c1; c2)
-  {
-    quantile = b_ + (proba - c1) / h_;
-  }
-  else    // p in (c2; 1.0)
-  {
-    quantile = d_ - sqrt(2.0 * (1.0 - proba) * (d_ - c_) / h_);
-  }
-  return quantile;
+  // p in (0, c1)
+  if (prob <= c1) return a_ + sqrt(2.0 * (b_ - a_) * proba / h_);
+  // p in (c1, c2)
+  if (prob <= c2) return b_ + (proba - c1) / h_;
+  // p in (c2, 1)
+  return d_ - sqrt(2.0 * (1.0 - proba) * (d_ - c_) / h_);
 }
 
 /* Get the roughness, i.e. the L2-norm of the PDF */
@@ -511,12 +487,10 @@ NumericalScalar Trapezoidal::getD() const
 void Trapezoidal::update()
 {
   setDimension(1);
-  if (b_ < a_)
-    throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter a must be greater or equal to argument b, here a=" << a_ << " b=" << b_;
-  if (c_ <= b_)
-    throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter b must be strictly greater than argument c, here b=" << b_ << " c=" << c_;
-  if (d_ < c_)
-    throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter d must be greater or equal to argument c, here c=" << c_ << " d=" << d_;
+  if (d_ <= a_) throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter a must be greater than argument d, here a=" << a_ << " d=" << d_;
+  if (b_ < a_) throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter a must be greater or equal to argument b, here a=" << a_ << " b=" << b_;
+  if (c_ < b_) throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter b must be strictly greater than argument c, here b=" << b_ << " c=" << c_;
+  if (d_ < c_) throw InvalidArgumentException(HERE) << " in Trapezoidal : distribution parameter d must be greater or equal to argument c, here c=" << c_ << " d=" << d_;
   h_ = 2. / (c_ - a_ + d_ - b_);
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
@@ -526,7 +500,7 @@ void Trapezoidal::update()
 /* Method save() stores the object through the StorageManager */
 void Trapezoidal::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute("a_", a_);
   adv.saveAttribute("b_", b_);
   adv.saveAttribute("c_", c_);
@@ -536,7 +510,7 @@ void Trapezoidal::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Trapezoidal::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute("a_", a_);
   adv.loadAttribute("b_", b_);
   adv.loadAttribute("c_", c_);
