@@ -3,7 +3,7 @@
  *  @file  TrapezoidalFactory.cxx
  *  @brief Factory for Trapezoidal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -139,7 +139,7 @@ Trapezoidal TrapezoidalFactory::buildAsTrapezoidal(const NumericalSample & sampl
 
   NumericalScalar rhoBeg(ResourceMap::GetAsNumericalScalar( "TrapezoidalFactory-RhoBeg" ));
   NumericalScalar rhoEnd(ResourceMap::GetAsNumericalScalar( "TrapezoidalFactory-RhoEnd" ));
-  int maxFun(ResourceMap::GetAsUnsignedLong( "TrapezoidalFactory-MaximumIterationsNumber" ));
+  int maxFun(ResourceMap::GetAsUnsignedLong( "TrapezoidalFactory-MaximumIteration" ));
   cobyla_message message( COBYLA_MSG_NONE );
 
   // use attributes to pass the data
@@ -151,7 +151,9 @@ Trapezoidal TrapezoidalFactory::buildAsTrapezoidal(const NumericalSample & sampl
   {
     LOGWARN(OSS() << "Error solving maximum likelihood problem by cobyla method, message=" << cobyla_rc_string[returnCode - COBYLA_MINRC]);
   }
-  return Trapezoidal(x[0], x[1], x[2], x[3]);
+  Trapezoidal result(x[0], x[1], x[2], x[3]);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Trapezoidal TrapezoidalFactory::buildAsTrapezoidal(const NumericalPointWithDescriptionCollection & parameters) const
