@@ -3,7 +3,7 @@
  *  @file  Triangular.cxx
  *  @brief The Triangular distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,17 +28,16 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(Triangular);
 
 static Factory<Triangular> RegisteredFactory("Triangular");
 
 /* Default constructor */
 Triangular::Triangular()
-  : NonEllipticalDistribution("Triangular"),
-    a_(-1.0), m_(0.0), b_(1.0)
+  : ContinuousDistribution("Triangular")
+  , a_(-1.0)
+  , m_(0.0)
+  , b_(1.0)
 {
   setDimension( 1 );
   computeRange();
@@ -48,8 +47,10 @@ Triangular::Triangular()
 Triangular::Triangular(const NumericalScalar a,
                        const NumericalScalar m,
                        const NumericalScalar b)
-  : NonEllipticalDistribution("Triangular"),
-    a_(0.), m_(0.), b_(0.)
+  : ContinuousDistribution("Triangular")
+  , a_(0.0)
+  , m_(0.0)
+  , b_(0.0)
 {
   // This call set also the range
   setAMB(a, m, b);
@@ -139,7 +140,7 @@ NumericalScalar Triangular::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= a_) return 0.0;
-  if (x > b_) return 1.0;
+  if (x >= b_) return 1.0;
   const NumericalScalar cdf(1.0 / (b_ - a_));
   if (x < m_) return (x - a_) * (x - a_) * cdf / (m_ - a_);
   return 1.0 - (x - b_) * (x - b_) * cdf / (b_ - m_);
@@ -222,8 +223,7 @@ NumericalPoint Triangular::computeCDFGradient(const NumericalPoint & point) cons
 
 /* Get the quantile of the distribution */
 NumericalScalar Triangular::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   const NumericalScalar ma(m_ - a_);
   const NumericalScalar ba(b_ - a_);
@@ -377,7 +377,7 @@ NumericalScalar Triangular::getB() const
 /* Method save() stores the object through the StorageManager */
 void Triangular::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "a_", a_ );
   adv.saveAttribute( "m_", m_ );
   adv.saveAttribute( "b_", b_ );
@@ -386,7 +386,7 @@ void Triangular::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Triangular::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "a_", a_ );
   adv.loadAttribute( "m_", m_ );
   adv.loadAttribute( "b_", b_ );
