@@ -3,7 +3,7 @@
  *  @file  TriangularFactory.cxx
  *  @brief Factory for Triangular distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -69,7 +69,9 @@ Triangular TriangularFactory::buildAsTriangular(const NumericalSample & sample)
   const NumericalScalar xMax(sample.getMax()[0]);
   const NumericalScalar b(xMax + fabs(xMax) / (size + 2));
   const NumericalScalar m(3.0 * sample.computeMean()[0] - a - b);
-  return Triangular(a, m, b);
+  Triangular result(a, m, b);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Triangular TriangularFactory::buildAsTriangular(const NumericalPointWithDescriptionCollection & parameters) const
