@@ -3,7 +3,7 @@
  *  @file  TruncatedDistribution.cxx
  *  @brief The TruncatedDistribution distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,7 @@ static Factory<TruncatedDistribution> RegisteredFactory("TruncatedDistribution")
 
 /* Default constructor */
 TruncatedDistribution::TruncatedDistribution()
-  : NonEllipticalDistribution("TruncatedDistribution")
+  : DistributionImplementation("TruncatedDistribution")
   , distribution_(Uniform(0.0, 1.0))
   , lowerBound_(0.0)
   , finiteLowerBound_(true)
@@ -62,7 +62,7 @@ TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
     const NumericalScalar lowerBound,
     const NumericalScalar upperBound,
     const NumericalScalar thresholdRealization)
-  : NonEllipticalDistribution("TruncatedDistribution")
+  : DistributionImplementation("TruncatedDistribution")
 {
   setDistribution(distribution);
   setThresholdRealization(thresholdRealization);
@@ -86,7 +86,7 @@ TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
     const NumericalScalar bound,
     const BoundSide side,
     const NumericalScalar thresholdRealization)
-  : NonEllipticalDistribution("TruncatedDistribution")
+  : DistributionImplementation("TruncatedDistribution")
 {
   if (distribution.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can truncate only distribution with dimension=1, here dimension=" << distribution.getDimension();
   distribution_ = distribution;
@@ -134,7 +134,7 @@ TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
 TruncatedDistribution::TruncatedDistribution(const Distribution & distribution,
     const Interval & truncationInterval,
     const NumericalScalar thresholdRealization)
-  : NonEllipticalDistribution("TruncatedDistribution")
+  : DistributionImplementation("TruncatedDistribution")
 {
   if (distribution.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can truncate only distribution with dimension=1, here dimension=" << distribution.getDimension();
   distribution_ = distribution;
@@ -206,7 +206,7 @@ void TruncatedDistribution::computeRange()
 NumericalPoint TruncatedDistribution::getRealization() const
 {
   // Do we use CDF inversion?
-  if ((cdfUpperBound_ - cdfLowerBound_) < thresholdRealization_) return computeQuantile(RandomGenerator::Generate());
+  if (isContinuous() && (cdfUpperBound_ - cdfLowerBound_) < thresholdRealization_) return computeQuantile(RandomGenerator::Generate());
   // Here we use simple rejection of the underlying distribution against the bounds
   for (;;)
   {
@@ -232,8 +232,7 @@ NumericalScalar TruncatedDistribution::computePDF(const NumericalPoint & point)
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalScalar x(point[0]);
-  const NumericalScalar quantileEpsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon"));
-  if ((x < lowerBound_ - quantileEpsilon) || (x > upperBound_ + quantileEpsilon)) return 0.0;
+  if ((x < lowerBound_ - quantileEpsilon_) || (x > upperBound_ + quantileEpsilon_)) return 0.0;
   return normalizationFactor_ * distribution_.computePDF(point);
 }
 
@@ -245,7 +244,7 @@ NumericalScalar TruncatedDistribution::computeCDF(const NumericalPoint & point)
 
   const NumericalScalar x(point[0]);
   if (x <= lowerBound_) return 0.0;
-  if (x > upperBound_) return 1.0;
+  if (x >= upperBound_) return 1.0;
   // If tail=true, don't call distribution_.computeCDF with tail=true in the next line!
   return normalizationFactor_ * (distribution_.computeCDF(point) - cdfLowerBound_);
 }
@@ -313,8 +312,7 @@ NumericalPoint TruncatedDistribution::computeCDFGradient(const NumericalPoint &
 
 /* Get the quantile of the distribution */
 NumericalScalar TruncatedDistribution::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return distribution_.computeQuantile(cdfUpperBound_ - prob * (cdfUpperBound_ - cdfLowerBound_))[0];
   return distribution_.computeQuantile(cdfLowerBound_ + prob * (cdfUpperBound_ - cdfLowerBound_))[0];
@@ -466,6 +464,12 @@ Bool TruncatedDistribution::isContinuous() const
   return distribution_.isContinuous();
 }
 
+/* Tell if the distribution is integer valued */
+Bool TruncatedDistribution::isDiscrete() const
+{
+  return distribution_.isDiscrete();
+}
+
 /* Tell if the distribution is integer valued */
 Bool TruncatedDistribution::isIntegral() const
 {
@@ -481,7 +485,7 @@ NumericalSample TruncatedDistribution::getSupport(const Interval & interval) con
 /* Method save() stores the object through the StorageManager */
 void TruncatedDistribution::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  DistributionImplementation::save(adv);
   adv.saveAttribute( "distribution_", distribution_ );
   adv.saveAttribute( "lowerBound_", lowerBound_ );
   adv.saveAttribute( "finiteLowerBound_", finiteLowerBound_ );
@@ -498,7 +502,7 @@ void TruncatedDistribution::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void TruncatedDistribution::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  DistributionImplementation::load(adv);
   adv.loadAttribute( "distribution_", distribution_ );
   adv.loadAttribute( "lowerBound_", lowerBound_ );
   adv.loadAttribute( "finiteLowerBound_", finiteLowerBound_ );
