@@ -3,7 +3,7 @@
  *  @file  TruncatedNormal.cxx
  *  @brief The TruncatedNormal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ static Factory<TruncatedNormal> RegisteredFactory("TruncatedNormal");
 
 /* Default onstructor */
 TruncatedNormal::TruncatedNormal()
-  : NonEllipticalDistribution("TruncatedNormal"),
+  : ContinuousDistribution("TruncatedNormal"),
     mu_(0.0),
     sigma_(1.0),
     a_(-1.0),
@@ -62,7 +62,7 @@ TruncatedNormal::TruncatedNormal(const NumericalScalar mu,
                                  const NumericalScalar sigma,
                                  const NumericalScalar a,
                                  const NumericalScalar b)
-  : NonEllipticalDistribution("TruncatedNormal"),
+  : ContinuousDistribution("TruncatedNormal"),
     mu_(mu),
     sigma_(0.0),
     a_(a),
@@ -107,7 +107,7 @@ Bool TruncatedNormal::operator ==(const TruncatedNormal & other) const
 /* String converter */
 String TruncatedNormal::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << TruncatedNormal::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -120,7 +120,7 @@ String TruncatedNormal::__repr__() const
 
 String TruncatedNormal::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(mu = " << mu_ << ", sigma = " << sigma_ << ", a = " << a_ << ", b = " << b_ << ")";
   return oss;
 }
@@ -188,7 +188,7 @@ NumericalScalar TruncatedNormal::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= a_) return 0.0;
-  if (x > b_) return 1.0;
+  if (x >= b_) return 1.0;
   return normalizationFactor_ * (DistFunc::pNormal((x - mu_) / sigma_) - PhiANorm_);
 }
 
@@ -272,8 +272,7 @@ NumericalPoint TruncatedNormal::computeCDFGradient(const NumericalPoint & point)
 
 /* Get the quantile of the distribution */
 NumericalScalar TruncatedNormal::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return mu_ + sigma_ * DistFunc::qNormal(PhiBNorm_ - prob / normalizationFactor_);
   return mu_ + sigma_ * DistFunc::qNormal(PhiANorm_ + prob / normalizationFactor_);
@@ -446,7 +445,7 @@ NumericalScalar TruncatedNormal::getB() const
 /* Method save() stores the object through the StorageManager */
 void TruncatedNormal::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "mu_", mu_ );
   adv.saveAttribute( "sigma_", sigma_ );
   adv.saveAttribute( "a_", a_ );
@@ -463,7 +462,7 @@ void TruncatedNormal::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void TruncatedNormal::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "mu_", mu_ );
   adv.loadAttribute( "sigma_", sigma_ );
   adv.loadAttribute( "a_", a_ );
