@@ -3,7 +3,7 @@
  *  @file  TruncatedNormalFactory.cxx
  *  @brief Factory for TruncatedNormal distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -62,16 +62,30 @@ TruncatedNormal TruncatedNormalFactory::buildAsTruncatedNormal(const NumericalSa
 {
   if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a TruncatedNormal distribution from an empty sample";
   if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a TruncatedNormal distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
+  // In order to avoid numerical stability issues, we normalize the data
+  const NumericalScalar xMin(sample.getMin()[0]);
+  const NumericalScalar xMax(sample.getMax()[0]);
+  const NumericalScalar alpha(2.0 / (xMax - xMin));
+  const NumericalScalar beta(xMin + xMax);
+  NumericalSample normalizedSample(sample);
+  normalizedSample *= NumericalPoint(1, alpha);
+  normalizedSample -= NumericalPoint(1, beta);
   // The method runRFactory checks the ability for R to compute parameters estimates
-  const NumericalPoint parametersValue(runRFactory(sample, TruncatedNormal()));
+  const NumericalPoint parametersValue(runRFactory(normalizedSample, TruncatedNormal()));
+  const NumericalScalar mu((parametersValue[0] + beta) / alpha);
+  const NumericalScalar sigma(parametersValue[1] / alpha);
+  const NumericalScalar a((parametersValue[2] + beta) / alpha);
+  const NumericalScalar b((parametersValue[3] + beta) / alpha);
   // Next, we try to build a TruncatedNormal distribution, which checks the parameters validity
   try
   {
-    return TruncatedNormal(parametersValue[0], parametersValue[1], parametersValue[2], parametersValue[3]);
+    TruncatedNormal result(mu, sigma, a, b);
+    result.setDescription(sample.getDescription());
+    return result;
   }
   catch (InvalidArgumentException & ex)
   {
-    throw InvalidArgumentException(HERE) << "Error: the estimated parameters values are not valid, mu=" << parametersValue[0] << ", sigma=" << parametersValue[1] << ", a=" << parametersValue[2] << ", b=" << parametersValue[3];
+    throw InvalidArgumentException(HERE) << "Error: the estimated parameters values are not valid, mu=" << mu << ", sigma=" << sigma << ", a=" << a << ", b=" << b;
   }
 }
 
