@@ -3,7 +3,7 @@
  *  @file  Uniform.cxx
  *  @brief The Uniform distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,7 +34,7 @@ static Factory<Uniform> RegisteredFactory("Uniform");
 
 /* Default constructor */
 Uniform::Uniform()
-  : NonEllipticalDistribution("Uniform")
+  : ContinuousDistribution("Uniform")
   , a_(-1.0)
   , b_(1.0)
 {
@@ -45,7 +45,7 @@ Uniform::Uniform()
 /* Parameters constructor */
 Uniform::Uniform(const NumericalScalar a,
                  const NumericalScalar b)
-  : NonEllipticalDistribution("Uniform")
+  : ContinuousDistribution("Uniform")
   , a_(a)
   , b_(b)
 {
@@ -64,7 +64,7 @@ Bool Uniform::operator ==(const Uniform & other) const
 /* String converter */
 String Uniform::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Uniform::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -75,7 +75,7 @@ String Uniform::__repr__() const
 
 String Uniform::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(a = " << a_ << ", b = " << b_ << ")";
   return oss;
 }
@@ -103,10 +103,11 @@ NumericalPoint Uniform::getRealization() const
 NumericalSample Uniform::getSample(const UnsignedLong size) const
 {
   NumericalSampleImplementation result(size, 1);
-  NumericalPoint point(RandomGenerator::Generate(size));
-  const NumericalScalar c(b_ - a_);
-  for (UnsignedLong i = 0; i < size; ++i) point[i] = c * point[i] + a_;
-  result.setData(point);
+  result.setData(RandomGenerator::Generate(size));
+  result.scale(NumericalPoint(1, b_ - a_));
+  result.translate(NumericalPoint(1, a_));
+  result.setName(getName());
+  result.setDescription(getDescription());
   return result;
 }
 
@@ -137,7 +138,7 @@ NumericalScalar Uniform::computeCDF(const NumericalPoint & point) const
 
   const NumericalScalar x(point[0]);
   if (x <= a_) return 0.0;
-  if (x > b_)  return 1.0;
+  if (x >= b_)  return 1.0;
   return (x - a_) / (b_ - a_);
 }
 
@@ -198,8 +199,7 @@ NumericalPoint Uniform::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Uniform::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return b_ - prob * (b_ - a_);
   return a_ + prob * (b_ - a_);
@@ -328,7 +328,7 @@ NumericalScalar Uniform::getB() const
 /* Method save() stores the object through the StorageManager */
 void Uniform::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "a_", a_ );
   adv.saveAttribute( "b_", b_ );
 }
@@ -336,7 +336,7 @@ void Uniform::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Uniform::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "a_", a_ );
   adv.loadAttribute( "b_", b_ );
   computeRange();
