@@ -3,7 +3,7 @@
  *  @file  UniformFactory.cxx
  *  @brief Factory for Uniform distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -68,7 +68,9 @@ Uniform UniformFactory::buildAsUniform(const NumericalSample & sample) const
   const NumericalScalar xMax(sample.getMax()[0]);
   const NumericalScalar b(xMax + fabs(xMax) / (2.0 + size));
   if (a >= b) throw InvalidArgumentException(HERE) << "Error: can build a Uniform distribution only if a < b, here a=" << a << " and b=" << b;
-  return Uniform(a, b);
+  Uniform result(a, b);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 Uniform UniformFactory::buildAsUniform(const NumericalPointWithDescriptionCollection & parameters) const
