@@ -3,7 +3,7 @@
  *  @file  UserDefined.cxx
  *  @brief The UserDefined distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -174,17 +174,17 @@ NumericalScalar UserDefined::computePDF(const NumericalPoint & point) const
     const NumericalScalar x(point[0]);
     UnsignedLong upper(size - 1);
     NumericalScalar xUpper(collection_[upper].getX()[0]);
-    if (x > xUpper + ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
+    if (x > xUpper + supportEpsilon_) return 0.0;
     UnsignedLong lower(0);
     NumericalScalar xLower(collection_[lower].getX()[0]);
-    if (x < xLower - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
+    if (x < xLower - supportEpsilon_) return 0.0;
     // Use dichotomic search of the correct index
     while (upper - lower > 1)
     {
       // The integer arithmetic insure that middle will be strictly between lower and upper as far as upper - lower > 1
       const UnsignedLong middle((upper + lower) / 2);
       const NumericalScalar xMiddle(collection_[middle].getX()[0]);
-      if (xMiddle > x + ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))
+      if (xMiddle > x + supportEpsilon_)
       {
         upper = middle;
         xUpper = xMiddle;
@@ -196,12 +196,12 @@ NumericalScalar UserDefined::computePDF(const NumericalPoint & point) const
       }
     } // while
     // At this point we have upper == lower or upper == lower + 1, with lower - epsilon <= x < upper + epsilon
-    if (fabs(x - xUpper) <= ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return collection_[upper].getP();
-    if (fabs(x - xLower) <= ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return collection_[lower].getP();
+    if (fabs(x - xUpper) <= supportEpsilon_) return collection_[upper].getP();
+    if (fabs(x - xLower) <= supportEpsilon_) return collection_[lower].getP();
     // x is not a point in the support of the distribution
     return 0.0;
   }
-  for (UnsignedLong i = 0; i < size; ++i) if ((point - collection_[i].getX()).norm() < ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) pdf += collection_[i].getP();
+  for (UnsignedLong i = 0; i < size; ++i) if ((point - collection_[i].getX()).norm() < supportEpsilon_) pdf += collection_[i].getP();
   return pdf;
 }
 
@@ -219,17 +219,17 @@ NumericalScalar UserDefined::computeCDF(const NumericalPoint & point) const
     const NumericalScalar x(point[0]);
     UnsignedLong upper(size - 1);
     NumericalScalar xUpper(collection_[upper].getX()[0]);
-    if (x > xUpper - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 1.0;
+    if (x > xUpper - supportEpsilon_) return 1.0;
     UnsignedLong lower(0);
     NumericalScalar xLower(collection_[lower].getX()[0]);
-    if (x <= xLower - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
+    if (x <= xLower - supportEpsilon_) return 0.0;
     // Use dichotomic search of the correct index
     while (upper - lower > 1)
     {
       // The integer arithmetic insure that middle will be strictly between lower and upper as far as upper - lower > 1
       const UnsignedLong middle((upper + lower) / 2);
       const NumericalScalar xMiddle(collection_[middle].getX()[0]);
-      if (xMiddle > x + ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))
+      if (xMiddle > x + supportEpsilon_)
       {
         upper = middle;
         xUpper = xMiddle;
@@ -243,7 +243,7 @@ NumericalScalar UserDefined::computeCDF(const NumericalPoint & point) const
     // At this point we have upper == lower or upper == lower + 1, with lower - epsilon <= x < upper + epsilon
     // If xLower < x < xUpper, the contribution of lower must be taken into account, else it
     // must be discarded
-    if (x <= xUpper - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return cumulativeProbabilities_[lower];
+    if (x <= xUpper - supportEpsilon_) return cumulativeProbabilities_[lower];
     return cumulativeProbabilities_[upper];
   }
   // Dimension > 1
@@ -251,7 +251,7 @@ NumericalScalar UserDefined::computeCDF(const NumericalPoint & point) const
   {
     const NumericalPoint x(collection_[i].getX());
     UnsignedLong j(0);
-    while ((j < dimension) && (x[j] <= point[j] + ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) ++j;
+    while ((j < dimension) && (x[j] <= point[j] + supportEpsilon_)) ++j;
     if (j == dimension) cdf += collection_[i].getP();
   }
   return cdf;
@@ -266,7 +266,7 @@ NumericalPoint UserDefined::computePDFGradient(const NumericalPoint & point) con
   NumericalPoint pdfGradient(size, 0.0);
   for (UnsignedLong i = 0; i < size; ++i)
   {
-    if ((point - collection_[i].getX()).norm() < ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))
+    if ((point - collection_[i].getX()).norm() < supportEpsilon_)
     {
       pdfGradient[i] = 1.0;
       return pdfGradient;
@@ -334,7 +334,7 @@ NumericalSample UserDefined::getSupport(const Interval & interval) const
     const NumericalPoint x(collection_[i].getX());
     if (interval.contains(x)) result.add(x);
   }
-  return result.sort(0);
+  return result;
 }
 
 /* Tell if the distribution is integer valued */
@@ -345,7 +345,7 @@ Bool UserDefined::isIntegral() const
   for (UnsignedLong i = 0; i < size; ++i)
   {
     const NumericalScalar x(collection_[i].getX()[0]);
-    if (fabs(x - round(x)) >= ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return false;
+    if (fabs(x - round(x)) >= supportEpsilon_) return false;
   }
   return true;
 }
@@ -468,39 +468,46 @@ void UserDefined::setPairCollection(const UserDefinedPairCollection & collection
   if (dimension == 0) throw InvalidArgumentException(HERE) << "Error: the points in the collection must have a dimension > 0";
   // Check if all the given probabilities are >= 0
   // Check if all the points have the same dimension
-  NumericalSample firstComponent(size, 1);
-  for (UnsignedLong i = 0; i < size; ++i)
-  {
-    if (collection[i].getX().getDimension() != dimension) throw InvalidArgumentException(HERE) << "UserDefined distribution must have all its point with the same dimension, which is not the case here collection=" << collection;
-    firstComponent[i][0] = collection[i].getX()[0];
-  }
+  for (UnsignedLong i = 1; i < size; ++i) if (collection[i].getX().getDimension() != dimension) throw InvalidArgumentException(HERE) << "UserDefined distribution must have all its point with the same dimension, which is not the case here collection=" << collection;
   setDimension(dimension);
   // First, sort the collection such that the sample made with the first component is in ascending order
-  const NumericalSample index(firstComponent.rank(0));
-  UserDefinedPairCollection sortedCollection(collection);
-  for (UnsignedLong i = 0; i < size; ++i) sortedCollection[(UnsignedLong)(round(index[i][0]))] = collection[i];
-  NumericalScalar sum(0.0);
-  const NumericalScalar firstProbability(sortedCollection[0].getP());
-  cumulativeProbabilities_ = NumericalPoint(size);
-  const NumericalScalar pdfEpsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultPDFEpsilon"));
+  NumericalSample weightedData(size, dimension + 1);
   for (UnsignedLong i = 0; i < size; ++i)
   {
-    const NumericalScalar p(sortedCollection[i].getP());
+    const NumericalPoint x(collection[i].getX());
+    for (UnsignedLong j = 0; j < dimension; ++j) weightedData[i][j] = x[j];
+    weightedData[i][dimension] = collection[i].getP();
+  }
+  // Sort the pairs
+  weightedData = weightedData.sortAccordingToAComponent(0);
+  // Check the probabilities and normalize them
+  const NumericalScalar firstProbability(weightedData[0][dimension]);
+  NumericalScalar sum(0.0);
+  cumulativeProbabilities_ = NumericalPoint(size);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    const NumericalScalar p(weightedData[i][dimension]);
     if (p < 0.0) throw InvalidArgumentException(HERE) << "UserDefined distribution must have positive probabilities, which is not the case here collection=" << collection;
     sum += p;
     cumulativeProbabilities_[i] = sum;
-    hasUniformWeights_ = hasUniformWeights_ && (fabs(p - firstProbability) < pdfEpsilon);
+    hasUniformWeights_ = hasUniformWeights_ && (fabs(p - firstProbability) < pdfEpsilon_);
   }
-  if (sum < ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultCDFEpsilon")) throw InvalidArgumentException(HERE) << "Error: the sum of probabilities is zero.";
+  if (sum < pdfEpsilon_) throw InvalidArgumentException(HERE) << "Error: the sum of probabilities is zero.";
   // Normalize the probabilities
   for (UnsignedLong i = 0; i < size; ++i)
   {
-    sortedCollection[i].setP(sortedCollection[i].getP() / sum);
+    weightedData[i][dimension] /= sum;
     cumulativeProbabilities_[i] /= sum;
   }
+  collection_ = UserDefinedPairCollection(size);
+  for (UnsignedLong i = 0; i < size; ++i)
+  {
+    NumericalPoint x(dimension);
+    for (UnsignedLong j = 0; j < dimension; ++j) x[j] = weightedData[i][j];
+    collection_[i] = UserDefinedPair(x, weightedData[i][dimension]);
+  }
   // We augment slightly the last cumulative probability, which should be equal to 1.0 but we enforce a value > 1.0. It stabilizes the sampling procedures without affecting their correctness (i.e. the algoritms are exact, not approximative)
-  cumulativeProbabilities_[size - 1] = 1.0 + 2.0 * ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon");
-  collection_ = sortedCollection;
+  cumulativeProbabilities_[size - 1] = 1.0 + 2.0 * supportEpsilon_;
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
@@ -514,8 +521,7 @@ UserDefined::UserDefinedPairCollection UserDefined::getPairCollection() const
 
 /* Quantile computation for dimension=1 */
 NumericalScalar UserDefined::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   UnsignedLong index(0);
   const NumericalScalar p(tail ? 1 - prob : prob);
@@ -526,6 +532,8 @@ NumericalScalar UserDefined::computeScalarQuantile(const NumericalScalar prob,
 /* Merge the identical points of the support */
 void UserDefined::compactSupport(const NumericalScalar epsilon)
 {
+  // No compaction if epsilon is negative
+  if (epsilon < 0.0) return;
   const UnsignedLong size(collection_.getSize());
   if (size == 0) return;
   NumericalPoint lastLocation(collection_[0].getX());
@@ -544,10 +552,7 @@ void UserDefined::compactSupport(const NumericalScalar epsilon)
       lastWeight = currentWeight;
     }
   }
-  // Check if the loop has been ended in the middle of an aggregation of points
-  // It is the case if the current weight is greater than the last weight
-  if (lastWeight > collection_[size - 1].getP())
-    compactCollection.add(UserDefinedPair(lastLocation, lastWeight));
+  compactCollection.add(UserDefinedPair(lastLocation, lastWeight));
   setPairCollection(compactCollection);
 }
 
