@@ -3,7 +3,7 @@
  *  @file  UserDefinedFactory.cxx
  *  @brief Factory for UserDefined distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -47,7 +47,13 @@ UserDefinedFactory * UserDefinedFactory::clone() const
 
 UserDefinedFactory::Implementation UserDefinedFactory::build(const NumericalSample & sample) const
 {
-  return buildAsUserDefined(sample).clone();
+  return buildAsUserDefined(sample, 0.0).clone();
+}
+
+UserDefinedFactory::Implementation UserDefinedFactory::build(const NumericalSample & sample,
+    const NumericalScalar epsilon) const
+{
+  return buildAsUserDefined(sample, epsilon).clone();
 }
 
 UserDefinedFactory::Implementation UserDefinedFactory::build() const
@@ -55,7 +61,8 @@ UserDefinedFactory::Implementation UserDefinedFactory::build() const
   return buildAsUserDefined().clone();
 }
 
-UserDefined UserDefinedFactory::buildAsUserDefined(const NumericalSample & sample) const
+UserDefined UserDefinedFactory::buildAsUserDefined(const NumericalSample & sample,
+    const NumericalScalar epsilon) const
 {
   const UnsignedLong size(sample.getSize());
   if (size == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a UserDefined distribution from an empty sample";
@@ -66,7 +73,10 @@ UserDefined UserDefinedFactory::buildAsUserDefined(const NumericalSample & sampl
     support[i].setX(sample[i]);
     support[i].setP(p);
   }
-  return UserDefined(support);
+  UserDefined result(support);
+  result.compactSupport(epsilon);
+  result.setDescription(sample.getDescription());
+  return result;
 }
 
 UserDefined UserDefinedFactory::buildAsUserDefined() const
