@@ -3,7 +3,7 @@
  *  @file  UserDefinedPair.cxx
  *  @brief The UserDefinedPair class.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,8 +28,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(UserDefinedPair);
 
 
@@ -37,8 +35,8 @@ static Factory<UserDefinedPair> RegisteredFactory("UserDefinedPair");
 
 /* Default constructor */
 UserDefinedPair::UserDefinedPair()
-  : x_(1, 0.0),
-    p_(1.0)
+  : x_(1, 0.0)
+  , p_(1.0)
 {
   // Nothing to do
 }
@@ -46,8 +44,8 @@ UserDefinedPair::UserDefinedPair()
 /* Parameters constructor */
 UserDefinedPair::UserDefinedPair(const NumericalPoint & x,
                                  const NumericalScalar p)
-  : x_(x),
-    p_(0.0)
+  : x_(x)
+  , p_(0.0)
 {
   setP(p);
 }
@@ -66,8 +64,9 @@ NumericalPoint UserDefinedPair::getX() const
 /* P accessor */
 void UserDefinedPair::setP(const NumericalScalar p)
 {
-  if ((p < 0.0) || (p > 1.0)) throw InvalidArgumentException(HERE) << "Error: the probability of a UserDefinedPair must be in [0, 1].";
-  p_ = p;
+  const NumericalScalar epsilon(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"));
+  if ((p < -epsilon) || (p > 1.0 + epsilon)) throw InvalidArgumentException(HERE) << "Error: the probability of a UserDefinedPair must be in [0, 1], here p=" << p << " and 1-p=" << 1.0 - p;
+  p_ = std::min(1.0, std::max(0.0, p));
 }
 
 NumericalScalar UserDefinedPair::getP() const
