@@ -3,7 +3,7 @@
  *  @file  Weibull.cxx
  *  @brief The Weibull distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ static Factory<Weibull> RegisteredFactory("Weibull");
 
 /* Default constructor */
 Weibull::Weibull()
-  : NonEllipticalDistribution("Weibull")
+  : ContinuousDistribution("Weibull")
   , alpha_(1.0)
   , beta_(1.0)
   , gamma_(0.0)
@@ -50,7 +50,7 @@ Weibull::Weibull(const NumericalScalar arg1,
                  const NumericalScalar arg2,
                  const NumericalScalar gamma,
                  const ParameterSet set)
-  : NonEllipticalDistribution("Weibull")
+  : ContinuousDistribution("Weibull")
   , alpha_(0.0)
   , beta_(0.0)
   , gamma_(gamma)
@@ -85,7 +85,7 @@ Bool Weibull::operator ==(const Weibull & other) const
 /* String converter */
 String Weibull::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Weibull::GetClassName()
       << " name=" << getName()
       << " dimension=" << getDimension()
@@ -97,7 +97,7 @@ String Weibull::__repr__() const
 
 String Weibull::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << offset << getClassName() << "(alpha = " << alpha_ << ", beta = " << beta_ << ", gamma = " << gamma_ << ")";
   return oss;
 }
@@ -203,8 +203,7 @@ NumericalPoint Weibull::computeCDFGradient(const NumericalPoint & point) const
 
 /* Get the quantile of the distribution */
 NumericalScalar Weibull::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if (tail) return gamma_ + alpha_ * pow(-log(prob), 1.0 / beta_);
   return gamma_ + alpha_ * pow(-log(1.0 - prob), 1.0 / beta_);
@@ -442,7 +441,7 @@ NumericalScalar Weibull::getGamma() const
 /* Method save() stores the object through the StorageManager */
 void Weibull::save(Advocate & adv) const
 {
-  NonEllipticalDistribution::save(adv);
+  ContinuousDistribution::save(adv);
   adv.saveAttribute( "alpha_", alpha_ );
   adv.saveAttribute( "beta_", beta_ );
   adv.saveAttribute( "gamma_", gamma_ );
@@ -451,7 +450,7 @@ void Weibull::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Weibull::load(Advocate & adv)
 {
-  NonEllipticalDistribution::load(adv);
+  ContinuousDistribution::load(adv);
   adv.loadAttribute( "alpha_", alpha_ );
   adv.loadAttribute( "beta_", beta_ );
   adv.loadAttribute( "gamma_", gamma_ );
