@@ -3,7 +3,7 @@
  *  @file  WeibullFactory.cxx
  *  @brief Factory for Weibull distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -68,7 +68,9 @@ Weibull WeibullFactory::buildAsWeibull(const NumericalSample & sample) const
   const NumericalScalar sigma(sample.computeStandardDeviationPerComponent()[0]);
   try
   {
-    return Weibull(mean, sigma, gamma, Weibull::MUSIGMA);
+    Weibull result(mean, sigma, gamma, Weibull::MUSIGMA);
+    result.setDescription(sample.getDescription());
+    return result;
   }
   catch (InvalidArgumentException & ex)
   {
