@@ -3,7 +3,7 @@
  *  @file  ZipfMandelbrot.cxx
  *  @brief The ZipfMandelbrot distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,9 +30,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(ZipfMandelbrot);
 
 static Factory<ZipfMandelbrot> RegisteredFactory("ZipfMandelbrot");
@@ -125,7 +122,7 @@ NumericalScalar ZipfMandelbrot::computePDF(const NumericalPoint & point) const
 
   const NumericalScalar k(point[0]);
 
-  if ((k < 1 - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (fabs(k - round(k)) > ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) || (k > n_ + ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))) return 0.0;
+  if ((k < 1 - supportEpsilon_) || (fabs(k - round(k)) > supportEpsilon_) || (k > n_ + supportEpsilon_)) return 0.0;
   return 1.0 / (pow(round(k) + q_, s_) * getHarmonicNumbers(n_) );
 }
 
@@ -136,8 +133,8 @@ NumericalScalar ZipfMandelbrot::computeCDF(const NumericalPoint & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
   const NumericalScalar k(point[0]);
 
-  if (k < 1 - ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 0.0;
-  if (k > n_ + ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon")) return 1.0;
+  if (k < 1 - supportEpsilon_) return 0.0;
+  if (k > n_ - 1 + supportEpsilon_) return 1.0;
 
   NumericalScalar value (getHarmonicNumbers(static_cast<UnsignedLong>(round(k))) / getHarmonicNumbers(n_));
   return value;
@@ -191,8 +188,7 @@ void ZipfMandelbrot::computeCovariance() const
 
 /* Get the quantile of the distribution */
 NumericalScalar ZipfMandelbrot::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   return round(DiscreteDistribution::computeScalarQuantile(prob, tail));
 }
