@@ -3,7 +3,7 @@
  *  @file  CopulaImplementation.cxx
  *  @brief Abstract top-level class for Continuous distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,6 +29,8 @@
 #include "Brent.hxx"
 #include "Curve.hxx"
 #include "MethodBoundNumericalMathEvaluationImplementation.hxx"
+#include "Combinations.hxx"
+#include "ComposedDistribution.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -61,12 +63,42 @@ String CopulaImplementation::__repr__() const
   return oss;
 }
 
+NumericalScalar CopulaImplementation::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  const UnsignedLong dimension(getDimension());
+  if (dimension == 1) return computeComplementaryCDF(point);
+  Bool allOutside(true);
+  for (UnsignedLong i = 0; i < dimension; ++i)
+  {
+    if (point[i] >= 1.0) return 0.0;
+    allOutside &= (point[i] <= 0.0);
+  }
+  if (allOutside) return 1.0;
+  // Use Poincaré's formula
+  NumericalScalar value(1.0 + (1 - 2 * (dimension % 2)) * computeCDF(point));
+  // We know the explicit value of the 1D marginal distributions
+  for (UnsignedLong i = 0; i < dimension; ++i) value -= point[i];
+  NumericalScalar sign(1.0);
+  for (UnsignedLong i = 2; i < dimension - 1; ++i)
+  {
+    NumericalScalar contribution(0.0);
+    Combinations::IndicesCollection indices(Combinations(i, dimension).generate());
+    NumericalPoint subPoint(i);
+    for (UnsignedLong j = 0; j < indices.getSize(); ++j)
+    {
+      for (UnsignedLong k = 0; k < i; ++k) subPoint[k] = point[indices[j][k]];
+      contribution += getMarginal(indices[j])->computeCDF(subPoint);
+    }
+    value += sign * contribution;
+    sign = -sign;
+  }
+  return value;
+}
+
 /* Generic implementation of the quantile computation for copulas */
 NumericalPoint CopulaImplementation::computeQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
-  NumericalScalar quantileEpsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon"));
-  if (prob < -quantileEpsilon || prob > 1.0 + quantileEpsilon) throw InvalidArgumentException(HERE) << "Error: cannot compute a quantile for a probability level outside of [0, 1]";
   const UnsignedLong dimension(getDimension());
   // Special case for bording values
   const NumericalScalar q(tail ? 1.0 - prob : prob);
@@ -86,43 +118,121 @@ NumericalPoint CopulaImplementation::computeQuantile(const NumericalScalar prob,
   const NumericalPoint rightValue(f(rightPoint));
   NumericalScalar rightCDF(rightValue[0]);
   // Use Brent's method to compute the quantile efficiently
-  Brent solver(cdfEpsilon_, cdfEpsilon_, cdfEpsilon_, ResourceMap::GetAsUnsignedLong( "DistributionImplementation-DefaultQuantileIteration" ));
+  Brent solver(cdfEpsilon_, cdfEpsilon_, cdfEpsilon_, quantileIterations_);
   return NumericalPoint(dimension, solver.solve(f, q, leftTau, rightTau, leftCDF, rightCDF));
 }
 
 
-/* Get the mean of the distribution */
+/* Get the mean of the copula */
 NumericalPoint CopulaImplementation::getMean() const
 {
   return NumericalPoint(getDimension(), 0.5);
 }
 
-/* Get the standard deviation of the distribution */
+/* Get the standard deviation of the copula */
 NumericalPoint CopulaImplementation::getStandardDeviation() const
 {
   // 0.2886751345948128822545744 = 1 / sqrt(12)
   return NumericalPoint(getDimension(), 0.2886751345948128822545744);
 }
 
-/* Get the skewness of the distribution */
+/* Get the Spearman correlation of the copula */
+CorrelationMatrix CopulaImplementation::getSpearmanCorrelation() const
+{
+  return getLinearCorrelation();
+}
+
+/* Get the Kendall concordance of the copula */
+CorrelationMatrix CopulaImplementation::getKendallTau() const
+{
+  const UnsignedLong dimension(getDimension());
+  CorrelationMatrix tau(dimension);
+  if (hasIndependentCopula()) return tau;
+  if (hasEllipticalCopula())
+  {
+    const CorrelationMatrix shape(getShapeMatrix());
+    for (UnsignedLong i = 0; i < dimension; ++i)
+      for(UnsignedLong j = 0; j < i; ++j)
+        tau(i, j) = asin(shape(i, j)) * (2.0 / M_PI);
+    return tau;
+  }
+  // Compute the weights and nodes of the 1D gauss quadrature over [-1, 1]
+  NumericalSample nodesAndWeights(getGaussNodesAndWeights());
+  // Convert the nodes and weights for the interval [0, 1]
+  for (UnsignedLong i = 0; i < integrationNodesNumber_; ++i)
+  {
+    nodesAndWeights[0][i] = 0.5 * (nodesAndWeights[0][i] + 1.0);
+    nodesAndWeights[1][i] *= 0.5;
+  }
+  // Performs the integration for each tau in the strictly lower triangle of the tau matrix
+  // We simply use a product gauss quadrature
+  // We first loop over the coefficients because the most expansive task is to get the 2D marginal copulas
+  // First, build the 2D sample of integration nodes
+  NumericalSample nodes(integrationNodesNumber_ * integrationNodesNumber_, 2);
+  UnsignedLong index(0);
+  for(UnsignedLong rowNodeIndex = 0; rowNodeIndex < integrationNodesNumber_; ++rowNodeIndex)
+  {
+    for(UnsignedLong columnNodeIndex = 0; columnNodeIndex < integrationNodesNumber_; ++columnNodeIndex)
+    {
+      nodes[index][0] = nodesAndWeights[0][rowNodeIndex];
+      nodes[index][1] = nodesAndWeights[0][columnNodeIndex];
+      ++index;
+    } // columnNodeIndex
+  } // rowNodeIndex
+  Indices indices(2);
+  for(UnsignedLong rowIndex = 0; rowIndex < dimension; ++rowIndex)
+  {
+    indices[0] = rowIndex;
+    for(UnsignedLong columnIndex = rowIndex + 1; columnIndex < dimension; ++columnIndex)
+    {
+      indices[1] = columnIndex;
+      // For the usual case of a bidimensional copula, no need to extract marginal distributions
+      Copula marginalCopula(*this);
+      if (dimension > 2) marginalCopula = getMarginal(indices);
+      if (!marginalCopula.hasIndependentCopula())
+      {
+        // Second, evaluate the PDF and the CDF on this sample
+        const NumericalSample samplePDF(marginalCopula.computePDF(nodes));
+        const NumericalSample sampleCDF(marginalCopula.computeCDF(nodes));
+        NumericalScalar value(0.0);
+        // Then we loop over the integration points
+        index = 0;
+        for(UnsignedLong rowNodeIndex = 0; rowNodeIndex < integrationNodesNumber_; ++rowNodeIndex)
+        {
+          const NumericalScalar weightI(nodesAndWeights[1][rowNodeIndex]);
+          for(UnsignedLong columnNodeIndex = 0; columnNodeIndex < integrationNodesNumber_; ++columnNodeIndex)
+          {
+            const NumericalScalar weightJ(nodesAndWeights[1][columnNodeIndex]);
+            value += weightI * weightJ * sampleCDF[index][0] * samplePDF[index][0];
+            ++index;
+          } // loop over J integration nodes
+        } // loop over I integration nodes
+        tau(rowIndex, columnIndex) = 4.0 * value - 1.0;
+      }
+    } // loop over column indices
+  } // loop over row indices
+  return tau;
+}
+
+/* Get the skewness of the copula */
 NumericalPoint CopulaImplementation::getSkewness() const
 {
   return NumericalPoint(getDimension(), 0.0);
 }
 
-/* Get the kurtosis of the distribution */
+/* Get the kurtosis of the copula */
 NumericalPoint CopulaImplementation::getKurtosis() const
 {
   // 1.8 = 9/5
   return NumericalPoint(getDimension(), 1.8);
 }
 
-/* Compute the covariance of the distribution */
+/* Compute the covariance of the copula */
 void CopulaImplementation::computeCovariance() const
 {
   const UnsignedLong dimension(getDimension());
   // We need this to initialize the covariance matrix in two cases:
-  // + this is the first call to this routine (which could be checked by testing the dimension of the distribution and the dimension of the matrix
+  // + this is the first call to this routine (which could be checked by testing the dimension of the copula and the dimension of the matrix
   // + the copula has changed from a non-independent one to the independent copula
   covariance_ = CovarianceMatrix(dimension);
   // First the diagonal terms, which are the marginal covariances
@@ -195,7 +305,13 @@ CopulaImplementation::Implementation CopulaImplementation::getCopula() const
   return clone();
 }
 
-/* Compute the mathematical and numerical range of the distribution.
+/* Check if the copula is a copula */
+Bool CopulaImplementation::isCopula() const
+{
+  return true;
+}
+
+/* Compute the mathematical and numerical range of the copula.
    Its mathematical range is the smallest closed interval outside
    of which the PDF is zero, and the numerical range is the interval
    outside of which the PDF is rounded to zero in double precision */
