@@ -3,7 +3,7 @@
  *  @file  DiscreteDistribution.cxx
  *  @brief Abstract top-level class for Discrete distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,8 @@ CLASSNAMEINIT(DiscreteDistribution);
 
 /* Default constructor */
 DiscreteDistribution::DiscreteDistribution(const String & name)
-  : UsualDistribution(name)
+  : DistributionImplementation(name)
+  , supportEpsilon_(ResourceMap::GetAsNumericalScalar("DiscreteDistribution-SupportEpsilon"))
 {
   // Nothing to do
 }
@@ -76,4 +77,29 @@ Bool DiscreteDistribution::isIntegral() const
   return true;
 }
 
+/* Support tolerance accessor */
+void DiscreteDistribution::setSupportEpsilon(const NumericalScalar epsilon)
+{
+  supportEpsilon_ = epsilon;
+}
+
+NumericalScalar DiscreteDistribution::getSupportEpsilon() const
+{
+  return supportEpsilon_;
+}
+
+/* Method save() stores the object through the StorageManager */
+void DiscreteDistribution::save(Advocate & adv) const
+{
+  DistributionImplementation::save(adv);
+  adv.saveAttribute( "supportEpsilon_", supportEpsilon_ );
+}
+
+/* Method load() reloads the object from the StorageManager */
+void DiscreteDistribution::load(Advocate & adv)
+{
+  DistributionImplementation::load(adv);
+  adv.loadAttribute( "supportEpsilon_", supportEpsilon_ );
+}
+
 END_NAMESPACE_OPENTURNS
