@@ -3,7 +3,7 @@
  *  @file  Distribution.cxx
  *  @brief Abstract top-level class for all distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -170,12 +170,39 @@ SquareMatrix Distribution::getInverseCholesky() const
   return getImplementation()->getInverseCholesky();
 }
 
-/* Get the covariance of the distribution */
+/* Get the linear correlation of the distribution */
 CorrelationMatrix Distribution::getCorrelation() const
 {
   return getImplementation()->getCorrelation();
 }
 
+CorrelationMatrix Distribution::getLinearCorrelation() const
+{
+  return getImplementation()->getLinearCorrelation();
+}
+
+CorrelationMatrix Distribution::getPearsonCorrelation() const
+{
+  return getImplementation()->getPearsonCorrelation();
+}
+
+/* Get the Spearman correlation of the distribution */
+CorrelationMatrix Distribution::getSpearmanCorrelation() const
+{
+  return getImplementation()->getSpearmanCorrelation();
+}
+
+/* Get the Kendall concordance of the distribution */
+CorrelationMatrix Distribution::getKendallTau() const
+{
+  return getImplementation()->getKendallTau();
+}
+
+/* Get the Shape matrix of the copula */
+CorrelationMatrix Distribution::getShapeMatrix() const
+{
+  return getImplementation()->getShapeMatrix();
+}
 
 /* Get one realization of the distribution */
 NumericalPoint Distribution::getRealization() const
@@ -207,11 +234,6 @@ NumericalScalar Distribution::computeLogPDF(const NumericalPoint & point) const
 }
 
 /* Get the CDF of the distribution */
-NumericalScalar Distribution::computeCDF(const NumericalPoint & point, const Bool tail) const
-{
-  return getImplementation()->computeCDF(point, tail);
-}
-
 NumericalScalar Distribution::computeCDF(const NumericalPoint & point) const
 {
   return getImplementation()->computeCDF(point);
@@ -222,6 +244,11 @@ NumericalScalar Distribution::computeComplementaryCDF(const NumericalPoint & poi
   return getImplementation()->computeComplementaryCDF(point);
 }
 
+NumericalScalar Distribution::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  return getImplementation()->computeSurvivalFunction(point);
+}
+
 /* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
 NumericalComplex Distribution::computeCharacteristicFunction(const NumericalScalar x) const
 {
@@ -272,11 +299,6 @@ NumericalSample Distribution::computeLogPDF(const NumericalSample & sample) cons
 }
 
 /* Get the CDF of the distribution (for a sample) */
-NumericalSample Distribution::computeCDF(const NumericalSample & sample, const Bool tail) const
-{
-  return getImplementation()->computeCDF(sample, tail);
-}
-
 NumericalSample Distribution::computeCDF(const NumericalSample & sample) const
 {
   return getImplementation()->computeCDF(sample);
@@ -287,6 +309,11 @@ NumericalSample Distribution::computeComplementaryCDF(const NumericalSample & sa
   return getImplementation()->computeComplementaryCDF(sample);
 }
 
+NumericalSample Distribution::computeSurvivalFunction(const NumericalSample & sample) const
+{
+  return getImplementation()->computeSurvivalFunction(sample);
+}
+
 /* Get the DDF of the distribution (for a scalar) */
 NumericalScalar Distribution::computeDDF(const NumericalScalar scalar) const
 {
@@ -305,12 +332,6 @@ NumericalScalar Distribution::computeLogPDF(const NumericalScalar scalar) const
 }
 
 /* Get the CDF of the distribution (for a scalar) */
-NumericalScalar Distribution::computeCDF(const NumericalScalar scalar,
-    const Bool tail) const
-{
-  return getImplementation()->computeCDF(scalar, tail);
-}
-
 NumericalScalar Distribution::computeCDF(const NumericalScalar scalar) const
 {
   return getImplementation()->computeCDF(scalar);
@@ -321,6 +342,11 @@ NumericalScalar Distribution::computeComplementaryCDF(const NumericalScalar scal
   return getImplementation()->computeComplementaryCDF(scalar);
 }
 
+NumericalScalar Distribution::computeSurvivalFunction(const NumericalScalar scalar) const
+{
+  return getImplementation()->computeSurvivalFunction(scalar);
+}
+
 /* Get the probability content of an interval */
 NumericalScalar Distribution::computeProbability(const Interval & interval) const
 {
@@ -330,30 +356,27 @@ NumericalScalar Distribution::computeProbability(const Interval & interval) cons
 /*  Compute the PDF of 1D distributions over a regular grid */
 NumericalSample Distribution::computePDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber,
-    const NumericalScalar precision) const
+    const UnsignedLong pointNumber) const
 {
   NumericalSample grid;
-  return getImplementation()->computePDF(xMin, xMax, pointNumber, grid, precision);
+  return getImplementation()->computePDF(xMin, xMax, pointNumber, grid);
 }
 
 /*  Compute the CDF of 1D distributions over a regular grid */
 NumericalSample Distribution::computeCDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber,
-    const NumericalScalar precision) const
+    const UnsignedLong pointNumber) const
 {
   NumericalSample grid;
-  return getImplementation()->computeCDF(xMin, xMax, pointNumber, grid, precision);
+  return getImplementation()->computeCDF(xMin, xMax, pointNumber, grid);
 }
 
 NumericalSample Distribution::computeComplementaryCDF(const NumericalScalar xMin,
     const NumericalScalar xMax,
-    const UnsignedLong pointNumber,
-    const NumericalScalar precision) const
+    const UnsignedLong pointNumber) const
 {
   NumericalSample grid;
-  return getImplementation()->computeComplementaryCDF(xMin, xMax, pointNumber, grid, precision);
+  return getImplementation()->computeComplementaryCDF(xMin, xMax, pointNumber, grid);
 }
 
 /* Get the PDF gradient of the distribution */
@@ -396,10 +419,9 @@ NumericalSample Distribution::computeQuantile(const NumericalPoint & prob,
 NumericalSample Distribution::computeQuantile(const NumericalScalar qMin,
     const NumericalScalar qMax,
     const UnsignedLong pointNumber,
-    const NumericalScalar precision,
     const Bool tail) const
 {
-  return getImplementation()->computeQuantile(qMin, qMax, pointNumber, precision, tail);
+  return getImplementation()->computeQuantile(qMin, qMax, pointNumber, tail);
 }
 
 /* Get the implementation of the distribution */
@@ -414,6 +436,12 @@ Bool Distribution::isElliptical() const
   return getImplementation()->isElliptical();
 }
 
+/* Check if the distribution is a copula */
+Bool Distribution::isCopula() const
+{
+  return getImplementation()->isCopula();
+}
+
 /* Check if the distribution is continuous */
 Bool Distribution::isContinuous() const
 {
@@ -642,6 +670,19 @@ Graph Distribution::drawCDF() const
   return getImplementation()->drawCDF();
 }
 
+/* Draw the quantile of the distribution when its dimension is 1 or 2 */
+Graph Distribution::drawQuantile(const UnsignedLong pointNumber) const
+{
+  return getImplementation()->drawQuantile(pointNumber);
+}
+
+Graph Distribution::drawQuantile(const NumericalScalar qMin,
+                                 const NumericalScalar qMax,
+                                 const UnsignedLong pointNumber) const
+{
+  return getImplementation()->drawQuantile(qMin, qMax, pointNumber);
+}
+
 /* Parameters value and description accessor */
 Distribution::NumericalPointWithDescriptionCollection Distribution::getParametersCollection() const
 {
