@@ -3,7 +3,7 @@
  * @file  DistributionFactory.cxx
  * @brief Top-level class for all distribution factories
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,6 +52,7 @@
 #include "LogisticFactory.hxx"
 #include "LogNormalFactory.hxx"
 #include "LogUniformFactory.hxx"
+#include "MeixnerDistributionFactory.hxx"
 #include "MultinomialFactory.hxx"
 #include "NegativeBinomialFactory.hxx"
 #include "NormalCopulaFactory.hxx"
@@ -59,6 +60,7 @@
 #include "PoissonFactory.hxx"
 #include "RayleighFactory.hxx"
 #include "RiceFactory.hxx"
+#include "SkellamFactory.hxx"
 #include "StudentFactory.hxx"
 #include "TrapezoidalFactory.hxx"
 #include "TriangularFactory.hxx"
@@ -92,6 +94,7 @@ DistributionFactory::DistributionFactoryCollection DistributionFactory::GetConti
   collection.add(LogisticFactory());
   collection.add(LogNormalFactory());
   collection.add(LogUniformFactory());
+  collection.add(MeixnerDistributionFactory());
   collection.add(NormalFactory());
   collection.add(RayleighFactory());
   collection.add(RiceFactory());
@@ -130,6 +133,7 @@ DistributionFactory::DistributionFactoryCollection DistributionFactory::GetDiscr
   collection.add(NegativeBinomialFactory());
   collection.add(PoissonFactory());
   collection.add(UserDefinedFactory());
+  collection.add(SkellamFactory());
   return collection;
 }
 
