@@ -3,7 +3,7 @@
  *  @file  DistributionImplementationFactory.cxx
  *  @brief Top-level class for all distribution factories
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,7 +56,7 @@ DistributionImplementationFactory * DistributionImplementationFactory::clone() c
 /* String converter */
 String DistributionImplementationFactory::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << this->getClassName();
   return oss;
 }
