@@ -3,7 +3,7 @@
  *  @file  EllipticalDistribution.cxx
  *  @brief Abstract top-level class for elliptical distributions
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,7 +31,7 @@
 #include "InverseNatafEllipticalDistributionHessian.hxx"
 #include "Description.hxx"
 #include "PersistentObjectFactory.hxx"
-#include "Lapack.hxx"
+#include "TriangularMatrix.hxx"
 #include "IdentityMatrix.hxx"
 #include "ResourceMap.hxx"
 #include "SpecFunc.hxx"
@@ -172,7 +172,7 @@ NumericalPoint EllipticalDistribution::computeDDF(const NumericalPoint & point)
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
-  const NumericalScalar betaSquare(iLx.norm2());
+  const NumericalScalar betaSquare(iLx.normSquare());
   return 2.0 * normalizationFactor_ * computeDensityGeneratorDerivative(betaSquare) * inverseCholesky_.transpose() * iLx;
 }
 
@@ -181,9 +181,18 @@ NumericalScalar EllipticalDistribution::computePDF(const NumericalPoint & point)
 {
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
-  const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
-  const NumericalScalar betaSquare(iLx.norm2());
-  return normalizationFactor_ * computeDensityGenerator(betaSquare);
+  const UnsignedLong dimension(getDimension());
+  if (dimension == 1)
+  {
+    const NumericalScalar iLx((point[0] - mean_[0]) / sigma_[0]);
+    return normalizationFactor_ * computeDensityGenerator(iLx * iLx);
+  }
+  else
+  {
+    const NumericalPoint iLx(inverseCholesky_ * (point - mean_));
+    const NumericalScalar betaSquare(iLx.normSquare());
+    return normalizationFactor_ * computeDensityGenerator(betaSquare);
+  }
 }
 
 /* Get the PDF gradient of the distribution */
@@ -210,55 +219,52 @@ NumericalPoint EllipticalDistribution::computePDFGradient(const NumericalPoint &
   return pdfGradient;
 }
 
+/* Get the survival function of the distribution */
+NumericalScalar EllipticalDistribution::computeSurvivalFunction(const NumericalPoint & point) const
+{
+  return computeCDF(2.0 * mean_ - point);
+}
+
 /* Update the derivative attributes */
 void EllipticalDistribution::update()
 {
   const UnsignedLong dimension(getDimension());
-  shape_ = CovarianceMatrix(dimension);
-  // Build the shape matrix
-  shape_ = R_;
-  for (UnsignedLong i = 0; i < dimension; ++i)
-    for (UnsignedLong j = 0; j <= i; ++j)
-      shape_(i, j) *= sigma_[i] * sigma_[j];
-  // Compute its Cholesky factor
-  cholesky_ = shape_.computeCholesky();
-  // Inversion of the Cholesky factor using the dtrsm blas level 3 routine
-  // side tells if we solve M.X = alpha.B or X.M = alpha.B
-  char side('L');
-  int lside(1);
-  // M must be triangular. uplo tells if it is upper or lower triangular
-  char uplo('L');
-  int luplo(1);
-  // transa tells if M is transposed or not
-  char transa('N');
-  int ltransa(1);
-  // diag tells if M is unit diagonal or not
-  char diag('N');
-  int ldiag(1);
-  // the row dimension of M
-  int m(dimension);
-  // the column dimension of M
-  int n(dimension);
-  // we solve the case alpha=1
-  double alpha(1.0);
-  // leading dimension of M
-  int lda(dimension);
-  // leading dimension of B
-  int ldb(dimension);
-  // As we want to inverse M, we set B = Id
-  inverseCholesky_ = IdentityMatrix(dimension);
-  // B stores the result of the routine
-  DTRSM_F77(&side, &uplo, &transa, &diag, &m, &n, &alpha, const_cast<double*>(&((*cholesky_.getImplementation())[0])), &lda, const_cast<double*>(&((*inverseCholesky_.getImplementation())[0])), &ldb, &lside, &luplo, &ltransa, &ldiag);
+  if (dimension > 1)
+  {
+    // Build the shape matrix
+    shape_ = R_;
+    for (UnsignedLong i = 0; i < dimension; ++i)
+      for (UnsignedLong j = 0; j <= i; ++j)
+        shape_(i, j) *= sigma_[i] * sigma_[j];
+    // Compute its Cholesky factor
+    cholesky_ = shape_.computeCholesky();
 
-  // Inverse the correlation matrix R = D^(-1).L.L'.D^(-1)
-  // R^(-1) = D.L^(-1).L^(-1)'.D
-  inverseR_ = SymmetricMatrix(dimension);
-  const SquareMatrix inverseShape(inverseCholesky_.transpose() * inverseCholesky_);
-  for (UnsignedLong i = 0; i < dimension; ++i)
-    for (UnsignedLong j = 0; j <= i; ++j)
-      inverseR_(i, j) = sigma_[i] * inverseShape(i, j) * sigma_[j];
-  normalizationFactor_ = 1.0;
-  for (UnsignedLong i = 0; i < dimension; ++i) normalizationFactor_ /= cholesky_(i, i);
+    inverseCholesky_ = TriangularMatrix(cholesky_.getImplementation()).solveLinearSystem(IdentityMatrix(dimension)).getImplementation();
+
+    // Inverse the correlation matrix R = D^(-1).L.L'.D^(-1)
+    // R^(-1) = D.L^(-1).L^(-1)'.D
+    inverseR_ = SymmetricMatrix(dimension);
+    const SquareMatrix inverseShape(inverseCholesky_.transpose() * inverseCholesky_);
+    for (UnsignedLong i = 0; i < dimension; ++i)
+      for (UnsignedLong j = 0; j <= i; ++j)
+        inverseR_(i, j) = sigma_[i] * inverseShape(i, j) * sigma_[j];
+    normalizationFactor_ = 1.0;
+    for (UnsignedLong i = 0; i < dimension; ++i) normalizationFactor_ /= cholesky_(i, i);
+  }
+  else  // dimension 1
+  {
+    if (shape_.getDimension() == 0)  // First time we enter here, set matrix sizes
+    {
+      shape_ = CovarianceMatrix(1);
+      inverseR_ = IdentityMatrix(1);
+      cholesky_ = SquareMatrix(1);
+      inverseCholesky_ = SquareMatrix(1);
+    }
+    shape_(0, 0) = sigma_[0] * sigma_[0];
+    cholesky_(0, 0) = sigma_[0];
+    inverseCholesky_(0, 0) = 1.0 / sigma_[0];
+    normalizationFactor_ = 1.0 / sigma_[0];
+  }
   isAlreadyComputedMean_ = true;
 }
 
@@ -522,6 +528,23 @@ void EllipticalDistribution::setParametersCollection(const NumericalPointCollect
   isAlreadyComputedCovariance_ = false;
 }
 
+void EllipticalDistribution::setParametersCollection(const NumericalPoint & flattenCollection)
+{
+  const UnsignedLong dimension(getDimension());
+  if (dimension == 1)
+  {
+    if (flattenCollection.getDimension() != 2) throw InvalidArgumentException(HERE) << "Error: the given parameters point has an invalid dimension (" << flattenCollection.getDimension() << "), it should be 2";
+
+    mean_[0] = flattenCollection[0];
+    sigma_[0] = flattenCollection[1];
+    if (sigma_[0] <= 0.0) throw InvalidArgumentException(HERE) << "The marginal standard deviations must be > 0 sigma=" << sigma_;
+    update();
+    computeRange();
+    isAlreadyComputedCovariance_ = false;
+  }
+  else DistributionImplementation::setParametersCollection(flattenCollection);
+}
+
 /* Method save() stores the object through the StorageManager */
 void EllipticalDistribution::save(Advocate & adv) const
 {
