@@ -3,7 +3,7 @@
  *  @file  Event.cxx
  *  @brief The class that implements all random vectors
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -71,7 +71,7 @@ Event::Event(const Process & process,
 /* String converter */
 String Event::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << Event::GetClassName()
       << " name=" << getName()
       << " implementation=" << getImplementation()->__repr__();
