@@ -3,7 +3,7 @@
  *  @file  Process.cxx
  *  @brief The class that implements all random vectors
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -111,13 +111,18 @@ Bool Process::isComposite() const
 /* Here is the interface that all derived class may implement */
 
 /* Dimension accessor */
+UnsignedLong Process::getMeshDimension() const
+{
+  return getImplementation()->getMeshDimension();
+}
+
 UnsignedLong Process::getDimension() const
 {
   return getImplementation()->getDimension();
 }
 
 /* Discrete realization accessor */
-TimeSeries Process::getRealization() const
+Field Process::getRealization() const
 {
   return getImplementation()->getRealization();
 }
@@ -141,6 +146,19 @@ void Process::setTimeGrid(const RegularGrid & timeGrid)
   return getImplementation()->setTimeGrid(timeGrid);
 }
 
+/* Mesh accessor - get */
+Mesh Process::getMesh() const
+{
+  return getImplementation()->getMesh();
+}
+
+/* Mesh accessor - set */
+void Process::setMesh(const Mesh & mesh)
+{
+  copyOnWrite();
+  return getImplementation()->setMesh(mesh);
+}
+
 ProcessSample Process::getSample(const UnsignedLong size) const
 {
   return getImplementation()->getSample(size);
