@@ -3,7 +3,7 @@
  *  @file  ProcessImplementation.cxx
  *  @brief An interface for all implementation class of process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,6 +26,8 @@
 #include "Exception.hxx"
 #include "NumericalMathFunction.hxx"
 #include "PiecewiseLinearEvaluationImplementation.hxx"
+#include "DatabaseNumericalMathEvaluationImplementation.hxx"
+#include "RegularGrid.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -38,7 +40,7 @@ ProcessImplementation::ProcessImplementation(const String & name)
   : PersistentObject(name),
     description_(),
     dimension_(1),
-    timeGrid_()
+    mesh_(RegularGrid(0.0, 1.0, 1))
 {
   // Nothing to do
 }
@@ -52,26 +54,31 @@ ProcessImplementation * ProcessImplementation::clone() const
 /* String converter */
 String ProcessImplementation::__repr__() const
 {
-  OSS oss;
-  oss << "class= " << ProcessImplementation::GetClassName()
-      << " dimension_ = " << dimension_
-      << " description = " << description_
-      << " timeGrid = " << timeGrid_;
+  OSS oss(true);
+  oss << "class=" << ProcessImplementation::GetClassName()
+      << " dimension_=" << dimension_
+      << " description=" << description_
+      << " mesh=" << mesh_;
   return oss;
 }
 
 /* String converter */
 String ProcessImplementation::__str__(const String & offset) const
 {
-  OSS oss;
-  oss << "class= " << ProcessImplementation::GetClassName()
-      << " dimension = " << dimension_
-      << " description = " << description_.__str__(offset)
-      << " timeGrid = " << timeGrid_.__str__(offset);
+  OSS oss(false);
+  oss << "class=" << ProcessImplementation::GetClassName()
+      << " dimension=" << dimension_
+      << " description=" << description_.__str__(offset)
+      << " mesh=" << mesh_.__str__(offset);
   return oss;
 }
 
 /* Dimension accessor */
+UnsignedLong ProcessImplementation::getMeshDimension() const
+{
+  return mesh_.getDimension();
+}
+
 UnsignedLong ProcessImplementation::getDimension() const
 {
   return dimension_;
@@ -96,12 +103,23 @@ Description ProcessImplementation::getDescription() const
 /* TimeGrid accessor */
 RegularGrid ProcessImplementation::getTimeGrid() const
 {
-  return timeGrid_;
+  return getMesh();
 }
 
 void ProcessImplementation::setTimeGrid(const RegularGrid & timeGrid)
 {
-  timeGrid_ = timeGrid;
+  setMesh(timeGrid);
+}
+
+/* Mesh accessor */
+Mesh ProcessImplementation::getMesh() const
+{
+  return mesh_;
+}
+
+void ProcessImplementation::setMesh(const Mesh & mesh)
+{
+  mesh_ = mesh;
 }
 
 
@@ -127,7 +145,7 @@ Bool ProcessImplementation::isComposite() const
 }
 
 /* Discrete realization accessor */
-TimeSeries ProcessImplementation::getRealization() const
+Field ProcessImplementation::getRealization() const
 {
   throw NotYetImplementedException(HERE);
 }
@@ -135,24 +153,21 @@ TimeSeries ProcessImplementation::getRealization() const
 /* Continuous realization accessor */
 NumericalMathFunction ProcessImplementation::getContinuousRealization() const
 {
-  const TimeSeries ts(getRealization());
-  // The continuous realization will be obtained by a piecewise linear interpolation
-  const UnsignedLong size(ts.getSize());
-  NumericalPoint locations(size);
-  NumericalSample values(size, dimension_);
-  for (UnsignedLong i = 0; i < size; ++i)
+  const Field field(getRealization());
+  const NumericalSample values(field.getValues());
+  if (mesh_.getDimension() == 1)
   {
-    locations[i] = ts[i][0];
-    for (UnsignedLong j = 0; j < dimension_; ++j)
-      values[i][j] = ts[i][j + 1];
+    // The continuous realization will be obtained by a piecewise linear interpolation
+    NumericalPoint locations(mesh_.getVertices().getImplementation()->getData());
+    return PiecewiseLinearEvaluationImplementation(locations, values);
   }
-  return PiecewiseLinearEvaluationImplementation(locations, values);
+  return DatabaseNumericalMathEvaluationImplementation(mesh_.getVertices(), values);
 }
 
 ProcessSample ProcessImplementation::getSample(const UnsignedLong size) const
 {
-  ProcessSample result(timeGrid_, size, dimension_);
-  for (UnsignedLong i = 0; i < size; ++i) result[i] = getRealization();
+  ProcessSample result(mesh_, size, dimension_);
+  for (UnsignedLong i = 0; i < size; ++i) result[i] = getRealization().getValues();
   return result;
 }
 
@@ -165,9 +180,10 @@ TimeSeries ProcessImplementation::getFuture(const UnsignedLong stepNumber) const
 ProcessSample ProcessImplementation::getFuture(const UnsignedLong stepNumber,
     const UnsignedLong size) const
 {
-  if (size == 0) return ProcessSample(timeGrid_, 0, dimension_);
+  if (mesh_.getDimension() != 1) throw NotDefinedException(HERE) << "Error: can extend the realization of a process only if defined on a 1D mesh.";
+  if (size == 0) return ProcessSample(mesh_, 0, dimension_);
   ProcessSample result(size, getFuture(stepNumber));
-  for (UnsignedLong i = 1; i < size; ++i) result[i] = getFuture(stepNumber);
+  for (UnsignedLong i = 1; i < size; ++i) result[i] = getFuture(stepNumber).getValues();
   return result;
 }
 
@@ -190,7 +206,7 @@ void ProcessImplementation::save(Advocate & adv) const
   PersistentObject::save(adv);
   adv.saveAttribute( "dimension_", dimension_ );
   adv.saveAttribute( "description_", description_ );
-  adv.saveAttribute( "timeGrid_", timeGrid_ );
+  adv.saveAttribute( "mesh_", mesh_ );
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -199,7 +215,7 @@ void ProcessImplementation::load(Advocate & adv)
   PersistentObject::load(adv);
   adv.loadAttribute( "dimension_", dimension_ );
   adv.loadAttribute( "description_", description_ );
-  adv.loadAttribute( "timeGrid_", timeGrid_ );
+  adv.loadAttribute( "mesh_", mesh_ );
 }
 
 END_NAMESPACE_OPENTURNS
