@@ -3,7 +3,7 @@
  *  @file  SklarCopula.cxx
  *  @brief The SklarCopula distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,11 +32,9 @@
 #include "NumericalMathFunctionImplementation.hxx"
 #include "RandomGenerator.hxx"
 #include "Uniform.hxx"
-#include "ResourceMap.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
 typedef NumericalMathFunctionImplementation::EvaluationImplementation EvaluationImplementation;
 typedef NumericalMathFunctionImplementation::GradientImplementation   GradientImplementation;
 typedef NumericalMathFunctionImplementation::HessianImplementation    HessianImplementation;
@@ -48,24 +46,26 @@ static Factory<SklarCopula> RegisteredFactory("SklarCopula");
 
 /* Default constructor */
 SklarCopula::SklarCopula()
-  : CopulaImplementation("SklarCopula"),
-    distribution_(),
-    marginalCollection_()
+  : CopulaImplementation("SklarCopula")
+  , distribution_()
+  , marginalCollection_()
 {
-  setDimension( 0 );
+  setDimension( 1 );
+  computeRange();
 }
 
 /* Parameters constructor */
 SklarCopula::SklarCopula(const Distribution & distribution)
-  : CopulaImplementation("SklarCopula"),
-    distribution_(distribution),
-    marginalCollection_(distribution.getDimension())
+  : CopulaImplementation("SklarCopula")
+  , distribution_(distribution)
+  , marginalCollection_(distribution.getDimension())
 {
   // We set the dimension of the SklarCopula distribution
   const UnsignedLong dimension(distribution.getDimension());
   setDimension( dimension );
   // Extract all the 1D marginal distributions
   for (UnsignedLong i = 0; i < dimension; ++i) marginalCollection_[i] = distribution.getMarginal(i);
+  computeRange();
 }
 
 /* Comparison operator */
@@ -162,7 +162,7 @@ NumericalScalar SklarCopula::computePDF(const NumericalPoint & point) const
     const NumericalPoint xi(marginalCollection_[i].computeQuantile(ui));
     x[i] = xi[0];
     factor *= marginalCollection_[i].computePDF(xi);
-    if (factor == 0.0) return 0.0;
+    if (fabs(factor) < pdfEpsilon_) return 0.0;
   }
   return distribution_.computePDF(x) / factor;
 }
@@ -245,7 +245,7 @@ NumericalPoint SklarCopula::computeQuantile(const NumericalScalar prob,
     const Bool tail) const
 {
   const UnsignedLong dimension(getDimension());
-  const NumericalScalar epsilon(ResourceMap::GetAsNumericalScalar("DistributionImplementation-DefaultQuantileEpsilon"));
+  const NumericalScalar epsilon(cdfEpsilon_);
   if (prob < -epsilon || prob > 1.0 + epsilon) throw InvalidArgumentException(HERE) << "Error: cannot compute a quantile for a probability level outside of [0, 1]";
   if (dimension == 1) return NumericalPoint(1, (tail ? 1.0 - prob : prob));
   NumericalPoint uq(distribution_.computeQuantile(prob));
@@ -393,6 +393,7 @@ void SklarCopula::load(Advocate & adv)
   CopulaImplementation::load(adv);
   adv.loadAttribute( "distribution_", distribution_ );
   adv.loadAttribute( "marginalCollection_", marginalCollection_ );
+  computeRange();
 }
 
 END_NAMESPACE_OPENTURNS
