@@ -3,7 +3,7 @@
  *  @file  UsualRandomVector.cxx
  *  @brief An implementation class for distribution-based random vectors
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,17 +26,15 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(UsualRandomVector);
 
 static Factory<UsualRandomVector> RegisteredFactory("UsualRandomVector");
 
 /* Default constructor */
-UsualRandomVector::UsualRandomVector(const Distribution & distribution, const String & name)
-  : RandomVectorImplementation(name),
-    distribution_(distribution)
+UsualRandomVector::UsualRandomVector(const Distribution & distribution,
+                                     const String & name)
+  : RandomVectorImplementation(name)
+  , distribution_(distribution)
 {
   // Get the description from the underlying distribution
   setDescription(distribution.getDescription());
@@ -57,8 +55,6 @@ String UsualRandomVector::__repr__() const
   return oss;
 }
 
-
-
 /* Here is the interface that all derived class must implement */
 
 
@@ -75,7 +71,7 @@ NumericalPoint UsualRandomVector::getRealization() const
 }
 
 /* Numerical sample accessor */
-NumericalSample UsualRandomVector::getSample(UnsignedLong size) const
+NumericalSample UsualRandomVector::getSample(const UnsignedLong size) const
 {
   return distribution_.getSample(size);
 }
