@@ -3,7 +3,7 @@
  *  @file  ARMA.cxx
  *  @brief A class which implements the ARMA process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,25 +32,22 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 typedef Collection< NumericalComplex >         NumericalComplexCollection;
 
-
 CLASSNAMEINIT(ARMA);
 
 static Factory<ARMA> RegisteredFactory("ARMA");
 
 ARMA::ARMA(const String & name)
-  : ProcessImplementation(name),
-    ARCoefficients_(0, 1),
-    MACoefficients_(0, 1),
-    noiseDistribution_(Normal()),
-    p_(0),
-    q_(0),
-    state_(NumericalSample(0, 1), NumericalSample(0, 1)),
-    hasComputedNThermalization_(true),
-    nThermalization_(2)
+  : ProcessImplementation(name)
+  , ARCoefficients_(0, 1)
+  , MACoefficients_(0, 1)
+  , noiseDistribution_(Normal())
+  , p_(0)
+  , q_(0)
+  , state_(NumericalSample(0, 1), NumericalSample(0, 1))
+  , hasComputedNThermalization_(true)
+  , nThermalization_(2)
 {
   setDimension(1);
   thermalize();
@@ -61,25 +58,25 @@ ARMA::ARMA(const ARMACoefficients & ARCoefficients,
            const ARMACoefficients & MACoefficients,
            const WhiteNoise & whiteNoise,
            const String & name)
-  : ProcessImplementation(name),
-    // Don't initialize these attributes before to check if they are valid
-    // as they can be huge
-    ARCoefficients_(),
-    MACoefficients_(),
-    noiseDistribution_(whiteNoise.getDistribution()),
-    p_(ARCoefficients.getSize()),
-    q_(MACoefficients.getSize()),
-    state_(),
-    hasComputedNThermalization_(false),
-    nThermalization_(0)
+  : ProcessImplementation(name)
+  // Don't initialize these attributes before to check if they are valid
+  // as they can be huge
+  , ARCoefficients_()
+  , MACoefficients_()
+  , noiseDistribution_(whiteNoise.getDistribution())
+  , p_(ARCoefficients.getSize())
+  , q_(MACoefficients.getSize())
+  , state_()
+  , hasComputedNThermalization_(false)
+  , nThermalization_(0)
 {
-
   if (ARCoefficients_.getDimension() != MACoefficients_.getDimension())
     throw InvalidArgumentException(HERE) << "Error:  Incompatible dimensions for coefficients of AR part and MA part";
   ARCoefficients_ = ARCoefficients;
   MACoefficients_ = MACoefficients;
 
   setDimension(ARCoefficients_.getDimension());
+  // This call checks that the given WhiteNoise is based on a RegularGrid
   setTimeGrid(whiteNoise.getTimeGrid());
   // The default state is with null values and noises
   state_ = ARMAState(NumericalSample(p_, dimension_), NumericalSample(q_, dimension_));
@@ -93,17 +90,17 @@ ARMA::ARMA(const ARMACoefficients & ARCoefficients,
            const WhiteNoise & whiteNoise,
            const ARMAState & state,
            const String & name)
-  : ProcessImplementation(name),
-    // Don't initialize these attributes before to check if they are valid
-    // as they can be huge
-    ARCoefficients_(),
-    MACoefficients_(),
-    noiseDistribution_(whiteNoise.getDistribution()),
-    p_(ARCoefficients.getSize()),
-    q_(MACoefficients.getSize()),
-    state_(),
-    hasComputedNThermalization_(false),
-    nThermalization_(0)
+  : ProcessImplementation(name)
+  // Don't initialize these attributes before to check if they are valid
+  // as they can be huge
+  , ARCoefficients_()
+  , MACoefficients_()
+  , noiseDistribution_(whiteNoise.getDistribution())
+  , p_(ARCoefficients.getSize())
+  , q_(MACoefficients.getSize())
+  , state_()
+  , hasComputedNThermalization_(false)
+  , nThermalization_(0)
 {
   if (ARCoefficients_.getDimension() != MACoefficients_.getDimension())
     throw InvalidArgumentException(HERE) << "Error:  Incompatible dimensions for coefficients of AR part and MA part";
@@ -111,6 +108,7 @@ ARMA::ARMA(const ARMACoefficients & ARCoefficients,
   MACoefficients_ = MACoefficients;
 
   setDimension(ARCoefficients_.getDimension());
+  // This call checks that the given WhiteNoise is based on a RegularGrid
   setTimeGrid(whiteNoise.getTimeGrid());
   setState(state);
 }
@@ -126,7 +124,7 @@ String ARMA::__repr__() const
 {
   OSS oss;
   oss << "class= " << ARMA::GetClassName()
-      << " timeGrid=" << timeGrid_
+      << " timeGrid=" << RegularGrid(mesh_)
       << " coefficients AR=" << ARCoefficients_
       << " coefficients MA=" << MACoefficients_
       << " noiseDistribution= " << noiseDistribution_
@@ -281,13 +279,13 @@ void ARMA::thermalize() const
 }
 
 /* Realization accessor */
-TimeSeries ARMA::getRealization() const
+Field ARMA::getRealization() const
 {
   // thermalize to "forget" the initial state --> change state
   thermalize();
 
   // Get the size of the realization
-  const UnsignedLong size(timeGrid_.getN());
+  const UnsignedLong size(RegularGrid(mesh_).getN());
 
   // Go size steps further: newState contains (size + p_) X values and (q_ + size) epsilon values
   const ARMAState newState(computeReccurence(size));
@@ -296,18 +294,18 @@ TimeSeries ARMA::getRealization() const
   setState(newState);
 
   // Use the X part of the newState to build the realization
-  return TimeSeries(timeGrid_, newState.getX().split(p_));
+  return Field(mesh_, newState.getX().split(p_));
 }
 
 // Prediction of the futur of an ARMA process
 // possible futur changes
 TimeSeries ARMA::getFuture(const UnsignedLong stepNumber) const
 {
-  if (stepNumber == 0) return TimeSeries(0, dimension_);
+  if (stepNumber == 0) throw InvalidArgumentException(HERE) << "Error: the number of future steps must be positive.";
   /* TimeGrid associated with the possible future */
-  const NumericalScalar timeStep(timeGrid_.getStep());
+  const NumericalScalar timeStep(RegularGrid(mesh_).getStep());
   // The EndTime is not considered to be included in the TimeGrid
-  const RegularGrid futurTimeGrid(timeGrid_.getEnd(), timeStep, stepNumber);
+  const RegularGrid futurTimeGrid(RegularGrid(mesh_).getEnd(), timeStep, stepNumber);
 
   // Run the computation
   const ARMAState newState(computeReccurence(stepNumber));
@@ -346,7 +344,7 @@ void ARMA::setState(const ARMAState & state) const
 /* WhiteNoise accessor of the ARMA process */
 WhiteNoise ARMA::getWhiteNoise() const
 {
-  return WhiteNoise(noiseDistribution_, timeGrid_);
+  return WhiteNoise(noiseDistribution_, mesh_);
 }
 
 void ARMA::setWhiteNoise(const WhiteNoise & whiteNoise)
