@@ -3,7 +3,7 @@
  *  @file  ARMACoefficients.cxx
  *  @brief ARMACoefficients class enables to stock coefficients of an ARMA process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,17 +31,14 @@ TEMPLATE_CLASSNAMEINIT(PersistentCollection< ARMACoefficients >);
 TEMPLATE_CLASSNAMEINIT(PersistentCollection< SquareMatrix >);
 static Factory< PersistentCollection< SquareMatrix > > RegisteredFactory1("PersistentCollection<SquareMatrix>");
 
-
-
-
 CLASSNAMEINIT(ARMACoefficients);
 static Factory<ARMACoefficients> RegisteredFactory("ARMACoefficients");
 
 /* Default constructor */
 ARMACoefficients::ARMACoefficients(const UnsignedLong & size,
                                    const UnsignedLong & dimension)
-  : PersistentCollection<SquareMatrix>(size, SquareMatrix(dimension) ),
-    dimension_(dimension)
+  : PersistentCollection<SquareMatrix>(size, SquareMatrix(dimension) )
+  , dimension_(dimension)
 {
   if (dimension == 0) throw InvalidArgumentException(HERE) << "Error: dimension should be at least 1";
 }
@@ -87,7 +84,7 @@ ARMACoefficients * ARMACoefficients::clone() const
 /* String converter */
 String ARMACoefficients::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << ARMACoefficients::GetClassName();
   for (UnsignedLong i = 0; i < getSize(); ++i) oss << ", shift=" << i << ", value=" << (*this)[i];
   return oss;
@@ -95,7 +92,7 @@ String ARMACoefficients::__repr__() const
 
 String ARMACoefficients::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   for (UnsignedLong i = 0; i < getSize(); ++i) oss << offset << "shift = " << i << "\n" << offset << (*this)[i].__str__(offset) << "\n";
   return oss;
 }
