@@ -3,7 +3,7 @@
  *  @file  ARMAFactory.cxx
  *  @brief The class that implements all random vectors
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,8 +28,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(ARMAFactory);
 
 /* Default constructor */
@@ -72,7 +70,7 @@ ARMAFactory * ARMAFactory::clone() const
 /* String converter */
 String ARMAFactory::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << GetClassName()
       << " implementation=" << getImplementation()->__repr__();
   return oss;
@@ -87,15 +85,13 @@ String ARMAFactory::__str__(const String & offset) const
 /* Build method */
 ARMA ARMAFactory::build(const TimeSeries & timeSeries) const
 {
-  return *(getImplementation()->build(timeSeries));
+  return getImplementation()->build(timeSeries);
 }
 
 /* Build method */
 ARMA ARMAFactory::build(const ProcessSample & sample) const
 {
-  return *(getImplementation()->build(sample));
+  return getImplementation()->build(sample);
 }
 
-
-
 END_NAMESPACE_OPENTURNS
