@@ -3,7 +3,7 @@
  *  @file  ARMAFactoryImplementation.cxx
  *  @brief An interface for all implementation class of process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,8 +27,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(ARMAFactoryImplementation);
 
 static Factory<ARMAFactoryImplementation> RegisteredFactory("ARMAFactoryImplementation");
@@ -36,12 +34,12 @@ static Factory<ARMAFactoryImplementation> RegisteredFactory("ARMAFactoryImplemen
 
 /* Default constructor */
 ARMAFactoryImplementation::ARMAFactoryImplementation(const String & name)
-  : PersistentObject(name),
-    p_(0),
-    currentP_(0),
-    q_(0),
-    currentQ_(0),
-    invertible_(true)
+  : PersistentObject(name)
+  , p_(0)
+  , currentP_(0)
+  , q_(0)
+  , currentQ_(0)
+  , invertible_(true)
 {
   // Nothing to do
 }
@@ -51,12 +49,12 @@ ARMAFactoryImplementation::ARMAFactoryImplementation(const UnsignedLong p,
     const UnsignedLong q,
     const Bool invertible,
     const String & name)
-  : PersistentObject(name),
-    p_(1, p),
-    currentP_(p),
-    q_(1, q),
-    currentQ_(q),
-    invertible_(invertible)
+  : PersistentObject(name)
+  , p_(1, p)
+  , currentP_(p)
+  , q_(1, q)
+  , currentQ_(q)
+  , invertible_(invertible)
 {
   // Nothing to do
 }
@@ -66,12 +64,12 @@ ARMAFactoryImplementation::ARMAFactoryImplementation(const Indices & p,
     const Indices & q,
     const Bool invertible,
     const String & name)
-  : PersistentObject(name),
-    p_(p),
-    currentP_(0),
-    q_(q),
-    currentQ_(0),
-    invertible_(invertible)
+  : PersistentObject(name)
+  , p_(p)
+  , currentP_(0)
+  , q_(q)
+  , currentQ_(0)
+  , invertible_(invertible)
 {
   // Nothing to do
 }
@@ -157,25 +155,25 @@ String ARMAFactoryImplementation::__str__(const String & offset) const
 }
 
 /* Build method */
-ARMA * ARMAFactoryImplementation::build(const TimeSeries & timeSeries) const
+ARMA ARMAFactoryImplementation::build(const TimeSeries & timeSeries) const
 {
   throw NotYetImplementedException(HERE);
 }
 
-ARMA * ARMAFactoryImplementation::build(const TimeSeries & timeSeries,
-                                        NumericalPoint & informationCriteria) const
+ARMA ARMAFactoryImplementation::build(const TimeSeries & timeSeries,
+                                      NumericalPoint & informationCriteria) const
 {
   throw NotYetImplementedException(HERE);
 }
 
 /* Build method */
-ARMA * ARMAFactoryImplementation::build(const ProcessSample & sample) const
+ARMA ARMAFactoryImplementation::build(const ProcessSample & sample) const
 {
   throw NotYetImplementedException(HERE);
 }
 
-ARMA * ARMAFactoryImplementation::build(const ProcessSample & sample,
-                                        NumericalPoint & informationCriteria) const
+ARMA ARMAFactoryImplementation::build(const ProcessSample & sample,
+                                      NumericalPoint & informationCriteria) const
 {
   throw NotYetImplementedException(HERE);
 }
