@@ -5,7 +5,7 @@
  *  using a maximization of the likelihood function. We use here some articles of J.A.Mauricio (http://www.ucm.es/info/ecocuan/jam/)
  *  to use an efficient method
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,8 +39,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
 CLASSNAMEINIT(ARMALikelihoodFactory);
 
 static Factory<ARMALikelihoodFactory> RegisteredFactory("ARMALikelihoodFactory");
@@ -50,19 +48,19 @@ static int modifiedCholeskyDecomposition(SquareMatrix &matrix,
 
 /* Default constructor */
 ARMALikelihoodFactory::ARMALikelihoodFactory(const String & name)
-  : ARMAFactoryImplementation(name),
-    currentG_(),
-    w_(),
-    dimension_(1),
-    covarianceMatrix_(),
-    autoCovariance_(),
-    crossCovariance_(),
-    blockPhiTThetaTMatrix_(),
-    sigma2_(1.0),
-    hasInitializedARCoefficients_(false),
-    hasInitializedMACoefficients_(false),
-    hasInitializedCovarianceMatrix_(false),
-    verbose_(false)
+  : ARMAFactoryImplementation(name)
+  , currentG_()
+  , w_()
+  , dimension_(1)
+  , covarianceMatrix_()
+  , autoCovariance_()
+  , crossCovariance_()
+  , blockPhiTThetaTMatrix_()
+  , sigma2_(1.0)
+  , hasInitializedARCoefficients_(false)
+  , hasInitializedMACoefficients_(false)
+  , hasInitializedCovarianceMatrix_(false)
+  , verbose_(false)
 {
   // Nothing to do
 }
@@ -73,19 +71,19 @@ ARMALikelihoodFactory::ARMALikelihoodFactory(const UnsignedLong p,
     const UnsignedLong dimension,
     const Bool invertible,
     const String & name)
-  : ARMAFactoryImplementation(p, q, invertible, name),
-    currentG_(),
-    w_(),
-    dimension_(),
-    covarianceMatrix_(),
-    autoCovariance_(),
-    crossCovariance_(),
-    blockPhiTThetaTMatrix_(),
-    sigma2_(1.0),
-    hasInitializedARCoefficients_(false),
-    hasInitializedMACoefficients_(false),
-    hasInitializedCovarianceMatrix_(false),
-    verbose_(false)
+  : ARMAFactoryImplementation(p, q, invertible, name)
+  , currentG_()
+  , w_()
+  , dimension_()
+  , covarianceMatrix_()
+  , autoCovariance_()
+  , crossCovariance_()
+  , blockPhiTThetaTMatrix_()
+  , sigma2_(1.0)
+  , hasInitializedARCoefficients_(false)
+  , hasInitializedMACoefficients_(false)
+  , hasInitializedCovarianceMatrix_(false)
+  , verbose_(false)
 {
   if (dimension == 0)
     throw InvalidArgumentException(HERE) << "Error : dimension could not be zero" ;
@@ -109,19 +107,19 @@ ARMALikelihoodFactory::ARMALikelihoodFactory(const Indices & p,
     const UnsignedLong dimension,
     const Bool invertible,
     const String & name)
-  : ARMAFactoryImplementation(p, q, invertible, name),
-    currentG_(),
-    w_(),
-    dimension_(),
-    covarianceMatrix_(),
-    autoCovariance_(),
-    crossCovariance_(),
-    blockPhiTThetaTMatrix_(),
-    sigma2_(1.0),
-    hasInitializedARCoefficients_(false),
-    hasInitializedMACoefficients_(false),
-    hasInitializedCovarianceMatrix_(false),
-    verbose_(false)
+  : ARMAFactoryImplementation(p, q, invertible, name)
+  , currentG_()
+  , w_()
+  , dimension_()
+  , covarianceMatrix_()
+  , autoCovariance_()
+  , crossCovariance_()
+  , blockPhiTThetaTMatrix_()
+  , sigma2_(1.0)
+  , hasInitializedARCoefficients_(false)
+  , hasInitializedMACoefficients_(false)
+  , hasInitializedCovarianceMatrix_(false)
+  , verbose_(false)
 {
   if (dimension == 0)
     throw InvalidArgumentException(HERE) << "Error : dimension could not be zero" ;
@@ -274,9 +272,9 @@ NumericalScalar ARMALikelihoodFactory::computeLogLikelihood(const NumericalPoint
       norm1 += eta(i, j) * eta(i, j);
     }
   }
-  NumericalScalar norm2(vector_h.norm2());
+  NumericalScalar normSquare(vector_h.normSquare());
 
-  NumericalScalar f1(norm1 - norm2);
+  NumericalScalar f1(norm1 - normSquare);
 
   // Step (k): compute the exact log-likelihood
   NumericalScalar determinantL(1.0);
@@ -327,7 +325,7 @@ int ARMALikelihoodFactory::ComputeObjectiveAndConstraint(int n,
         for (UnsignedLong columnIndex = 0; columnIndex < dimension; ++ columnIndex)
         {
           matrix( dimension * (p - 1) +  rowIndex, coefficientIndex * dimension + columnIndex ) = x[currentIndex] ;
-          currentIndex++;
+          ++currentIndex;
         }
       }
     }
@@ -361,7 +359,7 @@ int ARMALikelihoodFactory::ComputeObjectiveAndConstraint(int n,
         for (UnsignedLong columnIndex = 0; columnIndex < dimension; ++ columnIndex)
         {
           matrix( dimension * (q - 1) +  rowIndex, coefficientIndex * dimension + columnIndex ) = x[currentIndex];
-          currentIndex++;
+          ++currentIndex;
         }
       }
     }
@@ -481,10 +479,10 @@ int modifiedCholeskyDecomposition(SquareMatrix &matrix,
 /* String converter */
 String ARMALikelihoodFactory::__repr__() const
 {
-  OSS oss;
-  oss << "class= " << ARMALikelihoodFactory::GetClassName()
-      << "\nimplementation = " << ARMAFactoryImplementation::__repr__()
-      << "\ndimension = " << dimension_ ;
+  OSS oss(true);
+  oss << "class=" << ARMALikelihoodFactory::GetClassName()
+      << " implementation=" << ARMAFactoryImplementation::__repr__()
+      << " dimension=" << dimension_ ;
   return oss;
 }
 
@@ -506,7 +504,7 @@ void ARMALikelihoodFactory::setVerbose(const Bool verbose)
 }
 
 /* Build method */
-ARMA * ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
+ARMA ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
 {
   // Currently the implementation of the factory bases on m estimations of univariate models, m is the dimension of the
   // above time series
@@ -606,7 +604,7 @@ ARMA * ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
       for (UnsignedLong i = 0; i < dimension_; ++i)
       {
         phi_k(i, j) =  - beta[currentIndex];
-        currentIndex++;
+        ++currentIndex;
       }
     }
     phi[k] = phi_k;
@@ -621,7 +619,7 @@ ARMA * ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
       for (UnsignedLong i = 0; i < dimension_; ++i)
       {
         theta_k(i, j) =  - beta[currentIndex];
-        currentIndex++;
+        ++currentIndex;
       }
     }
     theta[k] = theta_k;
@@ -633,7 +631,7 @@ ARMA * ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
     for (UnsignedLong i = j; i < dimension_; ++i)
     {
       cov(i, j) = beta[currentIndex];
-      currentIndex += 1;
+      ++currentIndex;
     }
   }
 
@@ -643,20 +641,20 @@ ARMA * ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
     for (UnsignedLong i = j; i < dimension_; ++i)
     {
       cov(i, j) *= sigma2_;
-      currentIndex += 1;
+      ++currentIndex;
     }
   }
 
   const Normal distribution(NumericalPoint(dimension_), cov);
   const RegularGrid timeGrid(timeSeries.getTimeGrid());
   const WhiteNoise whiteNoise(distribution, timeGrid);
-  return ARMA(phi, theta, whiteNoise).clone();
+  return ARMA(phi, theta, whiteNoise);
 }
 
 /* Build method */
-ARMA * ARMALikelihoodFactory::build(const ProcessSample & sample) const
+ARMA ARMALikelihoodFactory::build(const ProcessSample & sample) const
 {
-  return ARMA().clone();
+  throw NotYetImplementedException(HERE);
 }
 
 // Set accessor for starting point of the optimization
@@ -694,7 +692,7 @@ void ARMALikelihoodFactory::defaultInitialize() const
   {
     // Univariate estimate
     const TimeSeries marginal_d(timeGrid, values.getMarginal(d));
-    ARMA marginalARMAModel(*(factory.build(marginal_d)));
+    ARMA marginalARMAModel(factory.build(marginal_d));
     const WhiteNoise whiteNoise(marginalARMAModel.getWhiteNoise());
     const NumericalScalar sigma(whiteNoise.getDistribution().getStandardDeviation()[0]);
     covarianceMatrix_(d, d) = sigma * sigma;
