@@ -3,7 +3,7 @@
  *  @file  ARMAState.cxx
  *  @brief ARMAState class enables to set a State before a simulation
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,17 +27,14 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(ARMAState);
 static Factory<ARMAState> RegisteredFactory("ARMAState");
 
 /* Default constructor */
 ARMAState::ARMAState()
-  : PersistentObject(),
-    x_(),
-    epsilon_()
+  : PersistentObject()
+  , x_()
+  , epsilon_()
 {
   // Nothing to do
 }
@@ -45,9 +42,9 @@ ARMAState::ARMAState()
 /* Standard constructor */
 ARMAState::ARMAState(const NumericalSample & x,
                      const NumericalSample & epsilon)
-  : PersistentObject(),
-    x_(x),
-    epsilon_(epsilon)
+  : PersistentObject()
+  , x_(x)
+  , epsilon_(epsilon)
 {
   // Nothing to do
 }
