@@ -3,7 +3,7 @@
  *  @file  CompositeProcess.cxx
  *  @brief A class which implements the CompositeProcess process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,9 +42,9 @@ CompositeProcess::CompositeProcess(const String & name)
 CompositeProcess::CompositeProcess(const DynamicalFunction & function,
                                    const Antecedent & p_antecedent,
                                    const String & name)
-  : ProcessImplementation(name),
-    function_(function),
-    p_antecedent_(p_antecedent)
+  : ProcessImplementation(name)
+  , function_(function)
+  , p_antecedent_(p_antecedent)
 {
   if (function.getInputDimension() != p_antecedent->getDimension())
     throw InvalidArgumentException(HERE) << "Error: trying to build a CompositeProcess from a Process and a DynamicalFunction with incompatible dimensions "
@@ -57,9 +57,9 @@ CompositeProcess::CompositeProcess(const DynamicalFunction & function,
 CompositeProcess::CompositeProcess(const DynamicalFunction & function,
                                    const Process & antecedent,
                                    const String & name)
-  : ProcessImplementation(name),
-    function_(function),
-    p_antecedent_(antecedent.getImplementation())
+  : ProcessImplementation(name)
+  , function_(function)
+  , p_antecedent_(antecedent.getImplementation())
 {
   if (function.getInputDimension() != p_antecedent_->getDimension())
     throw InvalidArgumentException(HERE) << "Error: trying to build a CompositeProcess from a Process and a DynamicalFunction with incompatible dimensions "
@@ -77,16 +77,16 @@ CompositeProcess * CompositeProcess::clone() const
 /* String converter */
 String CompositeProcess::__repr__() const
 {
-  OSS oss;
-  oss << "class = " << CompositeProcess::GetClassName()
-      << " function = " << function_.__repr__()
-      << " antecedent = " << p_antecedent_->__repr__();
+  OSS oss(true);
+  oss << "class=" << CompositeProcess::GetClassName()
+      << " function=" << function_.__repr__()
+      << " antecedent=" << p_antecedent_->__repr__();
   return oss;
 }
 
 String CompositeProcess::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << " CompositeProcess process dimension = " << dimension_ << "\n"
       << " Process = " << function_.__str__(offset + "  ")
       << "( " << p_antecedent_->__str__(offset + "  ")
@@ -113,11 +113,31 @@ DynamicalFunction CompositeProcess::getFunction() const
 }
 
 /* Realization accessor */
-TimeSeries CompositeProcess::getRealization() const
+Field CompositeProcess::getRealization() const
 {
   return function_(p_antecedent_->getRealization());
 }
 
+/* Compute the next steps of a random walk */
+TimeSeries CompositeProcess::getFuture(const UnsignedLong stepNumber) const
+{
+  /* TimeGrid of the process */
+  RegularGrid timeGrid;
+  try
+  {
+    timeGrid = getTimeGrid();
+  }
+  catch (...)
+  {
+    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular gris.";
+  }
+  if (stepNumber == 0) throw InvalidArgumentException(HERE) << "Error: the number of future steps must be positive.";
+  /* TimeGrid associated with the possible future */
+  const NumericalScalar timeStep(timeGrid.getStep());
+  const RegularGrid futurTimeGrid(timeGrid.getEnd(), timeStep, stepNumber);
+  return TimeSeries(futurTimeGrid, function_(p_antecedent_->getFuture(stepNumber)).getValues());
+}
+
 /* Get the random vector corresponding to the i-th marginal component */
 CompositeProcess::Implementation CompositeProcess::getMarginalProcess(const UnsignedLong i) const
 {
