@@ -3,7 +3,7 @@
  *  @file  RandomWalk.cxx
  *  @brief A class which implements the RandomWalk process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -103,22 +103,32 @@ Bool RandomWalk::isNormal() const
 }
 
 /* Realization accessor */
-TimeSeries RandomWalk::getRealization() const
+Field RandomWalk::getRealization() const
 {
-  const UnsignedLong size(timeGrid_.getN());
+  const UnsignedLong size(mesh_.getVerticesNumber());
   NumericalSample data(size, origin_);
   for (UnsignedLong i = 1; i < size; ++i) data[i] = data[i - 1] + distribution_.getRealization();
   currentPosition_ = data[data.getSize() - 1];
-  return TimeSeries(timeGrid_, data);
+  return Field(mesh_, data);
 }
 
 /* Compute the next steps of a random walk */
 TimeSeries RandomWalk::getFuture(const UnsignedLong stepNumber) const
 {
-  if (stepNumber == 0) return TimeSeries(0, dimension_);
+  /* TimeGrid of the process */
+  RegularGrid timeGrid;
+  try
+  {
+    timeGrid = getTimeGrid();
+  }
+  catch (...)
+  {
+    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular gris.";
+  }
+  if (stepNumber == 0) throw InvalidArgumentException(HERE) << "Error: the number of future steps must be positive.";
   /* TimeGrid associated with the possible future */
-  const NumericalScalar timeStep(timeGrid_.getStep());
-  const RegularGrid futurTimeGrid(timeGrid_.getEnd(), timeStep, stepNumber);
+  const NumericalScalar timeStep(RegularGrid(mesh_).getStep());
+  const RegularGrid futurTimeGrid(RegularGrid(mesh_).getEnd(), timeStep, stepNumber);
   NumericalSample data(stepNumber, dimension_);
   NumericalPoint previous(currentPosition_);
   for (UnsignedLong i = 0; i < stepNumber; ++i)
@@ -133,7 +143,7 @@ TimeSeries RandomWalk::getFuture(const UnsignedLong stepNumber) const
 RandomWalk::Implementation RandomWalk::getMarginalProcess(const UnsignedLong i) const
 {
   if (i >= dimension_) throw InvalidArgumentException(HERE) << "The index of a marginal process must be in the range [0, dim-1]";
-  return new RandomWalk(NumericalPoint(1, origin_[i]), distribution_.getMarginal(i), timeGrid_);
+  return new RandomWalk(NumericalPoint(1, origin_[i]), distribution_.getMarginal(i), mesh_);
 }
 
 /* Get the marginal process corresponding to indices components */
@@ -143,7 +153,7 @@ RandomWalk::Implementation RandomWalk::getMarginalProcess(const Indices & indice
   const UnsignedLong size(indices.getSize());
   NumericalPoint marginalOrigin(size);
   for (UnsignedLong i = 0; i < size; ++i) marginalOrigin[i] = origin_[indices[i]];
-  return new RandomWalk(marginalOrigin, distribution_.getMarginal(indices), timeGrid_);
+  return new RandomWalk(marginalOrigin, distribution_.getMarginal(indices), mesh_);
 }
 
 /* Distribution accessor */
