@@ -3,7 +3,7 @@
  *  @file  SpectralNormalProcess.cxx
  *  @brief A class which implements the SpectralNormalProcess process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,14 +39,14 @@ CLASSNAMEINIT(SpectralNormalProcess);
 static Factory<SpectralNormalProcess> RegisteredFactory("SpectralNormalProcess");
 
 SpectralNormalProcess::SpectralNormalProcess(const String & name)
-  : ProcessImplementation(name),
-    spectralModel_(),
-    maximalFrequency_(0.0),
-    nFrequency_(0),
-    frequencyStep_(0.0),
-    choleskyFactorsCache_(0),
-    alpha_(0),
-    fftAlgorithm_()
+  : ProcessImplementation(name)
+  , spectralModel_()
+  , maximalFrequency_(0.0)
+  , nFrequency_(0)
+  , frequencyStep_(0.0)
+  , choleskyFactorsCache_(0)
+  , alpha_(0)
+  , fftAlgorithm_()
 {
   // Nothing to do
 }
@@ -55,14 +55,14 @@ SpectralNormalProcess::SpectralNormalProcess(const String & name)
 SpectralNormalProcess::SpectralNormalProcess(const SecondOrderModel & model,
     const RegularGrid & timeGrid,
     const String & name)
-  : ProcessImplementation(name),
-    spectralModel_(model.getSpectralModel()),
-    maximalFrequency_(0.0),
-    nFrequency_(0),
-    frequencyStep_(0.0),
-    choleskyFactorsCache_(0),
-    alpha_(0),
-    fftAlgorithm_()
+  : ProcessImplementation(name)
+  , spectralModel_(model.getSpectralModel())
+  , maximalFrequency_(0.0)
+  , nFrequency_(0)
+  , frequencyStep_(0.0)
+  , choleskyFactorsCache_(0)
+  , alpha_(0)
+  , fftAlgorithm_()
 {
   setTimeGrid(timeGrid);
   setDimension(model.getDimension());
@@ -91,14 +91,14 @@ SpectralNormalProcess::SpectralNormalProcess(const SecondOrderModel & model,
     const NumericalScalar maximalFrequency,
     const UnsignedLong nFrequency,
     const String & name)
-  : ProcessImplementation(name),
-    spectralModel_(model.getSpectralModel()),
-    maximalFrequency_(maximalFrequency),
-    nFrequency_(nFrequency),
-    frequencyStep_(0.0),
-    choleskyFactorsCache_(0),
-    alpha_(0),
-    fftAlgorithm_()
+  : ProcessImplementation(name)
+  , spectralModel_(model.getSpectralModel())
+  , maximalFrequency_(maximalFrequency)
+  , nFrequency_(nFrequency)
+  , frequencyStep_(0.0)
+  , choleskyFactorsCache_(0)
+  , alpha_(0)
+  , fftAlgorithm_()
 {
   if (maximalFrequency <= 0.0) throw InvalidArgumentException(HERE) << "Error: the maximal frequency must be positive, here maximalFrequency=" << maximalFrequency;
   if (nFrequency < 1) throw InvalidArgumentException(HERE) << "Error: the number of frequency points in the positive domain must be at least 1.";
@@ -115,14 +115,14 @@ SpectralNormalProcess::SpectralNormalProcess(const SpectralModel & spectralModel
     const UnsignedLong nFrequency,
     const String & name)
 
-  : ProcessImplementation(name),
-    spectralModel_(spectralModel),
-    maximalFrequency_(maximalFrequency),
-    nFrequency_(nFrequency),
-    frequencyStep_(0.0),
-    choleskyFactorsCache_(0),
-    alpha_(0),
-    fftAlgorithm_()
+  : ProcessImplementation(name)
+  , spectralModel_(spectralModel)
+  , maximalFrequency_(maximalFrequency)
+  , nFrequency_(nFrequency)
+  , frequencyStep_(0.0)
+  , choleskyFactorsCache_(0)
+  , alpha_(0)
+  , fftAlgorithm_()
 {
   if (maximalFrequency <= 0.0) throw InvalidArgumentException(HERE) << "Error: the maximal frequency must be positive, here maximalFrequency=" << maximalFrequency;
   if (nFrequency < 1) throw InvalidArgumentException(HERE) << "Error: the number of frequency points in the positive domain must be at least 1.";
@@ -159,7 +159,7 @@ TriangularComplexMatrix SpectralNormalProcess::computeCholeskyFactor(const Unsig
   // The index k corresponds to the kth positive discretization point in the frequency domain [-f_max, f_max] discretized using the center of the regular partition into 2N cells of the interval.
   const NumericalScalar frequency((k + 0.5) * frequencyStep_);
   // Compute the DSP matrix
-  HermitianMatrix spectralDensityMatrix(spectralModel_.computeSpectralDensity(frequency));
+  HermitianMatrix spectralDensityMatrix(spectralModel_(frequency));
   // Flag to tell if the regularization has to be increased
   Bool continuationCondition(true);
   // Scale control values
@@ -177,7 +177,7 @@ TriangularComplexMatrix SpectralNormalProcess::computeCholeskyFactor(const Unsig
       continuationCondition = false;
     }
     // If the factorization failed, increase the regularization
-    catch (InvalidArgumentException & ex)
+    catch (InternalException & ex)
     {
       cumulatedScaling += scaling;
       for (UnsignedLong  index = 0; index < dimension_; ++index) spectralDensityMatrix(index, index) += scaling;
@@ -194,7 +194,7 @@ TriangularComplexMatrix SpectralNormalProcess::computeCholeskyFactor(const Unsig
 /* String converter */
 String SpectralNormalProcess::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << SpectralNormalProcess::GetClassName();
   oss << " timeGrid=" << getTimeGrid()
       << " spectralModel=" << spectralModel_
@@ -206,7 +206,7 @@ String SpectralNormalProcess::__repr__() const
 
 String SpectralNormalProcess::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << " SpectralNormalProcess=" << SpectralNormalProcess::GetClassName()
       << " dimension=" << dimension_
       << " spectralModel=" << spectralModel_
@@ -259,13 +259,13 @@ SpectralModel SpectralNormalProcess::getSpectralModel() const
 /* Set TimeGrid */
 void SpectralNormalProcess::setTimeGrid(const RegularGrid & tg)
 {
-  if (tg != timeGrid_)
+  if (tg != RegularGrid(mesh_))
   {
     // The time grid must contains an even number of points
     const UnsignedLong nT(tg.getN());
     if (nT % 2 != 0) throw InvalidArgumentException(HERE) << "Error: only time grids with an even (or better a power of two) number of points are allowed. You may use the AdaptGrid method.";
     // Fix the new timeGrid
-    timeGrid_ = tg;
+    mesh_ = tg;
     // Compute the frequency characteristics
     maximalFrequency_ = 0.5 / tg.getStep();
     nFrequency_ = nT / 2;
@@ -280,7 +280,7 @@ void SpectralNormalProcess::setTimeGrid(const RegularGrid & tg)
 /* Compute the time grid associated to the frequency grid */
 void SpectralNormalProcess::computeTimeGrid()
 {
-  timeGrid_ = RegularGrid(0.0, 1.0 / (2.0 * maximalFrequency_), 2 * nFrequency_);
+  mesh_ = RegularGrid(0.0, 1.0 / (2.0 * maximalFrequency_), 2 * nFrequency_);
 }
 
 /* Set the alpha vector */
@@ -299,7 +299,7 @@ void SpectralNormalProcess::computeAlpha()
 }
 
 /* Realization accessor */
-TimeSeries SpectralNormalProcess::getRealization() const
+Field SpectralNormalProcess::getRealization() const
 {
   // Build the big collection of size dimension * number of frequencies
   const UnsignedLong twoNF(2 * nFrequency_);
@@ -345,7 +345,7 @@ TimeSeries SpectralNormalProcess::getRealization() const
     const NumericalComplexCollection inverseFFTResult(fftAlgorithm_.inverseTransform(arrayCollection, i * twoNF, twoNF));
     for (UnsignedLong k = 0; k < twoNF; ++k) sampleValues[k][i] = std::real(inverseFFTResult[k] * alpha_[k]);
   }
-  return TimeSeries(timeGrid_, sampleValues);
+  return Field(mesh_, sampleValues);
 }
 
 /* Check if the process is stationary */
