@@ -3,7 +3,7 @@
  *  @file  TemporalNormalProcess.cxx
  *  @brief A class which implements the TemporalNormalProcess process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,8 +27,8 @@
 #include "Exception.hxx"
 #include "Log.hxx"
 #include "CovarianceMatrix.hxx"
-#include "Lapack.hxx"
 #include "DistFunc.hxx"
+#include "TriangularMatrix.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -44,7 +44,7 @@ TemporalNormalProcess::TemporalNormalProcess(const String & name)
   , hasStationaryTrend_(true)
   , checkedStationaryTrend_(true)
   , trend_()
-  , stationaryTrendValue_()
+  , stationaryTrendValue_(0)
 {
   // Nothing to do
 }
@@ -52,7 +52,7 @@ TemporalNormalProcess::TemporalNormalProcess(const String & name)
 /* Standard constructor  */
 TemporalNormalProcess::TemporalNormalProcess(const TrendTransform & trend,
     const SecondOrderModel & model,
-    const RegularGrid & timeGrid,
+    const Mesh & mesh,
     const String & name)
   : ProcessImplementation(name)
   , covarianceModel_(model.getCovarianceModel())
@@ -61,17 +61,17 @@ TemporalNormalProcess::TemporalNormalProcess(const TrendTransform & trend,
   , hasStationaryTrend_(false)
   , checkedStationaryTrend_(false)
   , trend_(trend)
-  , stationaryTrendValue_()
+  , stationaryTrendValue_(trend.getOutputDimension())
 {
   if (trend.getOutputDimension() != model.getDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an output dimension=" << trend.getOutputDimension() << " different from the second order model dimension=" << model.getDimension();
-  setTimeGrid(timeGrid);
+  setMesh(mesh);
   setDimension(model.getDimension());
 }
 
 /* Standard constructor  */
 TemporalNormalProcess::TemporalNormalProcess(const TrendTransform & trend,
     const CovarianceModel & covarianceModel,
-    const RegularGrid & timeGrid,
+    const Mesh & mesh,
     const String & name)
   : ProcessImplementation(name)
   , covarianceModel_(covarianceModel)
@@ -80,16 +80,16 @@ TemporalNormalProcess::TemporalNormalProcess(const TrendTransform & trend,
   , hasStationaryTrend_(false)
   , checkedStationaryTrend_(false)
   , trend_(trend)
-  , stationaryTrendValue_()
+  , stationaryTrendValue_(trend.getOutputDimension())
 {
   if (trend.getOutputDimension() != covarianceModel.getDimension()) throw InvalidArgumentException(HERE) << "Error: the given trend has an output dimension=" << trend.getOutputDimension() << " different from the covariance model dimension=" << covarianceModel.getDimension();
-  setTimeGrid(timeGrid);
+  setMesh(mesh);
   setDimension(covarianceModel.getDimension());
 }
 
 /* Standard constructor  */
 TemporalNormalProcess::TemporalNormalProcess(const SecondOrderModel & model,
-    const RegularGrid & timeGrid,
+    const Mesh & mesh,
     const String & name)
   : ProcessImplementation(name)
   , covarianceModel_(model.getCovarianceModel())
@@ -97,16 +97,19 @@ TemporalNormalProcess::TemporalNormalProcess(const SecondOrderModel & model,
   , isInitialized_(false)
   , hasStationaryTrend_(true)
   , checkedStationaryTrend_(true)
-  , trend_(NumericalMathFunction(Description(1, "t"), Description(model.getDimension(), "0.0")))
-  , stationaryTrendValue_()
+  , trend_()
+  , stationaryTrendValue_(model.getDimension())
 {
-  setTimeGrid(timeGrid);
+  setMesh(mesh);
   setDimension(model.getDimension());
+  Description inVars(mesh.getDimension());
+  for (UnsignedLong i = 0; i < mesh.getDimension(); ++i) inVars[i] = String(OSS() << "x" << i);
+  trend_ = TrendTransform(NumericalMathFunction(inVars, Description(getDimension(), "0")));
 }
 
 /* Standard constructor  */
 TemporalNormalProcess::TemporalNormalProcess(const CovarianceModel & covarianceModel,
-    const RegularGrid & timeGrid,
+    const Mesh & mesh,
     const String & name)
   : ProcessImplementation(name)
   , covarianceModel_(covarianceModel)
@@ -114,11 +117,14 @@ TemporalNormalProcess::TemporalNormalProcess(const CovarianceModel & covarianceM
   , isInitialized_(false)
   , hasStationaryTrend_(true)
   , checkedStationaryTrend_(true)
-  , trend_(NumericalMathFunction(Description(1, "t"), Description(covarianceModel.getDimension(), "0.0")))
-  , stationaryTrendValue_()
+  , trend_()
+  , stationaryTrendValue_(covarianceModel.getDimension())
 {
-  setTimeGrid(timeGrid);
+  setMesh(mesh);
   setDimension(covarianceModel.getDimension());
+  Description inVars(mesh.getDimension());
+  for (UnsignedLong i = 0; i < mesh.getDimension(); ++i) inVars[i] = String(OSS() << "x" << i);
+  trend_ = TrendTransform(NumericalMathFunction(inVars, Description(getDimension(), "0")));
 }
 
 /* Virtual constructor */
@@ -131,8 +137,8 @@ void TemporalNormalProcess::initialize() const
 {
   // Initialization of the process
   // Get the covariance matrix (its Cholesky factor)
-
-  CovarianceMatrix covarianceMatrix(covarianceModel_.discretizeCovariance(timeGrid_));
+  LOGINFO(OSS() << "Discretize the covariance model");
+  CovarianceMatrix covarianceMatrix(covarianceModel_.discretize(mesh_));
   const UnsignedLong fullSize(covarianceMatrix.getDimension());
   // Boolean flag to tell if the regularization is enough
   Bool continuationCondition(true);
@@ -147,15 +153,17 @@ void TemporalNormalProcess::initialize() const
   {
     try
     {
+      LOGINFO(OSS() << "Factor the covariance matrix");
       choleskyFactorCovarianceMatrix_ = covarianceMatrix.computeCholesky();
       continuationCondition = false;
     }
     // If it has not yet been computed, compute it and store it
-    catch (InvalidArgumentException & ex)
+    catch (InternalException & ex)
     {
       cumulatedScaling += scaling ;
       // Unroll the regularization to optimize the computation
       for (UnsignedLong i = 0; i < fullSize; ++i) covarianceMatrix(i, i) += scaling;
+      LOGWARN(OSS() << "Must regularize the covariance matrix, factor=" << cumulatedScaling);
       scaling *= 2.0;
     }
   }
@@ -174,9 +182,9 @@ void TemporalNormalProcess::initialize() const
 /* String converter */
 String TemporalNormalProcess::__repr__() const
 {
-  OSS oss;
+  OSS oss(true);
   oss << "class=" << TemporalNormalProcess::GetClassName();
-  oss << " timeGrid=" << getTimeGrid()
+  oss << " mesh=" << mesh_
       << " trend=" << trend_
       << " covarianceModel=" << covarianceModel_
       << " choleskyFactorCovarianceMatrix=" << choleskyFactorCovarianceMatrix_
@@ -188,70 +196,41 @@ String TemporalNormalProcess::__repr__() const
 
 String TemporalNormalProcess::__str__(const String & offset) const
 {
-  OSS oss;
+  OSS oss(false);
   oss << " TemporalNormalProcess=" << TemporalNormalProcess::GetClassName()
       << " dimension=" << dimension_
-      << " timeGrid=" << timeGrid_.__str__(offset)
-      << " trend=" << trend_.__str__(offset)
+      << " mesh=\n" << mesh_.__str__(offset)
+      << " trend=\n" << trend_.__str__(offset)
       << " covarianceModel=" << covarianceModel_.__str__(offset);
   return oss;
 }
 
-/* TimeGrid accessor */
-void TemporalNormalProcess::setTimeGrid(const RegularGrid & timeGrid)
+/* Mesh accessor */
+void TemporalNormalProcess::setMesh(const Mesh & mesh)
 {
   checkedStationaryTrend_ = false;
-  ProcessImplementation::setTimeGrid(timeGrid);
+  ProcessImplementation::setMesh(mesh);
 }
 
 /* Realization accessor */
-TimeSeries TemporalNormalProcess::getRealization() const
+Field TemporalNormalProcess::getRealization() const
 {
   if (!isInitialized_) initialize();
   // Constantes values
-  const UnsignedLong size(getTimeGrid().getN());
+  const UnsignedLong size(getMesh().getVerticesNumber());
   const UnsignedLong fullSize(choleskyFactorCovarianceMatrix_.getDimension());
   NumericalPoint gaussianPoint(fullSize);
   // N gaussian realizations
   for (UnsignedLong index = 0; index <  fullSize; ++index) gaussianPoint[index] = DistFunc::rNormal();
 
-  // Product matrix vector using Blas
-  // side tells if the triangular matrix is "Lower" or "Upper"
-  char uplo('L');
-  int luplo(1);
-
-  // trans tells if the matrix is transposed or not
-  char trans('N');
-  int ltrans(1);
-
-  // diag tells if M is unit diagonal or not
-  char diag('N');
-  int ldiag(1);
-
-  // the dimension of the matrix
-  int n(fullSize);
-
-  // leading dimension of M
-  int lda(fullSize);
-  int one(1);
-
-  // Call to optimize triangular matrix/vector product using Lapack
-  DTRMV_F77(&uplo, &trans, &diag, &n, const_cast<double*>(&((*choleskyFactorCovarianceMatrix_.getImplementation())[0])), &lda, const_cast<double*>(&(gaussianPoint[0])), &one, &luplo, &ltrans, &ldiag);
+  gaussianPoint = TriangularMatrix(choleskyFactorCovarianceMatrix_.getImplementation()) * gaussianPoint;
 
   NumericalSample gaussianSample(size, dimension_);
-  UnsignedLong position(0);
-  for (UnsignedLong index = 0; index < size; ++ index)
-  {
-    for (UnsignedLong dimensionIndex = 0; dimensionIndex < dimension_; ++ dimensionIndex)
-    {
-      gaussianSample[index][dimensionIndex] = gaussianPoint[position] ;
-      ++position;
-    }
-  }
+  gaussianSample.getImplementation()->setData(gaussianPoint);
   // If null trend
-  if (isTrendStationary() && (stationaryTrendValue_.norm() == 0.0)) return TimeSeries(timeGrid_, gaussianSample);
+  if (isTrendStationary() && (stationaryTrendValue_.norm() == 0.0)) return Field(mesh_, gaussianSample);
   // else apply the trend
-  return trend_(TimeSeries(timeGrid_, gaussianSample));
+  return trend_(Field(mesh_, gaussianSample));
 }
 
 /* Covariance model accessor */
@@ -284,13 +263,12 @@ void TemporalNormalProcess::checkStationaryTrend() const
 {
   hasStationaryTrend_ = true;
   checkedStationaryTrend_ = true;
-  const RegularGrid timeGrid(getTimeGrid());
-  const UnsignedLong n(timeGrid.getN());
+  const UnsignedLong n(mesh_.getVerticesNumber());
   if (n == 0) return;
-  const NumericalPoint stationaryTrendValue_((*trend_.getEvaluation())(NumericalPoint(1, timeGrid.getValue(0))));
+  const NumericalPoint stationaryTrendValue_((*trend_.getEvaluation())(mesh_.getVertices()[0]));
   for (UnsignedLong i = 1; i < n; ++i)
   {
-    if ((*trend_.getEvaluation())(NumericalPoint(1, timeGrid.getValue(i))) != stationaryTrendValue_)
+    if ((*trend_.getEvaluation())(mesh_.getVertices()[i]) != stationaryTrendValue_)
     {
       hasStationaryTrend_ = false;
       return;
@@ -313,6 +291,10 @@ void TemporalNormalProcess::save(Advocate & adv) const
   adv.saveAttribute("covarianceModel_", covarianceModel_);
   adv.saveAttribute("choleskyFactorCovarianceMatrix_", choleskyFactorCovarianceMatrix_);
   adv.saveAttribute("isInitialized_", isInitialized_);
+  adv.saveAttribute("hasStationaryTrend_", hasStationaryTrend_);
+  adv.saveAttribute("checkedStationaryTrend_", checkedStationaryTrend_);
+  adv.saveAttribute("trend_", trend_);
+  adv.saveAttribute("stationaryTrendValue_", stationaryTrendValue_);
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -322,6 +304,10 @@ void TemporalNormalProcess::load(Advocate & adv)
   adv.loadAttribute("covarianceModel_", covarianceModel_);
   adv.loadAttribute("choleskyFactorCovarianceMatrix_", choleskyFactorCovarianceMatrix_);
   adv.loadAttribute("isInitialized_", isInitialized_);
+  adv.loadAttribute("hasStationaryTrend_", hasStationaryTrend_);
+  adv.loadAttribute("checkedStationaryTrend_", checkedStationaryTrend_);
+  adv.loadAttribute("trend_", trend_);
+  adv.loadAttribute("stationaryTrendValue_", stationaryTrendValue_);
 }
 
 END_NAMESPACE_OPENTURNS
