@@ -3,7 +3,7 @@
  *  @file  WhiteNoise.cxx
  *  @brief A class which implements the WhiteNoise process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,17 +30,14 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
-
-
 CLASSNAMEINIT(WhiteNoise);
 
 static Factory<WhiteNoise> RegisteredFactory("WhiteNoise");
 
 /* Standard constructor */
 WhiteNoise::WhiteNoise(const String & name)
-  : ProcessImplementation(name),
-    distribution_(Normal())
+  : ProcessImplementation(name)
+  , distribution_(Normal())
 {
   // Nothing to do
 }
@@ -49,8 +46,8 @@ WhiteNoise::WhiteNoise(const String & name)
 WhiteNoise::WhiteNoise(const Distribution & distribution,
                        const String & name)
 /* throw (InvalidArgumentException) */
-  : ProcessImplementation(name),
-    distribution_()
+  : ProcessImplementation(name)
+  , distribution_()
 {
   // Check if the given distribution has a null mean
   setDistribution(distribution);
@@ -58,15 +55,15 @@ WhiteNoise::WhiteNoise(const Distribution & distribution,
 
 /* Standard constructor */
 WhiteNoise::WhiteNoise(const Distribution & distribution,
-                       const RegularGrid & timeGrid,
+                       const Mesh & mesh,
                        const String & name)
-  : ProcessImplementation(name),
-    distribution_()
+  : ProcessImplementation(name)
+  , distribution_()
 {
   // Set the dimension of the process
   // Check if the given distribution has a null mean
   setDistribution(distribution);
-  setTimeGrid(timeGrid);
+  setMesh(mesh);
 }
 
 /* Virtual constructor */
@@ -80,7 +77,7 @@ String WhiteNoise::__repr__() const
 {
   OSS oss;
   oss << "class=" << WhiteNoise::GetClassName()
-      << " distribution =" << distribution_ ;
+      << " distribution=" << distribution_ ;
   return oss;
 }
 
@@ -100,22 +97,38 @@ Bool WhiteNoise::isStationary() const
 /* Is the underlying gaussian ? */
 Bool WhiteNoise::isNormal() const
 {
-  return (distribution_.getImplementation()->getClassName() == "Normal");
+  return (distribution_.isElliptical() && distribution_.getStandardDistribution().hasIndependentCopula());
 }
 
 /* Realization accessor */
-TimeSeries WhiteNoise::getRealization() const
+Field WhiteNoise::getRealization() const
 {
-  return TimeSeries(timeGrid_, distribution_.getSample(timeGrid_.getN()));
+  return Field(mesh_, distribution_.getSample(mesh_.getVerticesNumber()));
+}
+
+/* Continuous realization accessor */
+NumericalMathFunction WhiteNoise::getContinuousRealization() const
+{
+  return NumericalMathFunction(mesh_.getVertices(), distribution_.getSample(mesh_.getVerticesNumber()));
 }
 
 /* Compute the next steps of a random walk */
 TimeSeries WhiteNoise::getFuture(const UnsignedLong stepNumber) const
 {
-  if (stepNumber == 0) return TimeSeries(0, dimension_);
+  /* TimeGrid of the process */
+  RegularGrid timeGrid;
+  try
+  {
+    timeGrid = getTimeGrid();
+  }
+  catch (...)
+  {
+    throw InternalException(HERE) << "Error: can extend the realization of a process only if defined on a regular gris.";
+  }
+  if (stepNumber == 0) throw InvalidArgumentException(HERE) << "Error: the number of future steps must be positive.";
   /* TimeGrid associated with the possible future */
-  const NumericalScalar timeStep(timeGrid_.getStep());
-  const RegularGrid futurTimeGrid(timeGrid_.getEnd(), timeStep, stepNumber);
+  const NumericalScalar timeStep(timeGrid.getStep());
+  const RegularGrid futurTimeGrid(timeGrid.getEnd(), timeStep, stepNumber);
   return TimeSeries(futurTimeGrid, distribution_.getSample(stepNumber));
 }
 
@@ -123,14 +136,14 @@ TimeSeries WhiteNoise::getFuture(const UnsignedLong stepNumber) const
 WhiteNoise::Implementation WhiteNoise::getMarginalProcess(const UnsignedLong i) const
 {
   if (i >= getDimension()) throw InvalidArgumentException(HERE) << "The index of a marginal process must be in the range [0, dim-1]";
-  return WhiteNoise(distribution_.getMarginal(i), timeGrid_).clone();
+  return WhiteNoise(distribution_.getMarginal(i), mesh_).clone();
 }
 
 /* Get the marginal random vector corresponding to indices components */
 WhiteNoise::Implementation WhiteNoise::getMarginalProcess(const Indices & indices) const
 {
   if (!indices.check(getDimension() - 1)) throw InvalidArgumentException(HERE) << "The indices of a marginal process must be in the range [0, dim-1] and  must be different";
-  return new WhiteNoise(distribution_.getMarginal(indices), timeGrid_);
+  return new WhiteNoise(distribution_.getMarginal(indices), mesh_);
 }
 
 /* Distribution accessor */
