@@ -3,7 +3,7 @@
  *  @file  WhittleFactory.cxx
  *  @brief An interface for all implementation class of process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,6 @@
 
 BEGIN_NAMESPACE_OPENTURNS
 
-
 TEMPLATE_CLASSNAMEINIT(PersistentCollection<WhittleFactoryState>);
 static Factory<PersistentCollection<WhittleFactoryState> > RegisteredFactory2("PersistentCollection<WhittleFactoryState>");
 
@@ -47,17 +46,17 @@ static Factory<WhittleFactory> RegisteredFactory("WhittleFactory");
 
 /* Default constructor */
 WhittleFactory::WhittleFactory(const String & name)
-  : ARMAFactoryImplementation(name),
-    spectralFactory_(WelchFactory()),
-    normalizedFrequencies_(0),
-    timeGrid_(),
-    m_(0),
-    spectralDensity_(),
-    sigma2_(0.0),
-    verbose_(false),
-    isHistoryEnabled_(true),
-    history_(0),
-    startingPoints_(0)
+  : ARMAFactoryImplementation(name)
+  , spectralFactory_(WelchFactory())
+  , normalizedFrequencies_(0)
+  , timeGrid_()
+  , m_(0)
+  , spectralDensity_()
+  , sigma2_(0.0)
+  , verbose_(false)
+  , isHistoryEnabled_(true)
+  , history_(0)
+  , startingPoints_(0)
 {
   // Nothing to do
 }
@@ -67,17 +66,17 @@ WhittleFactory::WhittleFactory(const UnsignedLong p,
                                const UnsignedLong q,
                                const Bool invertible,
                                const String & name)
-  : ARMAFactoryImplementation(p, q, invertible, name),
-    spectralFactory_(WelchFactory()),
-    normalizedFrequencies_(0),
-    timeGrid_(),
-    m_(0),
-    spectralDensity_(),
-    sigma2_(0.0),
-    verbose_(false),
-    isHistoryEnabled_(true),
-    history_(0),
-    startingPoints_(0)
+  : ARMAFactoryImplementation(p, q, invertible, name)
+  , spectralFactory_(WelchFactory())
+  , normalizedFrequencies_(0)
+  , timeGrid_()
+  , m_(0)
+  , spectralDensity_()
+  , sigma2_(0.0)
+  , verbose_(false)
+  , isHistoryEnabled_(true)
+  , history_(0)
+  , startingPoints_(0)
 {
   // Create the set of starting points using the parameters in the ResourceMap
   initializeStartingPoints();
@@ -88,17 +87,17 @@ WhittleFactory::WhittleFactory(const Indices & p,
                                const Indices & q,
                                const Bool invertible,
                                const String & name)
-  : ARMAFactoryImplementation(p, q, invertible, name),
-    spectralFactory_(WelchFactory()),
-    normalizedFrequencies_(0),
-    timeGrid_(),
-    m_(0),
-    spectralDensity_(),
-    sigma2_(0.0),
-    verbose_(false),
-    isHistoryEnabled_(true),
-    history_(0),
-    startingPoints_(0)
+  : ARMAFactoryImplementation(p, q, invertible, name)
+  , spectralFactory_(WelchFactory())
+  , normalizedFrequencies_(0)
+  , timeGrid_()
+  , m_(0)
+  , spectralDensity_()
+  , sigma2_(0.0)
+  , verbose_(false)
+  , isHistoryEnabled_(true)
+  , history_(0)
+  , startingPoints_(0)
 {
   // Create the set of starting points using the parameters in the ResourceMap
   initializeStartingPoints();
@@ -146,7 +145,7 @@ void WhittleFactory::computeSpectralDensity(const SpectralModel & spectralModel)
   for (UnsignedLong k = 0; k < m_ ; ++k)
   {
     const NumericalScalar frequency(frequencyGrid.getValue(k + kStart));
-    const NumericalScalar estimatedValue(std::real(spectralModel.computeSpectralDensity(frequency)(0, 0)) / dt);
+    const NumericalScalar estimatedValue(std::real(spectralModel(frequency)(0, 0)) / dt);
     spectralDensity_[k] = estimatedValue;
     normalizedFrequencies_[k] = M_PI * frequency / fMax;
   }
@@ -327,8 +326,8 @@ void WhittleFactory::setSpectralModelFactory(const SpectralModelFactory & factor
  *                       =\left|\frac{\beta(\exp(-i\lambda))}{\alpha(\exp(-i\lambda))}\right|^2
  * It can be noticed that dropping the term -\sum_{j=1}^m\log f(\lambda_j|\theta, \sigma^2) in the Whittle likelihood or the term
  */
-ARMA * WhittleFactory::build(const TimeSeries & timeSeries,
-                             NumericalPoint & informationCriteria) const
+ARMA WhittleFactory::build(const TimeSeries & timeSeries,
+                           NumericalPoint & informationCriteria) const
 {
   if (timeSeries.getDimension() != 1)
     throw NotYetImplementedException(HERE) << "Currently implemented for 1 d case only";
@@ -339,15 +338,15 @@ ARMA * WhittleFactory::build(const TimeSeries & timeSeries,
   return maximizeLogLikelihood(informationCriteria);
 }
 
-ARMA * WhittleFactory::build(const TimeSeries & timeSeries) const
+ARMA WhittleFactory::build(const TimeSeries & timeSeries) const
 {
   NumericalPoint informationCriteria;
   return build(timeSeries, informationCriteria);
 }
 
 /* Build method */
-ARMA * WhittleFactory::build(const ProcessSample & sample,
-                             NumericalPoint & informationCriteria) const
+ARMA WhittleFactory::build(const ProcessSample & sample,
+                           NumericalPoint & informationCriteria) const
 {
   if (sample.getDimension() != 1)
     throw NotYetImplementedException(HERE) << "Currently implemented for 1 d case only";
@@ -357,14 +356,14 @@ ARMA * WhittleFactory::build(const ProcessSample & sample,
   return maximizeLogLikelihood(informationCriteria);
 }
 
-ARMA * WhittleFactory::build(const ProcessSample & sample) const
+ARMA WhittleFactory::build(const ProcessSample & sample) const
 {
   NumericalPoint informationCriteria;
   return build(sample, informationCriteria);
 }
 
 /* Do the likelihood maximization */
-ARMA * WhittleFactory::maximizeLogLikelihood(NumericalPoint & informationCriteria) const
+ARMA WhittleFactory::maximizeLogLikelihood(NumericalPoint & informationCriteria) const
 {
   // First, clean the history
   clearHistory();
@@ -449,7 +448,7 @@ ARMA * WhittleFactory::maximizeLogLikelihood(NumericalPoint & informationCriteri
   } // Loop over p
   // Return the best information criteria
   informationCriteria = bestInformationCriteria;
-  return WhittleFactoryState(bestP, bestTheta, bestSigma2, bestInformationCriteria, timeGrid_).getARMA().clone();
+  return WhittleFactoryState(bestP, bestTheta, bestSigma2, bestInformationCriteria, timeGrid_).getARMA();
 }
 
 /* Starting points accessor */
