@@ -3,7 +3,7 @@
  *  @file  WhittleFactoryState.cxx
  *  @brief This class stores the current state of the fitting step in the WhittleFactory class.
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,12 +34,12 @@ static Factory<WhittleFactoryState> RegisteredFactory("WhittleFactoryState");
 
 /* Default constructor */
 WhittleFactoryState::WhittleFactoryState(const String & name)
-  : PersistentObject(name),
-    p_(0),
-    theta_(0),
-    sigma2_(0.0),
-    informationCriteria_(0),
-    timeGrid_()
+  : PersistentObject(name)
+  , p_(0)
+  , theta_(0)
+  , sigma2_(0.0)
+  , informationCriteria_(0)
+  , timeGrid_()
 {
   // Nothing to do
 }
@@ -51,12 +51,12 @@ WhittleFactoryState::WhittleFactoryState(const UnsignedLong p,
     const NumericalPoint & informationCriteria,
     const RegularGrid & timeGrid,
     const String & name)
-  : PersistentObject(name),
-    p_(p),
-    theta_(theta),
-    sigma2_(sigma2),
-    informationCriteria_(informationCriteria),
-    timeGrid_(timeGrid)
+  : PersistentObject(name)
+  , p_(p)
+  , theta_(theta)
+  , sigma2_(sigma2)
+  , informationCriteria_(informationCriteria)
+  , timeGrid_(timeGrid)
 {
   // Check the variance
   if (sigma2_ <= 0.0) throw InvalidArgumentException(HERE) << "Error: the given variance must be positive, here sigma2=" << sigma2;
