@@ -3,7 +3,7 @@
  *  @file  poutre.cxx
  *  @brief
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,6 +25,7 @@
 #include <iostream>
 #include <cmath>
 #include <cstdlib>
+#include <cstring>
 #include "OTconfig.hxx" // Only needed for test wrappers
 #include "WrapperCommon.h"
 #include "WrapperMacros.h"
@@ -62,16 +63,16 @@ void internalStateIncrement(struct internalState * p_internalState)
   if (p_internalState) p_internalState->numberOfCalls++;
 }
 
-static inline
-long internalStateGetNumberOfCalls(struct internalState * p_internalState)
-{
-  return (p_internalState ? p_internalState->numberOfCalls : -1);
-}
+// static inline
+// long internalStateGetNumberOfCalls(struct internalState * p_internalState)
+// {
+//   return (p_internalState ? p_internalState->numberOfCalls : -1);
+// }
 
-static inline
-void internalStatePrint(const char * functionName, struct internalState * p_internalState)
-{
-}
+// static inline
+// void internalStatePrint(const char * functionName, struct internalState * p_internalState)
+// {
+// }
 
 static inline
 void commonInternalStateCreation(void ** p_p_state, const struct WrapperExchangedData * p_exchangedData, void * p_error)
