@@ -3,7 +3,7 @@
  *  @file  t_CauchyModel_std.cxx
  *  @brief The test file of class CauchyModel
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -53,11 +53,11 @@ int main(int argc, char *argv[])
     fullprint << "myModel = " << myModel << std::endl;
 
     const NumericalScalar frequencyValue(1.0);
-    fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myModel.computeSpectralDensity(frequencyValue) << std::endl;
+    fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myModel(frequencyValue) << std::endl;
 
     /* Evaluation at time higher to check the decrease of the cauchy values */
     const NumericalScalar frequencyValueHigh(10.0);
-    fullprint << "spectral density matrix at f = " << frequencyValueHigh << " : " << myModel.computeSpectralDensity(frequencyValueHigh) << std::endl;
+    fullprint << "spectral density matrix at f = " << frequencyValueHigh << " : " << myModel(frequencyValueHigh) << std::endl;
 
     /* Default dimension parameter to evaluate the model */
     const UnsignedLong highDimension(3);
@@ -85,10 +85,10 @@ int main(int argc, char *argv[])
     CauchyModel myHighModel(amplitude, scale, spatialCorrelation);
     fullprint << "myHighModel = " << myHighModel << std::endl;
 
-    fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myHighModel.computeSpectralDensity(frequencyValue).clean(1.0e-6) << std::endl;
-    fullprint << "spectral density matrix at f = " << frequencyValue << " :\n" << myHighModel.computeSpectralDensity(frequencyValue).clean(1.0e-6).__str__() << std::endl;
-    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " : " << myHighModel.computeSpectralDensity(frequencyValueHigh).clean(1.0e-6) << std::endl;
-    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " :\n" << myHighModel.computeSpectralDensity(frequencyValueHigh).clean(1.0e-6).__str__() << std::endl;
+    fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myHighModel(frequencyValue).clean(1.0e-6) << std::endl;
+    fullprint << "spectral density matrix at f = " << frequencyValue << " :\n" << myHighModel(frequencyValue).clean(1.0e-6).__str__() << std::endl;
+    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " : " << myHighModel(frequencyValueHigh).clean(1.0e-6) << std::endl;
+    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " :\n" << myHighModel(frequencyValueHigh).clean(1.0e-6).__str__() << std::endl;
 
     CovarianceMatrix spatialCovariance(highDimension);
     for (UnsignedLong index = 0 ; index < highDimension; ++index)
@@ -103,10 +103,10 @@ int main(int argc, char *argv[])
     CauchyModel myHighModelCovariance(scale, spatialCovariance);
     fullprint << "myHighModelCovariance = " << myHighModelCovariance << std::endl;
 
-    fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myHighModelCovariance.computeSpectralDensity(frequencyValue).clean(1.0e-6) << std::endl;
-    fullprint << "spectral density matrix at f = " << frequencyValue << " :\n" << myHighModelCovariance.computeSpectralDensity(frequencyValue).clean(1.0e-6).__str__() << std::endl;
-    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " : " << myHighModelCovariance.computeSpectralDensity(frequencyValueHigh).clean(1.0e-6) << std::endl;
-    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " :\n" << myHighModelCovariance.computeSpectralDensity(frequencyValueHigh).clean(1.0e-6).__str__() << std::endl;
+    fullprint << "spectral density matrix at f = " << frequencyValue << " : " << myHighModelCovariance(frequencyValue).clean(1.0e-6) << std::endl;
+    fullprint << "spectral density matrix at f = " << frequencyValue << " :\n" << myHighModelCovariance(frequencyValue).clean(1.0e-6).__str__() << std::endl;
+    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " : " << myHighModelCovariance(frequencyValueHigh).clean(1.0e-6) << std::endl;
+    fullprint << "spectral density matrix at f = "  << frequencyValueHigh << " :\n" << myHighModelCovariance(frequencyValueHigh).clean(1.0e-6).__str__() << std::endl;
 
   }
   catch (TestFailed & ex)
