@@ -3,7 +3,7 @@
  *  @file  t_DistFunc_student.cxx
  *  @brief The test file of class DistFunc for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,11 +39,21 @@ int main(int argc, char *argv[])
     {
       // pStudent
       NumericalScalar nuMin(0.2);
-      NumericalScalar nuMax(5.0);
-      UnsignedLong n1(5);
-      NumericalScalar xMin(0.1);
-      NumericalScalar xMax(0.9);
-      UnsignedLong nX(10);
+      NumericalScalar nuMax(100.0);
+      UnsignedLong n1(10);
+      NumericalScalar xMin(-10.0);
+      NumericalScalar xMax(10.0);
+      UnsignedLong nX(20);
+      // First, the special cases: small integer nu
+      for (UnsignedLong nu = 1; nu <= 7; ++nu)
+      {
+        for (UnsignedLong iX = 0; iX < nX; ++iX)
+        {
+          NumericalScalar x(xMin + (xMax - xMin) * iX / (nX - 1));
+          fullprint << "pStudent(" << nu << ", " << x << ")=" << DistFunc::pStudent(nu, x) << ", complementary=" << DistFunc::pStudent(nu, x, true) << std::endl;
+        }
+      }
+      // Second, the general case: medium real nu
       for (UnsignedLong i1 = 0; i1 < n1; ++i1)
       {
         NumericalScalar nu(nuMin + (nuMax - nuMin) * i1 / (n1 - 1));
@@ -53,6 +63,18 @@ int main(int argc, char *argv[])
           fullprint << "pStudent(" << nu << ", " << x << ")=" << DistFunc::pStudent(nu, x) << ", complementary=" << DistFunc::pStudent(nu, x, true) << std::endl;
         }
       }
+      // Third, the extreme case: large real nu
+      NumericalScalar logNuMin(9.0);
+      NumericalScalar logNuMax(9.0);
+      for (UnsignedLong i1 = 0; i1 < n1; ++i1)
+      {
+        NumericalScalar nu(exp(logNuMin + (logNuMax - logNuMin) * i1 / (n1 - 1)));
+        for (UnsignedLong iX = 0; iX < nX; ++iX)
+        {
+          NumericalScalar x(xMin + (xMax - xMin) * iX / (nX - 1));
+          fullprint << "pStudent(" << nu << ", " << x << ")=" << DistFunc::pStudent(nu, x) << ", complementary=" << DistFunc::pStudent(nu, x, true) << std::endl;
+        }
+      }
     } // pStudent
     {
       // qStudent
@@ -62,6 +84,16 @@ int main(int argc, char *argv[])
       NumericalScalar qMin(0.1);
       NumericalScalar qMax(0.9);
       UnsignedLong nQ(10);
+      // First, the special cases: small integer nu
+      for (UnsignedLong nu = 1; nu <= 6; ++nu)
+      {
+        for (UnsignedLong iQ = 0; iQ < nQ; ++iQ)
+        {
+          NumericalScalar q(qMin + (qMax - qMin) * iQ / (nQ - 1));
+          fullprint << "qStudent(" << nu << ", " << q << ")=" << DistFunc::qStudent(nu, q) << ", complementary=" << DistFunc::qStudent(nu, q, true) << std::endl;
+        }
+      }
+      // Second, the general case: medium real nu
       for (UnsignedLong i1 = 0; i1 < n1; ++i1)
       {
         NumericalScalar nu(nuMin + (nuMax - nuMin) * i1 / (n1 - 1));
@@ -71,9 +103,21 @@ int main(int argc, char *argv[])
           fullprint << "qStudent(" << nu << ", " << q << ")=" << DistFunc::qStudent(nu, q) << ", complementary=" << DistFunc::qStudent(nu, q, true) << std::endl;
         }
       }
+      // Third, the extreme case: large real nu
+      NumericalScalar logNuMin(9.0);
+      NumericalScalar logNuMax(12.0);
+      for (UnsignedLong i1 = 0; i1 < n1; ++i1)
+      {
+        NumericalScalar nu(exp(logNuMin + (logNuMax - logNuMin) * i1 / (n1 - 1)));
+        for (UnsignedLong iQ = 0; iQ < nQ; ++iQ)
+        {
+          NumericalScalar q(qMin + (qMax - qMin) * iQ / (nQ - 1));
+          fullprint << "qStudent(" << nu << ", " << q << ")=" << DistFunc::qStudent(nu, q) << ", complementary=" << DistFunc::qStudent(nu, q, true) << std::endl;
+        }
+      }
     } // qStudent
     {
-      // qStudent
+      // rStudent
       NumericalScalar nuMin(0.2);
       NumericalScalar nuMax(5.0);
       UnsignedLong n1(5);
