@@ -3,7 +3,7 @@
  *  @file  t_Distributions_draw.cxx
  *  @brief The test file of class Normal for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,8 +63,19 @@ int main(int argc, char *argv[])
     graphCDF = dist1D.drawCDF(101);
     graphCDF.draw("PointNumberDrawCDF_1D");
     fullprint << "graphCDF=" << graphCDF.getBitmap() << std::endl;
+    Graph graphQuantile(dist1D.drawQuantile());
+    graphQuantile.draw("DefaultDrawQuantile_1D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist1D.drawQuantile(101);
+    graphQuantile.draw("PointNumberDrawQuantile_1D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist1D.drawQuantile(0.1, 0.9, 101);
+    graphQuantile.draw("FullParameterDrawQuantile_1D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist1D.drawQuantile(0.1, 0.9);
+    graphQuantile.draw("RangeDrawQuantile_1D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
     // Check drawing methods for 2D distributions
-    std::cerr << "bug" << std::endl;
     graphPDF = dist2D.drawPDF();
     graphPDF.draw("DefaultDrawPDF_2D");
     fullprint << "graphPDF=" << graphPDF.getBitmap() << std::endl;
@@ -102,6 +113,18 @@ int main(int argc, char *argv[])
     graphCDF = distND.drawMarginal2DCDF(2, 3, NumericalPoint(2, -4.0), NumericalPoint(2, 4.0), Indices(2, 101));
     graphCDF.draw("FullParametersDrawMarginal2DCDF_ND");
     fullprint << "graphCDF=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist2D.drawQuantile();
+    graphQuantile.draw("DefaultDrawQuantile_2D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist2D.drawQuantile(101);
+    graphQuantile.draw("PointNumberDrawQuantile_2D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist2D.drawQuantile(0.1, 0.9, 101);
+    graphQuantile.draw("FullParameterDrawQuantile_2D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
+    graphQuantile = dist2D.drawQuantile(0.1, 0.9);
+    graphQuantile.draw("RangeDrawQuantile_2D");
+    fullprint << "graphQuantile=" << graphCDF.getBitmap() << std::endl;
   }
   catch (TestFailed & ex)
   {
