@@ -3,7 +3,7 @@
  *  @file  t_Event_std.cxx
  *  @brief The test file of Event class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -57,7 +57,12 @@ int main(int argc, char *argv[])
     fullprint << "vect sample =" << vect.getSample(5) << std::endl;
 
     /* We create a numerical math function */
-    NumericalMathFunction myFunction("poutre");
+    Description input(4);
+    input[0] = "E";
+    input[1] = "F";
+    input[2] = "L";
+    input[3] = "I";
+    NumericalMathFunction myFunction(input, Description(1, "d"), Description(1, "-F*L^3/(3*E*I)"));
 
     /* We create a composite random vector */
     RandomVector output(myFunction, vect);
