@@ -3,7 +3,7 @@
  *  @file  t_ExponentialModel_std.cxx
  *  @brief The test file of class ExponentialModel
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -53,17 +53,17 @@ int main(int argc, char *argv[])
     fullprint << "myModel = " << myModel << std::endl;
 
     const NumericalScalar timeValueOne(1.0);
-    fullprint << "covariance matrix at t = " << timeValueOne << " : " << myModel.computeCovariance(timeValueOne) << std::endl;
-    fullprint << "covariance matrix at t = " << -1.0 * timeValueOne << " : " << myModel.computeCovariance(-1.0 * timeValueOne) << std::endl;
+    fullprint << "covariance matrix at t = " << timeValueOne << " : " << myModel(timeValueOne) << std::endl;
+    fullprint << "covariance matrix at t = " << -1.0 * timeValueOne << " : " << myModel(-1.0 * timeValueOne) << std::endl;
 
     /* Evaluation at time higher to check the decrease of the exponential values */
     const NumericalScalar timeValueHigh(4.0);
-    fullprint << "covariance matrix at t = "  << timeValueHigh << " : " << myModel.computeCovariance(timeValueHigh) << std::endl;
+    fullprint << "covariance matrix at t = "  << timeValueHigh << " : " << myModel(timeValueHigh) << std::endl;
 
     /* Discretize the process on a small time grid */
     RegularGrid timeGrid(0.0, 1.0 / 3.0, 4);
     fullprint << "discretized covariance over the time grid=" << timeGrid << " is" << std::endl;
-    fullprint << myModel.discretizeCovariance(timeGrid) << std::endl;
+    fullprint << myModel.discretize(timeGrid) << std::endl;
     /* Default dimension parameter to evaluate the model */
     const UnsignedLong highDimension(3);
 
@@ -88,12 +88,12 @@ int main(int argc, char *argv[])
     ExponentialModel myHighModel(amplitude, scale, spatialCorrelation);
     fullprint << "myHighModel = " << myHighModel << std::endl;
 
-    fullprint << "covariance matrix at t = " << timeValueOne << " : " << myHighModel.computeCovariance(timeValueOne) << std::endl;
-    fullprint << "covariance matrix at t = " << -timeValueOne << " : " << myHighModel.computeCovariance(-timeValueOne) << std::endl;
-    fullprint << "covariance matrix at t = "  << timeValueHigh << " : " << myHighModel.computeCovariance(timeValueHigh) << std::endl;
+    fullprint << "covariance matrix at t = " << timeValueOne << " : " << myHighModel(timeValueOne) << std::endl;
+    fullprint << "covariance matrix at t = " << -timeValueOne << " : " << myHighModel(-timeValueOne) << std::endl;
+    fullprint << "covariance matrix at t = "  << timeValueHigh << " : " << myHighModel(timeValueHigh) << std::endl;
 
     fullprint << "discretized covariance over the time grid=" << timeGrid << " is" << std::endl;
-    fullprint << myHighModel.discretizeCovariance(timeGrid) << std::endl;
+    fullprint << myHighModel.discretize(timeGrid) << std::endl;
 
   }
   catch (TestFailed & ex)
