@@ -3,7 +3,7 @@
  *  @file  t_FORM_std.cxx
  *  @brief The test file of FORM class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -49,7 +49,12 @@ int main(int argc, char *argv[])
   {
 
     /* We create a numerical math function */
-    NumericalMathFunction myFunction("poutre");
+    Description input(4);
+    input[0] = "E";
+    input[1] = "F";
+    input[2] = "L";
+    input[3] = "I";
+    NumericalMathFunction myFunction(input, Description(1, "d"), Description(1, "-F*L^3/(3*E*I)"));
 
     UnsignedLong dim(myFunction.getInputDimension());
     /* We create a normal distribution point of dimension 1 */
@@ -73,7 +78,11 @@ int main(int argc, char *argv[])
 
     /* We create a NearestPoint algorithm */
     // Test function operator ()
-    NumericalMathFunction levelFunction("TestOptimLinear");
+    input[0] = "x1";
+    input[1] = "x2";
+    input[2] = "x3";
+    input[3] = "x4";
+    NumericalMathFunction levelFunction(input, Description(1, "d"), Description(1, "x1+2*x2-3*x3+4*x4"));
     AbdoRackwitzSpecificParameters specific;
     NumericalPoint startingPoint(4, 1.0);
     AbdoRackwitz myAlgorithm(specific, levelFunction);
