@@ -3,7 +3,7 @@
  *  @file  t_Graph_mix.cxx
  *  @brief The test file of Graph class for EDF case number 9
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -68,51 +68,51 @@ int main(int argc, char *argv[])
     // Create the line
     Curve myLine(tmp, "red", "solid", 2, "Line");
 
-    NumericalSample data(0, 1);
+    NumericalPoint data(0);
     Description palette;
     Description labels;
 
-    data.add(NumericalPoint(1, 5665855));
+    data.add(5665855);
     labels.add("chirac");
     palette.add("blue");
 
-    data.add(NumericalPoint(1, 4804713));
+    data.add(4804713);
     labels.add("lepen");
     palette.add("white");
 
-    data.add(NumericalPoint(1, 4610113));
+    data.add(4610113);
     labels.add("jospin");
     palette.add("pink");
 
-    data.add(NumericalPoint(1, 1949170));
+    data.add(1949170);
     labels.add("bayrou");
     palette.add("yellow");
 
-    data.add(NumericalPoint(1, 1630045));
+    data.add(1630045);
     labels.add("laguiller");
     palette.add("red");
 
-    data.add(NumericalPoint(1, 1518528));
+    data.add(1518528);
     labels.add("chevenement");
     palette.add("ivory");
 
-    data.add(NumericalPoint(1, 1495724));
+    data.add(1495724);
     labels.add("mamere");
     palette.add("green");
 
-    data.add(NumericalPoint(1, 1210562));
+    data.add(1210562);
     labels.add("besancenot");
     palette.add("orange");
 
-    data.add(NumericalPoint(1, 1204689));
+    data.add(1204689);
     labels.add("saint-josse");
     palette.add("maroon");
 
-    data.add(NumericalPoint(1, 1113484));
+    data.add(1113484);
     labels.add("madelin");
     palette.add("violet");
 
-    data.add(NumericalPoint(1, 3295588));
+    data.add(3295588);
     labels.add("cumul candidats < 3.5% ");
     palette.add("purple");
 
