@@ -3,7 +3,7 @@
  *  @file  t_Histogram_std.cxx
  *  @brief The test file of class Histogram for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ int main(int argc, char *argv[])
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
     fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
     size = 100;
-    for (UnsignedLong i = 0; i < 5; ++i)
+    for (UnsignedLong i = 0; i < 2; ++i)
     {
       fullprint << "Kolmogorov test for the generator, sample size=" << size << " is " << (FittingTest::Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure() ? "accepted" : "rejected") << std::endl;
       size *= 10;
@@ -88,6 +88,8 @@ int main(int argc, char *argv[])
     fullprint << "cdf=" << CDF << std::endl;
     NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << CCDF << std::endl;
+    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    fullprint << "survival=" << Survival << std::endl;
     //    NumericalPoint PDFgr = distribution.computePDFGradient( point );
     //    fullprint << "pdf gradient     =" << PDFgr << std::endl;
     //    NumericalPoint PDFgrFD(1 + 2 * collectionSize);
@@ -137,6 +139,12 @@ int main(int argc, char *argv[])
     fullprint << "mean=" << mean << std::endl;
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
+    CovarianceMatrix correlation = distribution.getCorrelation();
+    fullprint << "correlation=" << correlation << std::endl;
+    CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
+    fullprint << "spearman=" << spearman << std::endl;
+    CovarianceMatrix kendall = distribution.getKendallTau();
+    fullprint << "kendall=" << kendall << std::endl;
     Histogram::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
     for (UnsignedLong i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
