@@ -3,7 +3,7 @@
  *  @file  t_InverseNormalFactory_std.cxx
  *  @brief The test file of class InverseNormal for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -44,6 +44,11 @@ int main(int argc, char *argv[])
     Distribution estimatedDistribution(factory.build(sample));
     fullprint << "Distribution          =" << distribution << std::endl;
     fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    ResourceMap::Set("InverseNormalFactory-Method", "Moments");
+    estimatedDistribution = factory.build(sample);
+    fullprint << "Distribution          =" << distribution << std::endl;
+    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
+    ResourceMap::Set("InverseNormalFactory-Method", "MLE");
     // fullprint << "Covariance=" << covariance << std::endl;
     estimatedDistribution = factory.build();
     fullprint << "Default distribution=" << estimatedDistribution << std::endl;
