@@ -3,7 +3,7 @@
  *  @file  t_KernelMixture_std.cxx
  *  @brief The test file of class KernelMixture for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,6 @@ int main(int argc, char *argv[])
   TESTPREAMBLE;
   OStream fullprint(std::cout);
   setRandomGenerator();
-
   try
   {
 
@@ -76,7 +75,7 @@ int main(int argc, char *argv[])
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
-    UnsignedLong size = 10000;
+    UnsignedLong size = 100;
     NumericalSample oneSample = distribution.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
@@ -106,6 +105,8 @@ int main(int argc, char *argv[])
     fullprint << "cdf=" << CDF << std::endl;
     NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << CCDF << std::endl;
+    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    fullprint << "survival=" << Survival << std::endl;
     fullprint << "cdf (ref)=" << distributionRef.computeCDF( point ) << std::endl;
     NumericalComplex CF = distribution.computeCharacteristicFunction( point[0] );
     fullprint << "characteristic function=" << CF << std::endl;
@@ -121,6 +122,12 @@ int main(int argc, char *argv[])
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
     fullprint << "covariance (ref)=" << distributionRef.getCovariance() << std::endl;
+    CovarianceMatrix correlation = distribution.getCorrelation();
+    fullprint << "correlation=" << correlation << std::endl;
+//     CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
+//     fullprint << "spearman=" << spearman << std::endl;
+//     CovarianceMatrix kendall = distribution.getKendallTau();
+//     fullprint << "kendall=" << kendall << std::endl;
     //    KernelMixture::NumericalPointCollection parameters = distribution.getParametersCollection();
     //    fullprint << "parameters=" << parameters << std::endl;
   }
