@@ -3,7 +3,7 @@
  *  @file  t_KernelSmoothing_std.cxx
  *  @brief The test file of class KernelSmoothing for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,6 @@ int main(int argc, char *argv[])
   TESTPREAMBLE;
   OStream fullprint(std::cout);
   setRandomGenerator();
-
   try
   {
     UnsignedLong dim(2);
@@ -117,10 +116,15 @@ int main(int argc, char *argv[])
     }
     // Test with varying binning
     {
+      std::cerr << "build sample" << std::endl;
       NumericalSample sample(Normal().getSample(5000));
+      std::cerr << "low bin count" << std::endl;
       Distribution ks1(KernelSmoothing(Normal(), true, 64).build(sample));
+      std::cerr << "high bin count" << std::endl;
       Distribution ks2(KernelSmoothing(Normal(), true, 1024).build(sample));
+      std::cerr << "no bin" << std::endl;
       Distribution ks3(KernelSmoothing(Normal(), false).build(sample));
+      std::cerr << "Compute PDF" << std::endl;
       NumericalPoint point(1, 0.3);
       fullprint << "with low  bin count, pdf=" << ks1.computePDF(point) << std::endl;
       fullprint << "with high bin count, pdf=" << ks2.computePDF(point) << std::endl;
