@@ -3,7 +3,7 @@
  *  @file  t_Log_std.cxx
  *  @brief The test file of class Log for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,10 +24,6 @@
 #include "OTtestcode.hxx"
 #include "OStream.hxx"
 
-#ifdef WIN32
-// MinGW pthread.h includes windows.h which define a HUGE number of macros..
-#undef ERROR
-#endif
 #include "Log.hxx"
 
 using namespace OT;
