@@ -3,7 +3,7 @@
  *  @file  t_MergeRandomAndConstantInput.cxx
  *  @brief The test file of class NumericalMathFunction for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,13 @@ int main(int argc, char *argv[])
   {
 
     /** External code. This code has an input vector of dimension 4, namely (p0, p1, p2, p3)'. */
-    NumericalMathFunction externalCode("poutre");
+    Description input(4);
+    input[0] = "E";
+    input[1] = "F";
+    input[2] = "L";
+    input[3] = "I";
+    NumericalMathFunction externalCode(input, Description(1, "d"), Description(1, "F*L^3/(3*E*I)"));
+
     UnsignedLong dim(externalCode.getInputDimension());
 
     /** The external code will be connected to 2 independent random variables X0 and X1 and one deterministic variable X2 with the following scheme:
