@@ -3,7 +3,7 @@
  *  @file  t_Mixture_std.cxx
  *  @brief The test file of class Mixture for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,6 +29,7 @@ using namespace OT::Test;
 
 int main(int argc, char *argv[])
 {
+  ResourceMap::Set("DistributionImplementation-parallel", "1");
   TESTPREAMBLE;
   OStream fullprint(std::cout);
   setRandomGenerator();
@@ -85,7 +86,7 @@ int main(int argc, char *argv[])
     Mixture distribution(aCollection, NumericalPoint(aCollection.getSize(), 2.0));
     fullprint << "Distribution " << distribution << std::endl;
     distribution = Mixture(aCollection);
-    fullprint << "Distribution " << distribution << std::endl;
+    fullprint << "Distribution " << distribution.__str__() << std::endl;
 
     // Is this distribution elliptical ?
     fullprint << "Elliptical = " << (distribution.isElliptical() ? "true" : "false") << std::endl;
@@ -98,7 +99,7 @@ int main(int argc, char *argv[])
     fullprint << "oneRealization=" << oneRealization << std::endl;
 
     // Test for sampling
-    UnsignedLong size = 10000;
+    UnsignedLong size = 1000;
     NumericalSample oneSample = distribution.getSample( size );
     fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
     fullprint << "mean=" << oneSample.computeMean() << std::endl;
@@ -106,7 +107,7 @@ int main(int argc, char *argv[])
     if (distribution.getDimension() == 1)
     {
       size = 100;
-      for (UnsignedLong i = 0; i < 5; ++i)
+      for (UnsignedLong i = 0; i < 2; ++i)
       {
         fullprint << "Kolmogorov test for the generator, sample size=" << size << " is " << (FittingTest::Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure() ? "accepted" : "rejected") << std::endl;
         size *= 10;
@@ -142,6 +143,8 @@ int main(int argc, char *argv[])
     fullprint << "cdf=" << CDF << std::endl;
     NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << CCDF << std::endl;
+    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    fullprint << "survival =" << Survival << std::endl;
     if (dimension == 1)
     {
       NumericalComplex CF = distribution.computeCharacteristicFunction( point[0] );
@@ -156,7 +159,14 @@ int main(int argc, char *argv[])
     fullprint << "mean=" << mean << std::endl;
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
+    CovarianceMatrix correlation = distribution.getCorrelation();
+    fullprint << "correlation=" << correlation << std::endl;
+//     CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
+//     fullprint << "spearman=" << spearman << std::endl;
+//     CovarianceMatrix kendall = distribution.getKendallTau();
+//     fullprint << "kendall=" << kendall << std::endl;
     Mixture::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
+    fullprint << "parameters=" << parameters << std::endl;
 
     // Constructor with separate weights. Also check small weights removal
     NumericalPoint weights;
@@ -172,6 +182,8 @@ int main(int argc, char *argv[])
     fullprint << "atoms kept in mixture=" << newMixture.getDistributionCollection() << std::endl;
     fullprint << "newMixture=" << newMixture.__str__() << std::endl;
 
+
+
   }
   catch (TestFailed & ex)
   {
