@@ -3,7 +3,7 @@
  *  @file  t_MonteCarlo_draw.cxx
  *  @brief The test file of MonteCarlo class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,12 @@ int main(int argc, char *argv[])
   {
 
     /* We create a numerical math function */
-    NumericalMathFunction myFunction("poutre");
+    Description input(4);
+    input[0] = "E";
+    input[1] = "F";
+    input[2] = "L";
+    input[3] = "I";
+    NumericalMathFunction myFunction(input, Description(1, "d"), Description(1, "-F*L^3/(3*E*I)"));
 
     UnsignedLong dim(myFunction.getInputDimension());
     /* We create a normal distribution point of dimension 1 */
