@@ -3,7 +3,7 @@
  *  @file  t_Multinomial_std.cxx
  *  @brief The test file of class Multinomial for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -92,6 +92,8 @@ int main(int argc, char *argv[])
     fullprint << "cdf=" << std::setprecision(5) << CDF << std::setprecision(6) << std::endl;
     NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
     fullprint << "ccdf=" << std::setprecision(5) << CCDF << std::setprecision(6) << std::endl;
+    //    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+    //    fullprint << "survival=" << Survival << std::endl;
     NumericalPoint quantile = distribution.computeQuantile( 0.95 );
     fullprint << "quantile=" << quantile << std::endl;
     fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
@@ -99,6 +101,12 @@ int main(int argc, char *argv[])
     fullprint << "mean=" << mean << std::endl;
     CovarianceMatrix covariance = distribution.getCovariance();
     fullprint << "covariance=" << covariance << std::endl;
+    CovarianceMatrix correlation = distribution.getCorrelation();
+    fullprint << "correlation=" << correlation << std::endl;
+    //    CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
+    //    fullprint << "spearman=" << spearman << std::endl;
+    //    CovarianceMatrix kendall = distribution.getKendallTau();
+    //    fullprint << "kendall=" << kendall << std::endl;
     Multinomial::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
     fullprint << "parameters=" << parameters << std::endl;
   }
