@@ -3,7 +3,7 @@
  *  @file  t_NearestPointChecker_std.cxx
  *  @brief The test file of class NearestPointChecker for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,12 @@ int main(int argc, char *argv[])
     {
       // Function
       UnsignedLong sampleSize(20);
-      NumericalMathFunction levelFunction("TestOptimLinear");
+      Description input(4);
+      input[0] = "x1";
+      input[1] = "x2";
+      input[2] = "x3";
+      input[3] = "x4";
+      NumericalMathFunction levelFunction(input, Description(1, "y1"), Description(1, "x1+2*x2-3*x3+4*x4"));
       LessOrEqual myOperator;
       NumericalScalar threshold(2.0);
       NumericalSample mySample(0, levelFunction.getInputDimension());
