@@ -3,7 +3,7 @@
  *  @file  t_Normal_std.cxx
  *  @brief The test file of class Normal for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -98,7 +98,7 @@ int main(int argc, char *argv[])
       if (distribution.getDimension() == 1)
       {
         size = 100;
-        for (UnsignedLong i = 0; i < 5; ++i)
+        for (UnsignedLong i = 0; i < 2; ++i)
         {
           RandomGenerator::SetSeed(1);
           fullprint << "Kolmogorov test for the generator, sample size=" << size << " is " << (FittingTest::Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure() ? "accepted" : "rejected") << std::endl;
@@ -131,6 +131,8 @@ int main(int argc, char *argv[])
         NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
         fullprint << "ccdf=" << CCDF << std::endl;
       }
+      NumericalScalar Survival = distribution.computeSurvivalFunction( point );
+      fullprint << "survival=" << Survival << std::endl;
       NumericalComplex CF = distribution.computeCharacteristicFunction( point );
       fullprint << "characteristic function=" << CF << std::endl;
       NumericalComplex LCF = distribution.computeLogCharacteristicFunction( point );
@@ -175,13 +177,19 @@ int main(int argc, char *argv[])
       fullprint << "kurtosis=" << kurtosis << std::endl;
       CovarianceMatrix covariance = distribution.getCovariance();
       fullprint << "covariance=" << covariance << std::endl;
+      CovarianceMatrix correlation = distribution.getCorrelation();
+      fullprint << "correlation=" << correlation << std::endl;
+      CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
+      fullprint << "spearman=" << spearman << std::endl;
+      CovarianceMatrix kendall = distribution.getKendallTau();
+      fullprint << "kendall=" << kendall << std::endl;
       Normal::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
       fullprint << "parameters=" << parameters << std::endl;
       for (UnsignedLong i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
       fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;
 
       // Specific to this distribution
-      NumericalScalar beta(point.norm2());
+      NumericalScalar beta(point.normSquare());
       NumericalScalar densityGenerator(distribution.computeDensityGenerator(beta));
       fullprint << "density generator=" << densityGenerator << std::endl;
       fullprint << "pdf via density generator=" << distribution.EllipticalDistribution::computePDF(point) << std::endl;
