@@ -3,7 +3,7 @@
  *  @file  t_NumericalMathFunction_analytical.cxx
  *  @brief The test file of class NumericalMathFunction for analytical
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -67,41 +67,48 @@ int main(int argc, char *argv[])
     elementaryFunctions.add("rint");
     elementaryFunctions.add("abs");
     /* Check the creation of the elementary functions */
-    NumericalPoint x(1, 0.4);
     for (UnsignedLong i = 0; i < elementaryFunctions.getSize(); ++i)
     {
-      NumericalPoint x(1, 0.4);
+      NumericalPoint x(1, 0.4 / 3);
 
       // acosh only defined for 1 <= x <= pi
       if ( elementaryFunctions[i] == String("acosh") )
       {
-        x[0] = 1.4;
+        x[0] = 1.4 / 3;
       }
 
-      NumericalMathFunction f("x", elementaryFunctions[i] + "(x)", "y");
-      std::cout << "f=" << f << std::endl;
-      std::cout << "f(" << x[0] << ")=" << std::scientific << std::setprecision(4) << f(x)[0] << std::endl;
+      NumericalMathFunction f("x", "2*" + elementaryFunctions[i] + "(3*x)", "y");
+      fullprint << "f=" << f.__str__() << std::endl;
+      fullprint << "f(" << x[0] << ")=" << std::scientific << std::setprecision(4) << f(x)[0] << std::endl;
+      NumericalScalar df(CenteredFiniteDifferenceGradient(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceGradient-DefaultEpsilon" ), f.getEvaluationImplementation()).gradient(x)(0, 0));
+      NumericalScalar grad_f(0.0);
       try
       {
-        NumericalScalar grad_f = f.gradient(x)(0, 0);
-        std::cout << "df(" << x[0] << ")=" << std::scientific << std::setprecision(4) << grad_f << std::endl;
+        grad_f = f.gradient(x)(0, 0);
       }
       catch(...)
       {
-        std::cout << "finite difference" << std::endl;
+        fullprint << "finite difference" << std::endl;
         f.setGradientImplementation(new CenteredFiniteDifferenceGradient(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceGradient-DefaultEpsilon" ), f.getEvaluationImplementation()));
-        std::cout << "df(" << x[0] << ")=" << std::scientific << std::setprecision(4) << f.gradient(x)(0, 0) << std::endl;
+        grad_f = f.gradient(x)(0, 0);
       }
+      fullprint << "df(" << x[0] << ")=" << std::scientific << std::setprecision(4) << grad_f << std::endl;
+      NumericalScalar error(fabs(grad_f) > 1.0e-5 ? fabs(df / grad_f - 1.0) : fabs(df - grad_f));
+      if (error > 1e-5) std::cout << "GRADIENT ERROR! error=" << error << ", check " + elementaryFunctions[i] << std::endl;
+      NumericalScalar d2f(CenteredFiniteDifferenceHessian(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceHessian-DefaultEpsilon" ), f.getEvaluationImplementation()).hessian(x)(0, 0, 0));
+      NumericalScalar hess_f(0.0);
       try
       {
-        NumericalScalar hess_f = f.hessian(x)(0, 0, 0);
-        std::cout << "d2f(" << x[0] << ")=" << std::scientific << std::setprecision(4) << hess_f << std::endl;
+        hess_f = f.hessian(x)(0, 0, 0);
       }
       catch(...)
       {
         f.setHessianImplementation(new CenteredFiniteDifferenceHessian(ResourceMap::GetAsNumericalScalar( "CenteredFiniteDifferenceHessian-DefaultEpsilon" ), f.getEvaluationImplementation()));
-        std::cout << "d2f(" << x[0] << ")=" << std::scientific << std::setprecision(4) << f.hessian(x)(0, 0, 0) << std::endl;
+        hess_f = f.hessian(x)(0, 0, 0);
       }
+      std::cout << "d2f(" << x[0] << ")=" << std::scientific << std::setprecision(4) << hess_f << std::endl;
+      error = (fabs(hess_f) > 1.0e-5 ? fabs(d2f / hess_f - 1.0) : fabs(d2f - hess_f));
+      if (error > 1e-4) std::cout << "HESSIAN ERROR! error=" << error << ", check " + elementaryFunctions[i] << std::endl;
     }
     Description inp(2);
     inp[0] = "x0";
@@ -116,8 +123,42 @@ int main(int argc, char *argv[])
     NumericalMathFunction nmf(inp, out, form);
     NumericalMathFunction marginal0(nmf.getMarginal(0));
     NumericalMathFunction marginal1(nmf.getMarginal(1));
-    std::cout << "marginal 0=" << marginal0 << std::endl;
-    std::cout << "marginal 1=" << marginal1 << std::endl;
+    fullprint << "marginal 0=" << marginal0.__str__() << std::endl;
+    fullprint << "marginal 1=" << marginal1.__str__() << std::endl;
+
+    // test sample as input of a function
+    Description inputVariables(3);
+    inputVariables[0] = "xi1";
+    inputVariables[1] = "xi2";
+    inputVariables[2] = "xi3";
+    Description outputVariables(1);
+    outputVariables[0] = "y";
+    Description formula(1);
+    formula[0] = (OSS() << "sin(xi1) + 7. * (sin(xi2)) ^ 2 + 0.1 * xi3^4 * sin(xi1)");
+    NumericalMathFunction model(inputVariables, outputVariables, formula);
+
+    // Create an input distribution to calculate reference values
+    Collection<Distribution> marginals(3);
+    marginals[0] = Uniform(-M_PI, M_PI);
+    marginals[1] = Uniform(-M_PI, M_PI);
+    marginals[2] = Uniform(-M_PI, M_PI);
+    ComposedDistribution distribution(marginals);
+    NumericalSample inputsSample(distribution.getSample( 100 ));
+
+    NumericalPoint refResultValues(100, 0.);
+    NumericalPoint pt(3, 0.);
+    for (UnsignedLong i = 0; i < 100; ++i)
+    {
+      pt[0] = inputsSample[i][0];
+      pt[1] = inputsSample[i][1];
+      pt[2] = inputsSample[i][2];
+      refResultValues[i] = model(pt)[0];
+    }
+
+    NumericalSample resultSample(model(inputsSample));
+
+    fullprint << "First reference value : " << refResultValues[0] << std::endl;
+    fullprint << "First result calculated : " << resultSample[0][0] << std::endl;
   }
   catch (TestFailed & ex)
   {
