@@ -3,7 +3,7 @@
  *  @file  t_NumericalMathFunction_composition.cxx
  *  @brief The test file of class NumericalMathFunction for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,10 +36,32 @@ int main(int argc, char *argv[])
   {
 
     /** Left hand side of the composition */
-    NumericalMathFunction left("TestCompositionLeft");
+    Description input(2);
+    input[0] = "x1";
+    input[1] = "x2";
+    Description output(3);
+    output[0] = "y1";
+    output[1] = "y2";
+    output[2] = "y3";
+    Description formula(3);
+    formula[0] = "x1*sin(x2)";
+    formula[1] = "cos(x1+x2)";
+    formula[2] = "(x2+1)*exp(x1-2*x2)";
+    NumericalMathFunction left(input, output, formula);
 
     /** Right hand side of the composition */
-    NumericalMathFunction right("TestCompositionRight");
+    Description input_r(4);
+    input_r[0] = "x1";
+    input_r[1] = "x2";
+    input_r[2] = "x3";
+    input_r[3] = "x4";
+    Description output_r(2);
+    output_r[0] = "y1";
+    output_r[1] = "y2";
+    Description formula_r(2);
+    formula_r[0] = "(x1*x1+x2^3*x1)/(2*x3*x3+x4^4+1)";
+    formula_r[1] = "cos(x2*x2+x4)/(x1*x1+1+x3^4)";
+    NumericalMathFunction right(input_r, output_r, formula_r);
 
     /** Compositon of left and right */
     NumericalMathFunction composed(ComposedNumericalMathFunction(left, right));
