@@ -3,7 +3,7 @@
  *  @file  t_NumericalMathFunction_std.cxx
  *  @brief The test file of class NumericalMathFunction for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -43,7 +43,18 @@ int main(int argc, char *argv[])
 
 
     /** Instance creation */
-    NumericalMathFunction myFunc("TestCompositionLeft");
+    Description input(2);
+    input[0] = "x1";
+    input[1] = "x2";
+    Description output(3);
+    output[0] = "y1";
+    output[1] = "y2";
+    output[2] = "y3";
+    Description formula(3);
+    formula[0] = "x1*sin(x2)";
+    formula[1] = "cos(x1+x2)";
+    formula[2] = "(x2+1)*exp(x1-2*x2)";
+    NumericalMathFunction myFunc(input, output, formula);
 
     /** Copy constructor */
     NumericalMathFunction newFunc(myFunc);
