@@ -3,7 +3,7 @@
  *  @file  t_NumericalSample_computation.cxx
  *  @brief The test file of class NumericalSample for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -73,6 +73,8 @@ int main(int argc, char *argv[])
     indices[1] = 0;
     fullprint << "Marginal [2, 0]=" << sample.getMarginal(indices) << std::endl;
     fullprint << "Rank=" << sample.rank() << std::endl;
+    fullprint << "Sort=" << sample.sort() << std::endl;
+    fullprint << "Sort according to component 0=" << sample.sortAccordingToAComponent(0) << std::endl;
     NumericalScalar prob(0.25);
     fullprint << "Quantile per component(" << prob << ")=" << sample.computeQuantilePerComponent(prob) << std::endl;
     //    fullprint << "Quantile(" << prob << ")=" << sample.computeQuantile(prob) << std::endl;
@@ -94,6 +96,25 @@ int main(int argc, char *argv[])
     }
     fullprint << "Pearson correlation (exact)=" << R << std::endl;
     fullprint << "Spearman correlation (exact)=" << Rtmp << std::endl;
+    // Add some ties
+    sample[0][0] = 1;
+    sample[0][1] = 0;
+    sample[0][2] = 9;
+    sample[1][0] = 2;
+    sample[1][1] = 3;
+    sample[1][2] = 9;
+    sample[2][0] = 5;
+    sample[2][1] = 1;
+    sample[2][2] = 9;
+    sample[3][0] = 2;
+    sample[3][1] = 2;
+    sample[3][2] = 9;
+    fullprint << "Rank=" << sample.rank() << std::endl;
+    fullprint << "Rank component 0=" << sample.rank(0) << std::endl;
+    fullprint << "Sort=" << sample.sort() << std::endl;
+    fullprint << "Sort according to component 0=" << sample.sortAccordingToAComponent(0) << std::endl;
+    fullprint << "Spearman correlation=" << sample.computeSpearmanCorrelation() << std::endl;
+    fullprint << "Kendall tau=" << sample.computeKendallTau() << std::endl;
     UnsignedLong size(10000);
     NumericalPoint p1(dim, 0.0);
     NumericalPoint p2(dim, 1.0);
