@@ -3,7 +3,7 @@
  *  @file  t_ProcessSample_std.cxx
  *  @brief The test file of class ProcessSample for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -63,7 +63,7 @@ int main(int argc, char *argv[])
     fullprint << "psample1=" << psample1 << std::endl;
 
     // change the first component using operator []
-    psample1[0] = timeSerie;
+    psample1.setField(0, timeSerie);
     psample1.setName("PSample1");
     fullprint << "changing psample1[0] with []" << std::endl;
     fullprint << "psample1[0]=" << psample1[0] << std::endl;
@@ -75,27 +75,27 @@ int main(int argc, char *argv[])
     fullprint << "psample2=" << psample2 << std::endl;
 
     // TimeSeriesCollection
-    TimeSeriesCollection collection;
-    collection.add(timeSerie);
+    //    TimeSeriesCollection collection;
+    //    collection.add(timeSerie);
 
-    sample.scale( NumericalPoint( 1, 0.1 ) );
-    TimeSeries newtimeSeries(timeGrid, sample);
-    collection.add( newtimeSeries );
+    //    sample.scale( NumericalPoint( 1, 0.1 ) );
+    //    TimeSeries newtimeSeries(timeGrid, sample);
+    //    collection.add( newtimeSeries );
 
     // We create a ProcessSample with collection arguments arguments
-    ProcessSample psample3( collection );
+    //    ProcessSample psample3( collection );
 
-    psample3.setName("PSample3");
-    fullprint << "Constructor based on collection " << std::endl;
-    fullprint << "psample3=" << psample3 << std::endl;
+    //    psample3.setName("PSample3");
+    //    fullprint << "Constructor based on collection " << std::endl;
+    //    fullprint << "psample3=" << psample3 << std::endl;
 
-    TimeSeries ts = psample3[1];
-    fullprint << "last element of psample3=" << ts << std::endl;
+    //    TimeSeries ts = psample3[1];
+    //    fullprint << "last element of psample3=" << ts << std::endl;
 
     // print mean twice for non-regression test #434
-    fullprint << "psample 3 mean=" << psample3.computeMean() << std::endl;
-    fullprint << "psample 3 mean=" << psample3.computeMean() << std::endl;
-    fullprint << "psample 3 temporal mean=" << psample3.computeTemporalMean() << std::endl;
+    //    fullprint << "psample 3 mean=" << psample3.computeMean() << std::endl;
+    //    fullprint << "psample 3 mean=" << psample3.computeMean() << std::endl;
+    //    fullprint << "psample 3 temporal mean=" << psample3.computeTemporalMean() << std::endl;
 
 
 
