@@ -3,7 +3,7 @@
  *  @file  t_QuadraticCumul_importanceFactors.cxx
  *  @brief The test file of class QuadraticCumul for the standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
  */
 #include "OT.hxx"
 #include "OTtestcode.hxx"
+#include <iterator>
 
 using namespace OT;
 using namespace OT::Test;
@@ -35,9 +36,12 @@ int main(int argc, char *argv[])
   try
   {
 
-
     /* We create a NumericalMathFunction */
-    NumericalMathFunction myFunc("TestQuadraticCumul");
+    Description inputVar(2);
+    inputVar[0] = "x1";
+    inputVar[1] = "x2";
+    NumericalMathFunction myFunc(inputVar, Description(1, "f1"), Description(1, "(x2 + 1) * exp(x1 - 2 * x2)"));
+
     /* We create a distribution */
     UnsignedLong dim(myFunc.getInputDimension());
     NumericalPoint meanPoint(dim, 0.1);
