@@ -3,7 +3,7 @@
  *  @file  t_QuadraticCumul_run.cxx
  *  @brief The test file of class QuadraticCumul for the standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,19 @@ int main(int argc, char *argv[])
 
 
     /* We create a NumericalMathFunction */
-    NumericalMathFunction myFunc("TestCompositionRight");
+    Description input_r(4);
+    input_r[0] = "x1";
+    input_r[1] = "x2";
+    input_r[2] = "x3";
+    input_r[3] = "x4";
+    Description output_r(2);
+    output_r[0] = "y1";
+    output_r[1] = "y2";
+    Description formula_r(2);
+    formula_r[0] = "(x1*x1+x2^3*x1)/(2*x3*x3+x4^4+1)";
+    formula_r[1] = "cos(x2*x2+x4)/(x1*x1+1+x3^4)";
+    NumericalMathFunction myFunc(input_r, output_r, formula_r);
+
     /* We create a distribution */
     UnsignedLong dim(myFunc.getInputDimension());
     NumericalPoint meanPoint(dim, 0.2);
