@@ -3,7 +3,7 @@
  *  @file  t_RandomGenerator_std.cxx
  *  @brief The test file of class RandomGenerator for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,12 +38,12 @@ int main(int argc, char *argv[])
     RandomGenerator::SetSeed(0);
     // Test the state accessor for reading
     RandomGeneratorState initialState(RandomGenerator::GetState());
-    fullprint << "state index=" << initialState.index_ << " state array=" << initialState.state_ << std::endl;
+    fullprint << "state index=" << initialState.getIndex() << " state array=" << initialState.getBuffer() << std::endl;
     // Test the generation of one realization
     NumericalScalar realization(RandomGenerator::Generate());
     fullprint << "one realization=" << realization << std::endl;
     RandomGeneratorState state(RandomGenerator::GetState());
-    fullprint << "new state index=" << state.index_ << std::endl;
+    fullprint << "new state index=" << state.getIndex() << std::endl;
     // Test the generation of several realizations
     UnsignedLong size(10000);
     NumericalPoint several(RandomGenerator::Generate(size));
