@@ -3,7 +3,7 @@
  *  @file  t_SQP_nonlinear.cxx
  *  @brief The test file of class SQP for solving a nonlinear problem
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -47,8 +47,12 @@ int main(int argc, char *argv[])
 
   try
   {
-
-    NumericalMathFunction levelFunction("TestOptimNonLinear");
+    Description input(4);
+    input[0] = "x1";
+    input[1] = "x2";
+    input[2] = "x3";
+    input[3] = "x4";
+    NumericalMathFunction levelFunction(input, Description(1, "y1"), Description(1, "x1*cos(x1)+2*x2*x3-3*x3+4*x3*x4"));
     // Add a finite difference gradient to the function, as SQP algorithm
     // needs it
     CenteredFiniteDifferenceGradient myGradient(1e-7, levelFunction.getEvaluationImplementation());
@@ -69,7 +73,7 @@ int main(int argc, char *argv[])
     mySQPAlgorithm.run();
     NearestPointAlgorithmImplementationResult result(mySQPAlgorithm.getResult());
     fullprint << "result = " << printNumericalPoint(result.getMinimizer(), 4) << std::endl;
-    Graph convergence(result.getErrorHistory());
+    Graph convergence(result.drawErrorHistory());
     fullprint << "evaluation calls number=" << levelFunction.getEvaluationCallsNumber() << std::endl;
     fullprint << "gradient   calls number=" << levelFunction.getGradientCallsNumber() << std::endl;
     fullprint << "hessian    calls number=" << levelFunction.getHessianCallsNumber() << std::endl;
