@@ -3,7 +3,7 @@
  *  @file  t_SpectralNormalProcess_std.cxx
  *  @brief The test file of class Spectral Normal Process
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -60,27 +60,27 @@ int main(int argc, char *argv[])
 
     SpectralNormalProcess mySpectralProcess0(myModel, myTimeGrid);
 
-    std::cout << "mySpectralProcess0 = " << mySpectralProcess0 << std::endl;
-    std::cout << "Realization = " << mySpectralProcess0.getRealization() << std::endl;
+    fullprint << "mySpectralProcess0 = " << mySpectralProcess0.__str__() << std::endl;
+    fullprint << "Realization = " << mySpectralProcess0.getRealization().__str__() << std::endl;
 
     // Constructor using maximalFrequency value and size of discretization
     const NumericalScalar maximalFrequency(10.0);
     SpectralNormalProcess mySpectralProcess1(myModel, maximalFrequency, points);
     RegularGrid tg(mySpectralProcess1.getTimeGrid());
 
-    std::cout << "mySpectralProcess1 = " << mySpectralProcess1 << std::endl;
-    std::cout << "Realization = " << mySpectralProcess1.getRealization() << std::endl;
+    fullprint << "mySpectralProcess1 = " << mySpectralProcess1.__str__() << std::endl;
+    fullprint << "Realization = " << mySpectralProcess1.getRealization().__str__() << std::endl;
 
     /* Second order model with parameters */
     CauchyModel mySpecModel(amplitude, scale);
-    std::cout << "mySpecModel = " << mySpecModel << std::endl;
+    fullprint << "mySpecModel = " << mySpecModel << std::endl;
 
     SpectralNormalProcess mySpectralProcess2(mySpecModel, myTimeGrid);
-    std::cout << "mySpectralProcess2 = " << mySpectralProcess2 << std::endl;
-    std::cout << "Realization = " << mySpectralProcess2.getRealization() << std::endl;
+    fullprint << "mySpectralProcess2 = " << mySpectralProcess2.__str__() << std::endl;
+    fullprint << "Realization = " << mySpectralProcess2.getRealization().__str__() << std::endl;
     SpectralNormalProcess mySpectralProcess3(mySpecModel, maximalFrequency, points);
-    std::cout << "mySpectralProcess3 = " << mySpectralProcess3 << std::endl;
-    std::cout << "Realization = " << mySpectralProcess3.getRealization() << std::endl;
+    fullprint << "mySpectralProcess3 = " << mySpectralProcess3.__str__() << std::endl;
+    fullprint << "Realization = " << mySpectralProcess3.getRealization().__str__() << std::endl;
 
   }
   catch (TestFailed & ex)
