@@ -3,7 +3,7 @@
  *  @file  t_SquareMatrix_std.cxx
  *  @brief The test file of class SquareMatrix for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -60,12 +60,6 @@ int main(int argc, char *argv[])
     /* String converter */
     fullprint << "squareMatrix1 = " << squareMatrix1 << std::endl;
 
-    /* TMP */
-    SymmetricMatrix sym(2);
-    sym(0, 1) = 2.0;
-    SquareMatrix squ(sym);
-    std::cerr << "sym=\n" << sym << std::endl;
-    std::cerr << "squ=\n" << squ << std::endl;
     /** TEST NUMBER TWO : COPY CONSTRUCTOR AND STRING CONVERTER */
     fullprint << "test number two : copy constructor and string converter" << std::endl;
 
