@@ -3,7 +3,7 @@
  *  @file  t_Staircase_std.cxx
  *  @brief The test file of class Staircase for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -93,7 +93,7 @@ int main(int argc, char *argv[])
     myStaircase1b.setPattern("S");
     myStaircase1b.setColor("green");
     myStaircase1b.setLineStyle("dashed");
-    myStaircase1b.setLegendName("eCDF1b, pat=S");
+    myStaircase1b.setLegend("eCDF1b, pat=S");
 
     // Then, draw it
     myGraph.add(myStaircase1);
