@@ -3,7 +3,7 @@
  *  @file  t_StrongMaximumTest_std.cxx
  *  @brief The test file of StrongMaximumTest class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -56,7 +56,10 @@ int main(int argc, char *argv[])
   {
 
     /* We create a numerical math function */
-    NumericalMathFunction myFunction("TestStrongMaximumTest");
+    Description input(2);
+    input[0] = "x1";
+    input[1] = "x2";
+    NumericalMathFunction myFunction(input, Description(1, "y1"), Description(1, "(x1-0.3)*(x1-0.3)-x2*x2"));
 
     UnsignedLong dim(myFunction.getInputDimension());
     /* We create a normal distribution point of dimension 1 */
