@@ -3,7 +3,7 @@
  *  @file  t_StrongMaximumTest_tabulatedValues.cxx
  *  @brief The test file of StrongMaximumTest class
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -50,7 +50,14 @@ int main(int argc, char *argv[])
       fullprint << "dimension = " << dim << std::endl;
 
       /* We create a numerical math function */
-      NumericalMathFunction myFunction(oss);
+      Description inputVar(dim);
+      for (UnsignedLong i = 0; i < dim; ++i)
+      {
+        OSS oss;
+        oss << "x" << i + 1;
+        inputVar[i] = oss;
+      }
+      NumericalMathFunction myFunction(inputVar, Description(1, "y"), Description(1, "0"));
 
       /* We create a normal distribution point of dimension 1 */
       NumericalPoint mean(dim, 0.0);
