@@ -3,7 +3,7 @@
  *  @file  t_Study_saveload.cxx
  *  @brief The test file of class Study for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -607,7 +607,7 @@ int main(int argc, char *argv[])
       UserDefinedSpectralModel::HermitianMatrixCollection dspCollection(size);
       RegularGrid frequencyGrid(0.0, 2.0 / size, size);
       for (UnsignedLong i = 0; i < size; ++i)
-        dspCollection[i] = cauchyModel.computeSpectralDensity(frequencyGrid.getValue(i));
+        dspCollection[i] = cauchyModel(frequencyGrid.getValue(i));
       userDefinedSpectralModel = UserDefinedSpectralModel(frequencyGrid, dspCollection);
     }
     study.add("userDefinedSpectralModel", userDefinedSpectralModel);
@@ -917,7 +917,7 @@ int main(int argc, char *argv[])
           for (UnsignedLong j = i; j < timeGrid.getN(); ++j)
           {
             const NumericalScalar s(timeGrid.getValue(j));
-            covarianceCollection[k] = referenceModel.computeCovariance(t, s);
+            covarianceCollection[k] = referenceModel(t, s);
             k++;
           }
         }
@@ -928,7 +928,7 @@ int main(int argc, char *argv[])
         for (UnsignedLong i = 0; i < size; ++i)
         {
           const NumericalScalar t(timeGrid.getValue(i));
-          covarianceCollection[i] = referenceModel.computeCovariance(0, t);
+          covarianceCollection[i] = referenceModel(0, t);
         }
         userDefinedStationaryCovarianceModel = UserDefinedStationaryCovarianceModel(timeGrid, covarianceCollection);
       }
@@ -936,7 +936,10 @@ int main(int argc, char *argv[])
     study.add("userDefinedCovarianceModel", userDefinedCovarianceModel);
     study.add("userDefinedStationaryCovarianceModel", userDefinedStationaryCovarianceModel);
 
-
+    // Create a RandomGeneratorState
+    RandomGenerator::SetSeed(0);
+    RandomGeneratorState randomGeneratorState(RandomGenerator::GetState());
+    study.add("randomGeneratorState", randomGeneratorState);
 
     fullprint << "Save the study..." << std::endl;
     study.save();
@@ -972,6 +975,7 @@ int main(int argc, char *argv[])
 
     // Stat
     compare<NumericalSample >( numericalSample, study2, "mySample");
+    compare<RandomGeneratorState>( randomGeneratorState, study2 );
 
     // Func
     compare<NumericalMathFunction >( analytical, study2 , "analytical");
