@@ -3,7 +3,7 @@
  *  @file  t_TNC_linear.cxx
  *  @brief The test file of class TNC for solving a linear problem
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,12 @@ int main(int argc, char *argv[])
     try
     {
       // Test function operator ()
-      NumericalMathFunction levelFunction("TestOptimNonLinear");
+      Description input(4);
+      input[0] = "x1";
+      input[1] = "x2";
+      input[2] = "x3";
+      input[3] = "x4";
+      NumericalMathFunction levelFunction(input, Description(1, "y1"), Description(1, "x1*cos(x1)+2*x2*x3-3*x3+4*x3*x4"));
       TNCSpecificParameters specific;
       NumericalPoint startingPointNearMinimizationCorner(4);
       startingPointNearMinimizationCorner[0] = 3.0;
