@@ -3,7 +3,7 @@
  *  @file  t_TimeSeries_std.cxx
  *  @brief The test file of class TimeSeries for standard methods
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -106,20 +106,20 @@ int main(int argc, char *argv[])
     fullprint << "ts2=" << ts2 << std::endl;
 
 
-    try
-    {
-      // We get the tenth element of the ts
-      // THIS SHOULD NORMALY FAIL
-      NumericalPoint tenthElement = ts1.at(9);
+    // try
+    // {
+    //   // We get the tenth element of the ts
+    //   // THIS SHOULD NORMALY FAIL
+    //   NumericalPoint tenthElement = ts1.at(9);
 
-      // Normally, we should never go here
-      throw TestFailed("Exception has NOT been thrown or catched !");
+    //   // Normally, we should never go here
+    //   throw TestFailed("Exception has NOT been thrown or catched !");
 
-    }
-    catch (OutOfBoundException & ex)
-    {
-      // Nothing to do
-    }
+    // }
+    // catch (OutOfBoundException & ex)
+    // {
+    //   // Nothing to do
+    // }
 
     RegularGrid tg1( 0.0, 0.1, 11 );
     TimeSeries ts3( tg1, DIM );
