@@ -3,7 +3,7 @@
  *  @file  t_UserDefinedSpectralModel_std.cxx
  *  @brief The test file of class UserDefinedSpectralModel
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -84,7 +84,7 @@ int main(int argc, char *argv[])
     UserDefinedSpectralModel::HermitianMatrixCollection dspCollection(size);
     RegularGrid frequencyGrid(0.0, 2.0 / size, size);
     for (UnsignedLong i = 0; i < size; ++i)
-      dspCollection[i] = referenceModel.computeSpectralDensity(frequencyGrid.getValue(i));
+      dspCollection[i] = referenceModel(frequencyGrid.getValue(i));
 
     /* Create a UserDefinedSpectralModel */
     UserDefinedSpectralModel myModel(frequencyGrid, dspCollection);
@@ -95,7 +95,7 @@ int main(int argc, char *argv[])
     for (UnsignedLong i = 0; i < samplingGrid.getN(); ++i)
     {
       NumericalScalar frequency(samplingGrid.getValue(i));
-      fullprint << "frequency=" << clean(frequency) << ", myModel=\n" << clean(myModel.computeSpectralDensity(frequency)) << ", referenceModel=\n" << clean(referenceModel.computeSpectralDensity(frequency)) << std::endl;
+      fullprint << "frequency=" << clean(frequency) << ", myModel=\n" << clean(myModel(frequency)) << ", referenceModel=\n" << clean(referenceModel(frequency)) << std::endl;
     }
 
   }
