@@ -3,7 +3,7 @@
  *  @file  t_WelchFactory_std.cxx
  *  @brief The test file of class WelchFactory
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,7 @@ int main(int argc, char *argv[])
     // Filtering Windows
     WelchFactory myFactory;
 
-    // Build a UserDefinedSpectralModel using the Wellch method
+    // Build a UserDefinedSpectralModel using the Welch method
     SpectralModel mySpectralModel(myFactory.build(sample));
 
     // Get the frequency grid of the model
@@ -64,7 +64,7 @@ int main(int argc, char *argv[])
         for (UnsignedLong k = 0; k < myFrequencyGrid.getN(); ++k)
         {
           const NumericalScalar frequency(myFrequencyGrid.getStart() + k * myFrequencyGrid.getStep());
-          const NumericalScalar estimatedValue(std::real(mySpectralModel.computeSpectralDensity(frequency)(i, j)));
+          const NumericalScalar estimatedValue(std::real(mySpectralModel(frequency)(i, j)));
           const NumericalScalar modelValue(std::real(model.computeSpectralDensity(frequency)(i, j)));
           fullprint << "Frequency =  " <<  frequency ;
           fullprint << ", evaluation = " << estimatedValue << " model = " << modelValue << std::endl;
@@ -74,7 +74,7 @@ int main(int argc, char *argv[])
     // Create a Time Series
     TimeSeries timeSeries(myProcess.getRealization());
 
-    // Build a UserDefinedSpectralModel using the Wellch method
+    // Build a UserDefinedSpectralModel using the Welch method
     SpectralModel mySpectralModel2(myFactory.build(timeSeries));
 
     // Get the frequency grid of the model
