@@ -3,7 +3,7 @@
  * @file  PythonDistributionImplementation.cxx
  * @brief This class binds a Python object to an Open TURNS' Distribution
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -70,6 +70,10 @@ PythonDistributionImplementation::PythonDistributionImplementation(PyObject * py
                             const_cast<char *>( "()" ) ));
   setDimension(checkAndConvert< _PyInt_, UnsignedLong >( dim.get() ));
 
+  if ( !PyObject_HasAttrString( pyObj_, const_cast<char *>("computeCDF") ) ) throw InvalidArgumentException(HERE) << "Error: the given object does not have a computeCDF() method.";
+
+  if ((getDimension() > 1) && !PyObject_HasAttrString( pyObj_, const_cast<char *>("getRange") ) ) throw InvalidArgumentException(HERE) << "Error: the given object does not have a getRange() method.";
+
   computeRange();
 }
 
@@ -296,6 +300,30 @@ NumericalScalar PythonDistributionImplementation::computeComplementaryCDF(const
 }
 
 
+/* Get the characteristic function of the distribution, i.e. phi(u) = E(exp(I*u*X)) */
+NumericalComplex PythonDistributionImplementation::computeCharacteristicFunction(const NumericalScalar x) const
+{
+  if ( PyObject_HasAttrString( pyObj_, const_cast<char *>("computeCharacteristicFunction") ) )
+  {
+    ScopedPyObjectPointer methodName(convert< String, _PyString_>( "computeCharacteristicFunction" ));
+    ScopedPyObjectPointer cX(convert< NumericalScalar, _PyFloat_ >( x ));
+    ScopedPyObjectPointer callResult(PyObject_CallMethodObjArgs( pyObj_,
+                                     methodName.get(),
+                                     cX.get(), NULL ));
+
+    if ( callResult.isNull() )
+    {
+      handleException();
+    }
+    NumericalComplex result = convert< _PyComplex_, NumericalComplex >( callResult.get() );
+    return result;
+  }
+  else
+  {
+    return DistributionImplementation::computeCharacteristicFunction( x );
+  }
+}
+
 /* Get the PDFGradient of the distribution */
 NumericalPoint PythonDistributionImplementation::computePDFGradient(const NumericalPoint & inP) const
 {
@@ -338,8 +366,7 @@ NumericalPoint PythonDistributionImplementation::computeCDFGradient(const Numeri
 
 /* Get the quantile of the distribution */
 NumericalScalar PythonDistributionImplementation::computeScalarQuantile(const NumericalScalar prob,
-    const Bool tail,
-    const NumericalScalar precision) const
+    const Bool tail) const
 {
   if ( PyObject_HasAttrString( pyObj_, const_cast<char *>("computeScalarQuantile") ) )
   {
@@ -358,7 +385,7 @@ NumericalScalar PythonDistributionImplementation::computeScalarQuantile(const Nu
   }
   else
   {
-    return DistributionImplementation::computeScalarQuantile( prob, tail, precision );
+    return DistributionImplementation::computeScalarQuantile( prob, tail );
   }
 }
 
@@ -465,6 +492,32 @@ NumericalPoint PythonDistributionImplementation::getKurtosis() const
   }
 }
 
+
+/* Get the raw moments of the distribution */
+NumericalPoint PythonDistributionImplementation::getStandardMoment(const UnsignedLong n) const
+{
+  if ( PyObject_HasAttrString( pyObj_, const_cast<char *>("getStandardMoment") ) )
+  {
+    ScopedPyObjectPointer methodName(convert< String, _PyString_>( "getStandardMoment" ));
+    ScopedPyObjectPointer nArg(convert< UnsignedLong, _PyInt_ >( n ));
+    ScopedPyObjectPointer callResult(PyObject_CallMethodObjArgs( pyObj_,
+                                     methodName.get(),
+                                     nArg.get(), NULL ));
+    if ( callResult.isNull() )
+    {
+      handleException();
+    }
+    NumericalPoint result(convert< _PySequence_, NumericalPoint >( callResult.get() ));
+    if (result.getDimension() != getDimension()) throw InvalidDimensionException(HERE) << "Moment returned by PythonDistribution has incorrect dimension. Got " << result.getDimension() << ". Expected" << getDimension();
+    return result;
+  }
+  else
+  {
+    return DistributionImplementation::getStandardMoment( n );
+  }
+}
+
+
 /* Get the raw moments of the distribution */
 NumericalPoint PythonDistributionImplementation::getMoment(const UnsignedLong n) const
 {
@@ -514,6 +567,28 @@ NumericalPoint PythonDistributionImplementation::getCenteredMoment(const Unsigne
 }
 
 
+/* Check if the distribution is a copula */
+Bool PythonDistributionImplementation::isCopula() const
+{
+  if ( PyObject_HasAttrString( pyObj_, const_cast<char *>("isCopula") ) )
+  {
+    ScopedPyObjectPointer callResult(PyObject_CallMethod ( pyObj_,
+                                     const_cast<char *>( "isCopula" ),
+                                     const_cast<char *>( "()" ) ));
+    if ( callResult.isNull() )
+    {
+      handleException();
+    }
+    Bool result = convert< _PyBool_, Bool >( callResult.get() );
+    return result;
+  }
+  else
+  {
+    return DistributionImplementation::isCopula();
+  }
+}
+
+
 /* Check if the distribution is elliptical */
 Bool PythonDistributionImplementation::isElliptical() const
 {
