@@ -3,7 +3,7 @@
  * @file  PythonNumericalMathEvaluationImplementation.cxx
  * @brief This class binds a Python function to an Open TURNS' NumericalMathFunction
  *
- *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+ *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -219,16 +219,17 @@ NumericalPoint PythonNumericalMathEvaluationImplementation::operator() (const Nu
 /* Operator () */
 NumericalSample PythonNumericalMathEvaluationImplementation::operator() (const NumericalSample & inS) const
 {
-  const UnsignedLong size( inS.getSize() );
-  const UnsignedLong inDim( inS.getDimension() );
-  const UnsignedLong outDim( getOutputDimension() );
+  const UnsignedLong size = inS.getSize();
+  const UnsignedLong inDim = inS.getDimension();
+  const UnsignedLong outDim = getOutputDimension();
+  const bool useCache = p_cache_->isEnabled();
 
-  NumericalSample outS( size, outDim );
-
-  std::set<NumericalPoint> sortedValues;
-  for (UnsignedLong i = 0; i < size; ++ i )
+  NumericalSample outS(size, outDim);
+  NumericalSample toDo(0, inDim);
+  if ( useCache )
   {
-    if ( p_cache_->isEnabled() )
+    std::set<NumericalPoint> uniqueValues;
+    for ( UnsignedLong i = 0; i < size; ++ i )
     {
       CacheKeyType inKey( inS[i].getCollection() );
       if ( p_cache_->hasKey( inKey ) )
@@ -237,24 +238,24 @@ NumericalSample PythonNumericalMathEvaluationImplementation::operator() (const N
       }
       else
       {
-        sortedValues.insert( inS[i] );
+        uniqueValues.insert( inS[i] );
       }
     }
-    else
+    for(std::set<NumericalPoint>::const_iterator it = uniqueValues.begin(); it != uniqueValues.end(); ++it)
     {
-      sortedValues.insert( inS[i] );
+      // store unique values
+      toDo.add(*it);
     }
   }
-
-  NumericalSample toDo( 0, inDim );
-  for(std::set<NumericalPoint>::const_iterator it = sortedValues.begin(); it != sortedValues.end(); ++it)
+  else
   {
-    toDo.add( *it );
+    // compute all values, including duplicates
+    toDo = inS;
   }
 
   UnsignedLong toDoSize = toDo.getSize();
   CacheType tempCache( toDoSize );
-  tempCache.enable();
+  if ( useCache ) tempCache.enable();
 
   if ( toDoSize > 0 )
   {
@@ -288,13 +289,24 @@ NumericalSample PythonNumericalMathEvaluationImplementation::operator() (const N
             const UnsignedLong lengthElt = PySequence_Size( elt.get() );
             if ( lengthElt == outDim )
             {
-              NumericalPoint outP(outDim);
-              for (UnsignedLong j = 0; j < outDim; ++j)
+              if ( useCache )
               {
-                ScopedPyObjectPointer val(PySequence_GetItem( elt.get(), j ));
-                outP[j] = convert< _PyFloat_, NumericalScalar >( val.get() );
+                NumericalPoint outP(outDim);
+                for (UnsignedLong j = 0; j < outDim; ++j)
+                {
+                  ScopedPyObjectPointer val(PySequence_GetItem( elt.get(), j ));
+                  outP[j] = convert< _PyFloat_, NumericalScalar >( val.get() );
+                }
+                tempCache.add( toDo[i].getCollection(), outP.getCollection() );
+              }
+              else
+              {
+                for (UnsignedLong j = 0; j < outDim; ++j)
+                {
+                  ScopedPyObjectPointer val(PySequence_GetItem( elt.get(), j ));
+                  outS[i][j] = convert< _PyFloat_, NumericalScalar >( val.get() );
+                }
               }
-              tempCache.add( toDo[i].getCollection(), outP.getCollection() );
             }
             else
             {
@@ -317,17 +329,17 @@ NumericalSample PythonNumericalMathEvaluationImplementation::operator() (const N
     }
   }
 
-  for( UnsignedLong i = 0; i < size; ++i )
+  if ( useCache )
   {
-    CacheKeyType inKey( inS[i].getCollection() );
-    if ( tempCache.hasKey( inKey ) )
+    // fill all the output values
+    for( UnsignedLong i = 0; i < size; ++i )
     {
-      outS[i] = NumericalPoint::ImplementationType( tempCache.find( inKey ) );
+      CacheKeyType inKey( inS[i].getCollection() );
+      if ( tempCache.hasKey( inKey ) )
+      {
+        outS[i] = NumericalPoint::ImplementationType( tempCache.find( inKey ) );
+      }
     }
-  }
-
-  if ( p_cache_->isEnabled() )
-  {
     p_cache_->merge( tempCache );
   }
   if (isHistoryEnabled_)
