@@ -2,7 +2,7 @@
 #
 #  __init__.py
 #
-#  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+#  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
 #
 #  This library is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -22,14 +22,14 @@
 #
 
 """
-    Open TURNS --- The uncertainty engineering software
+    OpenTURNS --- The uncertainty engineering software
     ===================================================
 
     Documentation is available online at http://www.openturns.org.
 
     Contents
     --------
-      Open TURNS imports all the functions from the OT namespace.
+      OpenTURNS imports all the functions from the OT namespace.
 
     Available subpackages
     ---------------------
@@ -65,31 +65,21 @@
     Utility tools
     -------------
 
-      __version__                           --- Open TURNS version string
+      __version__                           --- OpenTURNS version string
 
     Environment variables
     ---------------------
 
       OPENTURNS_HOME                        --- Custom installation path
-      OPENTURNS_MODULE_PATH                 --- Submodule path
       OPENTURNS_CONFIG_PATH                 --- Path to configuration file
       OPENTURNS_WRAPPER_PATH                --- Path to custom wrappers
       OPENTURNS_LOG_SEVERITY                --- Log severity flag, for example "ALL"
 
 """
-import os
 import sys
-import platform
 import warnings
-if platform.system() == "Windows":
-    # the following line will be modified by the windows installer
-    OT_PYTHON_PATH = ""
-    if OT_PYTHON_PATH != "":
-        # set Path to OT module
-        os.environ['PATH'] = OT_PYTHON_PATH + ';' + os.environ['PATH']
 
-
-# check if interactive mode
+# SWIG-related: check if interactive mode
 if not hasattr(sys, 'ps1'):
     try:
         # ipython does not define ps1
@@ -133,8 +123,6 @@ from .uncertainty import *
 
 from .coupling_tools import *
 
-# TODO: remove deprecated Show function
-
 
 def Show(graph):
     warnings.warn(
@@ -142,37 +130,4 @@ def Show(graph):
     from .viewer import View
     view = View(graph).show()
 
-# define the version
 __version__ = PlatformInfo.GetVersion()
-
-# This code sets the sys.path (through site module) to point to the module
-# standard dirs
-dirs = os.getenv("OPENTURNS_MODULE_PATH", None)
-if dirs:
-    import string
-    if(platform.system() != "Windows"):
-        path_separator = ":"
-    else:
-        path_separator = ";"
-    dirlist = string.split(dirs, path_separator)
-else:
-    dirlist = list()
-dirlist.append("%s/openturns/lib/openturns/module" % os.getenv("HOME"))
-dirlist.append(Path.GetModuleDirectory())
-dirlist.append(Path.GetInstallationDirectory())
-
-import site
-otpaths = set()
-for d in dirlist:
-    if(platform.system() != "Windows"):
-        python_suffix = "/lib/python%d.%d/site-packages" % (
-            sys.version_info[0], sys.version_info[1])
-    else:
-        python_suffix = "/lib/python%d%d/site-packages" % (
-            sys.version_info[0], sys.version_info[1])
-    site.addsitedir(d + python_suffix, otpaths)
-# print "known_paths =", otpaths
-
-
-def PRINT(obj):
-    return repr(obj)
