@@ -5,7 +5,7 @@
 # @brief Gives functions that help coupling against external code,
 #   .i.e: manipulate template file.
 #
-# Copyright (C) 2005-2013 EDF-EADS-Phimeca
+# Copyright (C) 2005-2014 Airbus-EDF-Phimeca
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -55,7 +55,7 @@ def check_param(obj, obj_type):
                              ") must be of " + str(obj_type) + "!")
 
 
-def replace(infile, outfile, tokens, values, encoding=default_encoding):
+def replace(infile, outfile, tokens, values, formats=None, encoding=default_encoding):
     """
     replace tokens on a file
 
@@ -66,7 +66,9 @@ def replace(infile, outfile, tokens, values, encoding=default_encoding):
     tokens:  a list of regex that will be replaced
     values:  list of values (can be string, float, ...) that will replace
              the tokens. The list must have the same size as tokens.
-    encoding: file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
+    formats: (optional) a list of formats for printing the values in the
+             parsed files at tokens locations.
+    encoding: (optional) file encoding, see http://docs.python.org/2/library/codecs.html#codec-base-classes
 
     exception:
         AssertionError: parameters badly set
@@ -104,6 +106,12 @@ def replace(infile, outfile, tokens, values, encoding=default_encoding):
         raise AssertionError("Error: tokens size is != values size!")
     check_param(tokens, list)
     check_param(values, list)
+    if formats is not None:
+        check_param(formats, list)
+        if len(values) != len(formats):
+            raise AssertionError("Error: values size is != formats size!")
+    else:
+        formats = ['%s'] * len(values)
 
     inplace = False
     if outfile == None or infile == outfile:
@@ -126,7 +134,7 @@ def replace(infile, outfile, tokens, values, encoding=default_encoding):
             found = regex_token.search(line)
             while found != None:
                 found_tokens[i] = True
-                line = line.replace(found.group(0), str(values[i]))
+                line = line.replace(found.group(0), formats[i] % values[i])
                 found = regex_token.search(line)
             i += 1
 
