@@ -3,7 +3,7 @@
 #  @file  viewer.py
 #  @brief Script to plot OpenTURNS graphs
 #
-#  Copyright (C) 2005-2013 EDF-EADS-Phimeca
+#  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
 #
 #  This program is free software; you can redistribute it and/or
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -57,43 +57,49 @@ class View(object):
     graph:
         An OpenTURNS Graph object, or else a Drawable object.
 
+    figure:
+        The figure to draw on, as matplotlib.figure.Figure
+
+    axes:
+        The axes to draw on, as matplotlib.axes.Axes
+
     plot_kwargs:
         Used when drawing Cloud, Curve drawables
         Passed on as matplotlib.axes.Axes.plot kwargs
 
     axes_kwargs:
-        Passed on as matplotlib.figure.Figure.add_subplot kwargs
+        Passed on to matplotlib.figure.Figure.add_subplot kwargs
 
     bar_kwargs:
         Used when drawing BarPlot drawables
-        Passed on as matplotlib.pyplot.bar kwargs
+        Passed on to matplotlib.pyplot.bar kwargs
 
     pie_kwargs:
         Used when drawing Pie drawables
-        Passed on as matplotlib.pyplot.pie kwargs
+        Passed on to matplotlib.pyplot.pie kwargs
 
     polygon_kwargs:
         Used when drawing Polygon drawables
-        Passed on as matplotlib.patches.Polygon kwargs
+        Passed on to matplotlib.patches.Polygon kwargs
 
     contour_kwargs:
         Used when drawing Contour drawables
-        Passed on as matplotlib.pyplot.contour kwargs
+        Passed on to matplotlib.pyplot.contour kwargs
 
     clabel_kwargs:
         Used when drawing Contour drawables
-        Passed on as matplotlib.pyplot.clabel kwargs
+        Passed on to matplotlib.pyplot.clabel kwargs
 
     step_kwargs:
         Used when drawing Staircase drawables
-        Passed on as matplotlib.pyplot.step kwargs
+        Passed on to matplotlib.pyplot.step kwargs
 
     text_kwargs:
         Used when drawing Pairs drawables
-        Passed on as matplotlib.axes.Axes.text kwargs
+        Passed on to matplotlib.axes.Axes.text kwargs
 
     legend_kwargs:
-        Passed on as matplotlib.axes.Axes.legend kwargs
+        Passed on to matplotlib.axes.Axes.legend kwargs
     """
 
     # check that the argument is a dictionnary
@@ -109,6 +115,8 @@ class View(object):
     # constructor
     def __init__(self,
                  graph,
+                 figure=None,
+                 axes=[],
                  plot_kwargs=None,
                  axes_kwargs=None,
                  bar_kwargs=None,
@@ -174,10 +182,21 @@ class View(object):
         axes_kwargs.setdefault(
             'ylim', [graph.getBoundingBox()[2], graph.getBoundingBox()[3]])
 
-        self._fig = pyplot.figure()
-        self._ax = [self._fig.add_subplot(111, **axes_kwargs)]
-        self._ax[0].grid()
+        # set figure
+        if figure is None:
+            self._fig = pyplot.figure()
+        else:
+            self._fig = figure
+            if len(axes) == 0:
+                axes = self._fig.axes
 
+        # set axes
+        if len(axes) == 0:
+            self._ax = [self._fig.add_subplot(111, **axes_kwargs)]
+        else:
+            self._ax = axes
+
+        self._ax[0].grid()
         for drawable in drawables:
             # reset working dictionaries by excplicitely creating copies
             plot_kwargs = dict(plot_kwargs_default)
@@ -199,7 +218,7 @@ class View(object):
 
             # set marker
             pointStyleDict = {'square': 's', 'circle': 'o', 'triangleup': '2', 'plus': '+', 'times': '+', 'diamond': '+', 'triangledown':
-                              'v', 'star': '*', 'fsquare': 's', 'fcircle': 'o', 'ftriangleup': '2', 'fdiamond': 'D', 'bullet': '+', 'dot': ',', 'none': 'None'}
+                              'v', 'star': '*', 'fsquare': 's', 'fcircle': 'o', 'ftriangleup': '2', 'fdiamond': 'D', 'bullet': '.', 'dot': ',', 'none': 'None'}
             if not 'marker' in plot_kwargs_default:
                 try:
                     plot_kwargs['marker'] = pointStyleDict[
@@ -329,6 +348,7 @@ class View(object):
                 axes_kwargs['yticks'] = []
 
                 dim = drawable.getData().getDimension()
+                labels = drawable.getLabels()
 
                 # adjust font
                 if (not 'fontsize' in text_kwargs_default) and (not 'size' in text_kwargs_default):
@@ -337,8 +357,9 @@ class View(object):
                 text_kwargs.setdefault('verticalalignment', 'center')
                 for i in range(dim):
                     for j in range(dim):
-                        self._ax.append(self._fig.add_subplot(
-                            dim, dim, 1 + i * dim + j, **axes_kwargs))
+                        if len(self._ax) <= dim * dim:
+                            self._ax.append(self._fig.add_subplot(
+                                dim, dim, 1 + i * dim + j, **axes_kwargs))
                         if i != j:
                             x = drawable.getData().getMarginal(i)
                             y = drawable.getData().getMarginal(j)
@@ -358,7 +379,7 @@ class View(object):
                             text_kwargs['transform'] = self._ax[
                                 1 + i * dim + j].transAxes
                             self._ax[1 + i * dim + j].text(
-                                0.5, 0.5, 'marginal ' + str(i + 1), **text_kwargs)
+                                0.5, 0.5, labels[i], **text_kwargs)
 
             else:
                 raise ValueError(
@@ -428,7 +449,7 @@ class View(object):
 
         Accessor to the underlying figure object.
 
-        Refer to matplotlib.Figure for further information.
+        Refer to matplotlib.figure.Figure for further information.
         """
         return self._fig
 
