@@ -10,15 +10,7 @@ try:
     sampleSize = 1000
 
     # we create an analytical function
-    input = Description(dimension)
-    input[0] = "x0"
-    input[1] = "x1"
-
-    foutput = Description("f")
-
-    formulas = Description("10+3*x0+x1")
-
-    analytical = NumericalMathFunction(input, foutput, formulas)
+    analytical = NumericalMathFunction(['x0', 'x1'], ['f'], ['10+3*x0+x1'])
 
     # we create a collection of uniform distributions over [-Pi Pi[
     aCollection = DistributionCollection()
