@@ -68,7 +68,7 @@ try:
     output.setDescription(outputDescription)
 
     # We create an Event from this RandomVector
-    myEvent = Event(output, ComparisonOperator(Greater()), 0.0, "Event 1")
+    myEvent = Event(output, Greater(), 0.0, "Event 1")
 
     # We create a NearestPoint algorithm
     myCobyla = Cobyla()
@@ -135,7 +135,7 @@ try:
     print "postscript=", graph3b.getPostscript()
 
     # Graph 4 : Convergence history
-    graph4 = result.getOptimizationResult().getErrorHistory()
+    graph4 = result.getOptimizationResult().drawErrorHistory()
     graph4.draw("ConvergenceHistory", 640, 480)
     print "bitmap=", graph4.getBitmap()
     print "postscript=", graph4.getPostscript()
