@@ -4,7 +4,7 @@ from openturns import *
 from math import fabs
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
