@@ -4,7 +4,7 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 
 def cleanPoint(inPoint):
@@ -17,6 +17,7 @@ def cleanPoint(inPoint):
 
 
 def cleanMatrix(inMatrix):
+    tmp = inMatrix.__str__()
     rowDim = inMatrix.getNbRows()
     colDim = inMatrix.getNbColumns()
     for i in range(rowDim):
