@@ -4,10 +4,11 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 
 def cleanMatrix(inMatrix):
+    tmp = inMatrix.__str__()
     rowDim = inMatrix.getNbRows()
     colDim = inMatrix.getNbColumns()
     for i in range(rowDim):
