@@ -4,7 +4,7 @@ from openturns import *
 import math
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
