@@ -27,17 +27,8 @@ try:
               + sob_2[2] + sob_3[0], sob_2[1] + sob_2[2] + sob_3[0]]
     sob_T3 = [sob_3[0]]
     # Create the Ishigami function
-    inputVariables = Description(dimension)
-    inputVariables[0] = "xi1"
-    inputVariables[1] = "xi2"
-    inputVariables[2] = "xi3"
-    outputVariables = Description(1)
-    outputVariables[0] = "y"
-    formula = Description(1)
-    formula[0] = "sin(xi1) + (" + str(a) + \
-        ") * (sin(xi2)) ^ 2 + (" + str(
-            b) + ") * xi3^4 * sin(xi1)"
-    model = NumericalMathFunction(inputVariables, outputVariables, formula)
+    model = NumericalMathFunction(['xi1', 'xi2', 'xi3'], ['y'], [
+                                  "sin(xi1) + (" + str(a) + ") * (sin(xi2)) ^ 2 + (" + str(b) + ") * xi3^4 * sin(xi1)"])
 
     # Create the input distribution
     marginalX = DistributionCollection(dimension)
