@@ -4,9 +4,10 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
+    PlatformInfo.SetNumericalPrecision(4)
     coll1 = DistributionCollection(0)
     coll1.add(Normal(1.0, 2.5))
     coll1.add(Gamma(1.5, 3.0))
