@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -19,7 +19,7 @@ try:
     scale = NumericalPoint(dimension, 1.0)
 
     size = 10
-    timeGrid = RegularGrid(0., 0.1, size)
+    timeGrid = RegularGrid(0.0, 0.1, size)
 
     # Cauchy model
     model = ExponentialCauchy(amplitude, scale)
@@ -33,16 +33,14 @@ try:
     # initiate
     myFactory = NonStationaryCovarianceModelFactory()
 
-    # Build a UserDefinedCovarianceModel using the Wellch method
-    myCovarianceModel = myFactory.build(sample)
-
-    # Get the time grid of the model
+    # Build a UserDefinedCovarianceModel using the Welch method
+    myCovarianceModel = myFactory.buildAsUserDefinedCovarianceModel(sample)
 
     for i in range(size):
         t = timeGrid.getValue(i)
         for j in range(size):
             s = timeGrid.getValue(j)
-            estimatedValue = myCovarianceModel.computeCovariance(t, s)[0, 0]
+            estimatedValue = myCovarianceModel(t, s)[0, 0]
             modelValue = model.computeCovariance(t, s)[0, 0]
             print "Covariance C( %.12g" % t, ",  %.12g" % s, ") : ", " evaluation =  %.12g" % estimatedValue, " model =  %.12g" % modelValue
 
