@@ -4,7 +4,7 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 
 def cleanScalar(inScalar):
@@ -158,7 +158,7 @@ try:
     print "parameters=", repr(parameters)
 
     # Specific to this distribution
-    beta = point.norm2()
+    beta = point.normSquare()
     densityGenerator = distribution.computeDensityGenerator(beta)
     print "density generator=%.6f" % densityGenerator
 
