@@ -6,10 +6,12 @@ TESTPREAMBLE()
 
 try:
     # Left hand side of the composition
-    left = NumericalMathFunction("TestCompositionLeft")
+    left = NumericalMathFunction(
+        ['x1', 'x2'], ['y1', 'y2', 'y3'], ['x1*sin(x2)', 'cos(x1+x2)', '(x2+1)*exp(x1-2*x2)'])
 
     # Right hand side of the composition
-    right = NumericalMathFunction("TestCompositionRight")
+    right = NumericalMathFunction(['x1', 'x2', 'x3', 'x4'], ['y1', 'y2'], [
+                                  '(x1*x1+x2^3*x1)/(2*x3*x3+x4^4+1)', 'cos(x2*x2+x4)/(x1*x1+1+x3^4)'])
 
     # Compositon of left and right
     composed = NumericalMathFunction(
