@@ -4,7 +4,7 @@ from openturns import *
 from math import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
     sample = NumericalSample(4, 3)
@@ -36,6 +36,8 @@ try:
     indices[1] = 0
     print "Marginal [2, 0]=", repr(sample.getMarginal(indices))
     print "Rank=", repr(sample.rank())
+    print "Sort=", repr(sample.sort())
+    print "Sort according to component 0=", repr(sample.sortAccordingToAComponent(0))
     prob = 0.25
     print "Quantile per component(", prob, ")=", repr(sample.computeQuantilePerComponent(prob))
     pointCDF = NumericalPoint(sample.getDimension(), 0.25)
@@ -50,6 +52,16 @@ try:
             Rtmp[i, j] = 6.0 * asin(R[i, j] / 2.0) / pi
     print "Pearson correlation (exact)=", repr(R)
     print "Spearman correlation (exact)=", repr(Rtmp)
+    sample[0] = NumericalPoint((1, 0, 9))
+    sample[1] = NumericalPoint((2, 3, 9))
+    sample[2] = NumericalPoint((5, 1, 9))
+    sample[3] = NumericalPoint((2, 2, 9))
+    print "Rank=", repr(sample.rank())
+    print "Rank component 0=", repr(sample.rank(0))
+    print "Sort=", repr(sample.sort())
+    print "Sort according to component 0=", repr(sample.sortAccordingToAComponent(0))
+    print "Spearman correlation=", repr(sample.computeSpearmanCorrelation())
+    print "Kendall tau=", repr(sample.computeKendallTau())
     size = 10000
     normal = Normal(NumericalPoint(dim, 0.0), NumericalPoint(dim, 1.0), R)
     print "Normal=", repr(normal)
