@@ -307,6 +307,12 @@ try:
     a1 = array(m0)
     print "SquareMatrix", m0, "=> array", a1
 
+    a0 = array(((1., 2.), (0., 4.)))
+    m0 = TriangularMatrix(a0)
+    print "array", a0, "=> TriangularMatrix", m0
+    a1 = array(m0)
+    print "TriangularMatrix", m0, "=> array", a1
+
     a0 = array(((1., 2.), (2., 4.)))
     m0 = SymmetricMatrix(a0)
     print "array", a0, "=> SymmetricMatrix", m0
