@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -34,7 +34,7 @@ try:
     output = RandomVector(myFunction, vect)
 
     # We create an Event from this RandomVector
-    myEvent = Event(output, ComparisonOperator(Less()), -3)
+    myEvent = Event(output, Less(), -3)
 
     # We create a FORM algorithm
     # The first parameter is a NearestPointAlgorithm
