@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -46,24 +46,24 @@ try:
     print "psample2=", psample2
 
     # TimeSeriesCollection
-    collection = TimeSeriesCollection()
-    collection.add(timeSeries)
+    ## collection = TimeSeriesCollection()
+    # collection.add(timeSeries)
 
-    sample.scale(NumericalPoint(1, 0.1))
-    newtimeSeries = TimeSeries(timeGrid, sample)
-    collection.add(newtimeSeries)
+    ## sample.scale(NumericalPoint(1, 0.1))
+    ## newtimeSeries = TimeSeries(timeGrid, sample)
+    # collection.add(newtimeSeries)
 
     # We create a ProcessSample with collection arguments arguments
-    psample3 = ProcessSample(collection)
+    ## psample3 = ProcessSample(collection)
 
-    psample3.setName("PSample3")
-    print "Constructor based on collection "
-    print "psample3=", psample3
+    # psample3.setName("PSample3")
+    # print "Constructor based on collection "
+    # print "psample3=", psample3
 
-    ts = psample3[1]
-    print "last element of psample3=", (ts)
-    print "psample3 mean=", psample3.computeMean()
-    print "psample3 temporal mean=", psample3.computeTemporalMean()
+    ## ts = psample3[1]
+    # print "last element of psample3=", (ts)
+    # print "psample3 mean=", psample3.computeMean()
+    # print "psample3 temporal mean=", psample3.computeTemporalMean()
 
 
 except:
