@@ -7,7 +7,8 @@ TESTPREAMBLE()
 try:
 
     # We create a NumericalMathFunction
-    myFunc = NumericalMathFunction("TestQuadraticCumul")
+    myFunc = NumericalMathFunction(
+        ['x1', 'x2'], ['f1'], ['(x2 + 1) * exp(x1 - 2 * x2)'])
 
     # We create a distribution
     dim = myFunc.getInputDimension()
