@@ -7,7 +7,9 @@ TESTPREAMBLE()
 try:
 
     # We create a NumericalMathFunction
-    myFunc = NumericalMathFunction("TestCompositionRight")
+    myFunc = NumericalMathFunction(['x1', 'x2', 'x3', 'x4'], ['y1', 'y2'], [
+                                   '(x1*x1+x2^3*x1)/(2*x3*x3+x4^4+1)', 'cos(x2*x2+x4)/(x1*x1+1+x3^4)'])
+
     # We create a distribution
     dim = myFunc.getInputDimension()
     meanPoint = NumericalPoint(dim, 0.2)
