@@ -33,7 +33,7 @@ try:
     output = RandomVector(myFunction, vect)
 
     # We create an Event from this RandomVector
-    myEvent = Event(output, ComparisonOperator(Less()), -3.0)
+    myEvent = Event(output, Less(), -3.0)
 
     # We create a Monte Carlo algorithm
     myAlgo = QuasiMonteCarlo(myEvent)
