@@ -16,7 +16,7 @@ try:
     print "one realization=%.6f" % realization
     state = RandomGenerator.GetState()
     print "state=", repr(state)
-    print "new state index=", state.index_
+    print "new state index=", state.getIndex()
 
     # Test the generation of several realizations
     size = 10000
