@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 try:
 
@@ -33,13 +33,14 @@ try:
     myFactory = StationaryCovarianceModelFactory()
 
     # Build a UserDefinedCovarianceModel using the Wellch method
-    myCovarianceModel = myFactory.build(sample)
+    myCovarianceModel = myFactory.buildAsUserDefinedStationaryCovarianceModel(
+        sample)
     tg = myCovarianceModel.getTimeGrid()
 
     # Get the time grid of the model
     for i in range(tg.getN()):
         t = tg.getValue(i)
-        estimatedValue = myCovarianceModel.computeCovariance(t)[0, 0]
+        estimatedValue = myCovarianceModel(t)[0, 0]
         modelValue = model.computeCovariance(t)[0, 0]
         print "Covariance C( %.12g" % t, ") : ", " evaluation =  %.12g" % estimatedValue, " model =  %.12g" % modelValue
 
