@@ -26,7 +26,8 @@ TESTPREAMBLE()
 try:
 
     # We create a numerical math function
-    myFunction = NumericalMathFunction("TestStrongMaximumTest")
+    myFunction = NumericalMathFunction(
+        ["x1", "x2"], ["y1"], ["(x1-0.3)*(x1-0.3)-x2*x2"])
 
     dim = myFunction.getInputDimension()
     # We create a normal distribution point of dimension 1
@@ -44,7 +45,7 @@ try:
     # We create a StandardEvent from this RandomVector  : RandomVector > 0.0
     seuil = 10
     myStandardEvent = StandardEvent(
-        output, ComparisonOperator(Greater()), seuil)
+        output, Greater(), seuil)
 
     # We create the design point
     designPoint = NumericalPoint(dim, 0.0)
