@@ -6,9 +6,7 @@ TESTPREAMBLE()
 
 try:
     # Create an intance
-    inputVars = Description(["t", "x"])
-    formula = Description(["x + t^2"])
-    myFunc = NumericalMathFunction(inputVars, formula)
+    myFunc = NumericalMathFunction(["t", "x"], ["x + t^2"])
     myTemporalFunc = TemporalFunction(myFunc)
 
     print "myTemporalFunc=", myTemporalFunc
