@@ -3,7 +3,7 @@
 from openturns import *
 
 TESTPREAMBLE()
-RandomGenerator().SetSeed(0)
+RandomGenerator.SetSeed(0)
 
 
 def cleanScalar(inScalar):
@@ -13,6 +13,7 @@ def cleanScalar(inScalar):
 
 
 def cleanMatrix(inMatrix):
+    tmp = inMatrix.__str__()
     inMatrix = ComplexMatrix(inMatrix.getImplementation())
     dim = inMatrix.getNbRows()
     for i in range(dim):
@@ -52,8 +53,7 @@ try:
     frequencyGrid = RegularGrid(0.0, 1.0 / size, size)
     dspCollection = HermitianMatrixCollection(frequencyGrid.getN())
     for i in range(frequencyGrid.getN()):
-        dspCollection[i] = referenceModel.computeSpectralDensity(
-            frequencyGrid.getValue(i))
+        dspCollection[i] = referenceModel(frequencyGrid.getValue(i))
 
     # Create a UserDefinedSpectralModel
     myModel = UserDefinedSpectralModel(frequencyGrid, dspCollection)
@@ -65,8 +65,8 @@ try:
     for i in range(samplingGrid.getN()):
         frequency = samplingGrid.getValue(i)
         print "frequency= %g myModel=" % cleanScalar(frequency)
-        print cleanMatrix(myModel.computeSpectralDensity(frequency)), ", referenceModel="
-        print cleanMatrix(referenceModel.computeSpectralDensity(frequency))
+        print cleanMatrix(myModel(frequency)), ", referenceModel="
+        print cleanMatrix(referenceModel(frequency))
 
 except:
     import sys
