@@ -126,7 +126,8 @@ def check_replace():
     sys.stderr.write("parsed template in: " + time_to_parse + "s\n")
     # parsed template=3G -> 25s on bx (ssd, core i7@2.5GHz)
     if int(time_to_parse) > max_time:
-        print('time to get token took too long (should be ' + str(max_time) + 's max)')
+        print('time to get token took too long (should be ' +
+              str(max_time) + 's max)')
         exit(1)
     else:
         print('check replace big template: ok')
@@ -366,7 +367,8 @@ def check_get_regex_perf():
     # get file=3G -> 16s on bx (ssd, core i7@2.5GHz)
     sys.stderr.write("get regex in file in: " + time_to_parse + "s\n")
     if int(time_to_parse) > max_time:
-        print('time to get token took too long (should be ' + str(max_time) + 's max)')
+        print('time to get token took too long (should be ' +
+              str(max_time) + 's max)')
         exit(1)
     else:
         print("get regex in file: ok")
@@ -483,7 +485,8 @@ def check_get_tokens_perf():
     # get file=3G -> 18s on bx (ssd, core i7@2.5GHz)
     sys.stderr.write('get token in file in: ' + time_to_parse + 's\n')
     if int(time_to_parse) > max_time:
-        print('time to get token took too long (should be ' + str(max_time) + 's max)')
+        print('time to get token took too long (should be ' +
+              str(max_time) + 's max)')
         exit(1)
     else:
         print('get tokens: ok')
@@ -510,7 +513,8 @@ def check_get_tokens_skip_perf():
     # get file=3G -> 21s on bx (ssd, core i7@2.5GHz)
     sys.stderr.write("get token skip in file in: " + time_to_parse + "s\n")
     if int(time_to_parse) > max_time:
-        print('time to get token took too long (should be ' + str(max_time) + 's max)')
+        print('time to get token took too long (should be ' +
+              str(max_time) + 's max)')
         exit(1)
     else:
         print('get tokens skip: ok')
@@ -541,7 +545,8 @@ def check_get_line_col_perf():
     sys.stderr.write(
         'get token skip line col in file in: ' + time_to_parse + 's\n')
     if int(time_to_parse) > max_time:
-        print('time to get token took too long (should be ' + str(max_time) + 's max)')
+        print('time to get token took too long (should be ' +
+              str(max_time) + 's max)')
         exit(1)
     else:
         print('get line col: ok')
